// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package livestream aliases all exported identifiers in package
// "cloud.google.com/go/video/livestream/apiv1/livestreampb".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package livestream

import (
	src "cloud.google.com/go/video/livestream/apiv1/livestreampb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/video/livestream/apiv1/livestreampb
const (
	Channel_AWAITING_INPUT              = src.Channel_AWAITING_INPUT
	Channel_STARTING                    = src.Channel_STARTING
	Channel_STOPPED                     = src.Channel_STOPPED
	Channel_STOPPING                    = src.Channel_STOPPING
	Channel_STREAMING                   = src.Channel_STREAMING
	Channel_STREAMING_ERROR             = src.Channel_STREAMING_ERROR
	Channel_STREAMING_NO_INPUT          = src.Channel_STREAMING_NO_INPUT
	Channel_STREAMING_STATE_UNSPECIFIED = src.Channel_STREAMING_STATE_UNSPECIFIED
	Event_FAILED                        = src.Event_FAILED
	Event_PENDING                       = src.Event_PENDING
	Event_RUNNING                       = src.Event_RUNNING
	Event_SCHEDULED                     = src.Event_SCHEDULED
	Event_STATE_UNSPECIFIED             = src.Event_STATE_UNSPECIFIED
	Event_STOPPED                       = src.Event_STOPPED
	Event_SUCCEEDED                     = src.Event_SUCCEEDED
	Input_HD                            = src.Input_HD
	Input_RTMP_PUSH                     = src.Input_RTMP_PUSH
	Input_SD                            = src.Input_SD
	Input_SRT_PUSH                      = src.Input_SRT_PUSH
	Input_TIER_UNSPECIFIED              = src.Input_TIER_UNSPECIFIED
	Input_TYPE_UNSPECIFIED              = src.Input_TYPE_UNSPECIFIED
	Input_UHD                           = src.Input_UHD
	LogConfig_DEBUG                     = src.LogConfig_DEBUG
	LogConfig_ERROR                     = src.LogConfig_ERROR
	LogConfig_INFO                      = src.LogConfig_INFO
	LogConfig_LOG_SEVERITY_UNSPECIFIED  = src.LogConfig_LOG_SEVERITY_UNSPECIFIED
	LogConfig_OFF                       = src.LogConfig_OFF
	LogConfig_WARNING                   = src.LogConfig_WARNING
	Manifest_DASH                       = src.Manifest_DASH
	Manifest_HLS                        = src.Manifest_HLS
	Manifest_MANIFEST_TYPE_UNSPECIFIED  = src.Manifest_MANIFEST_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/video/livestream/apiv1/livestreampb
var (
	Channel_StreamingState_name                           = src.Channel_StreamingState_name
	Channel_StreamingState_value                          = src.Channel_StreamingState_value
	Event_State_name                                      = src.Event_State_name
	Event_State_value                                     = src.Event_State_value
	File_google_cloud_video_livestream_v1_outputs_proto   = src.File_google_cloud_video_livestream_v1_outputs_proto
	File_google_cloud_video_livestream_v1_resources_proto = src.File_google_cloud_video_livestream_v1_resources_proto
	File_google_cloud_video_livestream_v1_service_proto   = src.File_google_cloud_video_livestream_v1_service_proto
	Input_Tier_name                                       = src.Input_Tier_name
	Input_Tier_value                                      = src.Input_Tier_value
	Input_Type_name                                       = src.Input_Type_name
	Input_Type_value                                      = src.Input_Type_value
	LogConfig_LogSeverity_name                            = src.LogConfig_LogSeverity_name
	LogConfig_LogSeverity_value                           = src.LogConfig_LogSeverity_value
	Manifest_ManifestType_name                            = src.Manifest_ManifestType_name
	Manifest_ManifestType_value                           = src.Manifest_ManifestType_value
)

// Properties of the audio format.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type AudioFormat = src.AudioFormat

// Audio stream resource.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type AudioStream = src.AudioStream

// Properties of the audio stream.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type AudioStreamProperty = src.AudioStreamProperty

// The mapping for the input streams and audio channels.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type AudioStream_AudioMapping = src.AudioStream_AudioMapping

// Channel resource represents the processor that does a user-defined
// "streaming" operation, which includes getting an input stream through an
// input, transcoding it to multiple renditions, and publishing output live
// streams in certain formats (for example, HLS or DASH) to the specified
// location.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Channel = src.Channel

// Response message for Start/Stop Channel long-running operations.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type ChannelOperationResponse = src.ChannelOperationResponse

// Location of output file(s) in a Google Cloud Storage bucket.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Channel_Output = src.Channel_Output

// State of streaming operation that the channel is running.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Channel_StreamingState = src.Channel_StreamingState

// Request message for "LivestreamService.CreateChannel".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type CreateChannelRequest = src.CreateChannelRequest

// Request message for "LivestreamService.CreateEvent".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type CreateEventRequest = src.CreateEventRequest

// Request message for "LivestreamService.CreateInput".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type CreateInputRequest = src.CreateInputRequest

// Request message for "LivestreamService.DeleteChannel".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type DeleteChannelRequest = src.DeleteChannelRequest

// Request message for "LivestreamService.DeleteEvent".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type DeleteEventRequest = src.DeleteEventRequest

// Request message for "LivestreamService.DeleteInput".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type DeleteInputRequest = src.DeleteInputRequest

// Encoding of an input element such as an audio, video, or text track.
// Elementary streams must be packaged before mapping and sharing between
// different output formats.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type ElementaryStream = src.ElementaryStream
type ElementaryStream_AudioStream = src.ElementaryStream_AudioStream
type ElementaryStream_TextStream = src.ElementaryStream_TextStream
type ElementaryStream_VideoStream = src.ElementaryStream_VideoStream

// Event is a sub-resource of a channel, which can be scheduled by the user to
// execute operations on a channel resource without having to stop the channel.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Event = src.Event
type Event_AdBreak = src.Event_AdBreak

// Inserts a new ad opportunity.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Event_AdBreakTask = src.Event_AdBreakTask

// State of the event
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Event_State = src.Event_State

// Request message for "LivestreamService.GetChannel".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type GetChannelRequest = src.GetChannelRequest

// Request message for "LivestreamService.GetEvent".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type GetEventRequest = src.GetEventRequest

// Request message for "LivestreamService.GetInput".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type GetInputRequest = src.GetInputRequest

// Input resource represents the endpoint from which the channel ingests the
// input stream.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Input = src.Input

// A group of information for attaching an input resource to this channel.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type InputAttachment = src.InputAttachment

// Configurations to follow when automatic failover happens.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type InputAttachment_AutomaticFailover = src.InputAttachment_AutomaticFailover

// Properties of the input stream.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type InputStreamProperty = src.InputStreamProperty

// Security rules for access control. Each field represents one security rule.
// Only when the source of the input stream satisfies all the fields, this
// input stream can be accepted.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Input_SecurityRule = src.Input_SecurityRule

// Tier of the input specification.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Input_Tier = src.Input_Tier

// The type of the input.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Input_Type = src.Input_Type

// Request message for "LivestreamService.ListChannels".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type ListChannelsRequest = src.ListChannelsRequest

// Response message for "LivestreamService.ListChannels".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type ListChannelsResponse = src.ListChannelsResponse

// Request message for "LivestreamService.ListEvents".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type ListEventsRequest = src.ListEventsRequest

// Response message for "LivestreamService.ListEvents".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type ListEventsResponse = src.ListEventsResponse

// Request message for "LivestreamService.ListInputs".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type ListInputsRequest = src.ListInputsRequest

// Response message for "LivestreamService.ListInputs".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type ListInputsResponse = src.ListInputsResponse

// LivestreamServiceClient is the client API for LivestreamService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type LivestreamServiceClient = src.LivestreamServiceClient

// LivestreamServiceServer is the server API for LivestreamService service.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type LivestreamServiceServer = src.LivestreamServiceServer

// Configuration of platform logs. See [Using and managing platform
// logs](https://cloud.google.com/logging/docs/api/platform-logs#managing-logs)
// for more information about how to view platform logs through Cloud Logging.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type LogConfig = src.LogConfig

// The severity level of platform logging for this channel. Logs with a
// severity level higher than or equal to the chosen severity level will be
// logged and can be viewed through Cloud Logging. The severity level of a log
// is ranked as followed from low to high: DEBUG < INFO < NOTICE < WARNING <
// ERROR < CRITICAL < ALERT < EMERGENCY. See
// [LogSeverity](https://cloud.google.com/logging/docs/reference/v2/rest/v2/LogEntry#logseverity)
// for more information.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type LogConfig_LogSeverity = src.LogConfig_LogSeverity

// Manifest configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Manifest = src.Manifest

// The manifest type can be either `HLS` or `DASH`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type Manifest_ManifestType = src.Manifest_ManifestType

// Multiplexing settings for output stream.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type MuxStream = src.MuxStream

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type OperationMetadata = src.OperationMetadata

// Preprocessing configurations.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type PreprocessingConfig = src.PreprocessingConfig

// Video cropping configuration for the input video. The cropped input video
// is scaled to match the output resolution.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type PreprocessingConfig_Crop = src.PreprocessingConfig_Crop

// Pad filter configuration for the input video. The padded input video is
// scaled after padding with black to match the output resolution.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type PreprocessingConfig_Pad = src.PreprocessingConfig_Pad

// Segment settings for `fmp4` and `ts`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type SegmentSettings = src.SegmentSettings

// Sprite sheet configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type SpriteSheet = src.SpriteSheet

// Request message for "LivestreamService.StartChannel".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type StartChannelRequest = src.StartChannelRequest

// Request message for "LivestreamService.StopChannel".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type StopChannelRequest = src.StopChannelRequest

// Encoding of a text stream. For example, closed captions or subtitles.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type TextStream = src.TextStream

// UnimplementedLivestreamServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type UnimplementedLivestreamServiceServer = src.UnimplementedLivestreamServiceServer

// Request message for "LivestreamService.UpdateChannel".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type UpdateChannelRequest = src.UpdateChannelRequest

// Request message for "LivestreamService.UpdateInput".
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type UpdateInputRequest = src.UpdateInputRequest

// Properties of the video format.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type VideoFormat = src.VideoFormat

// Video stream resource.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type VideoStream = src.VideoStream

// Properties of the video stream.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type VideoStreamProperty = src.VideoStreamProperty
type VideoStream_H264 = src.VideoStream_H264

// H264 codec settings.
//
// Deprecated: Please use types in: cloud.google.com/go/video/livestream/apiv1/livestreampb
type VideoStream_H264CodecSettings = src.VideoStream_H264CodecSettings
type VideoStream_H264CodecSettings_GopDuration = src.VideoStream_H264CodecSettings_GopDuration
type VideoStream_H264CodecSettings_GopFrameCount = src.VideoStream_H264CodecSettings_GopFrameCount

// Deprecated: Please use funcs in: cloud.google.com/go/video/livestream/apiv1/livestreampb
func NewLivestreamServiceClient(cc grpc.ClientConnInterface) LivestreamServiceClient {
	return src.NewLivestreamServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/video/livestream/apiv1/livestreampb
func RegisterLivestreamServiceServer(s *grpc.Server, srv LivestreamServiceServer) {
	src.RegisterLivestreamServiceServer(s, srv)
}
