// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package servicemanagement aliases all exported identifiers in package
// "cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb".
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package servicemanagement

import (
	src "cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
const (
	ConfigFile_FILE_DESCRIPTOR_SET_PROTO = src.ConfigFile_FILE_DESCRIPTOR_SET_PROTO
	ConfigFile_FILE_TYPE_UNSPECIFIED     = src.ConfigFile_FILE_TYPE_UNSPECIFIED
	ConfigFile_OPEN_API_JSON             = src.ConfigFile_OPEN_API_JSON
	ConfigFile_OPEN_API_YAML             = src.ConfigFile_OPEN_API_YAML
	ConfigFile_PROTO_FILE                = src.ConfigFile_PROTO_FILE
	ConfigFile_SERVICE_CONFIG_YAML       = src.ConfigFile_SERVICE_CONFIG_YAML
	Diagnostic_ERROR                     = src.Diagnostic_ERROR
	Diagnostic_WARNING                   = src.Diagnostic_WARNING
	GetServiceConfigRequest_BASIC        = src.GetServiceConfigRequest_BASIC
	GetServiceConfigRequest_FULL         = src.GetServiceConfigRequest_FULL
	OperationMetadata_CANCELLED          = src.OperationMetadata_CANCELLED
	OperationMetadata_DONE               = src.OperationMetadata_DONE
	OperationMetadata_FAILED             = src.OperationMetadata_FAILED
	OperationMetadata_IN_PROGRESS        = src.OperationMetadata_IN_PROGRESS
	OperationMetadata_NOT_STARTED        = src.OperationMetadata_NOT_STARTED
	OperationMetadata_STATUS_UNSPECIFIED = src.OperationMetadata_STATUS_UNSPECIFIED
	Rollout_CANCELLED                    = src.Rollout_CANCELLED
	Rollout_FAILED                       = src.Rollout_FAILED
	Rollout_FAILED_ROLLED_BACK           = src.Rollout_FAILED_ROLLED_BACK
	Rollout_IN_PROGRESS                  = src.Rollout_IN_PROGRESS
	Rollout_PENDING                      = src.Rollout_PENDING
	Rollout_ROLLOUT_STATUS_UNSPECIFIED   = src.Rollout_ROLLOUT_STATUS_UNSPECIFIED
	Rollout_SUCCESS                      = src.Rollout_SUCCESS
)

// Deprecated: Please use vars in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
var (
	ConfigFile_FileType_name                                  = src.ConfigFile_FileType_name
	ConfigFile_FileType_value                                 = src.ConfigFile_FileType_value
	Diagnostic_Kind_name                                      = src.Diagnostic_Kind_name
	Diagnostic_Kind_value                                     = src.Diagnostic_Kind_value
	File_google_api_servicemanagement_v1_resources_proto      = src.File_google_api_servicemanagement_v1_resources_proto
	File_google_api_servicemanagement_v1_servicemanager_proto = src.File_google_api_servicemanagement_v1_servicemanager_proto
	GetServiceConfigRequest_ConfigView_name                   = src.GetServiceConfigRequest_ConfigView_name
	GetServiceConfigRequest_ConfigView_value                  = src.GetServiceConfigRequest_ConfigView_value
	OperationMetadata_Status_name                             = src.OperationMetadata_Status_name
	OperationMetadata_Status_value                            = src.OperationMetadata_Status_value
	Rollout_RolloutStatus_name                                = src.Rollout_RolloutStatus_name
	Rollout_RolloutStatus_value                               = src.Rollout_RolloutStatus_value
)

// Change report associated with a particular service configuration. It
// contains a list of ConfigChanges based on the comparison between two service
// configurations.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ChangeReport = src.ChangeReport

// Generic specification of a source configuration file
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ConfigFile = src.ConfigFile
type ConfigFile_FileType = src.ConfigFile_FileType

// Represents a service configuration with its name and id.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ConfigRef = src.ConfigRef

// Represents a source file which is used to generate the service
// configuration defined by `google.api.Service`.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ConfigSource = src.ConfigSource

// Request message for CreateServiceConfig method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type CreateServiceConfigRequest = src.CreateServiceConfigRequest

// Request message for CreateService method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type CreateServiceRequest = src.CreateServiceRequest

// Request message for 'CreateServiceRollout'
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type CreateServiceRolloutRequest = src.CreateServiceRolloutRequest

// Request message for DeleteService method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type DeleteServiceRequest = src.DeleteServiceRequest

// Represents a diagnostic message (error or warning)
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type Diagnostic = src.Diagnostic

// The kind of diagnostic information possible.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type Diagnostic_Kind = src.Diagnostic_Kind

// Request message for GenerateConfigReport method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type GenerateConfigReportRequest = src.GenerateConfigReportRequest

// Response message for GenerateConfigReport method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type GenerateConfigReportResponse = src.GenerateConfigReportResponse

// Request message for GetServiceConfig method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type GetServiceConfigRequest = src.GetServiceConfigRequest
type GetServiceConfigRequest_ConfigView = src.GetServiceConfigRequest_ConfigView

// Request message for `GetService` method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type GetServiceRequest = src.GetServiceRequest

// Request message for GetServiceRollout method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type GetServiceRolloutRequest = src.GetServiceRolloutRequest

// Request message for ListServiceConfigs method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ListServiceConfigsRequest = src.ListServiceConfigsRequest

// Response message for ListServiceConfigs method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ListServiceConfigsResponse = src.ListServiceConfigsResponse

// Request message for 'ListServiceRollouts'
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ListServiceRolloutsRequest = src.ListServiceRolloutsRequest

// Response message for ListServiceRollouts method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ListServiceRolloutsResponse = src.ListServiceRolloutsResponse

// Request message for `ListServices` method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ListServicesRequest = src.ListServicesRequest

// Response message for `ListServices` method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ListServicesResponse = src.ListServicesResponse

// The full representation of a Service that is managed by Google Service
// Management.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ManagedService = src.ManagedService

// The metadata associated with a long running operation resource.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type OperationMetadata = src.OperationMetadata

// Code describes the status of the operation (or one of its steps).
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type OperationMetadata_Status = src.OperationMetadata_Status

// Represents the status of one operation step.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type OperationMetadata_Step = src.OperationMetadata_Step

// A rollout resource that defines how service configuration versions are
// pushed to control plane systems. Typically, you create a new version of the
// service config, and then create a Rollout to push the service config.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type Rollout = src.Rollout

// Strategy used to delete a service. This strategy is a placeholder only used
// by the system generated rollout to delete a service.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type Rollout_DeleteServiceStrategy = src.Rollout_DeleteServiceStrategy
type Rollout_DeleteServiceStrategy_ = src.Rollout_DeleteServiceStrategy_

// Status of a Rollout.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type Rollout_RolloutStatus = src.Rollout_RolloutStatus

// Strategy that specifies how clients of Google Service Controller want to
// send traffic to use different config versions. This is generally used by API
// proxy to split traffic based on your configured percentage for each config
// version. One example of how to gradually rollout a new service configuration
// using this strategy: Day 1 Rollout { id:
// "example.googleapis.com/rollout_20160206" traffic_percent_strategy {
// percentages: { "example.googleapis.com/20160201": 70.00
// "example.googleapis.com/20160206": 30.00 } } } Day 2 Rollout { id:
// "example.googleapis.com/rollout_20160207" traffic_percent_strategy: {
// percentages: { "example.googleapis.com/20160206": 100.00 } } }
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type Rollout_TrafficPercentStrategy = src.Rollout_TrafficPercentStrategy
type Rollout_TrafficPercentStrategy_ = src.Rollout_TrafficPercentStrategy_

// ServiceManagerClient is the client API for ServiceManager service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ServiceManagerClient = src.ServiceManagerClient

// ServiceManagerServer is the server API for ServiceManager service.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type ServiceManagerServer = src.ServiceManagerServer

// Request message for SubmitConfigSource method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type SubmitConfigSourceRequest = src.SubmitConfigSourceRequest

// Response message for SubmitConfigSource method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type SubmitConfigSourceResponse = src.SubmitConfigSourceResponse

// Request message for UndeleteService method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type UndeleteServiceRequest = src.UndeleteServiceRequest

// Response message for UndeleteService method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type UndeleteServiceResponse = src.UndeleteServiceResponse

// UnimplementedServiceManagerServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
type UnimplementedServiceManagerServer = src.UnimplementedServiceManagerServer

// Deprecated: Please use funcs in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
func NewServiceManagerClient(cc grpc.ClientConnInterface) ServiceManagerClient {
	return src.NewServiceManagerClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/servicemanagement/apiv1/servicemanagementpb
func RegisterServiceManagerServer(s *grpc.Server, srv ServiceManagerServer) {
	src.RegisterServiceManagerServer(s, srv)
}
