// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package grafeas aliases all exported identifiers in package
// "cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb".
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package grafeas

import (
	src "cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use vars in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
var (
	File_google_devtools_containeranalysis_v1beta1_grafeas_grafeas_proto = src.File_google_devtools_containeranalysis_v1beta1_grafeas_grafeas_proto
)

// Request to create notes in batch.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type BatchCreateNotesRequest = src.BatchCreateNotesRequest

// Response for creating notes in batch.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type BatchCreateNotesResponse = src.BatchCreateNotesResponse

// Request to create occurrences in batch.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type BatchCreateOccurrencesRequest = src.BatchCreateOccurrencesRequest

// Response for creating occurrences in batch.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type BatchCreateOccurrencesResponse = src.BatchCreateOccurrencesResponse

// Request to create a new note.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type CreateNoteRequest = src.CreateNoteRequest

// Request to create a new occurrence.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type CreateOccurrenceRequest = src.CreateOccurrenceRequest

// Request to delete a note.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type DeleteNoteRequest = src.DeleteNoteRequest

// Request to delete a occurrence.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type DeleteOccurrenceRequest = src.DeleteOccurrenceRequest

// Request to get a note.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type GetNoteRequest = src.GetNoteRequest

// Request to get the note to which the specified occurrence is attached.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type GetOccurrenceNoteRequest = src.GetOccurrenceNoteRequest

// Request to get an occurrence.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type GetOccurrenceRequest = src.GetOccurrenceRequest

// Request to get a vulnerability summary for some set of occurrences.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type GetVulnerabilityOccurrencesSummaryRequest = src.GetVulnerabilityOccurrencesSummaryRequest

// GrafeasV1Beta1Client is the client API for GrafeasV1Beta1 service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type GrafeasV1Beta1Client = src.GrafeasV1Beta1Client

// GrafeasV1Beta1Server is the server API for GrafeasV1Beta1 service.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type GrafeasV1Beta1Server = src.GrafeasV1Beta1Server

// Request to list occurrences for a note.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type ListNoteOccurrencesRequest = src.ListNoteOccurrencesRequest

// Response for listing occurrences for a note.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type ListNoteOccurrencesResponse = src.ListNoteOccurrencesResponse

// Request to list notes.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type ListNotesRequest = src.ListNotesRequest

// Response for listing notes.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type ListNotesResponse = src.ListNotesResponse

// Request to list occurrences.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type ListOccurrencesRequest = src.ListOccurrencesRequest

// Response for listing occurrences.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type ListOccurrencesResponse = src.ListOccurrencesResponse

// A type of analysis that can be done for a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type Note = src.Note
type Note_AttestationAuthority = src.Note_AttestationAuthority
type Note_BaseImage = src.Note_BaseImage
type Note_Build = src.Note_Build
type Note_Deployable = src.Note_Deployable
type Note_Discovery = src.Note_Discovery
type Note_Package = src.Note_Package
type Note_Vulnerability = src.Note_Vulnerability

// An instance of an analysis type that has been found on a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type Occurrence = src.Occurrence
type Occurrence_Attestation = src.Occurrence_Attestation
type Occurrence_Build = src.Occurrence_Build
type Occurrence_Deployment = src.Occurrence_Deployment
type Occurrence_DerivedImage = src.Occurrence_DerivedImage
type Occurrence_Discovered = src.Occurrence_Discovered
type Occurrence_Installation = src.Occurrence_Installation
type Occurrence_Vulnerability = src.Occurrence_Vulnerability

// An entity that can have metadata. For example, a Docker image.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type Resource = src.Resource

// UnimplementedGrafeasV1Beta1Server can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type UnimplementedGrafeasV1Beta1Server = src.UnimplementedGrafeasV1Beta1Server

// Request to update a note.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type UpdateNoteRequest = src.UpdateNoteRequest

// Request to update an occurrence.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type UpdateOccurrenceRequest = src.UpdateOccurrenceRequest

// A summary of how many vulnerability occurrences there are per resource and
// severity type.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type VulnerabilityOccurrencesSummary = src.VulnerabilityOccurrencesSummary

// Per resource and severity counts of fixable and total vulnerabilities.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
type VulnerabilityOccurrencesSummary_FixableTotalByDigest = src.VulnerabilityOccurrencesSummary_FixableTotalByDigest

// Deprecated: Please use funcs in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
func NewGrafeasV1Beta1Client(cc grpc.ClientConnInterface) GrafeasV1Beta1Client {
	return src.NewGrafeasV1Beta1Client(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/containeranalysis/apiv1beta1/grafeas/grafeaspb
func RegisterGrafeasV1Beta1Server(s *grpc.Server, srv GrafeasV1Beta1Server) {
	src.RegisterGrafeasV1Beta1Server(s, srv)
}
