// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package agentendpoint aliases all exported identifiers in package
// "cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb".
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package agentendpoint

import (
	src "cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
const (
	ApplyConfigTaskOutput_CANCELLED                                             = src.ApplyConfigTaskOutput_CANCELLED
	ApplyConfigTaskOutput_FAILED                                                = src.ApplyConfigTaskOutput_FAILED
	ApplyConfigTaskOutput_STATE_UNSPECIFIED                                     = src.ApplyConfigTaskOutput_STATE_UNSPECIFIED
	ApplyConfigTaskOutput_SUCCEEDED                                             = src.ApplyConfigTaskOutput_SUCCEEDED
	ApplyConfigTaskProgress_APPLYING_CONFIG                                     = src.ApplyConfigTaskProgress_APPLYING_CONFIG
	ApplyConfigTaskProgress_STARTED                                             = src.ApplyConfigTaskProgress_STARTED
	ApplyConfigTaskProgress_STATE_UNSPECIFIED                                   = src.ApplyConfigTaskProgress_STATE_UNSPECIFIED
	ApplyPatchesTaskOutput_FAILED                                               = src.ApplyPatchesTaskOutput_FAILED
	ApplyPatchesTaskOutput_STATE_UNSPECIFIED                                    = src.ApplyPatchesTaskOutput_STATE_UNSPECIFIED
	ApplyPatchesTaskOutput_SUCCEEDED                                            = src.ApplyPatchesTaskOutput_SUCCEEDED
	ApplyPatchesTaskOutput_SUCCEEDED_REBOOT_REQUIRED                            = src.ApplyPatchesTaskOutput_SUCCEEDED_REBOOT_REQUIRED
	ApplyPatchesTaskProgress_APPLYING_PATCHES                                   = src.ApplyPatchesTaskProgress_APPLYING_PATCHES
	ApplyPatchesTaskProgress_DOWNLOADING_PATCHES                                = src.ApplyPatchesTaskProgress_DOWNLOADING_PATCHES
	ApplyPatchesTaskProgress_REBOOTING                                          = src.ApplyPatchesTaskProgress_REBOOTING
	ApplyPatchesTaskProgress_STARTED                                            = src.ApplyPatchesTaskProgress_STARTED
	ApplyPatchesTaskProgress_STATE_UNSPECIFIED                                  = src.ApplyPatchesTaskProgress_STATE_UNSPECIFIED
	AptSettings_DIST                                                            = src.AptSettings_DIST
	AptSettings_TYPE_UNSPECIFIED                                                = src.AptSettings_TYPE_UNSPECIFIED
	AptSettings_UPGRADE                                                         = src.AptSettings_UPGRADE
	ExecStepConfig_INTERPRETER_UNSPECIFIED                                      = src.ExecStepConfig_INTERPRETER_UNSPECIFIED
	ExecStepConfig_NONE                                                         = src.ExecStepConfig_NONE
	ExecStepConfig_POWERSHELL                                                   = src.ExecStepConfig_POWERSHELL
	ExecStepConfig_SHELL                                                        = src.ExecStepConfig_SHELL
	ExecStepTaskOutput_CANCELLED                                                = src.ExecStepTaskOutput_CANCELLED
	ExecStepTaskOutput_COMPLETED                                                = src.ExecStepTaskOutput_COMPLETED
	ExecStepTaskOutput_STATE_UNSPECIFIED                                        = src.ExecStepTaskOutput_STATE_UNSPECIFIED
	ExecStepTaskOutput_TIMED_OUT                                                = src.ExecStepTaskOutput_TIMED_OUT
	ExecStepTaskProgress_STARTED                                                = src.ExecStepTaskProgress_STARTED
	ExecStepTaskProgress_STATE_UNSPECIFIED                                      = src.ExecStepTaskProgress_STATE_UNSPECIFIED
	OSPolicyComplianceState_COMPLIANT                                           = src.OSPolicyComplianceState_COMPLIANT
	OSPolicyComplianceState_NON_COMPLIANT                                       = src.OSPolicyComplianceState_NON_COMPLIANT
	OSPolicyComplianceState_NO_OS_POLICIES_APPLICABLE                           = src.OSPolicyComplianceState_NO_OS_POLICIES_APPLICABLE
	OSPolicyComplianceState_OS_POLICY_COMPLIANCE_STATE_UNSPECIFIED              = src.OSPolicyComplianceState_OS_POLICY_COMPLIANCE_STATE_UNSPECIFIED
	OSPolicyComplianceState_UNKNOWN                                             = src.OSPolicyComplianceState_UNKNOWN
	OSPolicyResourceConfigStep_DESIRED_STATE_CHECK                              = src.OSPolicyResourceConfigStep_DESIRED_STATE_CHECK
	OSPolicyResourceConfigStep_DESIRED_STATE_CHECK_POST_ENFORCEMENT             = src.OSPolicyResourceConfigStep_DESIRED_STATE_CHECK_POST_ENFORCEMENT
	OSPolicyResourceConfigStep_DESIRED_STATE_ENFORCEMENT                        = src.OSPolicyResourceConfigStep_DESIRED_STATE_ENFORCEMENT
	OSPolicyResourceConfigStep_FAILED                                           = src.OSPolicyResourceConfigStep_FAILED
	OSPolicyResourceConfigStep_OUTCOME_UNSPECIFIED                              = src.OSPolicyResourceConfigStep_OUTCOME_UNSPECIFIED
	OSPolicyResourceConfigStep_SUCCEEDED                                        = src.OSPolicyResourceConfigStep_SUCCEEDED
	OSPolicyResourceConfigStep_TYPE_UNSPECIFIED                                 = src.OSPolicyResourceConfigStep_TYPE_UNSPECIFIED
	OSPolicyResourceConfigStep_VALIDATION                                       = src.OSPolicyResourceConfigStep_VALIDATION
	OSPolicy_ENFORCEMENT                                                        = src.OSPolicy_ENFORCEMENT
	OSPolicy_MODE_UNSPECIFIED                                                   = src.OSPolicy_MODE_UNSPECIFIED
	OSPolicy_Resource_ExecResource_Exec_INTERPRETER_UNSPECIFIED                 = src.OSPolicy_Resource_ExecResource_Exec_INTERPRETER_UNSPECIFIED
	OSPolicy_Resource_ExecResource_Exec_NONE                                    = src.OSPolicy_Resource_ExecResource_Exec_NONE
	OSPolicy_Resource_ExecResource_Exec_POWERSHELL                              = src.OSPolicy_Resource_ExecResource_Exec_POWERSHELL
	OSPolicy_Resource_ExecResource_Exec_SHELL                                   = src.OSPolicy_Resource_ExecResource_Exec_SHELL
	OSPolicy_Resource_FileResource_ABSENT                                       = src.OSPolicy_Resource_FileResource_ABSENT
	OSPolicy_Resource_FileResource_CONTENTS_MATCH                               = src.OSPolicy_Resource_FileResource_CONTENTS_MATCH
	OSPolicy_Resource_FileResource_DESIRED_STATE_UNSPECIFIED                    = src.OSPolicy_Resource_FileResource_DESIRED_STATE_UNSPECIFIED
	OSPolicy_Resource_FileResource_PRESENT                                      = src.OSPolicy_Resource_FileResource_PRESENT
	OSPolicy_Resource_PackageResource_DESIRED_STATE_UNSPECIFIED                 = src.OSPolicy_Resource_PackageResource_DESIRED_STATE_UNSPECIFIED
	OSPolicy_Resource_PackageResource_INSTALLED                                 = src.OSPolicy_Resource_PackageResource_INSTALLED
	OSPolicy_Resource_PackageResource_REMOVED                                   = src.OSPolicy_Resource_PackageResource_REMOVED
	OSPolicy_Resource_RepositoryResource_AptRepository_ARCHIVE_TYPE_UNSPECIFIED = src.OSPolicy_Resource_RepositoryResource_AptRepository_ARCHIVE_TYPE_UNSPECIFIED
	OSPolicy_Resource_RepositoryResource_AptRepository_DEB                      = src.OSPolicy_Resource_RepositoryResource_AptRepository_DEB
	OSPolicy_Resource_RepositoryResource_AptRepository_DEB_SRC                  = src.OSPolicy_Resource_RepositoryResource_AptRepository_DEB_SRC
	OSPolicy_VALIDATION                                                         = src.OSPolicy_VALIDATION
	PatchConfig_ALWAYS                                                          = src.PatchConfig_ALWAYS
	PatchConfig_DEFAULT                                                         = src.PatchConfig_DEFAULT
	PatchConfig_NEVER                                                           = src.PatchConfig_NEVER
	PatchConfig_REBOOT_CONFIG_UNSPECIFIED                                       = src.PatchConfig_REBOOT_CONFIG_UNSPECIFIED
	TaskDirective_CONTINUE                                                      = src.TaskDirective_CONTINUE
	TaskDirective_STOP                                                          = src.TaskDirective_STOP
	TaskDirective_TASK_DIRECTIVE_UNSPECIFIED                                    = src.TaskDirective_TASK_DIRECTIVE_UNSPECIFIED
	TaskType_APPLY_CONFIG_TASK                                                  = src.TaskType_APPLY_CONFIG_TASK
	TaskType_APPLY_PATCHES                                                      = src.TaskType_APPLY_PATCHES
	TaskType_EXEC_STEP_TASK                                                     = src.TaskType_EXEC_STEP_TASK
	TaskType_TASK_TYPE_UNSPECIFIED                                              = src.TaskType_TASK_TYPE_UNSPECIFIED
	WindowsUpdateSettings_CLASSIFICATION_UNSPECIFIED                            = src.WindowsUpdateSettings_CLASSIFICATION_UNSPECIFIED
	WindowsUpdateSettings_CRITICAL                                              = src.WindowsUpdateSettings_CRITICAL
	WindowsUpdateSettings_DEFINITION                                            = src.WindowsUpdateSettings_DEFINITION
	WindowsUpdateSettings_DRIVER                                                = src.WindowsUpdateSettings_DRIVER
	WindowsUpdateSettings_FEATURE_PACK                                          = src.WindowsUpdateSettings_FEATURE_PACK
	WindowsUpdateSettings_SECURITY                                              = src.WindowsUpdateSettings_SECURITY
	WindowsUpdateSettings_SERVICE_PACK                                          = src.WindowsUpdateSettings_SERVICE_PACK
	WindowsUpdateSettings_TOOL                                                  = src.WindowsUpdateSettings_TOOL
	WindowsUpdateSettings_UPDATE                                                = src.WindowsUpdateSettings_UPDATE
	WindowsUpdateSettings_UPDATE_ROLLUP                                         = src.WindowsUpdateSettings_UPDATE_ROLLUP
)

// Deprecated: Please use vars in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
var (
	ApplyConfigTaskOutput_State_name                                     = src.ApplyConfigTaskOutput_State_name
	ApplyConfigTaskOutput_State_value                                    = src.ApplyConfigTaskOutput_State_value
	ApplyConfigTaskProgress_State_name                                   = src.ApplyConfigTaskProgress_State_name
	ApplyConfigTaskProgress_State_value                                  = src.ApplyConfigTaskProgress_State_value
	ApplyPatchesTaskOutput_State_name                                    = src.ApplyPatchesTaskOutput_State_name
	ApplyPatchesTaskOutput_State_value                                   = src.ApplyPatchesTaskOutput_State_value
	ApplyPatchesTaskProgress_State_name                                  = src.ApplyPatchesTaskProgress_State_name
	ApplyPatchesTaskProgress_State_value                                 = src.ApplyPatchesTaskProgress_State_value
	AptSettings_Type_name                                                = src.AptSettings_Type_name
	AptSettings_Type_value                                               = src.AptSettings_Type_value
	ExecStepConfig_Interpreter_name                                      = src.ExecStepConfig_Interpreter_name
	ExecStepConfig_Interpreter_value                                     = src.ExecStepConfig_Interpreter_value
	ExecStepTaskOutput_State_name                                        = src.ExecStepTaskOutput_State_name
	ExecStepTaskOutput_State_value                                       = src.ExecStepTaskOutput_State_value
	ExecStepTaskProgress_State_name                                      = src.ExecStepTaskProgress_State_name
	ExecStepTaskProgress_State_value                                     = src.ExecStepTaskProgress_State_value
	File_google_cloud_osconfig_agentendpoint_v1_agentendpoint_proto      = src.File_google_cloud_osconfig_agentendpoint_v1_agentendpoint_proto
	File_google_cloud_osconfig_agentendpoint_v1_config_common_proto      = src.File_google_cloud_osconfig_agentendpoint_v1_config_common_proto
	File_google_cloud_osconfig_agentendpoint_v1_inventory_proto          = src.File_google_cloud_osconfig_agentendpoint_v1_inventory_proto
	File_google_cloud_osconfig_agentendpoint_v1_os_policy_proto          = src.File_google_cloud_osconfig_agentendpoint_v1_os_policy_proto
	File_google_cloud_osconfig_agentendpoint_v1_patch_jobs_proto         = src.File_google_cloud_osconfig_agentendpoint_v1_patch_jobs_proto
	File_google_cloud_osconfig_agentendpoint_v1_tasks_proto              = src.File_google_cloud_osconfig_agentendpoint_v1_tasks_proto
	OSPolicyComplianceState_name                                         = src.OSPolicyComplianceState_name
	OSPolicyComplianceState_value                                        = src.OSPolicyComplianceState_value
	OSPolicyResourceConfigStep_Outcome_name                              = src.OSPolicyResourceConfigStep_Outcome_name
	OSPolicyResourceConfigStep_Outcome_value                             = src.OSPolicyResourceConfigStep_Outcome_value
	OSPolicyResourceConfigStep_Type_name                                 = src.OSPolicyResourceConfigStep_Type_name
	OSPolicyResourceConfigStep_Type_value                                = src.OSPolicyResourceConfigStep_Type_value
	OSPolicy_Mode_name                                                   = src.OSPolicy_Mode_name
	OSPolicy_Mode_value                                                  = src.OSPolicy_Mode_value
	OSPolicy_Resource_ExecResource_Exec_Interpreter_name                 = src.OSPolicy_Resource_ExecResource_Exec_Interpreter_name
	OSPolicy_Resource_ExecResource_Exec_Interpreter_value                = src.OSPolicy_Resource_ExecResource_Exec_Interpreter_value
	OSPolicy_Resource_FileResource_DesiredState_name                     = src.OSPolicy_Resource_FileResource_DesiredState_name
	OSPolicy_Resource_FileResource_DesiredState_value                    = src.OSPolicy_Resource_FileResource_DesiredState_value
	OSPolicy_Resource_PackageResource_DesiredState_name                  = src.OSPolicy_Resource_PackageResource_DesiredState_name
	OSPolicy_Resource_PackageResource_DesiredState_value                 = src.OSPolicy_Resource_PackageResource_DesiredState_value
	OSPolicy_Resource_RepositoryResource_AptRepository_ArchiveType_name  = src.OSPolicy_Resource_RepositoryResource_AptRepository_ArchiveType_name
	OSPolicy_Resource_RepositoryResource_AptRepository_ArchiveType_value = src.OSPolicy_Resource_RepositoryResource_AptRepository_ArchiveType_value
	PatchConfig_RebootConfig_name                                        = src.PatchConfig_RebootConfig_name
	PatchConfig_RebootConfig_value                                       = src.PatchConfig_RebootConfig_value
	TaskDirective_name                                                   = src.TaskDirective_name
	TaskDirective_value                                                  = src.TaskDirective_value
	TaskType_name                                                        = src.TaskType_name
	TaskType_value                                                       = src.TaskType_value
	WindowsUpdateSettings_Classification_name                            = src.WindowsUpdateSettings_Classification_name
	WindowsUpdateSettings_Classification_value                           = src.WindowsUpdateSettings_Classification_value
)

// AgentEndpointServiceClient is the client API for AgentEndpointService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type AgentEndpointServiceClient = src.AgentEndpointServiceClient

// AgentEndpointServiceServer is the server API for AgentEndpointService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type AgentEndpointServiceServer = src.AgentEndpointServiceServer
type AgentEndpointService_ReceiveTaskNotificationClient = src.AgentEndpointService_ReceiveTaskNotificationClient
type AgentEndpointService_ReceiveTaskNotificationServer = src.AgentEndpointService_ReceiveTaskNotificationServer

// Message which instructs OS Config agent to apply the desired state
// configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyConfigTask = src.ApplyConfigTask

// Information reported from the agent regarding the output of the task of
// applying desired state configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyConfigTaskOutput = src.ApplyConfigTaskOutput

// Result of applying desired state config for an OS policy.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyConfigTaskOutput_OSPolicyResult = src.ApplyConfigTaskOutput_OSPolicyResult

// The final state of this task.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyConfigTaskOutput_State = src.ApplyConfigTaskOutput_State

// Information reported from the agent regarding the progress of the task of
// applying desired state configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyConfigTaskProgress = src.ApplyConfigTaskProgress

// The intermediate states of apply config task.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyConfigTaskProgress_State = src.ApplyConfigTaskProgress_State

// Message representing an OS policy.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyConfigTask_OSPolicy = src.ApplyConfigTask_OSPolicy

// Message which instructs agent to apply patches.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyPatchesTask = src.ApplyPatchesTask

// Information reported from the agent about applying patches execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyPatchesTaskOutput = src.ApplyPatchesTaskOutput

// The final states of applying patches.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyPatchesTaskOutput_State = src.ApplyPatchesTaskOutput_State

// Information reported from the agent about applying patches execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyPatchesTaskProgress = src.ApplyPatchesTaskProgress

// The intermediate states of applying patches.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ApplyPatchesTaskProgress_State = src.ApplyPatchesTaskProgress_State

// Apt patching will be performed by executing `apt-get update && apt-get
// upgrade`. Additional options can be set to control how this is executed.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type AptSettings = src.AptSettings

// Apt patch type.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type AptSettings_Type = src.AptSettings_Type

// A step that runs an executable for a PatchJob.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ExecStep = src.ExecStep

// Common configurations for an ExecStep.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ExecStepConfig = src.ExecStepConfig
type ExecStepConfig_GcsObject = src.ExecStepConfig_GcsObject

// The interpreter used to execute the a file.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ExecStepConfig_Interpreter = src.ExecStepConfig_Interpreter
type ExecStepConfig_LocalPath = src.ExecStepConfig_LocalPath

// Message which instructs agent to execute the following command.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ExecStepTask = src.ExecStepTask

// Information reported from the agent about the exec step execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ExecStepTaskOutput = src.ExecStepTaskOutput

// The final states of exec steps.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ExecStepTaskOutput_State = src.ExecStepTaskOutput_State

// Information reported from the agent about the exec step execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ExecStepTaskProgress = src.ExecStepTaskProgress

// The intermediate states of exec steps.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ExecStepTaskProgress_State = src.ExecStepTaskProgress_State

// GCS object representation.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type GcsObject = src.GcsObject

// Googet patching is performed by running `googet update`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type GooSettings = src.GooSettings

// The inventory details of a VM.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type Inventory = src.Inventory

// Operating system information for the VM.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type Inventory_OsInfo = src.Inventory_OsInfo

// Software package information of the operating system.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type Inventory_SoftwarePackage = src.Inventory_SoftwarePackage
type Inventory_SoftwarePackage_AptPackage = src.Inventory_SoftwarePackage_AptPackage
type Inventory_SoftwarePackage_CosPackage = src.Inventory_SoftwarePackage_CosPackage
type Inventory_SoftwarePackage_GoogetPackage = src.Inventory_SoftwarePackage_GoogetPackage
type Inventory_SoftwarePackage_QfePackage = src.Inventory_SoftwarePackage_QfePackage
type Inventory_SoftwarePackage_WindowsApplication = src.Inventory_SoftwarePackage_WindowsApplication
type Inventory_SoftwarePackage_WuaPackage = src.Inventory_SoftwarePackage_WuaPackage
type Inventory_SoftwarePackage_YumPackage = src.Inventory_SoftwarePackage_YumPackage
type Inventory_SoftwarePackage_ZypperPackage = src.Inventory_SoftwarePackage_ZypperPackage
type Inventory_SoftwarePackage_ZypperPatch = src.Inventory_SoftwarePackage_ZypperPatch

// Information related to the a standard versioned package. This includes
// package info for APT, Yum, Zypper, and Googet package managers.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type Inventory_VersionedPackage = src.Inventory_VersionedPackage

// Details about Windows Application - based on Windows Registry. All fields
// in this message are taken from:
// https://docs.microsoft.com/en-us/windows/win32/msi/uninstall-registry-key
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type Inventory_WindowsApplication = src.Inventory_WindowsApplication

// Information related to a Quick Fix Engineering package. Fields are taken
// from Windows QuickFixEngineering Interface and match the source names:
// https://docs.microsoft.com/en-us/windows/win32/cimwin32prov/win32-quickfixengineering
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type Inventory_WindowsQuickFixEngineeringPackage = src.Inventory_WindowsQuickFixEngineeringPackage

// Details related to a Windows Update package. Field data and names are taken
// from Windows Update API IUpdate Interface:
// https://docs.microsoft.com/en-us/windows/win32/api/_wua/ Descriptive fields
// like title, and description are localized based on the locale of the VM
// being updated.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type Inventory_WindowsUpdatePackage = src.Inventory_WindowsUpdatePackage

// Categories specified by the Windows Update.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type Inventory_WindowsUpdatePackage_WindowsUpdateCategory = src.Inventory_WindowsUpdatePackage_WindowsUpdateCategory

// Details related to a Zypper Patch.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type Inventory_ZypperPatch = src.Inventory_ZypperPatch

// An OS policy defines the desired state configuration for an instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy = src.OSPolicy

// Supported OSPolicy compliance states.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicyComplianceState = src.OSPolicyComplianceState

// Compliance data for an OS policy resource.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicyResourceCompliance = src.OSPolicyResourceCompliance

// ExecResource specific output.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicyResourceCompliance_ExecResourceOutput = src.OSPolicyResourceCompliance_ExecResourceOutput
type OSPolicyResourceCompliance_ExecResourceOutput_ = src.OSPolicyResourceCompliance_ExecResourceOutput_

// Step performed by the OS Config agent for configuring an `OSPolicyResource`
// to its desired state.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicyResourceConfigStep = src.OSPolicyResourceConfigStep

// Supported outcomes for a configuration step.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicyResourceConfigStep_Outcome = src.OSPolicyResourceConfigStep_Outcome

// Supported configuration step types
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicyResourceConfigStep_Type = src.OSPolicyResourceConfigStep_Type

// Policy mode
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Mode = src.OSPolicy_Mode

// An OS policy resource is used to define the desired state configuration and
// provides a specific functionality like installing/removing packages,
// executing a script etc. The system ensures that resources are always in
// their desired state by taking necessary actions if they have drifted from
// their desired state.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource = src.OSPolicy_Resource
type OSPolicy_Resource_Exec = src.OSPolicy_Resource_Exec

// A resource that contains custom validation and enforcement steps.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_ExecResource = src.OSPolicy_Resource_ExecResource

// A file or script to execute.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_ExecResource_Exec = src.OSPolicy_Resource_ExecResource_Exec
type OSPolicy_Resource_ExecResource_Exec_File = src.OSPolicy_Resource_ExecResource_Exec_File

// The interpreter to use.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_ExecResource_Exec_Interpreter = src.OSPolicy_Resource_ExecResource_Exec_Interpreter
type OSPolicy_Resource_ExecResource_Exec_Script = src.OSPolicy_Resource_ExecResource_Exec_Script

// A remote or local file.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_File = src.OSPolicy_Resource_File

// A resource that manages the state of a file.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_FileResource = src.OSPolicy_Resource_FileResource
type OSPolicy_Resource_FileResource_Content = src.OSPolicy_Resource_FileResource_Content

// Desired state of the file.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_FileResource_DesiredState = src.OSPolicy_Resource_FileResource_DesiredState
type OSPolicy_Resource_FileResource_File = src.OSPolicy_Resource_FileResource_File
type OSPolicy_Resource_File_ = src.OSPolicy_Resource_File_

// Specifies a file available as a Cloud Storage Object.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_File_Gcs = src.OSPolicy_Resource_File_Gcs
type OSPolicy_Resource_File_Gcs_ = src.OSPolicy_Resource_File_Gcs_
type OSPolicy_Resource_File_LocalPath = src.OSPolicy_Resource_File_LocalPath

// Specifies a file available via some URI.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_File_Remote = src.OSPolicy_Resource_File_Remote
type OSPolicy_Resource_File_Remote_ = src.OSPolicy_Resource_File_Remote_

// A resource that manages a system package.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_PackageResource = src.OSPolicy_Resource_PackageResource

// A package managed by APT. install: `apt-get update && apt-get -y install
// [name]` remove: `apt-get -y remove [name]`
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_PackageResource_APT = src.OSPolicy_Resource_PackageResource_APT
type OSPolicy_Resource_PackageResource_Apt = src.OSPolicy_Resource_PackageResource_Apt

// A deb package file. dpkg packages only support INSTALLED state.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_PackageResource_Deb = src.OSPolicy_Resource_PackageResource_Deb
type OSPolicy_Resource_PackageResource_Deb_ = src.OSPolicy_Resource_PackageResource_Deb_

// The desired state that the OS Config agent maintains on the VM.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_PackageResource_DesiredState = src.OSPolicy_Resource_PackageResource_DesiredState

// A package managed by GooGet. install: `googet -noconfirm install package`
// remove: `googet -noconfirm remove package`
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_PackageResource_GooGet = src.OSPolicy_Resource_PackageResource_GooGet
type OSPolicy_Resource_PackageResource_Googet = src.OSPolicy_Resource_PackageResource_Googet

// An MSI package. MSI packages only support INSTALLED state.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_PackageResource_MSI = src.OSPolicy_Resource_PackageResource_MSI
type OSPolicy_Resource_PackageResource_Msi = src.OSPolicy_Resource_PackageResource_Msi

// An RPM package file. RPM packages only support INSTALLED state.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_PackageResource_RPM = src.OSPolicy_Resource_PackageResource_RPM
type OSPolicy_Resource_PackageResource_Rpm = src.OSPolicy_Resource_PackageResource_Rpm

// A package managed by YUM. install: `yum -y install package` remove: `yum -y
// remove package`
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_PackageResource_YUM = src.OSPolicy_Resource_PackageResource_YUM
type OSPolicy_Resource_PackageResource_Yum = src.OSPolicy_Resource_PackageResource_Yum

// A package managed by Zypper. install: `zypper -y install package` remove:
// `zypper -y rm package`
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_PackageResource_Zypper = src.OSPolicy_Resource_PackageResource_Zypper
type OSPolicy_Resource_PackageResource_Zypper_ = src.OSPolicy_Resource_PackageResource_Zypper_
type OSPolicy_Resource_Pkg = src.OSPolicy_Resource_Pkg
type OSPolicy_Resource_Repository = src.OSPolicy_Resource_Repository

// A resource that manages a package repository.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_RepositoryResource = src.OSPolicy_Resource_RepositoryResource
type OSPolicy_Resource_RepositoryResource_Apt = src.OSPolicy_Resource_RepositoryResource_Apt

// Represents a single apt package repository. These will be added to a repo
// file that will be managed at /etc/apt/sources.list.d/google_osconfig.list.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_RepositoryResource_AptRepository = src.OSPolicy_Resource_RepositoryResource_AptRepository

// Type of archive.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_RepositoryResource_AptRepository_ArchiveType = src.OSPolicy_Resource_RepositoryResource_AptRepository_ArchiveType
type OSPolicy_Resource_RepositoryResource_Goo = src.OSPolicy_Resource_RepositoryResource_Goo

// Represents a Goo package repository. These are added to a repo file that is
// managed at `C:/ProgramData/GooGet/repos/google_osconfig.repo`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_RepositoryResource_GooRepository = src.OSPolicy_Resource_RepositoryResource_GooRepository
type OSPolicy_Resource_RepositoryResource_Yum = src.OSPolicy_Resource_RepositoryResource_Yum

// Represents a single yum package repository. These are added to a repo file
// that is managed at `/etc/yum.repos.d/google_osconfig.repo`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_RepositoryResource_YumRepository = src.OSPolicy_Resource_RepositoryResource_YumRepository
type OSPolicy_Resource_RepositoryResource_Zypper = src.OSPolicy_Resource_RepositoryResource_Zypper

// Represents a single zypper package repository. These are added to a repo
// file that is managed at `/etc/zypp/repos.d/google_osconfig.repo`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type OSPolicy_Resource_RepositoryResource_ZypperRepository = src.OSPolicy_Resource_RepositoryResource_ZypperRepository

// Patch configuration specifications. Contains details on how to apply
// patches to a VM instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type PatchConfig = src.PatchConfig

// Post-patch reboot settings.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type PatchConfig_RebootConfig = src.PatchConfig_RebootConfig

// A request message to receive task notifications.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ReceiveTaskNotificationRequest = src.ReceiveTaskNotificationRequest

// The streaming rpc message that will notify the agent when it has a task it
// needs to perform on the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ReceiveTaskNotificationResponse = src.ReceiveTaskNotificationResponse

// The request message for registering the agent.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type RegisterAgentRequest = src.RegisterAgentRequest

// The response message after the agent registered.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type RegisterAgentResponse = src.RegisterAgentResponse

// The request message for having the agent report inventory.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ReportInventoryRequest = src.ReportInventoryRequest

// The response message after the agent has reported inventory.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ReportInventoryResponse = src.ReportInventoryResponse

// A request message for signaling the completion of a task execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ReportTaskCompleteRequest = src.ReportTaskCompleteRequest
type ReportTaskCompleteRequest_ApplyConfigTaskOutput = src.ReportTaskCompleteRequest_ApplyConfigTaskOutput
type ReportTaskCompleteRequest_ApplyPatchesTaskOutput = src.ReportTaskCompleteRequest_ApplyPatchesTaskOutput
type ReportTaskCompleteRequest_ExecStepTaskOutput = src.ReportTaskCompleteRequest_ExecStepTaskOutput

// The response message after the agent signaled the current task complete.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ReportTaskCompleteResponse = src.ReportTaskCompleteResponse

// A request message for reporting the progress of current task.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ReportTaskProgressRequest = src.ReportTaskProgressRequest
type ReportTaskProgressRequest_ApplyConfigTaskProgress = src.ReportTaskProgressRequest_ApplyConfigTaskProgress
type ReportTaskProgressRequest_ApplyPatchesTaskProgress = src.ReportTaskProgressRequest_ApplyPatchesTaskProgress
type ReportTaskProgressRequest_ExecStepTaskProgress = src.ReportTaskProgressRequest_ExecStepTaskProgress

// The response message after the agent reported the current task progress.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ReportTaskProgressResponse = src.ReportTaskProgressResponse

// The strategy for retrying failed patches during the patch window.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type RetryStrategy = src.RetryStrategy

// A request message for signaling the start of a task execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type StartNextTaskRequest = src.StartNextTaskRequest

// A response message that contains the details of the task to work on.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type StartNextTaskResponse = src.StartNextTaskResponse

// A unit of work to be performed by the agent.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type Task = src.Task

// Specifies the current agent behavior.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type TaskDirective = src.TaskDirective

// Specifies the type of task to perform.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type TaskType = src.TaskType
type Task_ApplyConfigTask = src.Task_ApplyConfigTask
type Task_ApplyPatchesTask = src.Task_ApplyPatchesTask
type Task_ExecStepTask = src.Task_ExecStepTask

// UnimplementedAgentEndpointServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type UnimplementedAgentEndpointServiceServer = src.UnimplementedAgentEndpointServiceServer

// Windows patching is performed using the Windows Update Agent.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type WindowsUpdateSettings = src.WindowsUpdateSettings

// Microsoft Windows update classifications as defined in [1]
// https://support.microsoft.com/en-us/help/824684/description-of-the-standard-terminology-that-is-used-to-describe-micro
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type WindowsUpdateSettings_Classification = src.WindowsUpdateSettings_Classification

// Yum patching will be performed by executing `yum update`. Additional
// options can be set to control how this is executed. Note that not all
// settings are supported on all platforms.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type YumSettings = src.YumSettings

// Zypper patching is performed by running `zypper patch`. See also
// https://en.opensuse.org/SDB:Zypper_manual.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
type ZypperSettings = src.ZypperSettings

// Deprecated: Please use funcs in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
func NewAgentEndpointServiceClient(cc grpc.ClientConnInterface) AgentEndpointServiceClient {
	return src.NewAgentEndpointServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/osconfig/agentendpoint/apiv1/agentendpointpb
func RegisterAgentEndpointServiceServer(s *grpc.Server, srv AgentEndpointServiceServer) {
	src.RegisterAgentEndpointServiceServer(s, srv)
}
