// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package clientconnectorservices aliases all exported identifiers in package
// "cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb".
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package clientconnectorservices

import (
	src "cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
const (
	ClientConnectorService_CREATING                                      = src.ClientConnectorService_CREATING
	ClientConnectorService_DELETING                                      = src.ClientConnectorService_DELETING
	ClientConnectorService_DOWN                                          = src.ClientConnectorService_DOWN
	ClientConnectorService_ERROR                                         = src.ClientConnectorService_ERROR
	ClientConnectorService_Ingress_Config_TCP                            = src.ClientConnectorService_Ingress_Config_TCP
	ClientConnectorService_Ingress_Config_TRANSPORT_PROTOCOL_UNSPECIFIED = src.ClientConnectorService_Ingress_Config_TRANSPORT_PROTOCOL_UNSPECIFIED
	ClientConnectorService_RUNNING                                       = src.ClientConnectorService_RUNNING
	ClientConnectorService_STATE_UNSPECIFIED                             = src.ClientConnectorService_STATE_UNSPECIFIED
	ClientConnectorService_UPDATING                                      = src.ClientConnectorService_UPDATING
)

// Deprecated: Please use vars in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
var (
	ClientConnectorService_Ingress_Config_TransportProtocol_name                                    = src.ClientConnectorService_Ingress_Config_TransportProtocol_name
	ClientConnectorService_Ingress_Config_TransportProtocol_value                                   = src.ClientConnectorService_Ingress_Config_TransportProtocol_value
	ClientConnectorService_State_name                                                               = src.ClientConnectorService_State_name
	ClientConnectorService_State_value                                                              = src.ClientConnectorService_State_value
	File_google_cloud_beyondcorp_clientconnectorservices_v1_client_connector_services_service_proto = src.File_google_cloud_beyondcorp_clientconnectorservices_v1_client_connector_services_service_proto
)

// Message describing ClientConnectorService object.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorService = src.ClientConnectorService

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorServiceOperationMetadata = src.ClientConnectorServiceOperationMetadata

// The details of the egress info. One of the following options should be set.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorService_Egress = src.ClientConnectorService_Egress

// The peered VPC owned by the consumer project.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorService_Egress_PeeredVpc = src.ClientConnectorService_Egress_PeeredVpc
type ClientConnectorService_Egress_PeeredVpc_ = src.ClientConnectorService_Egress_PeeredVpc_

// Settings of how to connect to the ClientGateway. One of the following
// options should be set.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorService_Ingress = src.ClientConnectorService_Ingress

// The basic ingress config for ClientGateways.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorService_Ingress_Config = src.ClientConnectorService_Ingress_Config
type ClientConnectorService_Ingress_Config_ = src.ClientConnectorService_Ingress_Config_

// The setting used to configure ClientGateways. It is adding routes to the
// client's routing table after the connection is established.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorService_Ingress_Config_DestinationRoute = src.ClientConnectorService_Ingress_Config_DestinationRoute

// The protocol used to connect to the server.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorService_Ingress_Config_TransportProtocol = src.ClientConnectorService_Ingress_Config_TransportProtocol

// Represents the different states of a ClientConnectorService.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorService_State = src.ClientConnectorService_State

// ClientConnectorServicesServiceClient is the client API for
// ClientConnectorServicesService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorServicesServiceClient = src.ClientConnectorServicesServiceClient

// ClientConnectorServicesServiceServer is the server API for
// ClientConnectorServicesService service.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ClientConnectorServicesServiceServer = src.ClientConnectorServicesServiceServer

// Message for creating a ClientConnectorService.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type CreateClientConnectorServiceRequest = src.CreateClientConnectorServiceRequest

// Message for deleting a ClientConnectorService.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type DeleteClientConnectorServiceRequest = src.DeleteClientConnectorServiceRequest

// Message for getting a ClientConnectorService.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type GetClientConnectorServiceRequest = src.GetClientConnectorServiceRequest

// Message for requesting list of ClientConnectorServices.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ListClientConnectorServicesRequest = src.ListClientConnectorServicesRequest

// Message for response to listing ClientConnectorServices.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type ListClientConnectorServicesResponse = src.ListClientConnectorServicesResponse

// UnimplementedClientConnectorServicesServiceServer can be embedded to have
// forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type UnimplementedClientConnectorServicesServiceServer = src.UnimplementedClientConnectorServicesServiceServer

// Message for updating a ClientConnectorService
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
type UpdateClientConnectorServiceRequest = src.UpdateClientConnectorServiceRequest

// Deprecated: Please use funcs in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
func NewClientConnectorServicesServiceClient(cc grpc.ClientConnInterface) ClientConnectorServicesServiceClient {
	return src.NewClientConnectorServicesServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/beyondcorp/clientconnectorservices/apiv1/clientconnectorservicespb
func RegisterClientConnectorServicesServiceServer(s *grpc.Server, srv ClientConnectorServicesServiceServer) {
	src.RegisterClientConnectorServicesServiceServer(s, srv)
}
