// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package instance aliases all exported identifiers in package
// "cloud.google.com/go/spanner/admin/instance/apiv1/instancepb".
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package instance

import (
	src "cloud.google.com/go/spanner/admin/instance/apiv1/instancepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
const (
	InstanceConfig_CREATING          = src.InstanceConfig_CREATING
	InstanceConfig_GOOGLE_MANAGED    = src.InstanceConfig_GOOGLE_MANAGED
	InstanceConfig_READY             = src.InstanceConfig_READY
	InstanceConfig_STATE_UNSPECIFIED = src.InstanceConfig_STATE_UNSPECIFIED
	InstanceConfig_TYPE_UNSPECIFIED  = src.InstanceConfig_TYPE_UNSPECIFIED
	InstanceConfig_USER_MANAGED      = src.InstanceConfig_USER_MANAGED
	Instance_CREATING                = src.Instance_CREATING
	Instance_READY                   = src.Instance_READY
	Instance_STATE_UNSPECIFIED       = src.Instance_STATE_UNSPECIFIED
	ReplicaInfo_READ_ONLY            = src.ReplicaInfo_READ_ONLY
	ReplicaInfo_READ_WRITE           = src.ReplicaInfo_READ_WRITE
	ReplicaInfo_TYPE_UNSPECIFIED     = src.ReplicaInfo_TYPE_UNSPECIFIED
	ReplicaInfo_WITNESS              = src.ReplicaInfo_WITNESS
)

// Deprecated: Please use vars in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
var (
	File_google_spanner_admin_instance_v1_common_proto                 = src.File_google_spanner_admin_instance_v1_common_proto
	File_google_spanner_admin_instance_v1_spanner_instance_admin_proto = src.File_google_spanner_admin_instance_v1_spanner_instance_admin_proto
	InstanceConfig_State_name                                          = src.InstanceConfig_State_name
	InstanceConfig_State_value                                         = src.InstanceConfig_State_value
	InstanceConfig_Type_name                                           = src.InstanceConfig_Type_name
	InstanceConfig_Type_value                                          = src.InstanceConfig_Type_value
	Instance_State_name                                                = src.Instance_State_name
	Instance_State_value                                               = src.Instance_State_value
	ReplicaInfo_ReplicaType_name                                       = src.ReplicaInfo_ReplicaType_name
	ReplicaInfo_ReplicaType_value                                      = src.ReplicaInfo_ReplicaType_value
)

// Metadata type for the operation returned by
// [CreateInstanceConfig][google.spanner.admin.instance.v1.InstanceAdmin.CreateInstanceConfig].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type CreateInstanceConfigMetadata = src.CreateInstanceConfigMetadata

// The request for
// [CreateInstanceConfigRequest][InstanceAdmin.CreateInstanceConfigRequest].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type CreateInstanceConfigRequest = src.CreateInstanceConfigRequest

// Metadata type for the operation returned by
// [CreateInstance][google.spanner.admin.instance.v1.InstanceAdmin.CreateInstance].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type CreateInstanceMetadata = src.CreateInstanceMetadata

// The request for
// [CreateInstance][google.spanner.admin.instance.v1.InstanceAdmin.CreateInstance].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type CreateInstanceRequest = src.CreateInstanceRequest

// The request for
// [DeleteInstanceConfigRequest][InstanceAdmin.DeleteInstanceConfigRequest].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type DeleteInstanceConfigRequest = src.DeleteInstanceConfigRequest

// The request for
// [DeleteInstance][google.spanner.admin.instance.v1.InstanceAdmin.DeleteInstance].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type DeleteInstanceRequest = src.DeleteInstanceRequest

// The request for
// [GetInstanceConfigRequest][google.spanner.admin.instance.v1.InstanceAdmin.GetInstanceConfig].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type GetInstanceConfigRequest = src.GetInstanceConfigRequest

// The request for
// [GetInstance][google.spanner.admin.instance.v1.InstanceAdmin.GetInstance].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type GetInstanceRequest = src.GetInstanceRequest

// An isolated set of Cloud Spanner resources on which databases can be
// hosted.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type Instance = src.Instance

// InstanceAdminClient is the client API for InstanceAdmin service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type InstanceAdminClient = src.InstanceAdminClient

// InstanceAdminServer is the server API for InstanceAdmin service.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type InstanceAdminServer = src.InstanceAdminServer

// A possible configuration for a Cloud Spanner instance. Configurations
// define the geographic placement of nodes and their replication.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type InstanceConfig = src.InstanceConfig

// Indicates the current state of the instance config.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type InstanceConfig_State = src.InstanceConfig_State

// The type of this configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type InstanceConfig_Type = src.InstanceConfig_Type

// Indicates the current state of the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type Instance_State = src.Instance_State

// The request for
// [ListInstanceConfigOperations][google.spanner.admin.instance.v1.InstanceAdmin.ListInstanceConfigOperations].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type ListInstanceConfigOperationsRequest = src.ListInstanceConfigOperationsRequest

// The response for
// [ListInstanceConfigOperations][google.spanner.admin.instance.v1.InstanceAdmin.ListInstanceConfigOperations].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type ListInstanceConfigOperationsResponse = src.ListInstanceConfigOperationsResponse

// The request for
// [ListInstanceConfigs][google.spanner.admin.instance.v1.InstanceAdmin.ListInstanceConfigs].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type ListInstanceConfigsRequest = src.ListInstanceConfigsRequest

// The response for
// [ListInstanceConfigs][google.spanner.admin.instance.v1.InstanceAdmin.ListInstanceConfigs].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type ListInstanceConfigsResponse = src.ListInstanceConfigsResponse

// The request for
// [ListInstances][google.spanner.admin.instance.v1.InstanceAdmin.ListInstances].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type ListInstancesRequest = src.ListInstancesRequest

// The response for
// [ListInstances][google.spanner.admin.instance.v1.InstanceAdmin.ListInstances].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type ListInstancesResponse = src.ListInstancesResponse

// Encapsulates progress related information for a Cloud Spanner long running
// instance operations.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type OperationProgress = src.OperationProgress
type ReplicaInfo = src.ReplicaInfo

// Indicates the type of replica. See the [replica types
// documentation](https://cloud.google.com/spanner/docs/replication#replica_types)
// for more details.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type ReplicaInfo_ReplicaType = src.ReplicaInfo_ReplicaType

// UnimplementedInstanceAdminServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type UnimplementedInstanceAdminServer = src.UnimplementedInstanceAdminServer

// Metadata type for the operation returned by
// [UpdateInstanceConfig][google.spanner.admin.instance.v1.InstanceAdmin.UpdateInstanceConfig].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type UpdateInstanceConfigMetadata = src.UpdateInstanceConfigMetadata

// The request for
// [UpdateInstanceConfigRequest][InstanceAdmin.UpdateInstanceConfigRequest].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type UpdateInstanceConfigRequest = src.UpdateInstanceConfigRequest

// Metadata type for the operation returned by
// [UpdateInstance][google.spanner.admin.instance.v1.InstanceAdmin.UpdateInstance].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type UpdateInstanceMetadata = src.UpdateInstanceMetadata

// The request for
// [UpdateInstance][google.spanner.admin.instance.v1.InstanceAdmin.UpdateInstance].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
type UpdateInstanceRequest = src.UpdateInstanceRequest

// Deprecated: Please use funcs in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
func NewInstanceAdminClient(cc grpc.ClientConnInterface) InstanceAdminClient {
	return src.NewInstanceAdminClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/spanner/admin/instance/apiv1/instancepb
func RegisterInstanceAdminServer(s *grpc.Server, srv InstanceAdminServer) {
	src.RegisterInstanceAdminServer(s, srv)
}
