// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package appconnections aliases all exported identifiers in package
// "cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb".
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package appconnections

import (
	src "cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
const (
	AppConnection_CREATED                  = src.AppConnection_CREATED
	AppConnection_CREATING                 = src.AppConnection_CREATING
	AppConnection_DELETING                 = src.AppConnection_DELETING
	AppConnection_DOWN                     = src.AppConnection_DOWN
	AppConnection_Gateway_GCP_REGIONAL_MIG = src.AppConnection_Gateway_GCP_REGIONAL_MIG
	AppConnection_Gateway_TYPE_UNSPECIFIED = src.AppConnection_Gateway_TYPE_UNSPECIFIED
	AppConnection_STATE_UNSPECIFIED        = src.AppConnection_STATE_UNSPECIFIED
	AppConnection_TCP_PROXY                = src.AppConnection_TCP_PROXY
	AppConnection_TYPE_UNSPECIFIED         = src.AppConnection_TYPE_UNSPECIFIED
	AppConnection_UPDATING                 = src.AppConnection_UPDATING
)

// Deprecated: Please use vars in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
var (
	AppConnection_Gateway_Type_name                                              = src.AppConnection_Gateway_Type_name
	AppConnection_Gateway_Type_value                                             = src.AppConnection_Gateway_Type_value
	AppConnection_State_name                                                     = src.AppConnection_State_name
	AppConnection_State_value                                                    = src.AppConnection_State_value
	AppConnection_Type_name                                                      = src.AppConnection_Type_name
	AppConnection_Type_value                                                     = src.AppConnection_Type_value
	File_google_cloud_beyondcorp_appconnections_v1_app_connections_service_proto = src.File_google_cloud_beyondcorp_appconnections_v1_app_connections_service_proto
)

// A BeyondCorp AppConnection resource represents a BeyondCorp protected
// AppConnection to a remote application. It creates all the necessary GCP
// components needed for creating a BeyondCorp protected AppConnection.
// Multiple connectors can be authorised for a single AppConnection.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type AppConnection = src.AppConnection

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type AppConnectionOperationMetadata = src.AppConnectionOperationMetadata

// ApplicationEndpoint represents a remote application endpoint.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type AppConnection_ApplicationEndpoint = src.AppConnection_ApplicationEndpoint

// Gateway represents a user facing component that serves as an entrance to
// enable connectivity.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type AppConnection_Gateway = src.AppConnection_Gateway

// Enum listing possible gateway hosting options.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type AppConnection_Gateway_Type = src.AppConnection_Gateway_Type

// Represents the different states of a AppConnection.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type AppConnection_State = src.AppConnection_State

// Enum containing list of all possible network connectivity options supported
// by BeyondCorp AppConnection.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type AppConnection_Type = src.AppConnection_Type

// AppConnectionsServiceClient is the client API for AppConnectionsService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type AppConnectionsServiceClient = src.AppConnectionsServiceClient

// AppConnectionsServiceServer is the server API for AppConnectionsService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type AppConnectionsServiceServer = src.AppConnectionsServiceServer

// Request message for BeyondCorp.CreateAppConnection.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type CreateAppConnectionRequest = src.CreateAppConnectionRequest

// Request message for BeyondCorp.DeleteAppConnection.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type DeleteAppConnectionRequest = src.DeleteAppConnectionRequest

// Request message for BeyondCorp.GetAppConnection.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type GetAppConnectionRequest = src.GetAppConnectionRequest

// Request message for BeyondCorp.ListAppConnections.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type ListAppConnectionsRequest = src.ListAppConnectionsRequest

// Response message for BeyondCorp.ListAppConnections.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type ListAppConnectionsResponse = src.ListAppConnectionsResponse

// Request message for BeyondCorp.ResolveAppConnections.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type ResolveAppConnectionsRequest = src.ResolveAppConnectionsRequest

// Response message for BeyondCorp.ResolveAppConnections.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type ResolveAppConnectionsResponse = src.ResolveAppConnectionsResponse

// Details of the AppConnection.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type ResolveAppConnectionsResponse_AppConnectionDetails = src.ResolveAppConnectionsResponse_AppConnectionDetails

// UnimplementedAppConnectionsServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type UnimplementedAppConnectionsServiceServer = src.UnimplementedAppConnectionsServiceServer

// Request message for BeyondCorp.UpdateAppConnection.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
type UpdateAppConnectionRequest = src.UpdateAppConnectionRequest

// Deprecated: Please use funcs in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
func NewAppConnectionsServiceClient(cc grpc.ClientConnInterface) AppConnectionsServiceClient {
	return src.NewAppConnectionsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/beyondcorp/appconnections/apiv1/appconnectionspb
func RegisterAppConnectionsServiceServer(s *grpc.Server, srv AppConnectionsServiceServer) {
	src.RegisterAppConnectionsServiceServer(s, srv)
}
