// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package translate aliases all exported identifiers in package
// "cloud.google.com/go/translate/apiv3/translatepb".
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package translate

import (
	src "cloud.google.com/go/translate/apiv3/translatepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/translate/apiv3/translatepb
const (
	BatchTranslateDocumentMetadata_CANCELLED         = src.BatchTranslateDocumentMetadata_CANCELLED
	BatchTranslateDocumentMetadata_CANCELLING        = src.BatchTranslateDocumentMetadata_CANCELLING
	BatchTranslateDocumentMetadata_FAILED            = src.BatchTranslateDocumentMetadata_FAILED
	BatchTranslateDocumentMetadata_RUNNING           = src.BatchTranslateDocumentMetadata_RUNNING
	BatchTranslateDocumentMetadata_STATE_UNSPECIFIED = src.BatchTranslateDocumentMetadata_STATE_UNSPECIFIED
	BatchTranslateDocumentMetadata_SUCCEEDED         = src.BatchTranslateDocumentMetadata_SUCCEEDED
	BatchTranslateMetadata_CANCELLED                 = src.BatchTranslateMetadata_CANCELLED
	BatchTranslateMetadata_CANCELLING                = src.BatchTranslateMetadata_CANCELLING
	BatchTranslateMetadata_FAILED                    = src.BatchTranslateMetadata_FAILED
	BatchTranslateMetadata_RUNNING                   = src.BatchTranslateMetadata_RUNNING
	BatchTranslateMetadata_STATE_UNSPECIFIED         = src.BatchTranslateMetadata_STATE_UNSPECIFIED
	BatchTranslateMetadata_SUCCEEDED                 = src.BatchTranslateMetadata_SUCCEEDED
	CreateGlossaryMetadata_CANCELLED                 = src.CreateGlossaryMetadata_CANCELLED
	CreateGlossaryMetadata_CANCELLING                = src.CreateGlossaryMetadata_CANCELLING
	CreateGlossaryMetadata_FAILED                    = src.CreateGlossaryMetadata_FAILED
	CreateGlossaryMetadata_RUNNING                   = src.CreateGlossaryMetadata_RUNNING
	CreateGlossaryMetadata_STATE_UNSPECIFIED         = src.CreateGlossaryMetadata_STATE_UNSPECIFIED
	CreateGlossaryMetadata_SUCCEEDED                 = src.CreateGlossaryMetadata_SUCCEEDED
	DeleteGlossaryMetadata_CANCELLED                 = src.DeleteGlossaryMetadata_CANCELLED
	DeleteGlossaryMetadata_CANCELLING                = src.DeleteGlossaryMetadata_CANCELLING
	DeleteGlossaryMetadata_FAILED                    = src.DeleteGlossaryMetadata_FAILED
	DeleteGlossaryMetadata_RUNNING                   = src.DeleteGlossaryMetadata_RUNNING
	DeleteGlossaryMetadata_STATE_UNSPECIFIED         = src.DeleteGlossaryMetadata_STATE_UNSPECIFIED
	DeleteGlossaryMetadata_SUCCEEDED                 = src.DeleteGlossaryMetadata_SUCCEEDED
)

// Deprecated: Please use vars in: cloud.google.com/go/translate/apiv3/translatepb
var (
	BatchTranslateDocumentMetadata_State_name                = src.BatchTranslateDocumentMetadata_State_name
	BatchTranslateDocumentMetadata_State_value               = src.BatchTranslateDocumentMetadata_State_value
	BatchTranslateMetadata_State_name                        = src.BatchTranslateMetadata_State_name
	BatchTranslateMetadata_State_value                       = src.BatchTranslateMetadata_State_value
	CreateGlossaryMetadata_State_name                        = src.CreateGlossaryMetadata_State_name
	CreateGlossaryMetadata_State_value                       = src.CreateGlossaryMetadata_State_value
	DeleteGlossaryMetadata_State_name                        = src.DeleteGlossaryMetadata_State_name
	DeleteGlossaryMetadata_State_value                       = src.DeleteGlossaryMetadata_State_value
	File_google_cloud_translate_v3_translation_service_proto = src.File_google_cloud_translate_v3_translation_service_proto
)

// Input configuration for BatchTranslateDocument request.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type BatchDocumentInputConfig = src.BatchDocumentInputConfig
type BatchDocumentInputConfig_GcsSource = src.BatchDocumentInputConfig_GcsSource

// Output configuration for BatchTranslateDocument request.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type BatchDocumentOutputConfig = src.BatchDocumentOutputConfig
type BatchDocumentOutputConfig_GcsDestination = src.BatchDocumentOutputConfig_GcsDestination

// State metadata for the batch translation operation.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type BatchTranslateDocumentMetadata = src.BatchTranslateDocumentMetadata

// State of the job.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type BatchTranslateDocumentMetadata_State = src.BatchTranslateDocumentMetadata_State

// The BatchTranslateDocument request.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type BatchTranslateDocumentRequest = src.BatchTranslateDocumentRequest

// Stored in the
// [google.longrunning.Operation.response][google.longrunning.Operation.response]
// field returned by BatchTranslateDocument if at least one document is
// translated successfully.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type BatchTranslateDocumentResponse = src.BatchTranslateDocumentResponse

// State metadata for the batch translation operation.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type BatchTranslateMetadata = src.BatchTranslateMetadata

// State of the job.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type BatchTranslateMetadata_State = src.BatchTranslateMetadata_State

// Stored in the
// [google.longrunning.Operation.response][google.longrunning.Operation.response]
// field returned by BatchTranslateText if at least one sentence is translated
// successfully.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type BatchTranslateResponse = src.BatchTranslateResponse

// The batch translation request.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type BatchTranslateTextRequest = src.BatchTranslateTextRequest

// Stored in the
// [google.longrunning.Operation.metadata][google.longrunning.Operation.metadata]
// field returned by CreateGlossary.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type CreateGlossaryMetadata = src.CreateGlossaryMetadata

// Enumerates the possible states that the creation request can be in.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type CreateGlossaryMetadata_State = src.CreateGlossaryMetadata_State

// Request message for CreateGlossary.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type CreateGlossaryRequest = src.CreateGlossaryRequest

// Stored in the
// [google.longrunning.Operation.metadata][google.longrunning.Operation.metadata]
// field returned by DeleteGlossary.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type DeleteGlossaryMetadata = src.DeleteGlossaryMetadata

// Enumerates the possible states that the creation request can be in.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type DeleteGlossaryMetadata_State = src.DeleteGlossaryMetadata_State

// Request message for DeleteGlossary.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type DeleteGlossaryRequest = src.DeleteGlossaryRequest

// Stored in the
// [google.longrunning.Operation.response][google.longrunning.Operation.response]
// field returned by DeleteGlossary.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type DeleteGlossaryResponse = src.DeleteGlossaryResponse

// The request message for language detection.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type DetectLanguageRequest = src.DetectLanguageRequest
type DetectLanguageRequest_Content = src.DetectLanguageRequest_Content

// The response message for language detection.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type DetectLanguageResponse = src.DetectLanguageResponse

// The response message for language detection.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type DetectedLanguage = src.DetectedLanguage

// A document translation request input config.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type DocumentInputConfig = src.DocumentInputConfig
type DocumentInputConfig_Content = src.DocumentInputConfig_Content
type DocumentInputConfig_GcsSource = src.DocumentInputConfig_GcsSource

// A document translation request output config.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type DocumentOutputConfig = src.DocumentOutputConfig
type DocumentOutputConfig_GcsDestination = src.DocumentOutputConfig_GcsDestination

// A translated document message.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type DocumentTranslation = src.DocumentTranslation

// The Google Cloud Storage location for the output content.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type GcsDestination = src.GcsDestination

// The Google Cloud Storage location for the input content.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type GcsSource = src.GcsSource

// Request message for GetGlossary.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type GetGlossaryRequest = src.GetGlossaryRequest

// The request message for discovering supported languages.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type GetSupportedLanguagesRequest = src.GetSupportedLanguagesRequest

// Represents a glossary built from user provided data.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type Glossary = src.Glossary

// Input configuration for glossaries.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type GlossaryInputConfig = src.GlossaryInputConfig
type GlossaryInputConfig_GcsSource = src.GlossaryInputConfig_GcsSource

// Used with unidirectional glossaries.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type Glossary_LanguageCodePair = src.Glossary_LanguageCodePair

// Used with equivalent term set glossaries.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type Glossary_LanguageCodesSet = src.Glossary_LanguageCodesSet
type Glossary_LanguageCodesSet_ = src.Glossary_LanguageCodesSet_
type Glossary_LanguagePair = src.Glossary_LanguagePair

// Input configuration for BatchTranslateText request.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type InputConfig = src.InputConfig
type InputConfig_GcsSource = src.InputConfig_GcsSource

// Request message for ListGlossaries.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type ListGlossariesRequest = src.ListGlossariesRequest

// Response message for ListGlossaries.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type ListGlossariesResponse = src.ListGlossariesResponse

// Output configuration for BatchTranslateText request.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type OutputConfig = src.OutputConfig
type OutputConfig_GcsDestination = src.OutputConfig_GcsDestination

// A single supported language response corresponds to information related to
// one supported language.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type SupportedLanguage = src.SupportedLanguage

// The response message for discovering supported languages.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type SupportedLanguages = src.SupportedLanguages

// A document translation request.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type TranslateDocumentRequest = src.TranslateDocumentRequest

// A translated document response message.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type TranslateDocumentResponse = src.TranslateDocumentResponse

// Configures which glossary should be used for a specific target language,
// and defines options for applying that glossary.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type TranslateTextGlossaryConfig = src.TranslateTextGlossaryConfig

// The request message for synchronous translation.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type TranslateTextRequest = src.TranslateTextRequest
type TranslateTextResponse = src.TranslateTextResponse

// A single translation response.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type Translation = src.Translation

// TranslationServiceClient is the client API for TranslationService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type TranslationServiceClient = src.TranslationServiceClient

// TranslationServiceServer is the server API for TranslationService service.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type TranslationServiceServer = src.TranslationServiceServer

// UnimplementedTranslationServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/translate/apiv3/translatepb
type UnimplementedTranslationServiceServer = src.UnimplementedTranslationServiceServer

// Deprecated: Please use funcs in: cloud.google.com/go/translate/apiv3/translatepb
func NewTranslationServiceClient(cc grpc.ClientConnInterface) TranslationServiceClient {
	return src.NewTranslationServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/translate/apiv3/translatepb
func RegisterTranslationServiceServer(s *grpc.Server, srv TranslationServiceServer) {
	src.RegisterTranslationServiceServer(s, srv)
}
