// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package datastream aliases all exported identifiers in package
// "cloud.google.com/go/datastream/apiv1alpha1/datastreampb".
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package datastream

import (
	src "cloud.google.com/go/datastream/apiv1alpha1/datastreampb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
const (
	GcsFileFormat_AVRO                              = src.GcsFileFormat_AVRO
	GcsFileFormat_GCS_FILE_FORMAT_UNSPECIFIED       = src.GcsFileFormat_GCS_FILE_FORMAT_UNSPECIFIED
	JsonFileFormat_GZIP                             = src.JsonFileFormat_GZIP
	JsonFileFormat_JSON_COMPRESSION_UNSPECIFIED     = src.JsonFileFormat_JSON_COMPRESSION_UNSPECIFIED
	JsonFileFormat_NO_COMPRESSION                   = src.JsonFileFormat_NO_COMPRESSION
	PrivateConnection_CREATED                       = src.PrivateConnection_CREATED
	PrivateConnection_CREATING                      = src.PrivateConnection_CREATING
	PrivateConnection_FAILED                        = src.PrivateConnection_FAILED
	PrivateConnection_STATE_UNSPECIFIED             = src.PrivateConnection_STATE_UNSPECIFIED
	SchemaFileFormat_AVRO_SCHEMA_FILE               = src.SchemaFileFormat_AVRO_SCHEMA_FILE
	SchemaFileFormat_NO_SCHEMA_FILE                 = src.SchemaFileFormat_NO_SCHEMA_FILE
	SchemaFileFormat_SCHEMA_FILE_FORMAT_UNSPECIFIED = src.SchemaFileFormat_SCHEMA_FILE_FORMAT_UNSPECIFIED
	Stream_CREATED                                  = src.Stream_CREATED
	Stream_DRAINING                                 = src.Stream_DRAINING
	Stream_FAILED                                   = src.Stream_FAILED
	Stream_FAILED_PERMANENTLY                       = src.Stream_FAILED_PERMANENTLY
	Stream_MAINTENANCE                              = src.Stream_MAINTENANCE
	Stream_PAUSED                                   = src.Stream_PAUSED
	Stream_RUNNING                                  = src.Stream_RUNNING
	Stream_STARTING                                 = src.Stream_STARTING
	Stream_STATE_UNSPECIFIED                        = src.Stream_STATE_UNSPECIFIED
	ValidationMessage_ERROR                         = src.ValidationMessage_ERROR
	ValidationMessage_LEVEL_UNSPECIFIED             = src.ValidationMessage_LEVEL_UNSPECIFIED
	ValidationMessage_WARNING                       = src.ValidationMessage_WARNING
	Validation_FAILED                               = src.Validation_FAILED
	Validation_NOT_EXECUTED                         = src.Validation_NOT_EXECUTED
	Validation_PASSED                               = src.Validation_PASSED
	Validation_STATUS_UNSPECIFIED                   = src.Validation_STATUS_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
var (
	File_google_cloud_datastream_v1alpha1_datastream_proto           = src.File_google_cloud_datastream_v1alpha1_datastream_proto
	File_google_cloud_datastream_v1alpha1_datastream_resources_proto = src.File_google_cloud_datastream_v1alpha1_datastream_resources_proto
	GcsFileFormat_name                                               = src.GcsFileFormat_name
	GcsFileFormat_value                                              = src.GcsFileFormat_value
	JsonFileFormat_JsonCompression_name                              = src.JsonFileFormat_JsonCompression_name
	JsonFileFormat_JsonCompression_value                             = src.JsonFileFormat_JsonCompression_value
	PrivateConnection_State_name                                     = src.PrivateConnection_State_name
	PrivateConnection_State_value                                    = src.PrivateConnection_State_value
	SchemaFileFormat_name                                            = src.SchemaFileFormat_name
	SchemaFileFormat_value                                           = src.SchemaFileFormat_value
	Stream_State_name                                                = src.Stream_State_name
	Stream_State_value                                               = src.Stream_State_value
	ValidationMessage_Level_name                                     = src.ValidationMessage_Level_name
	ValidationMessage_Level_value                                    = src.ValidationMessage_Level_value
	Validation_Status_name                                           = src.Validation_Status_name
	Validation_Status_value                                          = src.Validation_Status_value
)

// AVRO file format configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type AvroFileFormat = src.AvroFileFormat
type ConnectionProfile = src.ConnectionProfile
type ConnectionProfile_ForwardSshConnectivity = src.ConnectionProfile_ForwardSshConnectivity
type ConnectionProfile_GcsProfile = src.ConnectionProfile_GcsProfile
type ConnectionProfile_MysqlProfile = src.ConnectionProfile_MysqlProfile
type ConnectionProfile_NoConnectivity = src.ConnectionProfile_NoConnectivity
type ConnectionProfile_OracleProfile = src.ConnectionProfile_OracleProfile
type ConnectionProfile_PrivateConnectivity = src.ConnectionProfile_PrivateConnectivity
type ConnectionProfile_StaticServiceIpConnectivity = src.ConnectionProfile_StaticServiceIpConnectivity
type CreateConnectionProfileRequest = src.CreateConnectionProfileRequest
type CreatePrivateConnectionRequest = src.CreatePrivateConnectionRequest

// route creation request
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type CreateRouteRequest = src.CreateRouteRequest
type CreateStreamRequest = src.CreateStreamRequest

// DatastreamClient is the client API for Datastream service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type DatastreamClient = src.DatastreamClient

// DatastreamServer is the server API for Datastream service.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type DatastreamServer = src.DatastreamServer
type DeleteConnectionProfileRequest = src.DeleteConnectionProfileRequest
type DeletePrivateConnectionRequest = src.DeletePrivateConnectionRequest

// route deletion request
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type DeleteRouteRequest = src.DeleteRouteRequest
type DeleteStreamRequest = src.DeleteStreamRequest

// The configuration of the stream destination.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type DestinationConfig = src.DestinationConfig
type DestinationConfig_GcsDestinationConfig = src.DestinationConfig_GcsDestinationConfig

// Request message for 'discover' ConnectionProfile request.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type DiscoverConnectionProfileRequest = src.DiscoverConnectionProfileRequest
type DiscoverConnectionProfileRequest_ConnectionProfile = src.DiscoverConnectionProfileRequest_ConnectionProfile
type DiscoverConnectionProfileRequest_ConnectionProfileName = src.DiscoverConnectionProfileRequest_ConnectionProfileName
type DiscoverConnectionProfileRequest_MysqlRdbms = src.DiscoverConnectionProfileRequest_MysqlRdbms
type DiscoverConnectionProfileRequest_OracleRdbms = src.DiscoverConnectionProfileRequest_OracleRdbms
type DiscoverConnectionProfileRequest_RecursionDepth = src.DiscoverConnectionProfileRequest_RecursionDepth
type DiscoverConnectionProfileRequest_Recursive = src.DiscoverConnectionProfileRequest_Recursive
type DiscoverConnectionProfileResponse = src.DiscoverConnectionProfileResponse
type DiscoverConnectionProfileResponse_MysqlRdbms = src.DiscoverConnectionProfileResponse_MysqlRdbms
type DiscoverConnectionProfileResponse_OracleRdbms = src.DiscoverConnectionProfileResponse_OracleRdbms

// Represent a user-facing Error.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type Error = src.Error

// Request message for 'FetchErrors' request.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type FetchErrorsRequest = src.FetchErrorsRequest

// Response message for a 'FetchErrors' response.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type FetchErrorsResponse = src.FetchErrorsResponse

// Request message for 'FetchStaticIps' request.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type FetchStaticIpsRequest = src.FetchStaticIpsRequest

// Response message for a 'FetchStaticIps' response.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type FetchStaticIpsResponse = src.FetchStaticIpsResponse

// Forward SSH Tunnel connectivity.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type ForwardSshTunnelConnectivity = src.ForwardSshTunnelConnectivity
type ForwardSshTunnelConnectivity_Password = src.ForwardSshTunnelConnectivity_Password
type ForwardSshTunnelConnectivity_PrivateKey = src.ForwardSshTunnelConnectivity_PrivateKey

// Google Cloud Storage destination configuration
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type GcsDestinationConfig = src.GcsDestinationConfig
type GcsDestinationConfig_AvroFileFormat = src.GcsDestinationConfig_AvroFileFormat
type GcsDestinationConfig_JsonFileFormat = src.GcsDestinationConfig_JsonFileFormat

// File format in Cloud Storage. Deprecated: Do not use.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type GcsFileFormat = src.GcsFileFormat

// Cloud Storage bucket profile.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type GcsProfile = src.GcsProfile
type GetConnectionProfileRequest = src.GetConnectionProfileRequest
type GetPrivateConnectionRequest = src.GetPrivateConnectionRequest

// route get request
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type GetRouteRequest = src.GetRouteRequest
type GetStreamRequest = src.GetStreamRequest

// JSON file format configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type JsonFileFormat = src.JsonFileFormat

// Json file compression.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type JsonFileFormat_JsonCompression = src.JsonFileFormat_JsonCompression
type ListConnectionProfilesRequest = src.ListConnectionProfilesRequest
type ListConnectionProfilesResponse = src.ListConnectionProfilesResponse
type ListPrivateConnectionsRequest = src.ListPrivateConnectionsRequest
type ListPrivateConnectionsResponse = src.ListPrivateConnectionsResponse

// route list request
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type ListRoutesRequest = src.ListRoutesRequest

// route list response
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type ListRoutesResponse = src.ListRoutesResponse
type ListStreamsRequest = src.ListStreamsRequest
type ListStreamsResponse = src.ListStreamsResponse

// MySQL Column.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type MysqlColumn = src.MysqlColumn

// MySQL database.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type MysqlDatabase = src.MysqlDatabase

// MySQL database profile.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type MysqlProfile = src.MysqlProfile

// MySQL database structure
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type MysqlRdbms = src.MysqlRdbms

// MySQL source configuration
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type MysqlSourceConfig = src.MysqlSourceConfig

// MySQL SSL configuration information.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type MysqlSslConfig = src.MysqlSslConfig

// MySQL table.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type MysqlTable = src.MysqlTable

// No connectivity settings.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type NoConnectivitySettings = src.NoConnectivitySettings

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type OperationMetadata = src.OperationMetadata

// Oracle Column.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type OracleColumn = src.OracleColumn

// Oracle database profile.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type OracleProfile = src.OracleProfile

// Oracle database structure.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type OracleRdbms = src.OracleRdbms

// Oracle schema.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type OracleSchema = src.OracleSchema

// Oracle data source configuration
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type OracleSourceConfig = src.OracleSourceConfig

// Oracle table.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type OracleTable = src.OracleTable

// The PrivateConnection resource is used to establish private connectivity
// between Datastream and a customer's network.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type PrivateConnection = src.PrivateConnection

// Private Connection state.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type PrivateConnection_State = src.PrivateConnection_State

// Private Connectivity
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type PrivateConnectivity = src.PrivateConnectivity

// The Route resource is the child of the PrivateConnection resource. It used
// to define a route for a PrivateConnection setup.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type Route = src.Route

// Schema file format.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type SchemaFileFormat = src.SchemaFileFormat

// The configuration of the stream source.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type SourceConfig = src.SourceConfig
type SourceConfig_MysqlSourceConfig = src.SourceConfig_MysqlSourceConfig
type SourceConfig_OracleSourceConfig = src.SourceConfig_OracleSourceConfig

// Static IP address connectivity.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type StaticServiceIpConnectivity = src.StaticServiceIpConnectivity
type Stream = src.Stream
type Stream_BackfillAll = src.Stream_BackfillAll

// Backfill strategy to automatically backfill the Stream's objects. Specific
// objects can be excluded.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type Stream_BackfillAllStrategy = src.Stream_BackfillAllStrategy
type Stream_BackfillAllStrategy_MysqlExcludedObjects = src.Stream_BackfillAllStrategy_MysqlExcludedObjects
type Stream_BackfillAllStrategy_OracleExcludedObjects = src.Stream_BackfillAllStrategy_OracleExcludedObjects
type Stream_BackfillNone = src.Stream_BackfillNone

// Backfill strategy to disable automatic backfill for the Stream's objects.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type Stream_BackfillNoneStrategy = src.Stream_BackfillNoneStrategy

// Stream state.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type Stream_State = src.Stream_State

// UnimplementedDatastreamServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type UnimplementedDatastreamServer = src.UnimplementedDatastreamServer
type UpdateConnectionProfileRequest = src.UpdateConnectionProfileRequest
type UpdateStreamRequest = src.UpdateStreamRequest
type Validation = src.Validation

// Represent user-facing validation result message.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type ValidationMessage = src.ValidationMessage

// Validation message level.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type ValidationMessage_Level = src.ValidationMessage_Level

// Contains the current validation results.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type ValidationResult = src.ValidationResult

// Validation execution status.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type Validation_Status = src.Validation_Status

// The VPC Peering configuration is used to create VPC peering between
// Datastream and the consumer's VPC.
//
// Deprecated: Please use types in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
type VpcPeeringConfig = src.VpcPeeringConfig

// Deprecated: Please use funcs in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
func NewDatastreamClient(cc grpc.ClientConnInterface) DatastreamClient {
	return src.NewDatastreamClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/datastream/apiv1alpha1/datastreampb
func RegisterDatastreamServer(s *grpc.Server, srv DatastreamServer) {
	src.RegisterDatastreamServer(s, srv)
}
