// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package certificatemanager aliases all exported identifiers in package
// "cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb".
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package certificatemanager

import (
	src "cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
const (
	CertificateIssuanceConfig_ECDSA_P256                                               = src.CertificateIssuanceConfig_ECDSA_P256
	CertificateIssuanceConfig_KEY_ALGORITHM_UNSPECIFIED                                = src.CertificateIssuanceConfig_KEY_ALGORITHM_UNSPECIFIED
	CertificateIssuanceConfig_RSA_2048                                                 = src.CertificateIssuanceConfig_RSA_2048
	CertificateMapEntry_MATCHER_UNSPECIFIED                                            = src.CertificateMapEntry_MATCHER_UNSPECIFIED
	CertificateMapEntry_PRIMARY                                                        = src.CertificateMapEntry_PRIMARY
	Certificate_DEFAULT                                                                = src.Certificate_DEFAULT
	Certificate_EDGE_CACHE                                                             = src.Certificate_EDGE_CACHE
	Certificate_ManagedCertificate_ACTIVE                                              = src.Certificate_ManagedCertificate_ACTIVE
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_AUTHORIZED                 = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_AUTHORIZED
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_AUTHORIZING                = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_AUTHORIZING
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_CAA                        = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_CAA
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_CONFIG                     = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_CONFIG
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_FAILED                     = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_FAILED
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_FAILURE_REASON_UNSPECIFIED = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_FAILURE_REASON_UNSPECIFIED
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_RATE_LIMITED               = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_RATE_LIMITED
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_STATE_UNSPECIFIED          = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_STATE_UNSPECIFIED
	Certificate_ManagedCertificate_FAILED                                              = src.Certificate_ManagedCertificate_FAILED
	Certificate_ManagedCertificate_PROVISIONING                                        = src.Certificate_ManagedCertificate_PROVISIONING
	Certificate_ManagedCertificate_ProvisioningIssue_AUTHORIZATION_ISSUE               = src.Certificate_ManagedCertificate_ProvisioningIssue_AUTHORIZATION_ISSUE
	Certificate_ManagedCertificate_ProvisioningIssue_RATE_LIMITED                      = src.Certificate_ManagedCertificate_ProvisioningIssue_RATE_LIMITED
	Certificate_ManagedCertificate_ProvisioningIssue_REASON_UNSPECIFIED                = src.Certificate_ManagedCertificate_ProvisioningIssue_REASON_UNSPECIFIED
	Certificate_ManagedCertificate_STATE_UNSPECIFIED                                   = src.Certificate_ManagedCertificate_STATE_UNSPECIFIED
	ServingState_ACTIVE                                                                = src.ServingState_ACTIVE
	ServingState_PENDING                                                               = src.ServingState_PENDING
	ServingState_SERVING_STATE_UNSPECIFIED                                             = src.ServingState_SERVING_STATE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
var (
	CertificateIssuanceConfig_KeyAlgorithm_name                                 = src.CertificateIssuanceConfig_KeyAlgorithm_name
	CertificateIssuanceConfig_KeyAlgorithm_value                                = src.CertificateIssuanceConfig_KeyAlgorithm_value
	CertificateMapEntry_Matcher_name                                            = src.CertificateMapEntry_Matcher_name
	CertificateMapEntry_Matcher_value                                           = src.CertificateMapEntry_Matcher_value
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_FailureReason_name  = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_FailureReason_name
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_FailureReason_value = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_FailureReason_value
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_State_name          = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_State_name
	Certificate_ManagedCertificate_AuthorizationAttemptInfo_State_value         = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_State_value
	Certificate_ManagedCertificate_ProvisioningIssue_Reason_name                = src.Certificate_ManagedCertificate_ProvisioningIssue_Reason_name
	Certificate_ManagedCertificate_ProvisioningIssue_Reason_value               = src.Certificate_ManagedCertificate_ProvisioningIssue_Reason_value
	Certificate_ManagedCertificate_State_name                                   = src.Certificate_ManagedCertificate_State_name
	Certificate_ManagedCertificate_State_value                                  = src.Certificate_ManagedCertificate_State_value
	Certificate_Scope_name                                                      = src.Certificate_Scope_name
	Certificate_Scope_value                                                     = src.Certificate_Scope_value
	File_google_cloud_certificatemanager_v1_certificate_issuance_config_proto   = src.File_google_cloud_certificatemanager_v1_certificate_issuance_config_proto
	File_google_cloud_certificatemanager_v1_certificate_manager_proto           = src.File_google_cloud_certificatemanager_v1_certificate_manager_proto
	ServingState_name                                                           = src.ServingState_name
	ServingState_value                                                          = src.ServingState_value
)

// Defines TLS certificate.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type Certificate = src.Certificate

// CertificateIssuanceConfig specifies how to issue and manage a certificate.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateIssuanceConfig = src.CertificateIssuanceConfig

// The CA that issues the workload certificate. It includes CA address, type,
// authentication to CA service, etc.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateIssuanceConfig_CertificateAuthorityConfig = src.CertificateIssuanceConfig_CertificateAuthorityConfig

// Contains information required to contact CA service.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateIssuanceConfig_CertificateAuthorityConfig_CertificateAuthorityServiceConfig = src.CertificateIssuanceConfig_CertificateAuthorityConfig_CertificateAuthorityServiceConfig
type CertificateIssuanceConfig_CertificateAuthorityConfig_CertificateAuthorityServiceConfig_ = src.CertificateIssuanceConfig_CertificateAuthorityConfig_CertificateAuthorityServiceConfig_

// The type of keypair to generate.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateIssuanceConfig_KeyAlgorithm = src.CertificateIssuanceConfig_KeyAlgorithm

// CertificateManagerClient is the client API for CertificateManager service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateManagerClient = src.CertificateManagerClient

// CertificateManagerServer is the server API for CertificateManager service.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateManagerServer = src.CertificateManagerServer

// Defines a collection of certificate configurations.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateMap = src.CertificateMap

// Defines a certificate map entry.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateMapEntry = src.CertificateMapEntry
type CertificateMapEntry_Hostname = src.CertificateMapEntry_Hostname

// Defines predefined cases other than SNI-hostname match when this
// configuration should be applied.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateMapEntry_Matcher = src.CertificateMapEntry_Matcher
type CertificateMapEntry_Matcher_ = src.CertificateMapEntry_Matcher_

// Describes a Target Proxy which uses this Certificate Map.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateMap_GclbTarget = src.CertificateMap_GclbTarget

// Defines IP configuration where this Certificate Map is serving.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CertificateMap_GclbTarget_IpConfig = src.CertificateMap_GclbTarget_IpConfig
type CertificateMap_GclbTarget_TargetHttpsProxy = src.CertificateMap_GclbTarget_TargetHttpsProxy
type CertificateMap_GclbTarget_TargetSslProxy = src.CertificateMap_GclbTarget_TargetSslProxy
type Certificate_Managed = src.Certificate_Managed

// Configuration and state of a Managed Certificate. Certificate Manager
// provisions and renews Managed Certificates automatically, for as long as
// it's authorized to do so.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type Certificate_ManagedCertificate = src.Certificate_ManagedCertificate

// State of the latest attempt to authorize a domain for certificate issuance.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type Certificate_ManagedCertificate_AuthorizationAttemptInfo = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo
type Certificate_ManagedCertificate_AuthorizationAttemptInfo_FailureReason = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_FailureReason
type Certificate_ManagedCertificate_AuthorizationAttemptInfo_State = src.Certificate_ManagedCertificate_AuthorizationAttemptInfo_State

// Information about issues with provisioning a Managed Certificate.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type Certificate_ManagedCertificate_ProvisioningIssue = src.Certificate_ManagedCertificate_ProvisioningIssue
type Certificate_ManagedCertificate_ProvisioningIssue_Reason = src.Certificate_ManagedCertificate_ProvisioningIssue_Reason
type Certificate_ManagedCertificate_State = src.Certificate_ManagedCertificate_State

// Certificate scope.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type Certificate_Scope = src.Certificate_Scope
type Certificate_SelfManaged = src.Certificate_SelfManaged

// Certificate data for a SelfManaged Certificate. SelfManaged Certificates
// are uploaded by the user. Updating such certificates before they expire
// remains the user's responsibility.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type Certificate_SelfManagedCertificate = src.Certificate_SelfManagedCertificate

// Request for the `CreateCertificateIssuanceConfig` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CreateCertificateIssuanceConfigRequest = src.CreateCertificateIssuanceConfigRequest

// Request for the `CreateCertificateMapEntry` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CreateCertificateMapEntryRequest = src.CreateCertificateMapEntryRequest

// Request for the `CreateCertificateMap` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CreateCertificateMapRequest = src.CreateCertificateMapRequest

// Request for the `CreateCertificate` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CreateCertificateRequest = src.CreateCertificateRequest

// Request for the `CreateDnsAuthorization` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type CreateDnsAuthorizationRequest = src.CreateDnsAuthorizationRequest

// Request for the `DeleteCertificateIssuanceConfig` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type DeleteCertificateIssuanceConfigRequest = src.DeleteCertificateIssuanceConfigRequest

// Request for the `DeleteCertificateMapEntry` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type DeleteCertificateMapEntryRequest = src.DeleteCertificateMapEntryRequest

// Request for the `DeleteCertificateMap` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type DeleteCertificateMapRequest = src.DeleteCertificateMapRequest

// Request for the `DeleteCertificate` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type DeleteCertificateRequest = src.DeleteCertificateRequest

// Request for the `DeleteDnsAuthorization` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type DeleteDnsAuthorizationRequest = src.DeleteDnsAuthorizationRequest

// A DnsAuthorization resource describes a way to perform domain authorization
// for certificate issuance.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type DnsAuthorization = src.DnsAuthorization

// The structure describing the DNS Resource Record that needs to be added to
// DNS configuration for the authorization to be usable by certificate.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type DnsAuthorization_DnsResourceRecord = src.DnsAuthorization_DnsResourceRecord

// Request for the `GetCertificateIssuanceConfig` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type GetCertificateIssuanceConfigRequest = src.GetCertificateIssuanceConfigRequest

// Request for the `GetCertificateMapEntry` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type GetCertificateMapEntryRequest = src.GetCertificateMapEntryRequest

// Request for the `GetCertificateMap` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type GetCertificateMapRequest = src.GetCertificateMapRequest

// Request for the `GetCertificate` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type GetCertificateRequest = src.GetCertificateRequest

// Request for the `GetDnsAuthorization` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type GetDnsAuthorizationRequest = src.GetDnsAuthorizationRequest

// Request for the `ListCertificateIssuanceConfigs` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ListCertificateIssuanceConfigsRequest = src.ListCertificateIssuanceConfigsRequest

// Response for the `ListCertificateIssuanceConfigs` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ListCertificateIssuanceConfigsResponse = src.ListCertificateIssuanceConfigsResponse

// Request for the `ListCertificateMapEntries` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ListCertificateMapEntriesRequest = src.ListCertificateMapEntriesRequest

// Response for the `ListCertificateMapEntries` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ListCertificateMapEntriesResponse = src.ListCertificateMapEntriesResponse

// Request for the `ListCertificateMaps` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ListCertificateMapsRequest = src.ListCertificateMapsRequest

// Response for the `ListCertificateMaps` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ListCertificateMapsResponse = src.ListCertificateMapsResponse

// Request for the `ListCertificates` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ListCertificatesRequest = src.ListCertificatesRequest

// Response for the `ListCertificates` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ListCertificatesResponse = src.ListCertificatesResponse

// Request for the `ListDnsAuthorizations` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ListDnsAuthorizationsRequest = src.ListDnsAuthorizationsRequest

// Response for the `ListDnsAuthorizations` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ListDnsAuthorizationsResponse = src.ListDnsAuthorizationsResponse

// Represents the metadata of the long-running operation. Output only.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type OperationMetadata = src.OperationMetadata

// Defines set of serving states associated with a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type ServingState = src.ServingState

// UnimplementedCertificateManagerServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type UnimplementedCertificateManagerServer = src.UnimplementedCertificateManagerServer

// Request for the `UpdateCertificateMapEntry` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type UpdateCertificateMapEntryRequest = src.UpdateCertificateMapEntryRequest

// Request for the `UpdateCertificateMap` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type UpdateCertificateMapRequest = src.UpdateCertificateMapRequest

// Request for the `UpdateCertificate` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type UpdateCertificateRequest = src.UpdateCertificateRequest

// Request for the `UpdateDnsAuthorization` method.
//
// Deprecated: Please use types in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
type UpdateDnsAuthorizationRequest = src.UpdateDnsAuthorizationRequest

// Deprecated: Please use funcs in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
func NewCertificateManagerClient(cc grpc.ClientConnInterface) CertificateManagerClient {
	return src.NewCertificateManagerClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/certificatemanager/apiv1/certificatemanagerpb
func RegisterCertificateManagerServer(s *grpc.Server, srv CertificateManagerServer) {
	src.RegisterCertificateManagerServer(s, srv)
}
