// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package errorreporting aliases all exported identifiers in package
// "cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb".
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package errorreporting

import (
	src "cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
const (
	ErrorGroupOrder_AFFECTED_USERS_DESC                   = src.ErrorGroupOrder_AFFECTED_USERS_DESC
	ErrorGroupOrder_COUNT_DESC                            = src.ErrorGroupOrder_COUNT_DESC
	ErrorGroupOrder_CREATED_DESC                          = src.ErrorGroupOrder_CREATED_DESC
	ErrorGroupOrder_GROUP_ORDER_UNSPECIFIED               = src.ErrorGroupOrder_GROUP_ORDER_UNSPECIFIED
	ErrorGroupOrder_LAST_SEEN_DESC                        = src.ErrorGroupOrder_LAST_SEEN_DESC
	QueryTimeRange_PERIOD_1_DAY                           = src.QueryTimeRange_PERIOD_1_DAY
	QueryTimeRange_PERIOD_1_HOUR                          = src.QueryTimeRange_PERIOD_1_HOUR
	QueryTimeRange_PERIOD_1_WEEK                          = src.QueryTimeRange_PERIOD_1_WEEK
	QueryTimeRange_PERIOD_30_DAYS                         = src.QueryTimeRange_PERIOD_30_DAYS
	QueryTimeRange_PERIOD_6_HOURS                         = src.QueryTimeRange_PERIOD_6_HOURS
	QueryTimeRange_PERIOD_UNSPECIFIED                     = src.QueryTimeRange_PERIOD_UNSPECIFIED
	ResolutionStatus_ACKNOWLEDGED                         = src.ResolutionStatus_ACKNOWLEDGED
	ResolutionStatus_MUTED                                = src.ResolutionStatus_MUTED
	ResolutionStatus_OPEN                                 = src.ResolutionStatus_OPEN
	ResolutionStatus_RESOLUTION_STATUS_UNSPECIFIED        = src.ResolutionStatus_RESOLUTION_STATUS_UNSPECIFIED
	ResolutionStatus_RESOLVED                             = src.ResolutionStatus_RESOLVED
	TimedCountAlignment_ALIGNMENT_EQUAL_AT_END            = src.TimedCountAlignment_ALIGNMENT_EQUAL_AT_END
	TimedCountAlignment_ALIGNMENT_EQUAL_ROUNDED           = src.TimedCountAlignment_ALIGNMENT_EQUAL_ROUNDED
	TimedCountAlignment_ERROR_COUNT_ALIGNMENT_UNSPECIFIED = src.TimedCountAlignment_ERROR_COUNT_ALIGNMENT_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
var (
	ErrorGroupOrder_name                                                         = src.ErrorGroupOrder_name
	ErrorGroupOrder_value                                                        = src.ErrorGroupOrder_value
	File_google_devtools_clouderrorreporting_v1beta1_common_proto                = src.File_google_devtools_clouderrorreporting_v1beta1_common_proto
	File_google_devtools_clouderrorreporting_v1beta1_error_group_service_proto   = src.File_google_devtools_clouderrorreporting_v1beta1_error_group_service_proto
	File_google_devtools_clouderrorreporting_v1beta1_error_stats_service_proto   = src.File_google_devtools_clouderrorreporting_v1beta1_error_stats_service_proto
	File_google_devtools_clouderrorreporting_v1beta1_report_errors_service_proto = src.File_google_devtools_clouderrorreporting_v1beta1_report_errors_service_proto
	QueryTimeRange_Period_name                                                   = src.QueryTimeRange_Period_name
	QueryTimeRange_Period_value                                                  = src.QueryTimeRange_Period_value
	ResolutionStatus_name                                                        = src.ResolutionStatus_name
	ResolutionStatus_value                                                       = src.ResolutionStatus_value
	TimedCountAlignment_name                                                     = src.TimedCountAlignment_name
	TimedCountAlignment_value                                                    = src.TimedCountAlignment_value
)

// Deletes all events in the project.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type DeleteEventsRequest = src.DeleteEventsRequest

// Response message for deleting error events.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type DeleteEventsResponse = src.DeleteEventsResponse

// A description of the context in which an error occurred. This data should
// be provided by the application when reporting an error, unless the error
// report has been generated automatically from Google App Engine logs.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ErrorContext = src.ErrorContext

// An error event which is returned by the Error Reporting system.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ErrorEvent = src.ErrorEvent

// Description of a group of similar error events.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ErrorGroup = src.ErrorGroup

// A sorting order of error groups.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ErrorGroupOrder = src.ErrorGroupOrder

// ErrorGroupServiceClient is the client API for ErrorGroupService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ErrorGroupServiceClient = src.ErrorGroupServiceClient

// ErrorGroupServiceServer is the server API for ErrorGroupService service.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ErrorGroupServiceServer = src.ErrorGroupServiceServer

// Data extracted for a specific group based on certain filter criteria, such
// as a given time period and/or service filter.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ErrorGroupStats = src.ErrorGroupStats

// ErrorStatsServiceClient is the client API for ErrorStatsService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ErrorStatsServiceClient = src.ErrorStatsServiceClient

// ErrorStatsServiceServer is the server API for ErrorStatsService service.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ErrorStatsServiceServer = src.ErrorStatsServiceServer

// A request to return an individual group.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type GetGroupRequest = src.GetGroupRequest

// HTTP request data that is related to a reported error. This data should be
// provided by the application when reporting an error, unless the error report
// has been generated automatically from Google App Engine logs.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type HttpRequestContext = src.HttpRequestContext

// Specifies a set of error events to return.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ListEventsRequest = src.ListEventsRequest

// Contains a set of requested error events.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ListEventsResponse = src.ListEventsResponse

// Specifies a set of `ErrorGroupStats` to return.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ListGroupStatsRequest = src.ListGroupStatsRequest

// Contains a set of requested error group stats.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ListGroupStatsResponse = src.ListGroupStatsResponse

// Requests might be rejected or the resulting timed count durations might be
// adjusted for lower durations.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type QueryTimeRange = src.QueryTimeRange

// The supported time ranges.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type QueryTimeRange_Period = src.QueryTimeRange_Period

// A request for reporting an individual error event.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ReportErrorEventRequest = src.ReportErrorEventRequest

// Response for reporting an individual error event. Data may be added to this
// message in the future.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ReportErrorEventResponse = src.ReportErrorEventResponse

// ReportErrorsServiceClient is the client API for ReportErrorsService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ReportErrorsServiceClient = src.ReportErrorsServiceClient

// ReportErrorsServiceServer is the server API for ReportErrorsService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ReportErrorsServiceServer = src.ReportErrorsServiceServer

// An error event which is reported to the Error Reporting system.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ReportedErrorEvent = src.ReportedErrorEvent

// Resolution status of an error group.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ResolutionStatus = src.ResolutionStatus

// Describes a running service that sends errors. Its version changes over
// time and multiple versions can run in parallel.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ServiceContext = src.ServiceContext

// Specifies criteria for filtering a subset of service contexts. The fields
// in the filter correspond to the fields in `ServiceContext`. Only exact,
// case-sensitive matches are supported. If a field is unset or empty, it
// matches arbitrary values.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type ServiceContextFilter = src.ServiceContextFilter

// Indicates a location in the source code of the service for which errors are
// reported. `functionName` must be provided by the application when reporting
// an error, unless the error report contains a `message` with a supported
// exception stack trace. All fields are optional for the later case.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type SourceLocation = src.SourceLocation

// The number of errors in a given time period. All numbers are approximate
// since the error events are sampled before counting them.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type TimedCount = src.TimedCount

// Specifies how the time periods of error group counts are aligned.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type TimedCountAlignment = src.TimedCountAlignment

// Information related to tracking the progress on resolving the error.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type TrackingIssue = src.TrackingIssue

// UnimplementedErrorGroupServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type UnimplementedErrorGroupServiceServer = src.UnimplementedErrorGroupServiceServer

// UnimplementedErrorStatsServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type UnimplementedErrorStatsServiceServer = src.UnimplementedErrorStatsServiceServer

// UnimplementedReportErrorsServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type UnimplementedReportErrorsServiceServer = src.UnimplementedReportErrorsServiceServer

// A request to replace the existing data for the given group.
//
// Deprecated: Please use types in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
type UpdateGroupRequest = src.UpdateGroupRequest

// Deprecated: Please use funcs in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
func NewErrorGroupServiceClient(cc grpc.ClientConnInterface) ErrorGroupServiceClient {
	return src.NewErrorGroupServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
func NewErrorStatsServiceClient(cc grpc.ClientConnInterface) ErrorStatsServiceClient {
	return src.NewErrorStatsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
func NewReportErrorsServiceClient(cc grpc.ClientConnInterface) ReportErrorsServiceClient {
	return src.NewReportErrorsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
func RegisterErrorGroupServiceServer(s *grpc.Server, srv ErrorGroupServiceServer) {
	src.RegisterErrorGroupServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
func RegisterErrorStatsServiceServer(s *grpc.Server, srv ErrorStatsServiceServer) {
	src.RegisterErrorStatsServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/errorreporting/apiv1beta1/errorreportingpb
func RegisterReportErrorsServiceServer(s *grpc.Server, srv ReportErrorsServiceServer) {
	src.RegisterReportErrorsServiceServer(s, srv)
}
