// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package storage aliases all exported identifiers in package
// "cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb".
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package storage

import (
	src "cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
const (
	ArrowSerializationOptions_ARROW_0_14         = src.ArrowSerializationOptions_ARROW_0_14
	ArrowSerializationOptions_ARROW_0_15         = src.ArrowSerializationOptions_ARROW_0_15
	ArrowSerializationOptions_FORMAT_UNSPECIFIED = src.ArrowSerializationOptions_FORMAT_UNSPECIFIED
	DataFormat_ARROW                             = src.DataFormat_ARROW
	DataFormat_AVRO                              = src.DataFormat_AVRO
	DataFormat_DATA_FORMAT_UNSPECIFIED           = src.DataFormat_DATA_FORMAT_UNSPECIFIED
	StorageError_INVALID_STREAM_STATE            = src.StorageError_INVALID_STREAM_STATE
	StorageError_INVALID_STREAM_TYPE             = src.StorageError_INVALID_STREAM_TYPE
	StorageError_STORAGE_ERROR_CODE_UNSPECIFIED  = src.StorageError_STORAGE_ERROR_CODE_UNSPECIFIED
	StorageError_STREAM_ALREADY_COMMITTED        = src.StorageError_STREAM_ALREADY_COMMITTED
	StorageError_STREAM_FINALIZED                = src.StorageError_STREAM_FINALIZED
	StorageError_STREAM_NOT_FOUND                = src.StorageError_STREAM_NOT_FOUND
	StorageError_TABLE_NOT_FOUND                 = src.StorageError_TABLE_NOT_FOUND
	TableFieldSchema_BIGNUMERIC                  = src.TableFieldSchema_BIGNUMERIC
	TableFieldSchema_BOOL                        = src.TableFieldSchema_BOOL
	TableFieldSchema_BYTES                       = src.TableFieldSchema_BYTES
	TableFieldSchema_DATE                        = src.TableFieldSchema_DATE
	TableFieldSchema_DATETIME                    = src.TableFieldSchema_DATETIME
	TableFieldSchema_DOUBLE                      = src.TableFieldSchema_DOUBLE
	TableFieldSchema_GEOGRAPHY                   = src.TableFieldSchema_GEOGRAPHY
	TableFieldSchema_INT64                       = src.TableFieldSchema_INT64
	TableFieldSchema_INTERVAL                    = src.TableFieldSchema_INTERVAL
	TableFieldSchema_JSON                        = src.TableFieldSchema_JSON
	TableFieldSchema_MODE_UNSPECIFIED            = src.TableFieldSchema_MODE_UNSPECIFIED
	TableFieldSchema_NULLABLE                    = src.TableFieldSchema_NULLABLE
	TableFieldSchema_NUMERIC                     = src.TableFieldSchema_NUMERIC
	TableFieldSchema_REPEATED                    = src.TableFieldSchema_REPEATED
	TableFieldSchema_REQUIRED                    = src.TableFieldSchema_REQUIRED
	TableFieldSchema_STRING                      = src.TableFieldSchema_STRING
	TableFieldSchema_STRUCT                      = src.TableFieldSchema_STRUCT
	TableFieldSchema_TIME                        = src.TableFieldSchema_TIME
	TableFieldSchema_TIMESTAMP                   = src.TableFieldSchema_TIMESTAMP
	TableFieldSchema_TYPE_UNSPECIFIED            = src.TableFieldSchema_TYPE_UNSPECIFIED
	WriteStream_BUFFERED                         = src.WriteStream_BUFFERED
	WriteStream_COMMITTED                        = src.WriteStream_COMMITTED
	WriteStream_PENDING                          = src.WriteStream_PENDING
	WriteStream_TYPE_UNSPECIFIED                 = src.WriteStream_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
var (
	ArrowSerializationOptions_Format_name                     = src.ArrowSerializationOptions_Format_name
	ArrowSerializationOptions_Format_value                    = src.ArrowSerializationOptions_Format_value
	DataFormat_name                                           = src.DataFormat_name
	DataFormat_value                                          = src.DataFormat_value
	File_google_cloud_bigquery_storage_v1beta2_arrow_proto    = src.File_google_cloud_bigquery_storage_v1beta2_arrow_proto
	File_google_cloud_bigquery_storage_v1beta2_avro_proto     = src.File_google_cloud_bigquery_storage_v1beta2_avro_proto
	File_google_cloud_bigquery_storage_v1beta2_protobuf_proto = src.File_google_cloud_bigquery_storage_v1beta2_protobuf_proto
	File_google_cloud_bigquery_storage_v1beta2_storage_proto  = src.File_google_cloud_bigquery_storage_v1beta2_storage_proto
	File_google_cloud_bigquery_storage_v1beta2_stream_proto   = src.File_google_cloud_bigquery_storage_v1beta2_stream_proto
	File_google_cloud_bigquery_storage_v1beta2_table_proto    = src.File_google_cloud_bigquery_storage_v1beta2_table_proto
	StorageError_StorageErrorCode_name                        = src.StorageError_StorageErrorCode_name
	StorageError_StorageErrorCode_value                       = src.StorageError_StorageErrorCode_value
	TableFieldSchema_Mode_name                                = src.TableFieldSchema_Mode_name
	TableFieldSchema_Mode_value                               = src.TableFieldSchema_Mode_value
	TableFieldSchema_Type_name                                = src.TableFieldSchema_Type_name
	TableFieldSchema_Type_value                               = src.TableFieldSchema_Type_value
	WriteStream_Type_name                                     = src.WriteStream_Type_name
	WriteStream_Type_value                                    = src.WriteStream_Type_value
)

// Request message for `AppendRows`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type AppendRowsRequest = src.AppendRowsRequest

// Proto schema and data.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type AppendRowsRequest_ProtoData = src.AppendRowsRequest_ProtoData
type AppendRowsRequest_ProtoRows = src.AppendRowsRequest_ProtoRows

// Response message for `AppendRows`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type AppendRowsResponse = src.AppendRowsResponse

// AppendResult is returned for successful append requests.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type AppendRowsResponse_AppendResult = src.AppendRowsResponse_AppendResult
type AppendRowsResponse_AppendResult_ = src.AppendRowsResponse_AppendResult_
type AppendRowsResponse_Error = src.AppendRowsResponse_Error

// Arrow RecordBatch.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ArrowRecordBatch = src.ArrowRecordBatch

// Arrow schema as specified in
// https://arrow.apache.org/docs/python/api/datatypes.html and serialized to
// bytes using IPC:
// https://arrow.apache.org/docs/format/Columnar.html#serialization-and-interprocess-communication-ipc
// See code samples on how this message can be deserialized.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ArrowSchema = src.ArrowSchema

// Contains options specific to Arrow Serialization.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ArrowSerializationOptions = src.ArrowSerializationOptions

// The IPC format to use when serializing Arrow streams.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ArrowSerializationOptions_Format = src.ArrowSerializationOptions_Format

// Avro rows.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type AvroRows = src.AvroRows

// Avro schema.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type AvroSchema = src.AvroSchema

// Request message for `BatchCommitWriteStreams`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type BatchCommitWriteStreamsRequest = src.BatchCommitWriteStreamsRequest

// Response message for `BatchCommitWriteStreams`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type BatchCommitWriteStreamsResponse = src.BatchCommitWriteStreamsResponse

// BigQueryReadClient is the client API for BigQueryRead service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type BigQueryReadClient = src.BigQueryReadClient

// BigQueryReadServer is the server API for BigQueryRead service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type BigQueryReadServer = src.BigQueryReadServer
type BigQueryRead_ReadRowsClient = src.BigQueryRead_ReadRowsClient
type BigQueryRead_ReadRowsServer = src.BigQueryRead_ReadRowsServer

// BigQueryWriteClient is the client API for BigQueryWrite service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type BigQueryWriteClient = src.BigQueryWriteClient

// BigQueryWriteServer is the server API for BigQueryWrite service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type BigQueryWriteServer = src.BigQueryWriteServer
type BigQueryWrite_AppendRowsClient = src.BigQueryWrite_AppendRowsClient
type BigQueryWrite_AppendRowsServer = src.BigQueryWrite_AppendRowsServer

// Request message for `CreateReadSession`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type CreateReadSessionRequest = src.CreateReadSessionRequest

// Request message for `CreateWriteStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type CreateWriteStreamRequest = src.CreateWriteStreamRequest

// Data format for input or output data.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type DataFormat = src.DataFormat

// Request message for invoking `FinalizeWriteStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type FinalizeWriteStreamRequest = src.FinalizeWriteStreamRequest

// Response message for `FinalizeWriteStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type FinalizeWriteStreamResponse = src.FinalizeWriteStreamResponse

// Request message for `FlushRows`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type FlushRowsRequest = src.FlushRowsRequest

// Respond message for `FlushRows`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type FlushRowsResponse = src.FlushRowsResponse

// Request message for `GetWriteStreamRequest`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type GetWriteStreamRequest = src.GetWriteStreamRequest
type ProtoRows = src.ProtoRows

// ProtoSchema describes the schema of the serialized protocol buffer data
// rows.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ProtoSchema = src.ProtoSchema

// Request message for `ReadRows`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ReadRowsRequest = src.ReadRowsRequest

// Response from calling `ReadRows` may include row data, progress and
// throttling information.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ReadRowsResponse = src.ReadRowsResponse
type ReadRowsResponse_ArrowRecordBatch = src.ReadRowsResponse_ArrowRecordBatch
type ReadRowsResponse_ArrowSchema = src.ReadRowsResponse_ArrowSchema
type ReadRowsResponse_AvroRows = src.ReadRowsResponse_AvroRows
type ReadRowsResponse_AvroSchema = src.ReadRowsResponse_AvroSchema

// Information about the ReadSession.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ReadSession = src.ReadSession
type ReadSession_ArrowSchema = src.ReadSession_ArrowSchema
type ReadSession_AvroSchema = src.ReadSession_AvroSchema

// Additional attributes when reading a table.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ReadSession_TableModifiers = src.ReadSession_TableModifiers

// Options dictating how we read a table.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ReadSession_TableReadOptions = src.ReadSession_TableReadOptions

// Information about a single stream that gets data out of the storage system.
// Most of the information about `ReadStream` instances is aggregated, making
// `ReadStream` lightweight.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ReadStream = src.ReadStream

// Request message for `SplitReadStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type SplitReadStreamRequest = src.SplitReadStreamRequest
type SplitReadStreamResponse = src.SplitReadStreamResponse

// Structured custom BigQuery Storage error message. The error can be attached
// as error details in the returned rpc Status. In particular, the use of error
// codes allows more structured error handling, and reduces the need to
// evaluate unstructured error text strings.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type StorageError = src.StorageError

// Error code for `StorageError`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type StorageError_StorageErrorCode = src.StorageError_StorageErrorCode

// Estimated stream statistics for a given Stream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type StreamStats = src.StreamStats
type StreamStats_Progress = src.StreamStats_Progress

// A field in TableSchema
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type TableFieldSchema = src.TableFieldSchema
type TableFieldSchema_Mode = src.TableFieldSchema_Mode
type TableFieldSchema_Type = src.TableFieldSchema_Type

// Schema of a table
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type TableSchema = src.TableSchema

// Information on if the current connection is being throttled.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type ThrottleState = src.ThrottleState

// UnimplementedBigQueryReadServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type UnimplementedBigQueryReadServer = src.UnimplementedBigQueryReadServer

// UnimplementedBigQueryWriteServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type UnimplementedBigQueryWriteServer = src.UnimplementedBigQueryWriteServer

// Information about a single stream that gets data inside the storage system.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type WriteStream = src.WriteStream

// Type enum of the stream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
type WriteStream_Type = src.WriteStream_Type

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
func NewBigQueryReadClient(cc grpc.ClientConnInterface) BigQueryReadClient {
	return src.NewBigQueryReadClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
func NewBigQueryWriteClient(cc grpc.ClientConnInterface) BigQueryWriteClient {
	return src.NewBigQueryWriteClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
func RegisterBigQueryReadServer(s *grpc.Server, srv BigQueryReadServer) {
	src.RegisterBigQueryReadServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/storage/apiv1beta2/storagepb
func RegisterBigQueryWriteServer(s *grpc.Server, srv BigQueryWriteServer) {
	src.RegisterBigQueryWriteServer(s, srv)
}
