// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package policytroubleshooter aliases all exported identifiers in package
// "cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb".
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package policytroubleshooter

import (
	src "cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
const (
	AccessState_ACCESS_STATE_UNSPECIFIED                   = src.AccessState_ACCESS_STATE_UNSPECIFIED
	AccessState_GRANTED                                    = src.AccessState_GRANTED
	AccessState_NOT_GRANTED                                = src.AccessState_NOT_GRANTED
	AccessState_UNKNOWN_CONDITIONAL                        = src.AccessState_UNKNOWN_CONDITIONAL
	AccessState_UNKNOWN_INFO_DENIED                        = src.AccessState_UNKNOWN_INFO_DENIED
	BindingExplanation_MEMBERSHIP_INCLUDED                 = src.BindingExplanation_MEMBERSHIP_INCLUDED
	BindingExplanation_MEMBERSHIP_NOT_INCLUDED             = src.BindingExplanation_MEMBERSHIP_NOT_INCLUDED
	BindingExplanation_MEMBERSHIP_UNKNOWN_INFO_DENIED      = src.BindingExplanation_MEMBERSHIP_UNKNOWN_INFO_DENIED
	BindingExplanation_MEMBERSHIP_UNKNOWN_UNSUPPORTED      = src.BindingExplanation_MEMBERSHIP_UNKNOWN_UNSUPPORTED
	BindingExplanation_MEMBERSHIP_UNSPECIFIED              = src.BindingExplanation_MEMBERSHIP_UNSPECIFIED
	BindingExplanation_ROLE_PERMISSION_INCLUDED            = src.BindingExplanation_ROLE_PERMISSION_INCLUDED
	BindingExplanation_ROLE_PERMISSION_NOT_INCLUDED        = src.BindingExplanation_ROLE_PERMISSION_NOT_INCLUDED
	BindingExplanation_ROLE_PERMISSION_UNKNOWN_INFO_DENIED = src.BindingExplanation_ROLE_PERMISSION_UNKNOWN_INFO_DENIED
	BindingExplanation_ROLE_PERMISSION_UNSPECIFIED         = src.BindingExplanation_ROLE_PERMISSION_UNSPECIFIED
	HeuristicRelevance_HEURISTIC_RELEVANCE_UNSPECIFIED     = src.HeuristicRelevance_HEURISTIC_RELEVANCE_UNSPECIFIED
	HeuristicRelevance_HIGH                                = src.HeuristicRelevance_HIGH
	HeuristicRelevance_NORMAL                              = src.HeuristicRelevance_NORMAL
)

// Deprecated: Please use vars in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
var (
	AccessState_name                                             = src.AccessState_name
	AccessState_value                                            = src.AccessState_value
	BindingExplanation_Membership_name                           = src.BindingExplanation_Membership_name
	BindingExplanation_Membership_value                          = src.BindingExplanation_Membership_value
	BindingExplanation_RolePermission_name                       = src.BindingExplanation_RolePermission_name
	BindingExplanation_RolePermission_value                      = src.BindingExplanation_RolePermission_value
	File_google_cloud_policytroubleshooter_v1_checker_proto      = src.File_google_cloud_policytroubleshooter_v1_checker_proto
	File_google_cloud_policytroubleshooter_v1_explanations_proto = src.File_google_cloud_policytroubleshooter_v1_explanations_proto
	HeuristicRelevance_name                                      = src.HeuristicRelevance_name
	HeuristicRelevance_value                                     = src.HeuristicRelevance_value
)

// Whether a member has a permission for a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type AccessState = src.AccessState

// Information about the member, resource, and permission to check.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type AccessTuple = src.AccessTuple

// Details about how a binding in a policy affects a member's ability to use a
// permission.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type BindingExplanation = src.BindingExplanation

// Details about whether the binding includes the member.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type BindingExplanation_AnnotatedMembership = src.BindingExplanation_AnnotatedMembership

// Whether the binding includes the member.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type BindingExplanation_Membership = src.BindingExplanation_Membership

// Whether a role includes a specific permission.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type BindingExplanation_RolePermission = src.BindingExplanation_RolePermission

// Details about how a specific IAM [Policy][google.iam.v1.Policy] contributed
// to the access check.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type ExplainedPolicy = src.ExplainedPolicy

// The extent to which a single data point contributes to an overall
// determination.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type HeuristicRelevance = src.HeuristicRelevance

// IamCheckerClient is the client API for IamChecker service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type IamCheckerClient = src.IamCheckerClient

// IamCheckerServer is the server API for IamChecker service.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type IamCheckerServer = src.IamCheckerServer

// Request for
// [TroubleshootIamPolicy][google.cloud.policytroubleshooter.v1.IamChecker.TroubleshootIamPolicy].
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type TroubleshootIamPolicyRequest = src.TroubleshootIamPolicyRequest

// Response for
// [TroubleshootIamPolicy][google.cloud.policytroubleshooter.v1.IamChecker.TroubleshootIamPolicy].
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type TroubleshootIamPolicyResponse = src.TroubleshootIamPolicyResponse

// UnimplementedIamCheckerServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
type UnimplementedIamCheckerServer = src.UnimplementedIamCheckerServer

// Deprecated: Please use funcs in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
func NewIamCheckerClient(cc grpc.ClientConnInterface) IamCheckerClient {
	return src.NewIamCheckerClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/policytroubleshooter/apiv1/policytroubleshooterpb
func RegisterIamCheckerServer(s *grpc.Server, srv IamCheckerServer) {
	src.RegisterIamCheckerServer(s, srv)
}
