// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package appconnectors aliases all exported identifiers in package
// "cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb".
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package appconnectors

import (
	src "cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
const (
	AppConnector_CREATED                   = src.AppConnector_CREATED
	AppConnector_CREATING                  = src.AppConnector_CREATING
	AppConnector_DELETING                  = src.AppConnector_DELETING
	AppConnector_DOWN                      = src.AppConnector_DOWN
	AppConnector_STATE_UNSPECIFIED         = src.AppConnector_STATE_UNSPECIFIED
	AppConnector_UPDATING                  = src.AppConnector_UPDATING
	HealthStatus_DEGRADED                  = src.HealthStatus_DEGRADED
	HealthStatus_HEALTHY                   = src.HealthStatus_HEALTHY
	HealthStatus_HEALTH_STATUS_UNSPECIFIED = src.HealthStatus_HEALTH_STATUS_UNSPECIFIED
	HealthStatus_UNHEALTHY                 = src.HealthStatus_UNHEALTHY
	HealthStatus_UNRESPONSIVE              = src.HealthStatus_UNRESPONSIVE
)

// Deprecated: Please use vars in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
var (
	AppConnector_State_name                                                           = src.AppConnector_State_name
	AppConnector_State_value                                                          = src.AppConnector_State_value
	File_google_cloud_beyondcorp_appconnectors_v1_app_connector_instance_config_proto = src.File_google_cloud_beyondcorp_appconnectors_v1_app_connector_instance_config_proto
	File_google_cloud_beyondcorp_appconnectors_v1_app_connectors_service_proto        = src.File_google_cloud_beyondcorp_appconnectors_v1_app_connectors_service_proto
	File_google_cloud_beyondcorp_appconnectors_v1_resource_info_proto                 = src.File_google_cloud_beyondcorp_appconnectors_v1_resource_info_proto
	HealthStatus_name                                                                 = src.HealthStatus_name
	HealthStatus_value                                                                = src.HealthStatus_value
)

// A BeyondCorp connector resource that represents an application facing
// component deployed proximal to and with direct access to the application
// instances. It is used to establish connectivity between the remote
// enterprise environment and GCP. It initiates connections to the applications
// and can proxy the data from users over the connection.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type AppConnector = src.AppConnector

// AppConnectorInstanceConfig defines the instance config of a AppConnector.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type AppConnectorInstanceConfig = src.AppConnectorInstanceConfig

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type AppConnectorOperationMetadata = src.AppConnectorOperationMetadata

// PrincipalInfo represents an Identity oneof.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type AppConnector_PrincipalInfo = src.AppConnector_PrincipalInfo

// ServiceAccount represents a GCP service account.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type AppConnector_PrincipalInfo_ServiceAccount = src.AppConnector_PrincipalInfo_ServiceAccount
type AppConnector_PrincipalInfo_ServiceAccount_ = src.AppConnector_PrincipalInfo_ServiceAccount_

// Represents the different states of a AppConnector.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type AppConnector_State = src.AppConnector_State

// AppConnectorsServiceClient is the client API for AppConnectorsService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type AppConnectorsServiceClient = src.AppConnectorsServiceClient

// AppConnectorsServiceServer is the server API for AppConnectorsService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type AppConnectorsServiceServer = src.AppConnectorsServiceServer

// Request message for BeyondCorp.CreateAppConnector.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type CreateAppConnectorRequest = src.CreateAppConnectorRequest

// Request message for BeyondCorp.DeleteAppConnector.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type DeleteAppConnectorRequest = src.DeleteAppConnectorRequest

// Request message for BeyondCorp.GetAppConnector.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type GetAppConnectorRequest = src.GetAppConnectorRequest

// HealthStatus represents the health status.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type HealthStatus = src.HealthStatus

// ImageConfig defines the control plane images to run.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type ImageConfig = src.ImageConfig

// Request message for BeyondCorp.ListAppConnectors.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type ListAppConnectorsRequest = src.ListAppConnectorsRequest

// Response message for BeyondCorp.ListAppConnectors.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type ListAppConnectorsResponse = src.ListAppConnectorsResponse

// NotificationConfig defines the mechanisms to notify instance agent.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type NotificationConfig = src.NotificationConfig

// The configuration for Pub/Sub messaging for the AppConnector.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type NotificationConfig_CloudPubSubNotificationConfig = src.NotificationConfig_CloudPubSubNotificationConfig
type NotificationConfig_PubsubNotification = src.NotificationConfig_PubsubNotification

// Request report the connector status.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type ReportStatusRequest = src.ReportStatusRequest

// ResourceInfo represents the information/status of an app connector
// resource. Such as: - remote_agent - container - runtime - appgateway -
// appconnector - appconnection - tunnel - logagent
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type ResourceInfo = src.ResourceInfo

// UnimplementedAppConnectorsServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type UnimplementedAppConnectorsServiceServer = src.UnimplementedAppConnectorsServiceServer

// Request message for BeyondCorp.UpdateAppConnector.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
type UpdateAppConnectorRequest = src.UpdateAppConnectorRequest

// Deprecated: Please use funcs in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
func NewAppConnectorsServiceClient(cc grpc.ClientConnInterface) AppConnectorsServiceClient {
	return src.NewAppConnectorsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/beyondcorp/appconnectors/apiv1/appconnectorspb
func RegisterAppConnectorsServiceServer(s *grpc.Server, srv AppConnectorsServiceServer) {
	src.RegisterAppConnectorsServiceServer(s, srv)
}
