// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package serviceusage aliases all exported identifiers in package
// "cloud.google.com/go/serviceusage/apiv1/serviceusagepb".
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package serviceusage

import (
	src "cloud.google.com/go/serviceusage/apiv1/serviceusagepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
const (
	DisableServiceRequest_CHECK                                  = src.DisableServiceRequest_CHECK
	DisableServiceRequest_CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED = src.DisableServiceRequest_CHECK_IF_SERVICE_HAS_USAGE_UNSPECIFIED
	DisableServiceRequest_SKIP                                   = src.DisableServiceRequest_SKIP
	State_DISABLED                                               = src.State_DISABLED
	State_ENABLED                                                = src.State_ENABLED
	State_STATE_UNSPECIFIED                                      = src.State_STATE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
var (
	DisableServiceRequest_CheckIfServiceHasUsage_name  = src.DisableServiceRequest_CheckIfServiceHasUsage_name
	DisableServiceRequest_CheckIfServiceHasUsage_value = src.DisableServiceRequest_CheckIfServiceHasUsage_value
	File_google_api_serviceusage_v1_resources_proto    = src.File_google_api_serviceusage_v1_resources_proto
	File_google_api_serviceusage_v1_serviceusage_proto = src.File_google_api_serviceusage_v1_serviceusage_proto
	State_name                                         = src.State_name
	State_value                                        = src.State_value
)

// Request message for the `BatchEnableServices` method.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type BatchEnableServicesRequest = src.BatchEnableServicesRequest

// Response message for the `BatchEnableServices` method. This response
// message is assigned to the `response` field of the returned Operation when
// that operation is done.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type BatchEnableServicesResponse = src.BatchEnableServicesResponse

// Provides error messages for the failing services.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type BatchEnableServicesResponse_EnableFailure = src.BatchEnableServicesResponse_EnableFailure

// Request message for the `BatchGetServices` method.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type BatchGetServicesRequest = src.BatchGetServicesRequest

// Response message for the `BatchGetServices` method.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type BatchGetServicesResponse = src.BatchGetServicesResponse

// Request message for the `DisableService` method.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type DisableServiceRequest = src.DisableServiceRequest

// Enum to determine if service usage should be checked when disabling a
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type DisableServiceRequest_CheckIfServiceHasUsage = src.DisableServiceRequest_CheckIfServiceHasUsage

// Response message for the `DisableService` method. This response message is
// assigned to the `response` field of the returned Operation when that
// operation is done.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type DisableServiceResponse = src.DisableServiceResponse

// Request message for the `EnableService` method.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type EnableServiceRequest = src.EnableServiceRequest

// Response message for the `EnableService` method. This response message is
// assigned to the `response` field of the returned Operation when that
// operation is done.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type EnableServiceResponse = src.EnableServiceResponse

// Request message for the `GetService` method.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type GetServiceRequest = src.GetServiceRequest

// Request message for the `ListServices` method.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type ListServicesRequest = src.ListServicesRequest

// Response message for the `ListServices` method.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type ListServicesResponse = src.ListServicesResponse

// The operation metadata returned for the batchend services operation.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type OperationMetadata = src.OperationMetadata

// A service that is available for use by the consumer.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type Service = src.Service

// The configuration of the service.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type ServiceConfig = src.ServiceConfig

// ServiceUsageClient is the client API for ServiceUsage service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type ServiceUsageClient = src.ServiceUsageClient

// ServiceUsageServer is the server API for ServiceUsage service.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type ServiceUsageServer = src.ServiceUsageServer

// Whether or not a service has been enabled for use by a consumer.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type State = src.State

// UnimplementedServiceUsageServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
type UnimplementedServiceUsageServer = src.UnimplementedServiceUsageServer

// Deprecated: Please use funcs in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
func NewServiceUsageClient(cc grpc.ClientConnInterface) ServiceUsageClient {
	return src.NewServiceUsageClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/serviceusage/apiv1/serviceusagepb
func RegisterServiceUsageServer(s *grpc.Server, srv ServiceUsageServer) {
	src.RegisterServiceUsageServer(s, srv)
}
