// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package notebooks aliases all exported identifiers in package
// "cloud.google.com/go/notebooks/apiv1/notebookspb".
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package notebooks

import (
	src "cloud.google.com/go/notebooks/apiv1/notebookspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/notebooks/apiv1/notebookspb
const (
	Event_EVENT_TYPE_UNSPECIFIED                             = src.Event_EVENT_TYPE_UNSPECIFIED
	Event_HEALTH                                             = src.Event_HEALTH
	Event_HEARTBEAT                                          = src.Event_HEARTBEAT
	Event_IDLE                                               = src.Event_IDLE
	Event_MAINTENANCE                                        = src.Event_MAINTENANCE
	ExecutionTemplate_BASIC                                  = src.ExecutionTemplate_BASIC
	ExecutionTemplate_BASIC_GPU                              = src.ExecutionTemplate_BASIC_GPU
	ExecutionTemplate_BASIC_TPU                              = src.ExecutionTemplate_BASIC_TPU
	ExecutionTemplate_CUSTOM                                 = src.ExecutionTemplate_CUSTOM
	ExecutionTemplate_DATAPROC                               = src.ExecutionTemplate_DATAPROC
	ExecutionTemplate_JOB_TYPE_UNSPECIFIED                   = src.ExecutionTemplate_JOB_TYPE_UNSPECIFIED
	ExecutionTemplate_NVIDIA_TESLA_A100                      = src.ExecutionTemplate_NVIDIA_TESLA_A100
	ExecutionTemplate_NVIDIA_TESLA_K80                       = src.ExecutionTemplate_NVIDIA_TESLA_K80
	ExecutionTemplate_NVIDIA_TESLA_P100                      = src.ExecutionTemplate_NVIDIA_TESLA_P100
	ExecutionTemplate_NVIDIA_TESLA_P4                        = src.ExecutionTemplate_NVIDIA_TESLA_P4
	ExecutionTemplate_NVIDIA_TESLA_T4                        = src.ExecutionTemplate_NVIDIA_TESLA_T4
	ExecutionTemplate_NVIDIA_TESLA_V100                      = src.ExecutionTemplate_NVIDIA_TESLA_V100
	ExecutionTemplate_PREMIUM_1                              = src.ExecutionTemplate_PREMIUM_1
	ExecutionTemplate_SCALE_TIER_UNSPECIFIED                 = src.ExecutionTemplate_SCALE_TIER_UNSPECIFIED
	ExecutionTemplate_SCHEDULER_ACCELERATOR_TYPE_UNSPECIFIED = src.ExecutionTemplate_SCHEDULER_ACCELERATOR_TYPE_UNSPECIFIED
	ExecutionTemplate_STANDARD_1                             = src.ExecutionTemplate_STANDARD_1
	ExecutionTemplate_TPU_V2                                 = src.ExecutionTemplate_TPU_V2
	ExecutionTemplate_TPU_V3                                 = src.ExecutionTemplate_TPU_V3
	ExecutionTemplate_VERTEX_AI                              = src.ExecutionTemplate_VERTEX_AI
	Execution_CANCELLED                                      = src.Execution_CANCELLED
	Execution_CANCELLING                                     = src.Execution_CANCELLING
	Execution_EXPIRED                                        = src.Execution_EXPIRED
	Execution_FAILED                                         = src.Execution_FAILED
	Execution_INITIALIZING                                   = src.Execution_INITIALIZING
	Execution_PREPARING                                      = src.Execution_PREPARING
	Execution_QUEUED                                         = src.Execution_QUEUED
	Execution_RUNNING                                        = src.Execution_RUNNING
	Execution_STATE_UNSPECIFIED                              = src.Execution_STATE_UNSPECIFIED
	Execution_SUCCEEDED                                      = src.Execution_SUCCEEDED
	GetInstanceHealthResponse_AGENT_NOT_INSTALLED            = src.GetInstanceHealthResponse_AGENT_NOT_INSTALLED
	GetInstanceHealthResponse_AGENT_NOT_RUNNING              = src.GetInstanceHealthResponse_AGENT_NOT_RUNNING
	GetInstanceHealthResponse_HEALTHY                        = src.GetInstanceHealthResponse_HEALTHY
	GetInstanceHealthResponse_HEALTH_STATE_UNSPECIFIED       = src.GetInstanceHealthResponse_HEALTH_STATE_UNSPECIFIED
	GetInstanceHealthResponse_UNHEALTHY                      = src.GetInstanceHealthResponse_UNHEALTHY
	Instance_ACCELERATOR_TYPE_UNSPECIFIED                    = src.Instance_ACCELERATOR_TYPE_UNSPECIFIED
	Instance_ACTIVE                                          = src.Instance_ACTIVE
	Instance_CMEK                                            = src.Instance_CMEK
	Instance_DELETED                                         = src.Instance_DELETED
	Instance_DISK_ENCRYPTION_UNSPECIFIED                     = src.Instance_DISK_ENCRYPTION_UNSPECIFIED
	Instance_DISK_TYPE_UNSPECIFIED                           = src.Instance_DISK_TYPE_UNSPECIFIED
	Instance_GMEK                                            = src.Instance_GMEK
	Instance_GVNIC                                           = src.Instance_GVNIC
	Instance_INITIALIZING                                    = src.Instance_INITIALIZING
	Instance_NVIDIA_TESLA_A100                               = src.Instance_NVIDIA_TESLA_A100
	Instance_NVIDIA_TESLA_K80                                = src.Instance_NVIDIA_TESLA_K80
	Instance_NVIDIA_TESLA_P100                               = src.Instance_NVIDIA_TESLA_P100
	Instance_NVIDIA_TESLA_P100_VWS                           = src.Instance_NVIDIA_TESLA_P100_VWS
	Instance_NVIDIA_TESLA_P4                                 = src.Instance_NVIDIA_TESLA_P4
	Instance_NVIDIA_TESLA_P4_VWS                             = src.Instance_NVIDIA_TESLA_P4_VWS
	Instance_NVIDIA_TESLA_T4                                 = src.Instance_NVIDIA_TESLA_T4
	Instance_NVIDIA_TESLA_T4_VWS                             = src.Instance_NVIDIA_TESLA_T4_VWS
	Instance_NVIDIA_TESLA_V100                               = src.Instance_NVIDIA_TESLA_V100
	Instance_PD_BALANCED                                     = src.Instance_PD_BALANCED
	Instance_PD_EXTREME                                      = src.Instance_PD_EXTREME
	Instance_PD_SSD                                          = src.Instance_PD_SSD
	Instance_PD_STANDARD                                     = src.Instance_PD_STANDARD
	Instance_PROVISIONING                                    = src.Instance_PROVISIONING
	Instance_REGISTERING                                     = src.Instance_REGISTERING
	Instance_STARTING                                        = src.Instance_STARTING
	Instance_STATE_UNSPECIFIED                               = src.Instance_STATE_UNSPECIFIED
	Instance_STOPPED                                         = src.Instance_STOPPED
	Instance_STOPPING                                        = src.Instance_STOPPING
	Instance_SUSPENDED                                       = src.Instance_SUSPENDED
	Instance_SUSPENDING                                      = src.Instance_SUSPENDING
	Instance_TPU_V2                                          = src.Instance_TPU_V2
	Instance_TPU_V3                                          = src.Instance_TPU_V3
	Instance_UNSPECIFIED_NIC_TYPE                            = src.Instance_UNSPECIFIED_NIC_TYPE
	Instance_UPGRADING                                       = src.Instance_UPGRADING
	Instance_UpgradeHistoryEntry_ACTION_UNSPECIFIED          = src.Instance_UpgradeHistoryEntry_ACTION_UNSPECIFIED
	Instance_UpgradeHistoryEntry_FAILED                      = src.Instance_UpgradeHistoryEntry_FAILED
	Instance_UpgradeHistoryEntry_ROLLBACK                    = src.Instance_UpgradeHistoryEntry_ROLLBACK
	Instance_UpgradeHistoryEntry_STARTED                     = src.Instance_UpgradeHistoryEntry_STARTED
	Instance_UpgradeHistoryEntry_STATE_UNSPECIFIED           = src.Instance_UpgradeHistoryEntry_STATE_UNSPECIFIED
	Instance_UpgradeHistoryEntry_SUCCEEDED                   = src.Instance_UpgradeHistoryEntry_SUCCEEDED
	Instance_UpgradeHistoryEntry_UPGRADE                     = src.Instance_UpgradeHistoryEntry_UPGRADE
	Instance_VIRTIO_NET                                      = src.Instance_VIRTIO_NET
	LocalDiskInitializeParams_DISK_TYPE_UNSPECIFIED          = src.LocalDiskInitializeParams_DISK_TYPE_UNSPECIFIED
	LocalDiskInitializeParams_PD_BALANCED                    = src.LocalDiskInitializeParams_PD_BALANCED
	LocalDiskInitializeParams_PD_EXTREME                     = src.LocalDiskInitializeParams_PD_EXTREME
	LocalDiskInitializeParams_PD_SSD                         = src.LocalDiskInitializeParams_PD_SSD
	LocalDiskInitializeParams_PD_STANDARD                    = src.LocalDiskInitializeParams_PD_STANDARD
	ReservationAffinity_ANY_RESERVATION                      = src.ReservationAffinity_ANY_RESERVATION
	ReservationAffinity_NO_RESERVATION                       = src.ReservationAffinity_NO_RESERVATION
	ReservationAffinity_SPECIFIC_RESERVATION                 = src.ReservationAffinity_SPECIFIC_RESERVATION
	ReservationAffinity_TYPE_UNSPECIFIED                     = src.ReservationAffinity_TYPE_UNSPECIFIED
	RuntimeAcceleratorConfig_ACCELERATOR_TYPE_UNSPECIFIED    = src.RuntimeAcceleratorConfig_ACCELERATOR_TYPE_UNSPECIFIED
	RuntimeAcceleratorConfig_NVIDIA_TESLA_A100               = src.RuntimeAcceleratorConfig_NVIDIA_TESLA_A100
	RuntimeAcceleratorConfig_NVIDIA_TESLA_K80                = src.RuntimeAcceleratorConfig_NVIDIA_TESLA_K80
	RuntimeAcceleratorConfig_NVIDIA_TESLA_P100               = src.RuntimeAcceleratorConfig_NVIDIA_TESLA_P100
	RuntimeAcceleratorConfig_NVIDIA_TESLA_P100_VWS           = src.RuntimeAcceleratorConfig_NVIDIA_TESLA_P100_VWS
	RuntimeAcceleratorConfig_NVIDIA_TESLA_P4                 = src.RuntimeAcceleratorConfig_NVIDIA_TESLA_P4
	RuntimeAcceleratorConfig_NVIDIA_TESLA_P4_VWS             = src.RuntimeAcceleratorConfig_NVIDIA_TESLA_P4_VWS
	RuntimeAcceleratorConfig_NVIDIA_TESLA_T4                 = src.RuntimeAcceleratorConfig_NVIDIA_TESLA_T4
	RuntimeAcceleratorConfig_NVIDIA_TESLA_T4_VWS             = src.RuntimeAcceleratorConfig_NVIDIA_TESLA_T4_VWS
	RuntimeAcceleratorConfig_NVIDIA_TESLA_V100               = src.RuntimeAcceleratorConfig_NVIDIA_TESLA_V100
	RuntimeAcceleratorConfig_TPU_V2                          = src.RuntimeAcceleratorConfig_TPU_V2
	RuntimeAcceleratorConfig_TPU_V3                          = src.RuntimeAcceleratorConfig_TPU_V3
	RuntimeAccessConfig_RUNTIME_ACCESS_TYPE_UNSPECIFIED      = src.RuntimeAccessConfig_RUNTIME_ACCESS_TYPE_UNSPECIFIED
	RuntimeAccessConfig_SERVICE_ACCOUNT                      = src.RuntimeAccessConfig_SERVICE_ACCOUNT
	RuntimeAccessConfig_SINGLE_USER                          = src.RuntimeAccessConfig_SINGLE_USER
	Runtime_ACTIVE                                           = src.Runtime_ACTIVE
	Runtime_AGENT_NOT_INSTALLED                              = src.Runtime_AGENT_NOT_INSTALLED
	Runtime_AGENT_NOT_RUNNING                                = src.Runtime_AGENT_NOT_RUNNING
	Runtime_DELETING                                         = src.Runtime_DELETING
	Runtime_HEALTHY                                          = src.Runtime_HEALTHY
	Runtime_HEALTH_STATE_UNSPECIFIED                         = src.Runtime_HEALTH_STATE_UNSPECIFIED
	Runtime_INITIALIZING                                     = src.Runtime_INITIALIZING
	Runtime_PROVISIONING                                     = src.Runtime_PROVISIONING
	Runtime_STARTING                                         = src.Runtime_STARTING
	Runtime_STATE_UNSPECIFIED                                = src.Runtime_STATE_UNSPECIFIED
	Runtime_STOPPED                                          = src.Runtime_STOPPED
	Runtime_STOPPING                                         = src.Runtime_STOPPING
	Runtime_UNHEALTHY                                        = src.Runtime_UNHEALTHY
	Runtime_UPGRADING                                        = src.Runtime_UPGRADING
	Schedule_DELETING                                        = src.Schedule_DELETING
	Schedule_DISABLED                                        = src.Schedule_DISABLED
	Schedule_ENABLED                                         = src.Schedule_ENABLED
	Schedule_INITIALIZING                                    = src.Schedule_INITIALIZING
	Schedule_PAUSED                                          = src.Schedule_PAUSED
	Schedule_STATE_UNSPECIFIED                               = src.Schedule_STATE_UNSPECIFIED
	Schedule_UPDATE_FAILED                                   = src.Schedule_UPDATE_FAILED
	UpgradeType_UPGRADE_ALL                                  = src.UpgradeType_UPGRADE_ALL
	UpgradeType_UPGRADE_CUDA                                 = src.UpgradeType_UPGRADE_CUDA
	UpgradeType_UPGRADE_FRAMEWORK                            = src.UpgradeType_UPGRADE_FRAMEWORK
	UpgradeType_UPGRADE_OS                                   = src.UpgradeType_UPGRADE_OS
	UpgradeType_UPGRADE_TYPE_UNSPECIFIED                     = src.UpgradeType_UPGRADE_TYPE_UNSPECIFIED
	VirtualMachineConfig_GVNIC                               = src.VirtualMachineConfig_GVNIC
	VirtualMachineConfig_UNSPECIFIED_NIC_TYPE                = src.VirtualMachineConfig_UNSPECIFIED_NIC_TYPE
	VirtualMachineConfig_VIRTIO_NET                          = src.VirtualMachineConfig_VIRTIO_NET
)

// Deprecated: Please use vars in: cloud.google.com/go/notebooks/apiv1/notebookspb
var (
	Event_EventType_name                                 = src.Event_EventType_name
	Event_EventType_value                                = src.Event_EventType_value
	ExecutionTemplate_JobType_name                       = src.ExecutionTemplate_JobType_name
	ExecutionTemplate_JobType_value                      = src.ExecutionTemplate_JobType_value
	ExecutionTemplate_ScaleTier_name                     = src.ExecutionTemplate_ScaleTier_name
	ExecutionTemplate_ScaleTier_value                    = src.ExecutionTemplate_ScaleTier_value
	ExecutionTemplate_SchedulerAcceleratorType_name      = src.ExecutionTemplate_SchedulerAcceleratorType_name
	ExecutionTemplate_SchedulerAcceleratorType_value     = src.ExecutionTemplate_SchedulerAcceleratorType_value
	Execution_State_name                                 = src.Execution_State_name
	Execution_State_value                                = src.Execution_State_value
	File_google_cloud_notebooks_v1_environment_proto     = src.File_google_cloud_notebooks_v1_environment_proto
	File_google_cloud_notebooks_v1_event_proto           = src.File_google_cloud_notebooks_v1_event_proto
	File_google_cloud_notebooks_v1_execution_proto       = src.File_google_cloud_notebooks_v1_execution_proto
	File_google_cloud_notebooks_v1_instance_config_proto = src.File_google_cloud_notebooks_v1_instance_config_proto
	File_google_cloud_notebooks_v1_instance_proto        = src.File_google_cloud_notebooks_v1_instance_proto
	File_google_cloud_notebooks_v1_managed_service_proto = src.File_google_cloud_notebooks_v1_managed_service_proto
	File_google_cloud_notebooks_v1_runtime_proto         = src.File_google_cloud_notebooks_v1_runtime_proto
	File_google_cloud_notebooks_v1_schedule_proto        = src.File_google_cloud_notebooks_v1_schedule_proto
	File_google_cloud_notebooks_v1_service_proto         = src.File_google_cloud_notebooks_v1_service_proto
	GetInstanceHealthResponse_HealthState_name           = src.GetInstanceHealthResponse_HealthState_name
	GetInstanceHealthResponse_HealthState_value          = src.GetInstanceHealthResponse_HealthState_value
	Instance_AcceleratorType_name                        = src.Instance_AcceleratorType_name
	Instance_AcceleratorType_value                       = src.Instance_AcceleratorType_value
	Instance_DiskEncryption_name                         = src.Instance_DiskEncryption_name
	Instance_DiskEncryption_value                        = src.Instance_DiskEncryption_value
	Instance_DiskType_name                               = src.Instance_DiskType_name
	Instance_DiskType_value                              = src.Instance_DiskType_value
	Instance_NicType_name                                = src.Instance_NicType_name
	Instance_NicType_value                               = src.Instance_NicType_value
	Instance_State_name                                  = src.Instance_State_name
	Instance_State_value                                 = src.Instance_State_value
	Instance_UpgradeHistoryEntry_Action_name             = src.Instance_UpgradeHistoryEntry_Action_name
	Instance_UpgradeHistoryEntry_Action_value            = src.Instance_UpgradeHistoryEntry_Action_value
	Instance_UpgradeHistoryEntry_State_name              = src.Instance_UpgradeHistoryEntry_State_name
	Instance_UpgradeHistoryEntry_State_value             = src.Instance_UpgradeHistoryEntry_State_value
	LocalDiskInitializeParams_DiskType_name              = src.LocalDiskInitializeParams_DiskType_name
	LocalDiskInitializeParams_DiskType_value             = src.LocalDiskInitializeParams_DiskType_value
	ReservationAffinity_Type_name                        = src.ReservationAffinity_Type_name
	ReservationAffinity_Type_value                       = src.ReservationAffinity_Type_value
	RuntimeAcceleratorConfig_AcceleratorType_name        = src.RuntimeAcceleratorConfig_AcceleratorType_name
	RuntimeAcceleratorConfig_AcceleratorType_value       = src.RuntimeAcceleratorConfig_AcceleratorType_value
	RuntimeAccessConfig_RuntimeAccessType_name           = src.RuntimeAccessConfig_RuntimeAccessType_name
	RuntimeAccessConfig_RuntimeAccessType_value          = src.RuntimeAccessConfig_RuntimeAccessType_value
	Runtime_HealthState_name                             = src.Runtime_HealthState_name
	Runtime_HealthState_value                            = src.Runtime_HealthState_value
	Runtime_State_name                                   = src.Runtime_State_name
	Runtime_State_value                                  = src.Runtime_State_value
	Schedule_State_name                                  = src.Schedule_State_name
	Schedule_State_value                                 = src.Schedule_State_value
	UpgradeType_name                                     = src.UpgradeType_name
	UpgradeType_value                                    = src.UpgradeType_value
	VirtualMachineConfig_NicType_name                    = src.VirtualMachineConfig_NicType_name
	VirtualMachineConfig_NicType_value                   = src.VirtualMachineConfig_NicType_value
)

// Definition of a container image for starting a notebook instance with the
// environment installed in a container.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ContainerImage = src.ContainerImage

// Request for creating a notebook environment.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type CreateEnvironmentRequest = src.CreateEnvironmentRequest

// Request to create notebook execution
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type CreateExecutionRequest = src.CreateExecutionRequest

// Request for creating a notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type CreateInstanceRequest = src.CreateInstanceRequest

// Request for creating a Managed Notebook Runtime.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type CreateRuntimeRequest = src.CreateRuntimeRequest

// Request for created scheduled notebooks
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type CreateScheduleRequest = src.CreateScheduleRequest

// Request for deleting a notebook environment.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type DeleteEnvironmentRequest = src.DeleteEnvironmentRequest

// Request for deleting a scheduled notebook execution
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type DeleteExecutionRequest = src.DeleteExecutionRequest

// Request for deleting a notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type DeleteInstanceRequest = src.DeleteInstanceRequest

// Request for deleting a Managed Notebook Runtime.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type DeleteRuntimeRequest = src.DeleteRuntimeRequest

// Request for deleting an Schedule
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type DeleteScheduleRequest = src.DeleteScheduleRequest

// Represents a custom encryption key configuration that can be applied to a
// resource. This will encrypt all disks in Virtual Machine.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type EncryptionConfig = src.EncryptionConfig

// Definition of a software environment that is used to start a notebook
// instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Environment = src.Environment
type Environment_ContainerImage = src.Environment_ContainerImage
type Environment_VmImage = src.Environment_VmImage

// The definition of an Event for a managed / semi-managed notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Event = src.Event

// The definition of the event types.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Event_EventType = src.Event_EventType

// The definition of a single executed notebook.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Execution = src.Execution

// The description a notebook execution workload.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ExecutionTemplate = src.ExecutionTemplate

// Parameters used in Dataproc JobType executions.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ExecutionTemplate_DataprocParameters = src.ExecutionTemplate_DataprocParameters
type ExecutionTemplate_DataprocParameters_ = src.ExecutionTemplate_DataprocParameters_

// The backend used for this execution.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ExecutionTemplate_JobType = src.ExecutionTemplate_JobType

// Required. Specifies the machine types, the number of replicas for workers
// and parameter servers.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ExecutionTemplate_ScaleTier = src.ExecutionTemplate_ScaleTier

// Definition of a hardware accelerator. Note that not all combinations of
// `type` and `core_count` are valid. Check [GPUs on Compute
// Engine](https://cloud.google.com/compute/docs/gpus) to find a valid
// combination. TPUs are not supported.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ExecutionTemplate_SchedulerAcceleratorConfig = src.ExecutionTemplate_SchedulerAcceleratorConfig

// Hardware accelerator types for AI Platform Training jobs.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ExecutionTemplate_SchedulerAcceleratorType = src.ExecutionTemplate_SchedulerAcceleratorType

// Parameters used in Vertex AI JobType executions.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ExecutionTemplate_VertexAIParameters = src.ExecutionTemplate_VertexAIParameters
type ExecutionTemplate_VertexAiParameters = src.ExecutionTemplate_VertexAiParameters

// Enum description of the state of the underlying AIP job.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Execution_State = src.Execution_State

// Request for getting a notebook environment.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type GetEnvironmentRequest = src.GetEnvironmentRequest

// Request for getting scheduled notebook execution
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type GetExecutionRequest = src.GetExecutionRequest

// Request for checking if a notebook instance is healthy.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type GetInstanceHealthRequest = src.GetInstanceHealthRequest

// Response for checking if a notebook instance is healthy.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type GetInstanceHealthResponse = src.GetInstanceHealthResponse

// If an instance is healthy or not.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type GetInstanceHealthResponse_HealthState = src.GetInstanceHealthResponse_HealthState

// Request for getting a notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type GetInstanceRequest = src.GetInstanceRequest

// Request for getting a Managed Notebook Runtime.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type GetRuntimeRequest = src.GetRuntimeRequest

// Request for getting scheduled notebook.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type GetScheduleRequest = src.GetScheduleRequest

// The definition of a notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance = src.Instance

// Notebook instance configurations that can be updated.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type InstanceConfig = src.InstanceConfig

// Definition of a hardware accelerator. Note that not all combinations of
// `type` and `core_count` are valid. Check [GPUs on Compute
// Engine](/compute/docs/gpus/#gpus-list) to find a valid combination. TPUs are
// not supported.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_AcceleratorConfig = src.Instance_AcceleratorConfig

// Definition of the types of hardware accelerators that can be used on this
// instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_AcceleratorType = src.Instance_AcceleratorType
type Instance_ContainerImage = src.Instance_ContainerImage

// An instance-attached disk resource.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_Disk = src.Instance_Disk

// Definition of the disk encryption options.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_DiskEncryption = src.Instance_DiskEncryption

// Possible disk types for notebook instances.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_DiskType = src.Instance_DiskType

// Guest OS features for boot disk.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_Disk_GuestOsFeature = src.Instance_Disk_GuestOsFeature

// The type of vNIC driver. Default should be UNSPECIFIED_NIC_TYPE.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_NicType = src.Instance_NicType

// A set of Shielded Instance options. Check [Images using supported Shielded
// VM features] Not all combinations are valid.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_ShieldedInstanceConfig = src.Instance_ShieldedInstanceConfig

// The definition of the states of this instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_State = src.Instance_State

// The entry of VM image upgrade history.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_UpgradeHistoryEntry = src.Instance_UpgradeHistoryEntry

// The definition of operations of this upgrade history entry.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_UpgradeHistoryEntry_Action = src.Instance_UpgradeHistoryEntry_Action

// The definition of the states of this upgrade history entry.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Instance_UpgradeHistoryEntry_State = src.Instance_UpgradeHistoryEntry_State
type Instance_VmImage = src.Instance_VmImage

// Request for checking if a notebook instance is upgradeable.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type IsInstanceUpgradeableRequest = src.IsInstanceUpgradeableRequest

// Response for checking if a notebook instance is upgradeable.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type IsInstanceUpgradeableResponse = src.IsInstanceUpgradeableResponse

// Request for listing environments.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ListEnvironmentsRequest = src.ListEnvironmentsRequest

// Response for listing environments.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ListEnvironmentsResponse = src.ListEnvironmentsResponse

// Request for listing scheduled notebook executions.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ListExecutionsRequest = src.ListExecutionsRequest

// Response for listing scheduled notebook executions
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ListExecutionsResponse = src.ListExecutionsResponse

// Request for listing notebook instances.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ListInstancesRequest = src.ListInstancesRequest

// Response for listing notebook instances.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ListInstancesResponse = src.ListInstancesResponse

// Request for listing Managed Notebook Runtimes.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ListRuntimesRequest = src.ListRuntimesRequest

// Response for listing Managed Notebook Runtimes.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ListRuntimesResponse = src.ListRuntimesResponse

// Request for listing scheduled notebook job.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ListSchedulesRequest = src.ListSchedulesRequest

// Response for listing scheduled notebook job.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ListSchedulesResponse = src.ListSchedulesResponse

// A Local attached disk resource.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type LocalDisk = src.LocalDisk

// Input only. Specifies the parameters for a new disk that will be created
// alongside the new instance. Use initialization parameters to create boot
// disks or local SSDs attached to the new runtime. This property is mutually
// exclusive with the source property; you can only define one or the other,
// but not both.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type LocalDiskInitializeParams = src.LocalDiskInitializeParams

// Possible disk types.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type LocalDiskInitializeParams_DiskType = src.LocalDiskInitializeParams_DiskType

// Optional. A list of features to enable on the guest operating system.
// Applicable only for bootable images. Read [Enabling guest operating system
// features](https://cloud.google.com/compute/docs/images/create-delete-deprecate-private-images#guest-os-features)
// to see a list of available options. Guest OS features for boot disk.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type LocalDisk_RuntimeGuestOsFeature = src.LocalDisk_RuntimeGuestOsFeature

// ManagedNotebookServiceClient is the client API for ManagedNotebookService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ManagedNotebookServiceClient = src.ManagedNotebookServiceClient

// ManagedNotebookServiceServer is the server API for ManagedNotebookService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ManagedNotebookServiceServer = src.ManagedNotebookServiceServer

// NotebookServiceClient is the client API for NotebookService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type NotebookServiceClient = src.NotebookServiceClient

// NotebookServiceServer is the server API for NotebookService service.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type NotebookServiceServer = src.NotebookServiceServer

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type OperationMetadata = src.OperationMetadata

// Request for getting a new access token.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RefreshRuntimeTokenInternalRequest = src.RefreshRuntimeTokenInternalRequest

// Response with a new access token.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RefreshRuntimeTokenInternalResponse = src.RefreshRuntimeTokenInternalResponse

// Request for registering a notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RegisterInstanceRequest = src.RegisterInstanceRequest

// Request for notebook instances to report information to Notebooks API.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ReportInstanceInfoRequest = src.ReportInstanceInfoRequest

// Request for reporting a Managed Notebook Event.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ReportRuntimeEventRequest = src.ReportRuntimeEventRequest

// Reservation Affinity for consuming Zonal reservation.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ReservationAffinity = src.ReservationAffinity

// Indicates whether to consume capacity from an reservation or not.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ReservationAffinity_Type = src.ReservationAffinity_Type

// Request for resetting a notebook instance
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ResetInstanceRequest = src.ResetInstanceRequest

// Request for resetting a Managed Notebook Runtime.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type ResetRuntimeRequest = src.ResetRuntimeRequest

// Request for rollbacking a notebook instance
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RollbackInstanceRequest = src.RollbackInstanceRequest

// The definition of a Runtime for a managed notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Runtime = src.Runtime

// Definition of the types of hardware accelerators that can be used.
// Definition of the types of hardware accelerators that can be used. See
// [Compute Engine
// AcceleratorTypes](https://cloud.google.com/compute/docs/reference/beta/acceleratorTypes).
// Examples: * `nvidia-tesla-k80` * `nvidia-tesla-p100` * `nvidia-tesla-v100` *
// `nvidia-tesla-p4` * `nvidia-tesla-t4` * `nvidia-tesla-a100`
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RuntimeAcceleratorConfig = src.RuntimeAcceleratorConfig

// Type of this accelerator.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RuntimeAcceleratorConfig_AcceleratorType = src.RuntimeAcceleratorConfig_AcceleratorType

// Specifies the login configuration for Runtime
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RuntimeAccessConfig = src.RuntimeAccessConfig

// Possible ways to access runtime. Authentication mode. Currently supports:
// Single User only.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RuntimeAccessConfig_RuntimeAccessType = src.RuntimeAccessConfig_RuntimeAccessType

// Contains runtime daemon metrics, such as OS and kernels and sessions stats.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RuntimeMetrics = src.RuntimeMetrics

// A set of Shielded Instance options. Check [Images using supported Shielded
// VM
// features](https://cloud.google.com/compute/docs/instances/modifying-shielded-vm).
// Not all combinations are valid.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RuntimeShieldedInstanceConfig = src.RuntimeShieldedInstanceConfig

// Specifies the selection and configuration of software inside the runtime.
// The properties to set on runtime. Properties keys are specified in
// `key:value` format, for example: * `idle_shutdown: true` *
// `idle_shutdown_timeout: 180` * `enable_health_monitoring: true`
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type RuntimeSoftwareConfig = src.RuntimeSoftwareConfig

// The runtime substate.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Runtime_HealthState = src.Runtime_HealthState

// The definition of the states of this runtime.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Runtime_State = src.Runtime_State
type Runtime_VirtualMachine = src.Runtime_VirtualMachine

// The definition of a schedule.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Schedule = src.Schedule

// State of the job.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type Schedule_State = src.Schedule_State

// Request for setting instance accelerator.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type SetInstanceAcceleratorRequest = src.SetInstanceAcceleratorRequest

// Request for setting instance labels.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type SetInstanceLabelsRequest = src.SetInstanceLabelsRequest

// Request for setting instance machine type.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type SetInstanceMachineTypeRequest = src.SetInstanceMachineTypeRequest

// Request for starting a notebook instance
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type StartInstanceRequest = src.StartInstanceRequest

// Request for starting a Managed Notebook Runtime.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type StartRuntimeRequest = src.StartRuntimeRequest

// Request for stopping a notebook instance
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type StopInstanceRequest = src.StopInstanceRequest

// Request for stopping a Managed Notebook Runtime.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type StopRuntimeRequest = src.StopRuntimeRequest

// Request for switching a Managed Notebook Runtime.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type SwitchRuntimeRequest = src.SwitchRuntimeRequest

// Request for created scheduled notebooks
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type TriggerScheduleRequest = src.TriggerScheduleRequest

// UnimplementedManagedNotebookServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type UnimplementedManagedNotebookServiceServer = src.UnimplementedManagedNotebookServiceServer

// UnimplementedNotebookServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type UnimplementedNotebookServiceServer = src.UnimplementedNotebookServiceServer

// Request for updating instance configurations.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type UpdateInstanceConfigRequest = src.UpdateInstanceConfigRequest

// Request for adding/changing metadata items for an instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type UpdateInstanceMetadataItemsRequest = src.UpdateInstanceMetadataItemsRequest

// Response for adding/changing metadata items for an instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type UpdateInstanceMetadataItemsResponse = src.UpdateInstanceMetadataItemsResponse

// Request for updating the Shielded Instance config for a notebook instance.
// You can only use this method on a stopped instance
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type UpdateShieldedInstanceConfigRequest = src.UpdateShieldedInstanceConfigRequest

// Request for upgrading a notebook instance from within the VM
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type UpgradeInstanceInternalRequest = src.UpgradeInstanceInternalRequest

// Request for upgrading a notebook instance
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type UpgradeInstanceRequest = src.UpgradeInstanceRequest

// Definition of the types of upgrade that can be used on this instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type UpgradeType = src.UpgradeType

// Runtime using Virtual Machine for computing.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type VirtualMachine = src.VirtualMachine

// The config settings for virtual machine.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type VirtualMachineConfig = src.VirtualMachineConfig

// Definition of the boot image used by the Runtime. Used to facilitate
// runtime upgradeability.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type VirtualMachineConfig_BootImage = src.VirtualMachineConfig_BootImage

// The type of vNIC driver. Default should be UNSPECIFIED_NIC_TYPE.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type VirtualMachineConfig_NicType = src.VirtualMachineConfig_NicType

// Definition of a custom Compute Engine virtual machine image for starting a
// notebook instance with the environment installed directly on the VM.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1/notebookspb
type VmImage = src.VmImage
type VmImage_ImageFamily = src.VmImage_ImageFamily
type VmImage_ImageName = src.VmImage_ImageName

// Deprecated: Please use funcs in: cloud.google.com/go/notebooks/apiv1/notebookspb
func NewManagedNotebookServiceClient(cc grpc.ClientConnInterface) ManagedNotebookServiceClient {
	return src.NewManagedNotebookServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/notebooks/apiv1/notebookspb
func NewNotebookServiceClient(cc grpc.ClientConnInterface) NotebookServiceClient {
	return src.NewNotebookServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/notebooks/apiv1/notebookspb
func RegisterManagedNotebookServiceServer(s *grpc.Server, srv ManagedNotebookServiceServer) {
	src.RegisterManagedNotebookServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/notebooks/apiv1/notebookspb
func RegisterNotebookServiceServer(s *grpc.Server, srv NotebookServiceServer) {
	src.RegisterNotebookServiceServer(s, srv)
}
