// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package metricsscope aliases all exported identifiers in package
// "cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb".
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package metricsscope

import (
	src "cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
const (
	OperationMetadata_CANCELLED         = src.OperationMetadata_CANCELLED
	OperationMetadata_CREATED           = src.OperationMetadata_CREATED
	OperationMetadata_DONE              = src.OperationMetadata_DONE
	OperationMetadata_RUNNING           = src.OperationMetadata_RUNNING
	OperationMetadata_STATE_UNSPECIFIED = src.OperationMetadata_STATE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
var (
	File_google_monitoring_metricsscope_v1_metrics_scope_proto  = src.File_google_monitoring_metricsscope_v1_metrics_scope_proto
	File_google_monitoring_metricsscope_v1_metrics_scopes_proto = src.File_google_monitoring_metricsscope_v1_metrics_scopes_proto
	OperationMetadata_State_name                                = src.OperationMetadata_State_name
	OperationMetadata_State_value                               = src.OperationMetadata_State_value
)

// Request for the `CreateMonitoredProject` method.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type CreateMonitoredProjectRequest = src.CreateMonitoredProjectRequest

// Request for the `DeleteMonitoredProject` method.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type DeleteMonitoredProjectRequest = src.DeleteMonitoredProjectRequest

// Request for the `GetMetricsScope` method.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type GetMetricsScopeRequest = src.GetMetricsScopeRequest

// Request for the `ListMetricsScopesByMonitoredProject` method.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type ListMetricsScopesByMonitoredProjectRequest = src.ListMetricsScopesByMonitoredProjectRequest

// Response for the `ListMetricsScopesByMonitoredProject` method.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type ListMetricsScopesByMonitoredProjectResponse = src.ListMetricsScopesByMonitoredProjectResponse

// Represents a [Metrics
// Scope](https://cloud.google.com/monitoring/settings#concept-scope) in Cloud
// Monitoring, which specifies one or more Google projects and zero or more AWS
// accounts to monitor together.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type MetricsScope = src.MetricsScope

// MetricsScopesClient is the client API for MetricsScopes service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type MetricsScopesClient = src.MetricsScopesClient

// MetricsScopesServer is the server API for MetricsScopes service.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type MetricsScopesServer = src.MetricsScopesServer

// A [project being
// monitored](https://cloud.google.com/monitoring/settings/multiple-projects#create-multi)
// by a `Metrics Scope`.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type MonitoredProject = src.MonitoredProject

// Contains metadata for longrunning operation for the edit Metrics Scope
// endpoints.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type OperationMetadata = src.OperationMetadata

// Batch operation states.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type OperationMetadata_State = src.OperationMetadata_State

// UnimplementedMetricsScopesServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
type UnimplementedMetricsScopesServer = src.UnimplementedMetricsScopesServer

// Deprecated: Please use funcs in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
func NewMetricsScopesClient(cc grpc.ClientConnInterface) MetricsScopesClient {
	return src.NewMetricsScopesClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/monitoring/metricsscope/apiv1/metricsscopepb
func RegisterMetricsScopesServer(s *grpc.Server, srv MetricsScopesServer) {
	src.RegisterMetricsScopesServer(s, srv)
}
