// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package deploy aliases all exported identifiers in package
// "cloud.google.com/go/deploy/apiv1/deploypb".
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package deploy

import (
	src "cloud.google.com/go/deploy/apiv1/deploypb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/deploy/apiv1/deploypb
const (
	DeployJobRun_CLOUD_BUILD_UNAVAILABLE                    = src.DeployJobRun_CLOUD_BUILD_UNAVAILABLE
	DeployJobRun_DEADLINE_EXCEEDED                          = src.DeployJobRun_DEADLINE_EXCEEDED
	DeployJobRun_EXECUTION_FAILED                           = src.DeployJobRun_EXECUTION_FAILED
	DeployJobRun_FAILURE_CAUSE_UNSPECIFIED                  = src.DeployJobRun_FAILURE_CAUSE_UNSPECIFIED
	ExecutionConfig_DEPLOY                                  = src.ExecutionConfig_DEPLOY
	ExecutionConfig_EXECUTION_ENVIRONMENT_USAGE_UNSPECIFIED = src.ExecutionConfig_EXECUTION_ENVIRONMENT_USAGE_UNSPECIFIED
	ExecutionConfig_RENDER                                  = src.ExecutionConfig_RENDER
	ExecutionConfig_VERIFY                                  = src.ExecutionConfig_VERIFY
	JobRun_FAILED                                           = src.JobRun_FAILED
	JobRun_IN_PROGRESS                                      = src.JobRun_IN_PROGRESS
	JobRun_STATE_UNSPECIFIED                                = src.JobRun_STATE_UNSPECIFIED
	JobRun_SUCCEEDED                                        = src.JobRun_SUCCEEDED
	Job_ABORTED                                             = src.Job_ABORTED
	Job_DISABLED                                            = src.Job_DISABLED
	Job_FAILED                                              = src.Job_FAILED
	Job_IN_PROGRESS                                         = src.Job_IN_PROGRESS
	Job_PENDING                                             = src.Job_PENDING
	Job_STATE_UNSPECIFIED                                   = src.Job_STATE_UNSPECIFIED
	Job_SUCCEEDED                                           = src.Job_SUCCEEDED
	Phase_ABORTED                                           = src.Phase_ABORTED
	Phase_FAILED                                            = src.Phase_FAILED
	Phase_IN_PROGRESS                                       = src.Phase_IN_PROGRESS
	Phase_PENDING                                           = src.Phase_PENDING
	Phase_STATE_UNSPECIFIED                                 = src.Phase_STATE_UNSPECIFIED
	Phase_SUCCEEDED                                         = src.Phase_SUCCEEDED
	Release_FAILED                                          = src.Release_FAILED
	Release_IN_PROGRESS                                     = src.Release_IN_PROGRESS
	Release_RENDER_STATE_UNSPECIFIED                        = src.Release_RENDER_STATE_UNSPECIFIED
	Release_SUCCEEDED                                       = src.Release_SUCCEEDED
	Release_TargetRender_CLOUD_BUILD_UNAVAILABLE            = src.Release_TargetRender_CLOUD_BUILD_UNAVAILABLE
	Release_TargetRender_EXECUTION_FAILED                   = src.Release_TargetRender_EXECUTION_FAILED
	Release_TargetRender_FAILED                             = src.Release_TargetRender_FAILED
	Release_TargetRender_FAILURE_CAUSE_UNSPECIFIED          = src.Release_TargetRender_FAILURE_CAUSE_UNSPECIFIED
	Release_TargetRender_IN_PROGRESS                        = src.Release_TargetRender_IN_PROGRESS
	Release_TargetRender_SUCCEEDED                          = src.Release_TargetRender_SUCCEEDED
	Release_TargetRender_TARGET_RENDER_STATE_UNSPECIFIED    = src.Release_TargetRender_TARGET_RENDER_STATE_UNSPECIFIED
	Rollout_APPROVAL_REJECTED                               = src.Rollout_APPROVAL_REJECTED
	Rollout_APPROVAL_STATE_UNSPECIFIED                      = src.Rollout_APPROVAL_STATE_UNSPECIFIED
	Rollout_APPROVED                                        = src.Rollout_APPROVED
	Rollout_CLOUD_BUILD_UNAVAILABLE                         = src.Rollout_CLOUD_BUILD_UNAVAILABLE
	Rollout_DEADLINE_EXCEEDED                               = src.Rollout_DEADLINE_EXCEEDED
	Rollout_DOES_NOT_NEED_APPROVAL                          = src.Rollout_DOES_NOT_NEED_APPROVAL
	Rollout_EXECUTION_FAILED                                = src.Rollout_EXECUTION_FAILED
	Rollout_FAILED                                          = src.Rollout_FAILED
	Rollout_FAILURE_CAUSE_UNSPECIFIED                       = src.Rollout_FAILURE_CAUSE_UNSPECIFIED
	Rollout_IN_PROGRESS                                     = src.Rollout_IN_PROGRESS
	Rollout_NEEDS_APPROVAL                                  = src.Rollout_NEEDS_APPROVAL
	Rollout_PENDING                                         = src.Rollout_PENDING
	Rollout_PENDING_APPROVAL                                = src.Rollout_PENDING_APPROVAL
	Rollout_PENDING_RELEASE                                 = src.Rollout_PENDING_RELEASE
	Rollout_REJECTED                                        = src.Rollout_REJECTED
	Rollout_RELEASE_ABANDONED                               = src.Rollout_RELEASE_ABANDONED
	Rollout_RELEASE_FAILED                                  = src.Rollout_RELEASE_FAILED
	Rollout_STATE_UNSPECIFIED                               = src.Rollout_STATE_UNSPECIFIED
	Rollout_SUCCEEDED                                       = src.Rollout_SUCCEEDED
	Rollout_VERIFICATION_CONFIG_NOT_FOUND                   = src.Rollout_VERIFICATION_CONFIG_NOT_FOUND
	Type_TYPE_PUBSUB_NOTIFICATION_FAILURE                   = src.Type_TYPE_PUBSUB_NOTIFICATION_FAILURE
	Type_TYPE_RENDER_STATUES_CHANGE                         = src.Type_TYPE_RENDER_STATUES_CHANGE
	Type_TYPE_UNSPECIFIED                                   = src.Type_TYPE_UNSPECIFIED
	VerifyJobRun_CLOUD_BUILD_UNAVAILABLE                    = src.VerifyJobRun_CLOUD_BUILD_UNAVAILABLE
	VerifyJobRun_DEADLINE_EXCEEDED                          = src.VerifyJobRun_DEADLINE_EXCEEDED
	VerifyJobRun_EXECUTION_FAILED                           = src.VerifyJobRun_EXECUTION_FAILED
	VerifyJobRun_FAILURE_CAUSE_UNSPECIFIED                  = src.VerifyJobRun_FAILURE_CAUSE_UNSPECIFIED
	VerifyJobRun_VERIFICATION_CONFIG_NOT_FOUND              = src.VerifyJobRun_VERIFICATION_CONFIG_NOT_FOUND
)

// Deprecated: Please use vars in: cloud.google.com/go/deploy/apiv1/deploypb
var (
	DeployJobRun_FailureCause_name                                          = src.DeployJobRun_FailureCause_name
	DeployJobRun_FailureCause_value                                         = src.DeployJobRun_FailureCause_value
	ExecutionConfig_ExecutionEnvironmentUsage_name                          = src.ExecutionConfig_ExecutionEnvironmentUsage_name
	ExecutionConfig_ExecutionEnvironmentUsage_value                         = src.ExecutionConfig_ExecutionEnvironmentUsage_value
	File_google_cloud_deploy_v1_cloud_deploy_proto                          = src.File_google_cloud_deploy_v1_cloud_deploy_proto
	File_google_cloud_deploy_v1_deliverypipeline_notification_payload_proto = src.File_google_cloud_deploy_v1_deliverypipeline_notification_payload_proto
	File_google_cloud_deploy_v1_jobrun_notification_payload_proto           = src.File_google_cloud_deploy_v1_jobrun_notification_payload_proto
	File_google_cloud_deploy_v1_log_enums_proto                             = src.File_google_cloud_deploy_v1_log_enums_proto
	File_google_cloud_deploy_v1_release_notification_payload_proto          = src.File_google_cloud_deploy_v1_release_notification_payload_proto
	File_google_cloud_deploy_v1_release_render_payload_proto                = src.File_google_cloud_deploy_v1_release_render_payload_proto
	File_google_cloud_deploy_v1_rollout_notification_payload_proto          = src.File_google_cloud_deploy_v1_rollout_notification_payload_proto
	File_google_cloud_deploy_v1_target_notification_payload_proto           = src.File_google_cloud_deploy_v1_target_notification_payload_proto
	JobRun_State_name                                                       = src.JobRun_State_name
	JobRun_State_value                                                      = src.JobRun_State_value
	Job_State_name                                                          = src.Job_State_name
	Job_State_value                                                         = src.Job_State_value
	Phase_State_name                                                        = src.Phase_State_name
	Phase_State_value                                                       = src.Phase_State_value
	Release_RenderState_name                                                = src.Release_RenderState_name
	Release_RenderState_value                                               = src.Release_RenderState_value
	Release_TargetRender_FailureCause_name                                  = src.Release_TargetRender_FailureCause_name
	Release_TargetRender_FailureCause_value                                 = src.Release_TargetRender_FailureCause_value
	Release_TargetRender_TargetRenderState_name                             = src.Release_TargetRender_TargetRenderState_name
	Release_TargetRender_TargetRenderState_value                            = src.Release_TargetRender_TargetRenderState_value
	Rollout_ApprovalState_name                                              = src.Rollout_ApprovalState_name
	Rollout_ApprovalState_value                                             = src.Rollout_ApprovalState_value
	Rollout_FailureCause_name                                               = src.Rollout_FailureCause_name
	Rollout_FailureCause_value                                              = src.Rollout_FailureCause_value
	Rollout_State_name                                                      = src.Rollout_State_name
	Rollout_State_value                                                     = src.Rollout_State_value
	Type_name                                                               = src.Type_name
	Type_value                                                              = src.Type_value
	VerifyJobRun_FailureCause_name                                          = src.VerifyJobRun_FailureCause_name
	VerifyJobRun_FailureCause_value                                         = src.VerifyJobRun_FailureCause_value
)

// The request object used by `AbandonRelease`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type AbandonReleaseRequest = src.AbandonReleaseRequest

// The response object for `AbandonRelease`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type AbandonReleaseResponse = src.AbandonReleaseResponse

// Information specifying an Anthos Cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type AnthosCluster = src.AnthosCluster

// The request object used by `ApproveRollout`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ApproveRolloutRequest = src.ApproveRolloutRequest

// The response object from `ApproveRollout`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ApproveRolloutResponse = src.ApproveRolloutResponse

// Description of an a image to use during Skaffold rendering.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type BuildArtifact = src.BuildArtifact

// CloudDeployClient is the client API for CloudDeploy service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type CloudDeployClient = src.CloudDeployClient

// CloudDeployServer is the server API for CloudDeploy service.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type CloudDeployServer = src.CloudDeployServer

// Information specifying where to deploy a Cloud Run Service.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type CloudRunLocation = src.CloudRunLocation

// CloudRunMetadata contains information from a Cloud Run deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type CloudRunMetadata = src.CloudRunMetadata

// Service-wide configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Config = src.Config

// The request object for `CreateDeliveryPipeline`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type CreateDeliveryPipelineRequest = src.CreateDeliveryPipelineRequest

// The request object for `CreateRelease`,
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type CreateReleaseRequest = src.CreateReleaseRequest

// CreateRolloutRequest is the request object used by `CreateRollout`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type CreateRolloutRequest = src.CreateRolloutRequest

// The request object for `CreateTarget`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type CreateTargetRequest = src.CreateTargetRequest

// Execution using the default Cloud Build pool.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type DefaultPool = src.DefaultPool

// The request object for `DeleteDeliveryPipeline`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type DeleteDeliveryPipelineRequest = src.DeleteDeliveryPipelineRequest

// The request object for `DeleteTarget`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type DeleteTargetRequest = src.DeleteTargetRequest

// A `DeliveryPipeline` resource in the Google Cloud Deploy API. A
// `DeliveryPipeline` defines a pipeline through which a Skaffold configuration
// can progress.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type DeliveryPipeline = src.DeliveryPipeline

// Payload proto for
// "clouddeploy.googleapis.com/deliverypipeline_notification" Platform Log
// event that describes the failure to send delivery pipeline status change
// Pub/Sub notification.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type DeliveryPipelineNotificationEvent = src.DeliveryPipelineNotificationEvent
type DeliveryPipeline_SerialPipeline = src.DeliveryPipeline_SerialPipeline

// A deploy Job.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type DeployJob = src.DeployJob

// DeployJobRun contains information specific to a deploy `JobRun`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type DeployJobRun = src.DeployJobRun

// DeployJobRunMetadata surfaces information associated with a `DeployJobRun`
// to the user.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type DeployJobRunMetadata = src.DeployJobRunMetadata

// Well-known deploy failures.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type DeployJobRun_FailureCause = src.DeployJobRun_FailureCause

// Deployment job composition.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type DeploymentJobs = src.DeploymentJobs

// Configuration of the environment to use when calling Skaffold.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ExecutionConfig = src.ExecutionConfig
type ExecutionConfig_DefaultPool = src.ExecutionConfig_DefaultPool

// Possible usages of this configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ExecutionConfig_ExecutionEnvironmentUsage = src.ExecutionConfig_ExecutionEnvironmentUsage
type ExecutionConfig_PrivatePool = src.ExecutionConfig_PrivatePool

// Request to get a configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type GetConfigRequest = src.GetConfigRequest

// The request object for `GetDeliveryPipeline`
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type GetDeliveryPipelineRequest = src.GetDeliveryPipelineRequest

// GetJobRunRequest is the request object used by `GetJobRun`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type GetJobRunRequest = src.GetJobRunRequest

// The request object for `GetRelease`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type GetReleaseRequest = src.GetReleaseRequest

// GetRolloutRequest is the request object used by `GetRollout`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type GetRolloutRequest = src.GetRolloutRequest

// The request object for `GetTarget`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type GetTargetRequest = src.GetTargetRequest

// Information specifying a GKE Cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type GkeCluster = src.GkeCluster

// Job represents an operation for a `Rollout`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Job = src.Job

// A `JobRun` resource in the Google Cloud Deploy API. A `JobRun` contains
// information of a single `Rollout` job evaluation.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type JobRun = src.JobRun

// Payload proto for "clouddeploy.googleapis.com/jobrun_notification" Platform
// Log event that describes the failure to send JobRun resource update Pub/Sub
// notification.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type JobRunNotificationEvent = src.JobRunNotificationEvent
type JobRun_DeployJobRun = src.JobRun_DeployJobRun

// Valid states of a `JobRun`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type JobRun_State = src.JobRun_State
type JobRun_VerifyJobRun = src.JobRun_VerifyJobRun
type Job_DeployJob = src.Job_DeployJob

// Valid states of a Job.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Job_State = src.Job_State
type Job_VerifyJob = src.Job_VerifyJob

// The request object for `ListDeliveryPipelines`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ListDeliveryPipelinesRequest = src.ListDeliveryPipelinesRequest

// The response object from `ListDeliveryPipelines`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ListDeliveryPipelinesResponse = src.ListDeliveryPipelinesResponse

// ListJobRunsRequest is the request object used by `ListJobRuns`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ListJobRunsRequest = src.ListJobRunsRequest

// ListJobRunsResponse is the response object returned by `ListJobRuns`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ListJobRunsResponse = src.ListJobRunsResponse

// The request object for `ListReleases`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ListReleasesRequest = src.ListReleasesRequest

// The response object from `ListReleases`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ListReleasesResponse = src.ListReleasesResponse

// ListRolloutsRequest is the request object used by `ListRollouts`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ListRolloutsRequest = src.ListRolloutsRequest

// ListRolloutsResponse is the response object reutrned by `ListRollouts`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ListRolloutsResponse = src.ListRolloutsResponse

// The request object for `ListTargets`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ListTargetsRequest = src.ListTargetsRequest

// The response object from `ListTargets`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ListTargetsResponse = src.ListTargetsResponse

// Metadata includes information associated with a `Rollout`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Metadata = src.Metadata

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type OperationMetadata = src.OperationMetadata

// Phase represents a collection of jobs that are logically grouped together
// for a `Rollout`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Phase = src.Phase
type Phase_DeploymentJobs = src.Phase_DeploymentJobs

// Valid states of a Phase.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Phase_State = src.Phase_State

// PipelineCondition contains all conditions relevant to a Delivery Pipeline.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type PipelineCondition = src.PipelineCondition

// PipelineReadyCondition contains information around the status of the
// Pipeline.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type PipelineReadyCondition = src.PipelineReadyCondition

// Execution using a private Cloud Build pool.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type PrivatePool = src.PrivatePool

// A `Release` resource in the Google Cloud Deploy API. A `Release` defines a
// specific Skaffold configuration instance that can be deployed.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Release = src.Release

// Payload proto for "clouddeploy.googleapis.com/release_notification"
// Platform Log event that describes the failure to send release status change
// Pub/Sub notification.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ReleaseNotificationEvent = src.ReleaseNotificationEvent

// Payload proto for "clouddeploy.googleapis.com/release_render" Platform Log
// event that describes the render status change.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type ReleaseRenderEvent = src.ReleaseRenderEvent

// Valid states of the render operation.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Release_RenderState = src.Release_RenderState

// Details of rendering for a single target.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Release_TargetRender = src.Release_TargetRender

// Well-known rendering failures.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Release_TargetRender_FailureCause = src.Release_TargetRender_FailureCause

// Valid states of the render operation.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Release_TargetRender_TargetRenderState = src.Release_TargetRender_TargetRenderState

// RetryJobRequest is the request object used by `RetryJob`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type RetryJobRequest = src.RetryJobRequest

// The response object from 'RetryJob'.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type RetryJobResponse = src.RetryJobResponse

// A `Rollout` resource in the Google Cloud Deploy API. A `Rollout` contains
// information around a specific deployment to a `Target`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Rollout = src.Rollout

// Payload proto for "clouddeploy.googleapis.com/rollout_notification"
// Platform Log event that describes the failure to send rollout status change
// Pub/Sub notification.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type RolloutNotificationEvent = src.RolloutNotificationEvent

// Valid approval states of a `Rollout`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Rollout_ApprovalState = src.Rollout_ApprovalState

// Well-known rollout failures.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Rollout_FailureCause = src.Rollout_FailureCause

// Valid states of a `Rollout`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Rollout_State = src.Rollout_State

// SerialPipeline defines a sequential set of stages for a `DeliveryPipeline`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type SerialPipeline = src.SerialPipeline

// Details of a supported Skaffold version.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type SkaffoldVersion = src.SkaffoldVersion

// Stage specifies a location to which to deploy.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Stage = src.Stage

// Standard represents the standard deployment strategy.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Standard = src.Standard

// Strategy contains deployment strategy information.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Strategy = src.Strategy
type Strategy_Standard = src.Strategy_Standard

// A `Target` resource in the Google Cloud Deploy API. A `Target` defines a
// location to which a Skaffold configuration can be deployed.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Target = src.Target

// The artifacts produced by a target render operation.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type TargetArtifact = src.TargetArtifact
type TargetArtifact_ArtifactUri = src.TargetArtifact_ArtifactUri

// Payload proto for "clouddeploy.googleapis.com/target_notification" Platform
// Log event that describes the failure to send target status change Pub/Sub
// notification.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type TargetNotificationEvent = src.TargetNotificationEvent
type Target_AnthosCluster = src.Target_AnthosCluster
type Target_Gke = src.Target_Gke
type Target_Run = src.Target_Run

// TargetsPresentCondition contains information on any Targets defined in the
// Delivery Pipeline that do not actually exist.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type TargetsPresentCondition = src.TargetsPresentCondition

// Type indicates the type of the log entry and can be used as a filter.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type Type = src.Type

// UnimplementedCloudDeployServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type UnimplementedCloudDeployServer = src.UnimplementedCloudDeployServer

// The request object for `UpdateDeliveryPipeline`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type UpdateDeliveryPipelineRequest = src.UpdateDeliveryPipelineRequest

// The request object for `UpdateTarget`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type UpdateTargetRequest = src.UpdateTargetRequest

// A verify Job.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type VerifyJob = src.VerifyJob

// VerifyJobRun contains information specific to a verify `JobRun`.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type VerifyJobRun = src.VerifyJobRun

// Well-known verify failures.
//
// Deprecated: Please use types in: cloud.google.com/go/deploy/apiv1/deploypb
type VerifyJobRun_FailureCause = src.VerifyJobRun_FailureCause

// Deprecated: Please use funcs in: cloud.google.com/go/deploy/apiv1/deploypb
func NewCloudDeployClient(cc grpc.ClientConnInterface) CloudDeployClient {
	return src.NewCloudDeployClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/deploy/apiv1/deploypb
func RegisterCloudDeployServer(s *grpc.Server, srv CloudDeployServer) {
	src.RegisterCloudDeployServer(s, srv)
}
