// Copyright 2021 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.26.0
// 	protoc        v3.12.2
// source: google/cloud/gsuiteaddons/logging/v1/g_suite_add_ons_log_entry.proto

package logging

import (
	reflect "reflect"
	sync "sync"

	status "google.golang.org/genproto/googleapis/rpc/status"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

// JSON payload of error messages that are logged to Cloud Logging. An error
// message (in English) is written to Cloud Logging (if not disabled) when an
// error is encountered while using an add-on.
type GSuiteAddOnsLogEntry struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// The deployment that caused the error. For add-ons built in Apps Script,
	// this is the deployment ID defined by Apps Script. For add-ons built in
	// other languages, this is the deployment ID defined in Google Cloud.
	Deployment string `protobuf:"bytes,1,opt,name=deployment,proto3" json:"deployment,omitempty"`
	// The error code and message.
	Error *status.Status `protobuf:"bytes,2,opt,name=error,proto3" json:"error,omitempty"`
	// The function name that was running when the error occurred. This field
	// might not always be set, for example, if an error happens when fetching the
	// list of installed add-ons for a user.
	DeploymentFunction string `protobuf:"bytes,3,opt,name=deployment_function,json=deploymentFunction,proto3" json:"deployment_function,omitempty"`
}

func (x *GSuiteAddOnsLogEntry) Reset() {
	*x = GSuiteAddOnsLogEntry{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *GSuiteAddOnsLogEntry) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GSuiteAddOnsLogEntry) ProtoMessage() {}

func (x *GSuiteAddOnsLogEntry) ProtoReflect() protoreflect.Message {
	mi := &file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GSuiteAddOnsLogEntry.ProtoReflect.Descriptor instead.
func (*GSuiteAddOnsLogEntry) Descriptor() ([]byte, []int) {
	return file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDescGZIP(), []int{0}
}

func (x *GSuiteAddOnsLogEntry) GetDeployment() string {
	if x != nil {
		return x.Deployment
	}
	return ""
}

func (x *GSuiteAddOnsLogEntry) GetError() *status.Status {
	if x != nil {
		return x.Error
	}
	return nil
}

func (x *GSuiteAddOnsLogEntry) GetDeploymentFunction() string {
	if x != nil {
		return x.DeploymentFunction
	}
	return ""
}

var File_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto protoreflect.FileDescriptor

var file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDesc = []byte{
	0x0a, 0x44, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2f, 0x63, 0x6c, 0x6f, 0x75, 0x64, 0x2f, 0x67,
	0x73, 0x75, 0x69, 0x74, 0x65, 0x61, 0x64, 0x64, 0x6f, 0x6e, 0x73, 0x2f, 0x6c, 0x6f, 0x67, 0x67,
	0x69, 0x6e, 0x67, 0x2f, 0x76, 0x31, 0x2f, 0x67, 0x5f, 0x73, 0x75, 0x69, 0x74, 0x65, 0x5f, 0x61,
	0x64, 0x64, 0x5f, 0x6f, 0x6e, 0x73, 0x5f, 0x6c, 0x6f, 0x67, 0x5f, 0x65, 0x6e, 0x74, 0x72, 0x79,
	0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x24, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63,
	0x6c, 0x6f, 0x75, 0x64, 0x2e, 0x67, 0x73, 0x75, 0x69, 0x74, 0x65, 0x61, 0x64, 0x64, 0x6f, 0x6e,
	0x73, 0x2e, 0x6c, 0x6f, 0x67, 0x67, 0x69, 0x6e, 0x67, 0x2e, 0x76, 0x31, 0x1a, 0x17, 0x67, 0x6f,
	0x6f, 0x67, 0x6c, 0x65, 0x2f, 0x72, 0x70, 0x63, 0x2f, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x2e,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0x91, 0x01, 0x0a, 0x14, 0x47, 0x53, 0x75, 0x69, 0x74, 0x65,
	0x41, 0x64, 0x64, 0x4f, 0x6e, 0x73, 0x4c, 0x6f, 0x67, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x1e,
	0x0a, 0x0a, 0x64, 0x65, 0x70, 0x6c, 0x6f, 0x79, 0x6d, 0x65, 0x6e, 0x74, 0x18, 0x01, 0x20, 0x01,
	0x28, 0x09, 0x52, 0x0a, 0x64, 0x65, 0x70, 0x6c, 0x6f, 0x79, 0x6d, 0x65, 0x6e, 0x74, 0x12, 0x28,
	0x0a, 0x05, 0x65, 0x72, 0x72, 0x6f, 0x72, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x12, 0x2e,
	0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x72, 0x70, 0x63, 0x2e, 0x53, 0x74, 0x61, 0x74, 0x75,
	0x73, 0x52, 0x05, 0x65, 0x72, 0x72, 0x6f, 0x72, 0x12, 0x2f, 0x0a, 0x13, 0x64, 0x65, 0x70, 0x6c,
	0x6f, 0x79, 0x6d, 0x65, 0x6e, 0x74, 0x5f, 0x66, 0x75, 0x6e, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x18,
	0x03, 0x20, 0x01, 0x28, 0x09, 0x52, 0x12, 0x64, 0x65, 0x70, 0x6c, 0x6f, 0x79, 0x6d, 0x65, 0x6e,
	0x74, 0x46, 0x75, 0x6e, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x42, 0x8d, 0x02, 0x0a, 0x28, 0x63, 0x6f,
	0x6d, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x63, 0x6c, 0x6f, 0x75, 0x64, 0x2e, 0x67,
	0x73, 0x75, 0x69, 0x74, 0x65, 0x61, 0x64, 0x64, 0x6f, 0x6e, 0x73, 0x2e, 0x6c, 0x6f, 0x67, 0x67,
	0x69, 0x6e, 0x67, 0x2e, 0x76, 0x31, 0x42, 0x19, 0x47, 0x53, 0x75, 0x69, 0x74, 0x65, 0x41, 0x64,
	0x64, 0x4f, 0x6e, 0x73, 0x4c, 0x6f, 0x67, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x50, 0x72, 0x6f, 0x74,
	0x6f, 0x50, 0x01, 0x5a, 0x4b, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x67, 0x6f, 0x6c, 0x61,
	0x6e, 0x67, 0x2e, 0x6f, 0x72, 0x67, 0x2f, 0x67, 0x65, 0x6e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2f,
	0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70, 0x69, 0x73, 0x2f, 0x63, 0x6c, 0x6f, 0x75, 0x64,
	0x2f, 0x67, 0x73, 0x75, 0x69, 0x74, 0x65, 0x61, 0x64, 0x64, 0x6f, 0x6e, 0x73, 0x2f, 0x6c, 0x6f,
	0x67, 0x67, 0x69, 0x6e, 0x67, 0x2f, 0x76, 0x31, 0x3b, 0x6c, 0x6f, 0x67, 0x67, 0x69, 0x6e, 0x67,
	0xaa, 0x02, 0x24, 0x47, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x43, 0x6c, 0x6f, 0x75, 0x64, 0x2e,
	0x47, 0x53, 0x75, 0x69, 0x74, 0x65, 0x41, 0x64, 0x64, 0x4f, 0x6e, 0x73, 0x2e, 0x4c, 0x6f, 0x67,
	0x67, 0x69, 0x6e, 0x67, 0x2e, 0x56, 0x31, 0xca, 0x02, 0x24, 0x47, 0x6f, 0x6f, 0x67, 0x6c, 0x65,
	0x5c, 0x43, 0x6c, 0x6f, 0x75, 0x64, 0x5c, 0x47, 0x53, 0x75, 0x69, 0x74, 0x65, 0x41, 0x64, 0x64,
	0x4f, 0x6e, 0x73, 0x5c, 0x4c, 0x6f, 0x67, 0x67, 0x69, 0x6e, 0x67, 0x5c, 0x56, 0x31, 0xea, 0x02,
	0x28, 0x47, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x3a, 0x3a, 0x43, 0x6c, 0x6f, 0x75, 0x64, 0x3a, 0x3a,
	0x47, 0x53, 0x75, 0x69, 0x74, 0x65, 0x41, 0x64, 0x64, 0x4f, 0x6e, 0x73, 0x3a, 0x3a, 0x4c, 0x6f,
	0x67, 0x67, 0x69, 0x6e, 0x67, 0x3a, 0x3a, 0x56, 0x31, 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f,
	0x33,
}

var (
	file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDescOnce sync.Once
	file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDescData = file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDesc
)

func file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDescGZIP() []byte {
	file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDescOnce.Do(func() {
		file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDescData = protoimpl.X.CompressGZIP(file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDescData)
	})
	return file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDescData
}

var file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_goTypes = []interface{}{
	(*GSuiteAddOnsLogEntry)(nil), // 0: google.cloud.gsuiteaddons.logging.v1.GSuiteAddOnsLogEntry
	(*status.Status)(nil),        // 1: google.rpc.Status
}
var file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_depIdxs = []int32{
	1, // 0: google.cloud.gsuiteaddons.logging.v1.GSuiteAddOnsLogEntry.error:type_name -> google.rpc.Status
	1, // [1:1] is the sub-list for method output_type
	1, // [1:1] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_init() }
func file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_init() {
	if File_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*GSuiteAddOnsLogEntry); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_goTypes,
		DependencyIndexes: file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_depIdxs,
		MessageInfos:      file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_msgTypes,
	}.Build()
	File_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto = out.File
	file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_rawDesc = nil
	file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_goTypes = nil
	file_google_cloud_gsuiteaddons_logging_v1_g_suite_add_ons_log_entry_proto_depIdxs = nil
}
