// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package gkebackup aliases all exported identifiers in package
// "cloud.google.com/go/gkebackup/apiv1/gkebackuppb".
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package gkebackup

import (
	src "cloud.google.com/go/gkebackup/apiv1/gkebackuppb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
const (
	Backup_CREATING                                            = src.Backup_CREATING
	Backup_DELETING                                            = src.Backup_DELETING
	Backup_FAILED                                              = src.Backup_FAILED
	Backup_IN_PROGRESS                                         = src.Backup_IN_PROGRESS
	Backup_STATE_UNSPECIFIED                                   = src.Backup_STATE_UNSPECIFIED
	Backup_SUCCEEDED                                           = src.Backup_SUCCEEDED
	RestoreConfig_CLUSTER_RESOURCE_CONFLICT_POLICY_UNSPECIFIED = src.RestoreConfig_CLUSTER_RESOURCE_CONFLICT_POLICY_UNSPECIFIED
	RestoreConfig_DELETE_AND_RESTORE                           = src.RestoreConfig_DELETE_AND_RESTORE
	RestoreConfig_FAIL_ON_CONFLICT                             = src.RestoreConfig_FAIL_ON_CONFLICT
	RestoreConfig_NAMESPACED_RESOURCE_RESTORE_MODE_UNSPECIFIED = src.RestoreConfig_NAMESPACED_RESOURCE_RESTORE_MODE_UNSPECIFIED
	RestoreConfig_NO_VOLUME_DATA_RESTORATION                   = src.RestoreConfig_NO_VOLUME_DATA_RESTORATION
	RestoreConfig_RESTORE_VOLUME_DATA_FROM_BACKUP              = src.RestoreConfig_RESTORE_VOLUME_DATA_FROM_BACKUP
	RestoreConfig_REUSE_VOLUME_HANDLE_FROM_BACKUP              = src.RestoreConfig_REUSE_VOLUME_HANDLE_FROM_BACKUP
	RestoreConfig_USE_BACKUP_VERSION                           = src.RestoreConfig_USE_BACKUP_VERSION
	RestoreConfig_USE_EXISTING_VERSION                         = src.RestoreConfig_USE_EXISTING_VERSION
	RestoreConfig_VOLUME_DATA_RESTORE_POLICY_UNSPECIFIED       = src.RestoreConfig_VOLUME_DATA_RESTORE_POLICY_UNSPECIFIED
	Restore_CREATING                                           = src.Restore_CREATING
	Restore_DELETING                                           = src.Restore_DELETING
	Restore_FAILED                                             = src.Restore_FAILED
	Restore_IN_PROGRESS                                        = src.Restore_IN_PROGRESS
	Restore_STATE_UNSPECIFIED                                  = src.Restore_STATE_UNSPECIFIED
	Restore_SUCCEEDED                                          = src.Restore_SUCCEEDED
	VolumeBackup_CREATING                                      = src.VolumeBackup_CREATING
	VolumeBackup_DELETING                                      = src.VolumeBackup_DELETING
	VolumeBackup_FAILED                                        = src.VolumeBackup_FAILED
	VolumeBackup_GCE_PERSISTENT_DISK                           = src.VolumeBackup_GCE_PERSISTENT_DISK
	VolumeBackup_SNAPSHOTTING                                  = src.VolumeBackup_SNAPSHOTTING
	VolumeBackup_STATE_UNSPECIFIED                             = src.VolumeBackup_STATE_UNSPECIFIED
	VolumeBackup_SUCCEEDED                                     = src.VolumeBackup_SUCCEEDED
	VolumeBackup_UPLOADING                                     = src.VolumeBackup_UPLOADING
	VolumeBackup_VOLUME_BACKUP_FORMAT_UNSPECIFIED              = src.VolumeBackup_VOLUME_BACKUP_FORMAT_UNSPECIFIED
	VolumeRestore_CREATING                                     = src.VolumeRestore_CREATING
	VolumeRestore_DELETING                                     = src.VolumeRestore_DELETING
	VolumeRestore_FAILED                                       = src.VolumeRestore_FAILED
	VolumeRestore_GCE_PERSISTENT_DISK                          = src.VolumeRestore_GCE_PERSISTENT_DISK
	VolumeRestore_RESTORING                                    = src.VolumeRestore_RESTORING
	VolumeRestore_STATE_UNSPECIFIED                            = src.VolumeRestore_STATE_UNSPECIFIED
	VolumeRestore_SUCCEEDED                                    = src.VolumeRestore_SUCCEEDED
	VolumeRestore_VOLUME_TYPE_UNSPECIFIED                      = src.VolumeRestore_VOLUME_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
var (
	Backup_State_name                                 = src.Backup_State_name
	Backup_State_value                                = src.Backup_State_value
	File_google_cloud_gkebackup_v1_backup_plan_proto  = src.File_google_cloud_gkebackup_v1_backup_plan_proto
	File_google_cloud_gkebackup_v1_backup_proto       = src.File_google_cloud_gkebackup_v1_backup_proto
	File_google_cloud_gkebackup_v1_common_proto       = src.File_google_cloud_gkebackup_v1_common_proto
	File_google_cloud_gkebackup_v1_gkebackup_proto    = src.File_google_cloud_gkebackup_v1_gkebackup_proto
	File_google_cloud_gkebackup_v1_restore_plan_proto = src.File_google_cloud_gkebackup_v1_restore_plan_proto
	File_google_cloud_gkebackup_v1_restore_proto      = src.File_google_cloud_gkebackup_v1_restore_proto
	File_google_cloud_gkebackup_v1_volume_proto       = src.File_google_cloud_gkebackup_v1_volume_proto
	RestoreConfig_ClusterResourceConflictPolicy_name  = src.RestoreConfig_ClusterResourceConflictPolicy_name
	RestoreConfig_ClusterResourceConflictPolicy_value = src.RestoreConfig_ClusterResourceConflictPolicy_value
	RestoreConfig_NamespacedResourceRestoreMode_name  = src.RestoreConfig_NamespacedResourceRestoreMode_name
	RestoreConfig_NamespacedResourceRestoreMode_value = src.RestoreConfig_NamespacedResourceRestoreMode_value
	RestoreConfig_VolumeDataRestorePolicy_name        = src.RestoreConfig_VolumeDataRestorePolicy_name
	RestoreConfig_VolumeDataRestorePolicy_value       = src.RestoreConfig_VolumeDataRestorePolicy_value
	Restore_State_name                                = src.Restore_State_name
	Restore_State_value                               = src.Restore_State_value
	VolumeBackup_State_name                           = src.VolumeBackup_State_name
	VolumeBackup_State_value                          = src.VolumeBackup_State_value
	VolumeBackup_VolumeBackupFormat_name              = src.VolumeBackup_VolumeBackupFormat_name
	VolumeBackup_VolumeBackupFormat_value             = src.VolumeBackup_VolumeBackupFormat_value
	VolumeRestore_State_name                          = src.VolumeRestore_State_name
	VolumeRestore_State_value                         = src.VolumeRestore_State_value
	VolumeRestore_VolumeType_name                     = src.VolumeRestore_VolumeType_name
	VolumeRestore_VolumeType_value                    = src.VolumeRestore_VolumeType_value
)

// Represents a request to perform a single point-in-time capture of some
// portion of the state of a GKE cluster, the record of the backup operation
// itself, and an anchor for the underlying artifacts that comprise the Backup
// (the config backup and VolumeBackups). Next id: 28
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type Backup = src.Backup

// BackupForGKEClient is the client API for BackupForGKE service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type BackupForGKEClient = src.BackupForGKEClient

// BackupForGKEServer is the server API for BackupForGKE service.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type BackupForGKEServer = src.BackupForGKEServer

// Defines the configuration and scheduling for a "line" of Backups.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type BackupPlan = src.BackupPlan

// BackupConfig defines the configuration of Backups created via this
// BackupPlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type BackupPlan_BackupConfig = src.BackupPlan_BackupConfig
type BackupPlan_BackupConfig_AllNamespaces = src.BackupPlan_BackupConfig_AllNamespaces
type BackupPlan_BackupConfig_SelectedApplications = src.BackupPlan_BackupConfig_SelectedApplications
type BackupPlan_BackupConfig_SelectedNamespaces = src.BackupPlan_BackupConfig_SelectedNamespaces

// RetentionPolicy defines a Backup retention policy for a BackupPlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type BackupPlan_RetentionPolicy = src.BackupPlan_RetentionPolicy

// Schedule defines scheduling parameters for automatically creating Backups
// via this BackupPlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type BackupPlan_Schedule = src.BackupPlan_Schedule
type Backup_AllNamespaces = src.Backup_AllNamespaces

// Information about the GKE cluster from which this Backup was created.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type Backup_ClusterMetadata = src.Backup_ClusterMetadata
type Backup_ClusterMetadata_AnthosVersion = src.Backup_ClusterMetadata_AnthosVersion
type Backup_ClusterMetadata_GkeVersion = src.Backup_ClusterMetadata_GkeVersion
type Backup_SelectedApplications = src.Backup_SelectedApplications
type Backup_SelectedNamespaces = src.Backup_SelectedNamespaces

// State
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type Backup_State = src.Backup_State

// Request message for CreateBackupPlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type CreateBackupPlanRequest = src.CreateBackupPlanRequest

// Request message for CreateBackup.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type CreateBackupRequest = src.CreateBackupRequest

// Request message for CreateRestorePlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type CreateRestorePlanRequest = src.CreateRestorePlanRequest

// Request message for CreateRestore.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type CreateRestoreRequest = src.CreateRestoreRequest

// Request message for DeleteBackupPlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type DeleteBackupPlanRequest = src.DeleteBackupPlanRequest

// Request message for DeleteBackup.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type DeleteBackupRequest = src.DeleteBackupRequest

// Request message for DeleteRestorePlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type DeleteRestorePlanRequest = src.DeleteRestorePlanRequest

// Request message for DeleteRestore.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type DeleteRestoreRequest = src.DeleteRestoreRequest

// Defined a customer managed encryption key that will be used to encrypt
// Backup artifacts.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type EncryptionKey = src.EncryptionKey

// Request message for GetBackupPlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type GetBackupPlanRequest = src.GetBackupPlanRequest

// Request message for GetBackup.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type GetBackupRequest = src.GetBackupRequest

// Request message for GetRestorePlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type GetRestorePlanRequest = src.GetRestorePlanRequest

// Request message for GetRestore.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type GetRestoreRequest = src.GetRestoreRequest

// Request message for GetVolumeBackup.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type GetVolumeBackupRequest = src.GetVolumeBackupRequest

// Request message for GetVolumeRestore.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type GetVolumeRestoreRequest = src.GetVolumeRestoreRequest

// Request message for ListBackupPlans.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListBackupPlansRequest = src.ListBackupPlansRequest

// Response message for ListBackupPlans.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListBackupPlansResponse = src.ListBackupPlansResponse

// Request message for ListBackups.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListBackupsRequest = src.ListBackupsRequest

// Response message for ListBackups.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListBackupsResponse = src.ListBackupsResponse

// Request message for ListRestorePlans.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListRestorePlansRequest = src.ListRestorePlansRequest

// Response message for ListRestorePlans.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListRestorePlansResponse = src.ListRestorePlansResponse

// Request message for ListRestores.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListRestoresRequest = src.ListRestoresRequest

// Response message for ListRestores.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListRestoresResponse = src.ListRestoresResponse

// Request message for ListVolumeBackups.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListVolumeBackupsRequest = src.ListVolumeBackupsRequest

// Response message for ListVolumeBackups.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListVolumeBackupsResponse = src.ListVolumeBackupsResponse

// Request message for ListVolumeRestores.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListVolumeRestoresRequest = src.ListVolumeRestoresRequest

// Response message for ListVolumeRestores.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type ListVolumeRestoresResponse = src.ListVolumeRestoresResponse

// A reference to a namespaced resource in Kubernetes.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type NamespacedName = src.NamespacedName

// A list of namespaced Kubernetes resources.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type NamespacedNames = src.NamespacedNames

// A list of Kubernetes Namespaces
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type Namespaces = src.Namespaces

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type OperationMetadata = src.OperationMetadata

// Represents both a request to Restore some portion of a Backup into a target
// GKE cluster and a record of the restore operation itself. Next id: 18
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type Restore = src.Restore

// Configuration of a restore. Next id: 9
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type RestoreConfig = src.RestoreConfig
type RestoreConfig_AllNamespaces = src.RestoreConfig_AllNamespaces

// Defines the behavior for handling the situation where cluster-scoped
// resources being restored already exist in the target cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type RestoreConfig_ClusterResourceConflictPolicy = src.RestoreConfig_ClusterResourceConflictPolicy

// Identifies the cluster-scoped resources to restore from the Backup.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type RestoreConfig_ClusterResourceRestoreScope = src.RestoreConfig_ClusterResourceRestoreScope

// This is a direct map to the Kubernetes GroupKind type
// [GroupKind](https://godoc.org/k8s.io/apimachinery/pkg/runtime/schema#GroupKind)
// and is used for identifying specific "types" of resources to restore.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type RestoreConfig_GroupKind = src.RestoreConfig_GroupKind

// Defines the behavior for handling the situation where sets of namespaced
// resources being restored already exist in the target cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type RestoreConfig_NamespacedResourceRestoreMode = src.RestoreConfig_NamespacedResourceRestoreMode
type RestoreConfig_SelectedApplications = src.RestoreConfig_SelectedApplications
type RestoreConfig_SelectedNamespaces = src.RestoreConfig_SelectedNamespaces

// A transformation rule to be applied against Kubernetes resources as they
// are selected for restoration from a Backup. A rule contains both filtering
// logic (which resources are subject to substitution) and substitution logic.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type RestoreConfig_SubstitutionRule = src.RestoreConfig_SubstitutionRule

// Defines how volume data should be restored
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type RestoreConfig_VolumeDataRestorePolicy = src.RestoreConfig_VolumeDataRestorePolicy

// The configuration of a potential series of Restore operations to be
// performed against Backups belong to a particular BackupPlan. Next id: 11
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type RestorePlan = src.RestorePlan

// Possible values for state of the Restore.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type Restore_State = src.Restore_State

// UnimplementedBackupForGKEServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type UnimplementedBackupForGKEServer = src.UnimplementedBackupForGKEServer

// Request message for UpdateBackupPlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type UpdateBackupPlanRequest = src.UpdateBackupPlanRequest

// Request message for UpdateBackup.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type UpdateBackupRequest = src.UpdateBackupRequest

// Request message for UpdateRestorePlan.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type UpdateRestorePlanRequest = src.UpdateRestorePlanRequest

// Request message for UpdateRestore.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type UpdateRestoreRequest = src.UpdateRestoreRequest

// Represents the backup of a specific persistent volume as a component of a
// Backup - both the record of the operation and a pointer to the underlying
// storage-specific artifacts. Next id: 14
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type VolumeBackup = src.VolumeBackup

// The current state of a VolumeBackup
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type VolumeBackup_State = src.VolumeBackup_State

// Identifies the format used for the volume backup.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type VolumeBackup_VolumeBackupFormat = src.VolumeBackup_VolumeBackupFormat

// Represents the operation of restoring a volume from a VolumeBackup. Next
// id: 13
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type VolumeRestore = src.VolumeRestore

// The current state of a VolumeRestore
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type VolumeRestore_State = src.VolumeRestore_State

// Supported volume types.
//
// Deprecated: Please use types in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
type VolumeRestore_VolumeType = src.VolumeRestore_VolumeType

// Deprecated: Please use funcs in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
func NewBackupForGKEClient(cc grpc.ClientConnInterface) BackupForGKEClient {
	return src.NewBackupForGKEClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/gkebackup/apiv1/gkebackuppb
func RegisterBackupForGKEServer(s *grpc.Server, srv BackupForGKEServer) {
	src.RegisterBackupForGKEServer(s, srv)
}
