// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package resourcesettings aliases all exported identifiers in package
// "cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb".
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package resourcesettings

import (
	src "cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
const (
	SettingMetadata_BOOLEAN                  = src.SettingMetadata_BOOLEAN
	SettingMetadata_DATA_TYPE_UNSPECIFIED    = src.SettingMetadata_DATA_TYPE_UNSPECIFIED
	SettingMetadata_ENUM_VALUE               = src.SettingMetadata_ENUM_VALUE
	SettingMetadata_STRING                   = src.SettingMetadata_STRING
	SettingMetadata_STRING_SET               = src.SettingMetadata_STRING_SET
	SettingView_SETTING_VIEW_BASIC           = src.SettingView_SETTING_VIEW_BASIC
	SettingView_SETTING_VIEW_EFFECTIVE_VALUE = src.SettingView_SETTING_VIEW_EFFECTIVE_VALUE
	SettingView_SETTING_VIEW_LOCAL_VALUE     = src.SettingView_SETTING_VIEW_LOCAL_VALUE
	SettingView_SETTING_VIEW_UNSPECIFIED     = src.SettingView_SETTING_VIEW_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
var (
	File_google_cloud_resourcesettings_v1_resource_settings_proto = src.File_google_cloud_resourcesettings_v1_resource_settings_proto
	SettingMetadata_DataType_name                                 = src.SettingMetadata_DataType_name
	SettingMetadata_DataType_value                                = src.SettingMetadata_DataType_value
	SettingView_name                                              = src.SettingView_name
	SettingView_value                                             = src.SettingView_value
)

// The request for GetSetting.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type GetSettingRequest = src.GetSettingRequest

// The request for ListSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type ListSettingsRequest = src.ListSettingsRequest

// The response from ListSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type ListSettingsResponse = src.ListSettingsResponse

// ResourceSettingsServiceClient is the client API for ResourceSettingsService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type ResourceSettingsServiceClient = src.ResourceSettingsServiceClient

// ResourceSettingsServiceServer is the server API for ResourceSettingsService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type ResourceSettingsServiceServer = src.ResourceSettingsServiceServer

// The schema for settings.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type Setting = src.Setting

// Metadata about a setting which is not editable by the end user.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type SettingMetadata = src.SettingMetadata

// The data type for setting values of this setting. See
// [Value][google.cloud.resourcesettings.v1.Value] for more details on the
// available data types.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type SettingMetadata_DataType = src.SettingMetadata_DataType

// View options for Settings.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type SettingView = src.SettingView

// UnimplementedResourceSettingsServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type UnimplementedResourceSettingsServiceServer = src.UnimplementedResourceSettingsServiceServer

// The request for UpdateSetting.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type UpdateSettingRequest = src.UpdateSettingRequest

// The data in a setting value.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type Value = src.Value
type Value_BooleanValue = src.Value_BooleanValue

// A enum value that can hold any enum type setting values. Each enum type is
// represented by a number, this representation is stored in the definitions.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type Value_EnumValue = src.Value_EnumValue
type Value_EnumValue_ = src.Value_EnumValue_

// A string set value that can hold a set of strings. The maximum length of
// each string is 200 characters and there can be a maximum of 50 strings in
// the string set.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
type Value_StringSet = src.Value_StringSet
type Value_StringSetValue = src.Value_StringSetValue
type Value_StringValue = src.Value_StringValue

// Deprecated: Please use funcs in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
func NewResourceSettingsServiceClient(cc grpc.ClientConnInterface) ResourceSettingsServiceClient {
	return src.NewResourceSettingsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/resourcesettings/apiv1/resourcesettingspb
func RegisterResourceSettingsServiceServer(s *grpc.Server, srv ResourceSettingsServiceServer) {
	src.RegisterResourceSettingsServiceServer(s, srv)
}
