// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package datafusion aliases all exported identifiers in package
// "cloud.google.com/go/datafusion/apiv1/datafusionpb".
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package datafusion

import (
	src "cloud.google.com/go/datafusion/apiv1/datafusionpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/datafusion/apiv1/datafusionpb
const (
	Accelerator_ACCELERATOR_TYPE_UNSPECIFIED = src.Accelerator_ACCELERATOR_TYPE_UNSPECIFIED
	Accelerator_CCAI_INSIGHTS                = src.Accelerator_CCAI_INSIGHTS
	Accelerator_CDC                          = src.Accelerator_CDC
	Accelerator_DISABLED                     = src.Accelerator_DISABLED
	Accelerator_ENABLED                      = src.Accelerator_ENABLED
	Accelerator_HEALTHCARE                   = src.Accelerator_HEALTHCARE
	Accelerator_STATE_UNSPECIFIED            = src.Accelerator_STATE_UNSPECIFIED
	Accelerator_UNKNOWN                      = src.Accelerator_UNKNOWN
	Instance_ACTIVE                          = src.Instance_ACTIVE
	Instance_AUTO_UPDATING                   = src.Instance_AUTO_UPDATING
	Instance_AUTO_UPGRADING                  = src.Instance_AUTO_UPGRADING
	Instance_BASIC                           = src.Instance_BASIC
	Instance_CREATING                        = src.Instance_CREATING
	Instance_DELETING                        = src.Instance_DELETING
	Instance_DEVELOPER                       = src.Instance_DEVELOPER
	Instance_DISABLED                        = src.Instance_DISABLED
	Instance_DISABLED_REASON_UNSPECIFIED     = src.Instance_DISABLED_REASON_UNSPECIFIED
	Instance_ENTERPRISE                      = src.Instance_ENTERPRISE
	Instance_FAILED                          = src.Instance_FAILED
	Instance_KMS_KEY_ISSUE                   = src.Instance_KMS_KEY_ISSUE
	Instance_RESTARTING                      = src.Instance_RESTARTING
	Instance_STATE_UNSPECIFIED               = src.Instance_STATE_UNSPECIFIED
	Instance_TYPE_UNSPECIFIED                = src.Instance_TYPE_UNSPECIFIED
	Instance_UPDATING                        = src.Instance_UPDATING
	Instance_UPGRADING                       = src.Instance_UPGRADING
	Version_TYPE_GENERAL_AVAILABILITY        = src.Version_TYPE_GENERAL_AVAILABILITY
	Version_TYPE_PREVIEW                     = src.Version_TYPE_PREVIEW
	Version_TYPE_UNSPECIFIED                 = src.Version_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/datafusion/apiv1/datafusionpb
var (
	Accelerator_AcceleratorType_name                 = src.Accelerator_AcceleratorType_name
	Accelerator_AcceleratorType_value                = src.Accelerator_AcceleratorType_value
	Accelerator_State_name                           = src.Accelerator_State_name
	Accelerator_State_value                          = src.Accelerator_State_value
	File_google_cloud_datafusion_v1_datafusion_proto = src.File_google_cloud_datafusion_v1_datafusion_proto
	Instance_DisabledReason_name                     = src.Instance_DisabledReason_name
	Instance_DisabledReason_value                    = src.Instance_DisabledReason_value
	Instance_State_name                              = src.Instance_State_name
	Instance_State_value                             = src.Instance_State_value
	Instance_Type_name                               = src.Instance_Type_name
	Instance_Type_value                              = src.Instance_Type_value
	Version_Type_name                                = src.Version_Type_name
	Version_Type_value                               = src.Version_Type_value
)

// Identifies Data Fusion accelerators for an instance.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type Accelerator = src.Accelerator

// Each type represents an Accelerator (Add-On) supported by Cloud Data Fusion
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type Accelerator_AcceleratorType = src.Accelerator_AcceleratorType

// Different values possible for the state of an accelerator
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type Accelerator_State = src.Accelerator_State

// Request message for creating a Data Fusion instance.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type CreateInstanceRequest = src.CreateInstanceRequest

// The crypto key configuration. This field is used by the Customer-managed
// encryption keys (CMEK) feature.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type CryptoKeyConfig = src.CryptoKeyConfig

// DataFusionClient is the client API for DataFusion service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type DataFusionClient = src.DataFusionClient

// DataFusionServer is the server API for DataFusion service.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type DataFusionServer = src.DataFusionServer

// Request message for deleting a Data Fusion instance.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type DeleteInstanceRequest = src.DeleteInstanceRequest

// Request message for getting details about a Data Fusion instance.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type GetInstanceRequest = src.GetInstanceRequest

// Represents a Data Fusion instance.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type Instance = src.Instance

// The reason for disabling the instance if the state is DISABLED.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type Instance_DisabledReason = src.Instance_DisabledReason

// Represents the state of a Data Fusion instance
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type Instance_State = src.Instance_State

// Represents the type of Data Fusion instance. Each type is configured with
// the default settings for processing and memory.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type Instance_Type = src.Instance_Type

// Request message for the list available versions request.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type ListAvailableVersionsRequest = src.ListAvailableVersionsRequest

// Response message for the list available versions request.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type ListAvailableVersionsResponse = src.ListAvailableVersionsResponse

// Request message for listing Data Fusion instances.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type ListInstancesRequest = src.ListInstancesRequest

// Response message for the list instance request.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type ListInstancesResponse = src.ListInstancesResponse

// Network configuration for a Data Fusion instance. These configurations are
// used for peering with the customer network. Configurations are optional when
// a public Data Fusion instance is to be created. However, providing these
// configurations allows several benefits, such as reduced network latency
// while accessing the customer resources from managed Data Fusion instance
// nodes, as well as access to the customer on-prem resources.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type NetworkConfig = src.NetworkConfig

// Represents the metadata of a long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type OperationMetadata = src.OperationMetadata

// Request message for restarting a Data Fusion instance.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type RestartInstanceRequest = src.RestartInstanceRequest

// UnimplementedDataFusionServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type UnimplementedDataFusionServer = src.UnimplementedDataFusionServer

// Request message for updating a Data Fusion instance. Data Fusion allows
// updating the labels, options, and stack driver settings. This is also used
// for CDF version upgrade.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type UpdateInstanceRequest = src.UpdateInstanceRequest

// The Data Fusion version. This proto message stores information about
// certain Data Fusion version, which is used for Data Fusion version upgrade.
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type Version = src.Version

// Each type represents the release availability of a CDF version
//
// Deprecated: Please use types in: cloud.google.com/go/datafusion/apiv1/datafusionpb
type Version_Type = src.Version_Type

// Deprecated: Please use funcs in: cloud.google.com/go/datafusion/apiv1/datafusionpb
func NewDataFusionClient(cc grpc.ClientConnInterface) DataFusionClient {
	return src.NewDataFusionClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/datafusion/apiv1/datafusionpb
func RegisterDataFusionServer(s *grpc.Server, srv DataFusionServer) {
	src.RegisterDataFusionServer(s, srv)
}
