// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package managedidentities aliases all exported identifiers in package
// "cloud.google.com/go/managedidentities/apiv1/managedidentitiespb".
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package managedidentities

import (
	src "cloud.google.com/go/managedidentities/apiv1/managedidentitiespb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
const (
	Domain_CREATING                   = src.Domain_CREATING
	Domain_DELETING                   = src.Domain_DELETING
	Domain_PERFORMING_MAINTENANCE     = src.Domain_PERFORMING_MAINTENANCE
	Domain_READY                      = src.Domain_READY
	Domain_REPAIRING                  = src.Domain_REPAIRING
	Domain_STATE_UNSPECIFIED          = src.Domain_STATE_UNSPECIFIED
	Domain_UNAVAILABLE                = src.Domain_UNAVAILABLE
	Domain_UPDATING                   = src.Domain_UPDATING
	Trust_BIDIRECTIONAL               = src.Trust_BIDIRECTIONAL
	Trust_CONNECTED                   = src.Trust_CONNECTED
	Trust_CREATING                    = src.Trust_CREATING
	Trust_DELETING                    = src.Trust_DELETING
	Trust_DISCONNECTED                = src.Trust_DISCONNECTED
	Trust_EXTERNAL                    = src.Trust_EXTERNAL
	Trust_FOREST                      = src.Trust_FOREST
	Trust_INBOUND                     = src.Trust_INBOUND
	Trust_OUTBOUND                    = src.Trust_OUTBOUND
	Trust_STATE_UNSPECIFIED           = src.Trust_STATE_UNSPECIFIED
	Trust_TRUST_DIRECTION_UNSPECIFIED = src.Trust_TRUST_DIRECTION_UNSPECIFIED
	Trust_TRUST_TYPE_UNSPECIFIED      = src.Trust_TRUST_TYPE_UNSPECIFIED
	Trust_UPDATING                    = src.Trust_UPDATING
)

// Deprecated: Please use vars in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
var (
	Domain_State_name                                                       = src.Domain_State_name
	Domain_State_value                                                      = src.Domain_State_value
	File_google_cloud_managedidentities_v1_managed_identities_service_proto = src.File_google_cloud_managedidentities_v1_managed_identities_service_proto
	File_google_cloud_managedidentities_v1_resource_proto                   = src.File_google_cloud_managedidentities_v1_resource_proto
	Trust_State_name                                                        = src.Trust_State_name
	Trust_State_value                                                       = src.Trust_State_value
	Trust_TrustDirection_name                                               = src.Trust_TrustDirection_name
	Trust_TrustDirection_value                                              = src.Trust_TrustDirection_value
	Trust_TrustType_name                                                    = src.Trust_TrustType_name
	Trust_TrustType_value                                                   = src.Trust_TrustType_value
)

// Request message for
// [AttachTrust][google.cloud.managedidentities.v1.AttachTrust]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type AttachTrustRequest = src.AttachTrustRequest

// Request message for
// [CreateMicrosoftAdDomain][google.cloud.managedidentities.v1.CreateMicrosoftAdDomain]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type CreateMicrosoftAdDomainRequest = src.CreateMicrosoftAdDomainRequest

// Request message for
// [DeleteDomain][google.cloud.managedidentities.v1.DeleteDomain]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type DeleteDomainRequest = src.DeleteDomainRequest

// Request message for
// [DetachTrust][google.cloud.managedidentities.v1.DetachTrust]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type DetachTrustRequest = src.DetachTrustRequest

// Represents a managed Microsoft Active Directory domain.
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type Domain = src.Domain

// Represents the different states of a managed domain.
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type Domain_State = src.Domain_State

// Request message for
// [GetDomain][google.cloud.managedidentities.v1.GetDomain]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type GetDomainRequest = src.GetDomainRequest

// Request message for
// [ListDomains][google.cloud.managedidentities.v1.ListDomains]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type ListDomainsRequest = src.ListDomainsRequest

// Response message for
// [ListDomains][google.cloud.managedidentities.v1.ListDomains]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type ListDomainsResponse = src.ListDomainsResponse

// ManagedIdentitiesServiceClient is the client API for
// ManagedIdentitiesService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type ManagedIdentitiesServiceClient = src.ManagedIdentitiesServiceClient

// ManagedIdentitiesServiceServer is the server API for
// ManagedIdentitiesService service.
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type ManagedIdentitiesServiceServer = src.ManagedIdentitiesServiceServer

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type OpMetadata = src.OpMetadata

// Request message for
// [ReconfigureTrust][google.cloud.managedidentities.v1.ReconfigureTrust]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type ReconfigureTrustRequest = src.ReconfigureTrustRequest

// Request message for
// [ResetAdminPassword][google.cloud.managedidentities.v1.ResetAdminPassword]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type ResetAdminPasswordRequest = src.ResetAdminPasswordRequest

// Response message for
// [ResetAdminPassword][google.cloud.managedidentities.v1.ResetAdminPassword]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type ResetAdminPasswordResponse = src.ResetAdminPasswordResponse

// Represents a relationship between two domains. This allows a controller in
// one domain to authenticate a user in another domain.
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type Trust = src.Trust

// Represents the different states of a domain trust.
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type Trust_State = src.Trust_State

// Represents the direction of trust. See
// [System.DirectoryServices.ActiveDirectory.TrustDirection](https://docs.microsoft.com/en-us/dotnet/api/system.directoryservices.activedirectory.trustdirection?view=netframework-4.7.2)
// for more information.
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type Trust_TrustDirection = src.Trust_TrustDirection

// Represents the different inter-forest trust types.
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type Trust_TrustType = src.Trust_TrustType

// UnimplementedManagedIdentitiesServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type UnimplementedManagedIdentitiesServiceServer = src.UnimplementedManagedIdentitiesServiceServer

// Request message for
// [UpdateDomain][google.cloud.managedidentities.v1.UpdateDomain]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type UpdateDomainRequest = src.UpdateDomainRequest

// Request message for
// [ValidateTrust][google.cloud.managedidentities.v1.ValidateTrust]
//
// Deprecated: Please use types in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
type ValidateTrustRequest = src.ValidateTrustRequest

// Deprecated: Please use funcs in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
func NewManagedIdentitiesServiceClient(cc grpc.ClientConnInterface) ManagedIdentitiesServiceClient {
	return src.NewManagedIdentitiesServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/managedidentities/apiv1/managedidentitiespb
func RegisterManagedIdentitiesServiceServer(s *grpc.Server, srv ManagedIdentitiesServiceServer) {
	src.RegisterManagedIdentitiesServiceServer(s, srv)
}
