// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package admin aliases all exported identifiers in package
// "cloud.google.com/go/datastore/admin/apiv1/adminpb".
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package admin

import (
	src "cloud.google.com/go/datastore/admin/apiv1/adminpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/datastore/admin/apiv1/adminpb
const (
	CommonMetadata_CANCELLED                             = src.CommonMetadata_CANCELLED
	CommonMetadata_CANCELLING                            = src.CommonMetadata_CANCELLING
	CommonMetadata_FAILED                                = src.CommonMetadata_FAILED
	CommonMetadata_FINALIZING                            = src.CommonMetadata_FINALIZING
	CommonMetadata_INITIALIZING                          = src.CommonMetadata_INITIALIZING
	CommonMetadata_PROCESSING                            = src.CommonMetadata_PROCESSING
	CommonMetadata_STATE_UNSPECIFIED                     = src.CommonMetadata_STATE_UNSPECIFIED
	CommonMetadata_SUCCESSFUL                            = src.CommonMetadata_SUCCESSFUL
	Index_ALL_ANCESTORS                                  = src.Index_ALL_ANCESTORS
	Index_ANCESTOR_MODE_UNSPECIFIED                      = src.Index_ANCESTOR_MODE_UNSPECIFIED
	Index_ASCENDING                                      = src.Index_ASCENDING
	Index_CREATING                                       = src.Index_CREATING
	Index_DELETING                                       = src.Index_DELETING
	Index_DESCENDING                                     = src.Index_DESCENDING
	Index_DIRECTION_UNSPECIFIED                          = src.Index_DIRECTION_UNSPECIFIED
	Index_ERROR                                          = src.Index_ERROR
	Index_NONE                                           = src.Index_NONE
	Index_READY                                          = src.Index_READY
	Index_STATE_UNSPECIFIED                              = src.Index_STATE_UNSPECIFIED
	MigrationProgressEvent_CONCURRENCY_MODE_UNSPECIFIED  = src.MigrationProgressEvent_CONCURRENCY_MODE_UNSPECIFIED
	MigrationProgressEvent_OPTIMISTIC                    = src.MigrationProgressEvent_OPTIMISTIC
	MigrationProgressEvent_OPTIMISTIC_WITH_ENTITY_GROUPS = src.MigrationProgressEvent_OPTIMISTIC_WITH_ENTITY_GROUPS
	MigrationProgressEvent_PESSIMISTIC                   = src.MigrationProgressEvent_PESSIMISTIC
	MigrationState_COMPLETE                              = src.MigrationState_COMPLETE
	MigrationState_MIGRATION_STATE_UNSPECIFIED           = src.MigrationState_MIGRATION_STATE_UNSPECIFIED
	MigrationState_PAUSED                                = src.MigrationState_PAUSED
	MigrationState_RUNNING                               = src.MigrationState_RUNNING
	MigrationStep_APPLY_WRITES_SYNCHRONOUSLY             = src.MigrationStep_APPLY_WRITES_SYNCHRONOUSLY
	MigrationStep_COPY_AND_VERIFY                        = src.MigrationStep_COPY_AND_VERIFY
	MigrationStep_MIGRATION_STEP_UNSPECIFIED             = src.MigrationStep_MIGRATION_STEP_UNSPECIFIED
	MigrationStep_PREPARE                                = src.MigrationStep_PREPARE
	MigrationStep_REDIRECT_EVENTUALLY_CONSISTENT_READS   = src.MigrationStep_REDIRECT_EVENTUALLY_CONSISTENT_READS
	MigrationStep_REDIRECT_STRONGLY_CONSISTENT_READS     = src.MigrationStep_REDIRECT_STRONGLY_CONSISTENT_READS
	MigrationStep_REDIRECT_WRITES                        = src.MigrationStep_REDIRECT_WRITES
	MigrationStep_START                                  = src.MigrationStep_START
	OperationType_CREATE_INDEX                           = src.OperationType_CREATE_INDEX
	OperationType_DELETE_INDEX                           = src.OperationType_DELETE_INDEX
	OperationType_EXPORT_ENTITIES                        = src.OperationType_EXPORT_ENTITIES
	OperationType_IMPORT_ENTITIES                        = src.OperationType_IMPORT_ENTITIES
	OperationType_OPERATION_TYPE_UNSPECIFIED             = src.OperationType_OPERATION_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/datastore/admin/apiv1/adminpb
var (
	CommonMetadata_State_name                            = src.CommonMetadata_State_name
	CommonMetadata_State_value                           = src.CommonMetadata_State_value
	File_google_datastore_admin_v1_datastore_admin_proto = src.File_google_datastore_admin_v1_datastore_admin_proto
	File_google_datastore_admin_v1_index_proto           = src.File_google_datastore_admin_v1_index_proto
	File_google_datastore_admin_v1_migration_proto       = src.File_google_datastore_admin_v1_migration_proto
	Index_AncestorMode_name                              = src.Index_AncestorMode_name
	Index_AncestorMode_value                             = src.Index_AncestorMode_value
	Index_Direction_name                                 = src.Index_Direction_name
	Index_Direction_value                                = src.Index_Direction_value
	Index_State_name                                     = src.Index_State_name
	Index_State_value                                    = src.Index_State_value
	MigrationProgressEvent_ConcurrencyMode_name          = src.MigrationProgressEvent_ConcurrencyMode_name
	MigrationProgressEvent_ConcurrencyMode_value         = src.MigrationProgressEvent_ConcurrencyMode_value
	MigrationState_name                                  = src.MigrationState_name
	MigrationState_value                                 = src.MigrationState_value
	MigrationStep_name                                   = src.MigrationStep_name
	MigrationStep_value                                  = src.MigrationStep_value
	OperationType_name                                   = src.OperationType_name
	OperationType_value                                  = src.OperationType_value
)

// Metadata common to all Datastore Admin operations.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type CommonMetadata = src.CommonMetadata

// The various possible states for an ongoing Operation.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type CommonMetadata_State = src.CommonMetadata_State

// The request for
// [google.datastore.admin.v1.DatastoreAdmin.CreateIndex][google.datastore.admin.v1.DatastoreAdmin.CreateIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type CreateIndexRequest = src.CreateIndexRequest

// DatastoreAdminClient is the client API for DatastoreAdmin service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type DatastoreAdminClient = src.DatastoreAdminClient

// DatastoreAdminServer is the server API for DatastoreAdmin service.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type DatastoreAdminServer = src.DatastoreAdminServer

// Metadata for Datastore to Firestore migration operations. The
// DatastoreFirestoreMigration operation is not started by the end-user via an
// explicit "creation" method. This is an intentional deviation from the LRO
// design pattern. This singleton resource can be accessed at:
// "projects/{project_id}/operations/datastore-firestore-migration"
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type DatastoreFirestoreMigrationMetadata = src.DatastoreFirestoreMigrationMetadata

// The request for
// [google.datastore.admin.v1.DatastoreAdmin.DeleteIndex][google.datastore.admin.v1.DatastoreAdmin.DeleteIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type DeleteIndexRequest = src.DeleteIndexRequest

// Identifies a subset of entities in a project. This is specified as
// combinations of kinds and namespaces (either or both of which may be all, as
// described in the following examples). Example usage: Entire project:
// kinds=[], namespace_ids=[] Kinds Foo and Bar in all namespaces:
// kinds=['Foo', 'Bar'], namespace_ids=[] Kinds Foo and Bar only in the default
// namespace: kinds=['Foo', 'Bar'], namespace_ids=[”] Kinds Foo and Bar in
// both the default and Baz namespaces: kinds=['Foo', 'Bar'],
// namespace_ids=[”, 'Baz'] The entire Baz namespace: kinds=[],
// namespace_ids=['Baz']
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type EntityFilter = src.EntityFilter

// Metadata for ExportEntities operations.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type ExportEntitiesMetadata = src.ExportEntitiesMetadata

// The request for
// [google.datastore.admin.v1.DatastoreAdmin.ExportEntities][google.datastore.admin.v1.DatastoreAdmin.ExportEntities].
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type ExportEntitiesRequest = src.ExportEntitiesRequest

// The response for
// [google.datastore.admin.v1.DatastoreAdmin.ExportEntities][google.datastore.admin.v1.DatastoreAdmin.ExportEntities].
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type ExportEntitiesResponse = src.ExportEntitiesResponse

// The request for
// [google.datastore.admin.v1.DatastoreAdmin.GetIndex][google.datastore.admin.v1.DatastoreAdmin.GetIndex].
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type GetIndexRequest = src.GetIndexRequest

// Metadata for ImportEntities operations.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type ImportEntitiesMetadata = src.ImportEntitiesMetadata

// The request for
// [google.datastore.admin.v1.DatastoreAdmin.ImportEntities][google.datastore.admin.v1.DatastoreAdmin.ImportEntities].
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type ImportEntitiesRequest = src.ImportEntitiesRequest

// Datastore composite index definition.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type Index = src.Index

// Metadata for Index operations.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type IndexOperationMetadata = src.IndexOperationMetadata

// For an ordered index, specifies whether each of the entity's ancestors will
// be included.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type Index_AncestorMode = src.Index_AncestorMode

// The direction determines how a property is indexed.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type Index_Direction = src.Index_Direction

// A property of an index.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type Index_IndexedProperty = src.Index_IndexedProperty

// The possible set of states of an index.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type Index_State = src.Index_State

// The request for
// [google.datastore.admin.v1.DatastoreAdmin.ListIndexes][google.datastore.admin.v1.DatastoreAdmin.ListIndexes].
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type ListIndexesRequest = src.ListIndexesRequest

// The response for
// [google.datastore.admin.v1.DatastoreAdmin.ListIndexes][google.datastore.admin.v1.DatastoreAdmin.ListIndexes].
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type ListIndexesResponse = src.ListIndexesResponse

// An event signifying the start of a new step in a [migration from Cloud
// Datastore to Cloud Firestore in Datastore
// mode](https://cloud.google.com/datastore/docs/upgrade-to-firestore).
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type MigrationProgressEvent = src.MigrationProgressEvent

// Concurrency modes for transactions in Cloud Firestore.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type MigrationProgressEvent_ConcurrencyMode = src.MigrationProgressEvent_ConcurrencyMode

// Details for the `PREPARE` step.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type MigrationProgressEvent_PrepareStepDetails = src.MigrationProgressEvent_PrepareStepDetails
type MigrationProgressEvent_PrepareStepDetails_ = src.MigrationProgressEvent_PrepareStepDetails_

// Details for the `REDIRECT_WRITES` step.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type MigrationProgressEvent_RedirectWritesStepDetails = src.MigrationProgressEvent_RedirectWritesStepDetails
type MigrationProgressEvent_RedirectWritesStepDetails_ = src.MigrationProgressEvent_RedirectWritesStepDetails_

// States for a migration.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type MigrationState = src.MigrationState

// An event signifying a change in state of a [migration from Cloud Datastore
// to Cloud Firestore in Datastore
// mode](https://cloud.google.com/datastore/docs/upgrade-to-firestore).
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type MigrationStateEvent = src.MigrationStateEvent

// Steps in a migration.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type MigrationStep = src.MigrationStep

// Operation types.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type OperationType = src.OperationType

// Measures the progress of a particular metric.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type Progress = src.Progress

// UnimplementedDatastoreAdminServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/datastore/admin/apiv1/adminpb
type UnimplementedDatastoreAdminServer = src.UnimplementedDatastoreAdminServer

// Deprecated: Please use funcs in: cloud.google.com/go/datastore/admin/apiv1/adminpb
func NewDatastoreAdminClient(cc grpc.ClientConnInterface) DatastoreAdminClient {
	return src.NewDatastoreAdminClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/datastore/admin/apiv1/adminpb
func RegisterDatastoreAdminServer(s *grpc.Server, srv DatastoreAdminServer) {
	src.RegisterDatastoreAdminServer(s, srv)
}
