// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package texttospeech aliases all exported identifiers in package
// "cloud.google.com/go/texttospeech/apiv1/texttospeechpb".
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package texttospeech

import (
	src "cloud.google.com/go/texttospeech/apiv1/texttospeechpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
const (
	AudioEncoding_ALAW                            = src.AudioEncoding_ALAW
	AudioEncoding_AUDIO_ENCODING_UNSPECIFIED      = src.AudioEncoding_AUDIO_ENCODING_UNSPECIFIED
	AudioEncoding_LINEAR16                        = src.AudioEncoding_LINEAR16
	AudioEncoding_MP3                             = src.AudioEncoding_MP3
	AudioEncoding_MULAW                           = src.AudioEncoding_MULAW
	AudioEncoding_OGG_OPUS                        = src.AudioEncoding_OGG_OPUS
	CustomVoiceParams_OFFLINE                     = src.CustomVoiceParams_OFFLINE
	CustomVoiceParams_REALTIME                    = src.CustomVoiceParams_REALTIME
	CustomVoiceParams_REPORTED_USAGE_UNSPECIFIED  = src.CustomVoiceParams_REPORTED_USAGE_UNSPECIFIED
	SsmlVoiceGender_FEMALE                        = src.SsmlVoiceGender_FEMALE
	SsmlVoiceGender_MALE                          = src.SsmlVoiceGender_MALE
	SsmlVoiceGender_NEUTRAL                       = src.SsmlVoiceGender_NEUTRAL
	SsmlVoiceGender_SSML_VOICE_GENDER_UNSPECIFIED = src.SsmlVoiceGender_SSML_VOICE_GENDER_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
var (
	AudioEncoding_name                                = src.AudioEncoding_name
	AudioEncoding_value                               = src.AudioEncoding_value
	CustomVoiceParams_ReportedUsage_name              = src.CustomVoiceParams_ReportedUsage_name
	CustomVoiceParams_ReportedUsage_value             = src.CustomVoiceParams_ReportedUsage_value
	File_google_cloud_texttospeech_v1_cloud_tts_proto = src.File_google_cloud_texttospeech_v1_cloud_tts_proto
	SsmlVoiceGender_name                              = src.SsmlVoiceGender_name
	SsmlVoiceGender_value                             = src.SsmlVoiceGender_value
)

// Description of audio data to be synthesized.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type AudioConfig = src.AudioConfig

// Configuration to set up audio encoder. The encoding determines the output
// audio format that we'd like.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type AudioEncoding = src.AudioEncoding

// Description of the custom voice to be synthesized.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type CustomVoiceParams = src.CustomVoiceParams

// The usage of the synthesized audio. You must report your honest and correct
// usage of the service as it's regulated by contract and will cause
// significant difference in billing.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type CustomVoiceParams_ReportedUsage = src.CustomVoiceParams_ReportedUsage

// The top-level message sent by the client for the `ListVoices` method.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type ListVoicesRequest = src.ListVoicesRequest

// The message returned to the client by the `ListVoices` method.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type ListVoicesResponse = src.ListVoicesResponse

// Gender of the voice as described in [SSML voice
// element](https://www.w3.org/TR/speech-synthesis11/#edef_voice).
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type SsmlVoiceGender = src.SsmlVoiceGender

// Contains text input to be synthesized. Either `text` or `ssml` must be
// supplied. Supplying both or neither returns
// [google.rpc.Code.INVALID_ARGUMENT][]. The input size is limited to 5000
// characters.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type SynthesisInput = src.SynthesisInput
type SynthesisInput_Ssml = src.SynthesisInput_Ssml
type SynthesisInput_Text = src.SynthesisInput_Text

// The top-level message sent by the client for the `SynthesizeSpeech` method.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type SynthesizeSpeechRequest = src.SynthesizeSpeechRequest

// The message returned to the client by the `SynthesizeSpeech` method.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type SynthesizeSpeechResponse = src.SynthesizeSpeechResponse

// TextToSpeechClient is the client API for TextToSpeech service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type TextToSpeechClient = src.TextToSpeechClient

// TextToSpeechServer is the server API for TextToSpeech service.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type TextToSpeechServer = src.TextToSpeechServer

// UnimplementedTextToSpeechServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type UnimplementedTextToSpeechServer = src.UnimplementedTextToSpeechServer

// Description of a voice supported by the TTS service.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type Voice = src.Voice

// Description of which voice to use for a synthesis request.
//
// Deprecated: Please use types in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
type VoiceSelectionParams = src.VoiceSelectionParams

// Deprecated: Please use funcs in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
func NewTextToSpeechClient(cc grpc.ClientConnInterface) TextToSpeechClient {
	return src.NewTextToSpeechClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/texttospeech/apiv1/texttospeechpb
func RegisterTextToSpeechServer(s *grpc.Server, srv TextToSpeechServer) {
	src.RegisterTextToSpeechServer(s, srv)
}
