// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package apikeys aliases all exported identifiers in package
// "cloud.google.com/go/apikeys/apiv2/apikeyspb".
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package apikeys

import (
	src "cloud.google.com/go/apikeys/apiv2/apikeyspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use vars in: cloud.google.com/go/apikeys/apiv2/apikeyspb
var (
	File_google_api_apikeys_v2_apikeys_proto   = src.File_google_api_apikeys_v2_apikeys_proto
	File_google_api_apikeys_v2_resources_proto = src.File_google_api_apikeys_v2_resources_proto
)

// Identifier of an Android application for key use.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type AndroidApplication = src.AndroidApplication

// The Android apps that are allowed to use the key.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type AndroidKeyRestrictions = src.AndroidKeyRestrictions

// ApiKeysClient is the client API for ApiKeys service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type ApiKeysClient = src.ApiKeysClient

// ApiKeysServer is the server API for ApiKeys service.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type ApiKeysServer = src.ApiKeysServer

// A restriction for a specific service and optionally one or multiple
// specific methods. Both fields are case insensitive.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type ApiTarget = src.ApiTarget

// The HTTP referrers (websites) that are allowed to use the key.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type BrowserKeyRestrictions = src.BrowserKeyRestrictions

// Request message for `CreateKey` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type CreateKeyRequest = src.CreateKeyRequest

// Request message for `DeleteKey` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type DeleteKeyRequest = src.DeleteKeyRequest

// Request message for `GetKey` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type GetKeyRequest = src.GetKeyRequest

// Request message for `GetKeyString` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type GetKeyStringRequest = src.GetKeyStringRequest

// Response message for `GetKeyString` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type GetKeyStringResponse = src.GetKeyStringResponse

// The iOS apps that are allowed to use the key.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type IosKeyRestrictions = src.IosKeyRestrictions

// The representation of a key managed by the API Keys API.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type Key = src.Key

// Request message for `ListKeys` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type ListKeysRequest = src.ListKeysRequest

// Response message for `ListKeys` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type ListKeysResponse = src.ListKeysResponse

// Request message for `LookupKey` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type LookupKeyRequest = src.LookupKeyRequest

// Response message for `LookupKey` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type LookupKeyResponse = src.LookupKeyResponse

// Describes the restrictions on the key.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type Restrictions = src.Restrictions
type Restrictions_AndroidKeyRestrictions = src.Restrictions_AndroidKeyRestrictions
type Restrictions_BrowserKeyRestrictions = src.Restrictions_BrowserKeyRestrictions
type Restrictions_IosKeyRestrictions = src.Restrictions_IosKeyRestrictions
type Restrictions_ServerKeyRestrictions = src.Restrictions_ServerKeyRestrictions

// The IP addresses of callers that are allowed to use the key.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type ServerKeyRestrictions = src.ServerKeyRestrictions

// Request message for `UndeleteKey` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type UndeleteKeyRequest = src.UndeleteKeyRequest

// UnimplementedApiKeysServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type UnimplementedApiKeysServer = src.UnimplementedApiKeysServer

// Request message for `UpdateKey` method.
//
// Deprecated: Please use types in: cloud.google.com/go/apikeys/apiv2/apikeyspb
type UpdateKeyRequest = src.UpdateKeyRequest

// Deprecated: Please use funcs in: cloud.google.com/go/apikeys/apiv2/apikeyspb
func NewApiKeysClient(cc grpc.ClientConnInterface) ApiKeysClient { return src.NewApiKeysClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/apikeys/apiv2/apikeyspb
func RegisterApiKeysServer(s *grpc.Server, srv ApiKeysServer) { src.RegisterApiKeysServer(s, srv) }
