// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package channel aliases all exported identifiers in package
// "cloud.google.com/go/channel/apiv1/channelpb".
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package channel

import (
	src "cloud.google.com/go/channel/apiv1/channelpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/channel/apiv1/channelpb
const (
	ChannelPartnerLinkState_ACTIVE                                         = src.ChannelPartnerLinkState_ACTIVE
	ChannelPartnerLinkState_CHANNEL_PARTNER_LINK_STATE_UNSPECIFIED         = src.ChannelPartnerLinkState_CHANNEL_PARTNER_LINK_STATE_UNSPECIFIED
	ChannelPartnerLinkState_INVITED                                        = src.ChannelPartnerLinkState_INVITED
	ChannelPartnerLinkState_REVOKED                                        = src.ChannelPartnerLinkState_REVOKED
	ChannelPartnerLinkState_SUSPENDED                                      = src.ChannelPartnerLinkState_SUSPENDED
	ChannelPartnerLinkView_BASIC                                           = src.ChannelPartnerLinkView_BASIC
	ChannelPartnerLinkView_FULL                                            = src.ChannelPartnerLinkView_FULL
	ChannelPartnerLinkView_UNSPECIFIED                                     = src.ChannelPartnerLinkView_UNSPECIFIED
	CloudIdentityInfo_CUSTOMER_TYPE_UNSPECIFIED                            = src.CloudIdentityInfo_CUSTOMER_TYPE_UNSPECIFIED
	CloudIdentityInfo_DOMAIN                                               = src.CloudIdentityInfo_DOMAIN
	CloudIdentityInfo_TEAM                                                 = src.CloudIdentityInfo_TEAM
	Column_DATA_TYPE_UNSPECIFIED                                           = src.Column_DATA_TYPE_UNSPECIFIED
	Column_DATE                                                            = src.Column_DATE
	Column_DATE_TIME                                                       = src.Column_DATE_TIME
	Column_DECIMAL                                                         = src.Column_DECIMAL
	Column_INT                                                             = src.Column_INT
	Column_MONEY                                                           = src.Column_MONEY
	Column_STRING                                                          = src.Column_STRING
	CustomerEvent_PRIMARY_DOMAIN_CHANGED                                   = src.CustomerEvent_PRIMARY_DOMAIN_CHANGED
	CustomerEvent_PRIMARY_DOMAIN_VERIFIED                                  = src.CustomerEvent_PRIMARY_DOMAIN_VERIFIED
	CustomerEvent_TYPE_UNSPECIFIED                                         = src.CustomerEvent_TYPE_UNSPECIFIED
	EduData_INSTITUTE_SIZE_UNSPECIFIED                                     = src.EduData_INSTITUTE_SIZE_UNSPECIFIED
	EduData_INSTITUTE_TYPE_UNSPECIFIED                                     = src.EduData_INSTITUTE_TYPE_UNSPECIFIED
	EduData_K12                                                            = src.EduData_K12
	EduData_SIZE_10001_OR_MORE                                             = src.EduData_SIZE_10001_OR_MORE
	EduData_SIZE_1001_2000                                                 = src.EduData_SIZE_1001_2000
	EduData_SIZE_101_500                                                   = src.EduData_SIZE_101_500
	EduData_SIZE_1_100                                                     = src.EduData_SIZE_1_100
	EduData_SIZE_2001_5000                                                 = src.EduData_SIZE_2001_5000
	EduData_SIZE_5001_10000                                                = src.EduData_SIZE_5001_10000
	EduData_SIZE_501_1000                                                  = src.EduData_SIZE_501_1000
	EduData_UNIVERSITY                                                     = src.EduData_UNIVERSITY
	EntitlementEvent_ACTIVATED                                             = src.EntitlementEvent_ACTIVATED
	EntitlementEvent_CANCELLED                                             = src.EntitlementEvent_CANCELLED
	EntitlementEvent_COMMITMENT_CHANGED                                    = src.EntitlementEvent_COMMITMENT_CHANGED
	EntitlementEvent_CREATED                                               = src.EntitlementEvent_CREATED
	EntitlementEvent_LICENSE_ASSIGNMENT_CHANGED                            = src.EntitlementEvent_LICENSE_ASSIGNMENT_CHANGED
	EntitlementEvent_LICENSE_CAP_CHANGED                                   = src.EntitlementEvent_LICENSE_CAP_CHANGED
	EntitlementEvent_PAID_SERVICE_STARTED                                  = src.EntitlementEvent_PAID_SERVICE_STARTED
	EntitlementEvent_PRICE_PLAN_SWITCHED                                   = src.EntitlementEvent_PRICE_PLAN_SWITCHED
	EntitlementEvent_RENEWAL_SETTING_CHANGED                               = src.EntitlementEvent_RENEWAL_SETTING_CHANGED
	EntitlementEvent_RENEWED                                               = src.EntitlementEvent_RENEWED
	EntitlementEvent_SKU_CHANGED                                           = src.EntitlementEvent_SKU_CHANGED
	EntitlementEvent_SUSPENDED                                             = src.EntitlementEvent_SUSPENDED
	EntitlementEvent_TYPE_UNSPECIFIED                                      = src.EntitlementEvent_TYPE_UNSPECIFIED
	Entitlement_ACTIVE                                                     = src.Entitlement_ACTIVE
	Entitlement_OTHER                                                      = src.Entitlement_OTHER
	Entitlement_PENDING_TOS_ACCEPTANCE                                     = src.Entitlement_PENDING_TOS_ACCEPTANCE
	Entitlement_PROVISIONING_STATE_UNSPECIFIED                             = src.Entitlement_PROVISIONING_STATE_UNSPECIFIED
	Entitlement_RENEWAL_WITH_TYPE_CANCEL                                   = src.Entitlement_RENEWAL_WITH_TYPE_CANCEL
	Entitlement_RESELLER_INITIATED                                         = src.Entitlement_RESELLER_INITIATED
	Entitlement_SUSPENDED                                                  = src.Entitlement_SUSPENDED
	Entitlement_SUSPENSION_REASON_UNSPECIFIED                              = src.Entitlement_SUSPENSION_REASON_UNSPECIFIED
	Entitlement_TRIAL_ENDED                                                = src.Entitlement_TRIAL_ENDED
	ListPurchasableSkusRequest_ChangeOfferPurchase_CHANGE_TYPE_UNSPECIFIED = src.ListPurchasableSkusRequest_ChangeOfferPurchase_CHANGE_TYPE_UNSPECIFIED
	ListPurchasableSkusRequest_ChangeOfferPurchase_DOWNGRADE               = src.ListPurchasableSkusRequest_ChangeOfferPurchase_DOWNGRADE
	ListPurchasableSkusRequest_ChangeOfferPurchase_UPGRADE                 = src.ListPurchasableSkusRequest_ChangeOfferPurchase_UPGRADE
	MediaType_MEDIA_TYPE_IMAGE                                             = src.MediaType_MEDIA_TYPE_IMAGE
	MediaType_MEDIA_TYPE_UNSPECIFIED                                       = src.MediaType_MEDIA_TYPE_UNSPECIFIED
	OperationMetadata_ACTIVATE_ENTITLEMENT                                 = src.OperationMetadata_ACTIVATE_ENTITLEMENT
	OperationMetadata_CANCEL_ENTITLEMENT                                   = src.OperationMetadata_CANCEL_ENTITLEMENT
	OperationMetadata_CHANGE_OFFER                                         = src.OperationMetadata_CHANGE_OFFER
	OperationMetadata_CHANGE_PARAMETERS                                    = src.OperationMetadata_CHANGE_PARAMETERS
	OperationMetadata_CHANGE_RENEWAL_SETTINGS                              = src.OperationMetadata_CHANGE_RENEWAL_SETTINGS
	OperationMetadata_CREATE_ENTITLEMENT                                   = src.OperationMetadata_CREATE_ENTITLEMENT
	OperationMetadata_OPERATION_TYPE_UNSPECIFIED                           = src.OperationMetadata_OPERATION_TYPE_UNSPECIFIED
	OperationMetadata_PROVISION_CLOUD_IDENTITY                             = src.OperationMetadata_PROVISION_CLOUD_IDENTITY
	OperationMetadata_START_PAID_SERVICE                                   = src.OperationMetadata_START_PAID_SERVICE
	OperationMetadata_SUSPEND_ENTITLEMENT                                  = src.OperationMetadata_SUSPEND_ENTITLEMENT
	OperationMetadata_TRANSFER_ENTITLEMENTS                                = src.OperationMetadata_TRANSFER_ENTITLEMENTS
	OperationMetadata_TRANSFER_ENTITLEMENTS_TO_GOOGLE                      = src.OperationMetadata_TRANSFER_ENTITLEMENTS_TO_GOOGLE
	ParameterDefinition_DOUBLE                                             = src.ParameterDefinition_DOUBLE
	ParameterDefinition_INT64                                              = src.ParameterDefinition_INT64
	ParameterDefinition_PARAMETER_TYPE_UNSPECIFIED                         = src.ParameterDefinition_PARAMETER_TYPE_UNSPECIFIED
	ParameterDefinition_STRING                                             = src.ParameterDefinition_STRING
	PaymentPlan_COMMITMENT                                                 = src.PaymentPlan_COMMITMENT
	PaymentPlan_FLEXIBLE                                                   = src.PaymentPlan_FLEXIBLE
	PaymentPlan_FREE                                                       = src.PaymentPlan_FREE
	PaymentPlan_OFFLINE                                                    = src.PaymentPlan_OFFLINE
	PaymentPlan_PAYMENT_PLAN_UNSPECIFIED                                   = src.PaymentPlan_PAYMENT_PLAN_UNSPECIFIED
	PaymentPlan_TRIAL                                                      = src.PaymentPlan_TRIAL
	PaymentType_PAYMENT_TYPE_UNSPECIFIED                                   = src.PaymentType_PAYMENT_TYPE_UNSPECIFIED
	PaymentType_POSTPAY                                                    = src.PaymentType_POSTPAY
	PaymentType_PREPAY                                                     = src.PaymentType_PREPAY
	PeriodType_DAY                                                         = src.PeriodType_DAY
	PeriodType_MONTH                                                       = src.PeriodType_MONTH
	PeriodType_PERIOD_TYPE_UNSPECIFIED                                     = src.PeriodType_PERIOD_TYPE_UNSPECIFIED
	PeriodType_YEAR                                                        = src.PeriodType_YEAR
	PromotionalOrderType_NEW_UPGRADE                                       = src.PromotionalOrderType_NEW_UPGRADE
	PromotionalOrderType_PROMOTIONAL_TYPE_UNSPECIFIED                      = src.PromotionalOrderType_PROMOTIONAL_TYPE_UNSPECIFIED
	PromotionalOrderType_PROMOTION_SWITCH                                  = src.PromotionalOrderType_PROMOTION_SWITCH
	PromotionalOrderType_TRANSFER                                          = src.PromotionalOrderType_TRANSFER
	RebillingBasis_COST_AT_LIST                                            = src.RebillingBasis_COST_AT_LIST
	RebillingBasis_DIRECT_CUSTOMER_COST                                    = src.RebillingBasis_DIRECT_CUSTOMER_COST
	RebillingBasis_REBILLING_BASIS_UNSPECIFIED                             = src.RebillingBasis_REBILLING_BASIS_UNSPECIFIED
	ReportStatus_AVAILABLE                                                 = src.ReportStatus_AVAILABLE
	ReportStatus_FAILED                                                    = src.ReportStatus_FAILED
	ReportStatus_STARTED                                                   = src.ReportStatus_STARTED
	ReportStatus_STATE_UNSPECIFIED                                         = src.ReportStatus_STATE_UNSPECIFIED
	ReportStatus_WRITING                                                   = src.ReportStatus_WRITING
	ResourceType_GB                                                        = src.ResourceType_GB
	ResourceType_IAAS_USAGE                                                = src.ResourceType_IAAS_USAGE
	ResourceType_LICENSED_USER                                             = src.ResourceType_LICENSED_USER
	ResourceType_MAU                                                       = src.ResourceType_MAU
	ResourceType_MINUTES                                                   = src.ResourceType_MINUTES
	ResourceType_RESOURCE_TYPE_UNSPECIFIED                                 = src.ResourceType_RESOURCE_TYPE_UNSPECIFIED
	ResourceType_SEAT                                                      = src.ResourceType_SEAT
	ResourceType_SUBSCRIPTION                                              = src.ResourceType_SUBSCRIPTION
	TransferEligibility_PENDING_TOS_ACCEPTANCE                             = src.TransferEligibility_PENDING_TOS_ACCEPTANCE
	TransferEligibility_REASON_UNSPECIFIED                                 = src.TransferEligibility_REASON_UNSPECIFIED
	TransferEligibility_SKU_NOT_ELIGIBLE                                   = src.TransferEligibility_SKU_NOT_ELIGIBLE
	TransferEligibility_SKU_SUSPENDED                                      = src.TransferEligibility_SKU_SUSPENDED
)

// Deprecated: Please use vars in: cloud.google.com/go/channel/apiv1/channelpb
var (
	ChannelPartnerLinkState_name                                    = src.ChannelPartnerLinkState_name
	ChannelPartnerLinkState_value                                   = src.ChannelPartnerLinkState_value
	ChannelPartnerLinkView_name                                     = src.ChannelPartnerLinkView_name
	ChannelPartnerLinkView_value                                    = src.ChannelPartnerLinkView_value
	CloudIdentityInfo_CustomerType_name                             = src.CloudIdentityInfo_CustomerType_name
	CloudIdentityInfo_CustomerType_value                            = src.CloudIdentityInfo_CustomerType_value
	Column_DataType_name                                            = src.Column_DataType_name
	Column_DataType_value                                           = src.Column_DataType_value
	CustomerEvent_Type_name                                         = src.CustomerEvent_Type_name
	CustomerEvent_Type_value                                        = src.CustomerEvent_Type_value
	EduData_InstituteSize_name                                      = src.EduData_InstituteSize_name
	EduData_InstituteSize_value                                     = src.EduData_InstituteSize_value
	EduData_InstituteType_name                                      = src.EduData_InstituteType_name
	EduData_InstituteType_value                                     = src.EduData_InstituteType_value
	EntitlementEvent_Type_name                                      = src.EntitlementEvent_Type_name
	EntitlementEvent_Type_value                                     = src.EntitlementEvent_Type_value
	Entitlement_ProvisioningState_name                              = src.Entitlement_ProvisioningState_name
	Entitlement_ProvisioningState_value                             = src.Entitlement_ProvisioningState_value
	Entitlement_SuspensionReason_name                               = src.Entitlement_SuspensionReason_name
	Entitlement_SuspensionReason_value                              = src.Entitlement_SuspensionReason_value
	File_google_cloud_channel_v1_channel_partner_links_proto        = src.File_google_cloud_channel_v1_channel_partner_links_proto
	File_google_cloud_channel_v1_common_proto                       = src.File_google_cloud_channel_v1_common_proto
	File_google_cloud_channel_v1_customers_proto                    = src.File_google_cloud_channel_v1_customers_proto
	File_google_cloud_channel_v1_entitlements_proto                 = src.File_google_cloud_channel_v1_entitlements_proto
	File_google_cloud_channel_v1_offers_proto                       = src.File_google_cloud_channel_v1_offers_proto
	File_google_cloud_channel_v1_operations_proto                   = src.File_google_cloud_channel_v1_operations_proto
	File_google_cloud_channel_v1_products_proto                     = src.File_google_cloud_channel_v1_products_proto
	File_google_cloud_channel_v1_reports_service_proto              = src.File_google_cloud_channel_v1_reports_service_proto
	File_google_cloud_channel_v1_repricing_proto                    = src.File_google_cloud_channel_v1_repricing_proto
	File_google_cloud_channel_v1_service_proto                      = src.File_google_cloud_channel_v1_service_proto
	File_google_cloud_channel_v1_subscriber_event_proto             = src.File_google_cloud_channel_v1_subscriber_event_proto
	ListPurchasableSkusRequest_ChangeOfferPurchase_ChangeType_name  = src.ListPurchasableSkusRequest_ChangeOfferPurchase_ChangeType_name
	ListPurchasableSkusRequest_ChangeOfferPurchase_ChangeType_value = src.ListPurchasableSkusRequest_ChangeOfferPurchase_ChangeType_value
	MediaType_name                                                  = src.MediaType_name
	MediaType_value                                                 = src.MediaType_value
	OperationMetadata_OperationType_name                            = src.OperationMetadata_OperationType_name
	OperationMetadata_OperationType_value                           = src.OperationMetadata_OperationType_value
	ParameterDefinition_ParameterType_name                          = src.ParameterDefinition_ParameterType_name
	ParameterDefinition_ParameterType_value                         = src.ParameterDefinition_ParameterType_value
	PaymentPlan_name                                                = src.PaymentPlan_name
	PaymentPlan_value                                               = src.PaymentPlan_value
	PaymentType_name                                                = src.PaymentType_name
	PaymentType_value                                               = src.PaymentType_value
	PeriodType_name                                                 = src.PeriodType_name
	PeriodType_value                                                = src.PeriodType_value
	PromotionalOrderType_name                                       = src.PromotionalOrderType_name
	PromotionalOrderType_value                                      = src.PromotionalOrderType_value
	RebillingBasis_name                                             = src.RebillingBasis_name
	RebillingBasis_value                                            = src.RebillingBasis_value
	ReportStatus_State_name                                         = src.ReportStatus_State_name
	ReportStatus_State_value                                        = src.ReportStatus_State_value
	ResourceType_name                                               = src.ResourceType_name
	ResourceType_value                                              = src.ResourceType_value
	TransferEligibility_Reason_name                                 = src.TransferEligibility_Reason_name
	TransferEligibility_Reason_value                                = src.TransferEligibility_Reason_value
)

// Request message for
// [CloudChannelService.ActivateEntitlement][google.cloud.channel.v1.CloudChannelService.ActivateEntitlement].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ActivateEntitlementRequest = src.ActivateEntitlementRequest

// Information needed to create an Admin User for Google Workspace.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type AdminUser = src.AdminUser

// Association links that an entitlement has to other entitlements.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type AssociationInfo = src.AssociationInfo

// Request message for
// [CloudChannelService.CancelEntitlement][google.cloud.channel.v1.CloudChannelService.CancelEntitlement].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CancelEntitlementRequest = src.CancelEntitlementRequest

// Request message for
// [CloudChannelService.ChangeOffer][google.cloud.channel.v1.CloudChannelService.ChangeOffer].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ChangeOfferRequest = src.ChangeOfferRequest

// Request message for [CloudChannelService.ChangeParametersRequest][].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ChangeParametersRequest = src.ChangeParametersRequest

// Request message for
// [CloudChannelService.ChangeRenewalSettings][google.cloud.channel.v1.CloudChannelService.ChangeRenewalSettings].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ChangeRenewalSettingsRequest = src.ChangeRenewalSettingsRequest

// Entity representing a link between distributors and their indirect
// resellers in an n-tier resale channel.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ChannelPartnerLink = src.ChannelPartnerLink

// ChannelPartnerLinkState represents state of a channel partner link.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ChannelPartnerLinkState = src.ChannelPartnerLinkState

// The level of granularity the
// [ChannelPartnerLink][google.cloud.channel.v1.ChannelPartnerLink] will
// display.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ChannelPartnerLinkView = src.ChannelPartnerLinkView

// Configuration for how a distributor will rebill a channel partner (also
// known as a distributor-authorized reseller).
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ChannelPartnerRepricingConfig = src.ChannelPartnerRepricingConfig

// Request message for
// [CloudChannelService.CheckCloudIdentityAccountsExist][google.cloud.channel.v1.CloudChannelService.CheckCloudIdentityAccountsExist].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CheckCloudIdentityAccountsExistRequest = src.CheckCloudIdentityAccountsExistRequest

// Response message for
// [CloudChannelService.CheckCloudIdentityAccountsExist][google.cloud.channel.v1.CloudChannelService.CheckCloudIdentityAccountsExist].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CheckCloudIdentityAccountsExistResponse = src.CheckCloudIdentityAccountsExistResponse

// CloudChannelReportsServiceClient is the client API for
// CloudChannelReportsService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CloudChannelReportsServiceClient = src.CloudChannelReportsServiceClient

// CloudChannelReportsServiceServer is the server API for
// CloudChannelReportsService service.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CloudChannelReportsServiceServer = src.CloudChannelReportsServiceServer

// CloudChannelServiceClient is the client API for CloudChannelService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CloudChannelServiceClient = src.CloudChannelServiceClient

// CloudChannelServiceServer is the server API for CloudChannelService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CloudChannelServiceServer = src.CloudChannelServiceServer

// Entity representing a Cloud Identity account that may be associated with a
// Channel Services API partner.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CloudIdentityCustomerAccount = src.CloudIdentityCustomerAccount

// Cloud Identity information for the Cloud Channel Customer.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CloudIdentityInfo = src.CloudIdentityInfo

// CustomerType of the customer
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CloudIdentityInfo_CustomerType = src.CloudIdentityInfo_CustomerType

// The definition of a report column. Specifies the data properties in the
// corresponding position of the report rows.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Column = src.Column

// Available data types for columns. Corresponds to the fields in the
// ReportValue `oneof` field.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Column_DataType = src.Column_DataType

// Commitment settings for commitment-based offers.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CommitmentSettings = src.CommitmentSettings

// Represents the constraints for buying the Offer.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Constraints = src.Constraints

// Contact information for a customer account.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ContactInfo = src.ContactInfo

// Request message for
// [CloudChannelService.CreateChannelPartnerLink][google.cloud.channel.v1.CloudChannelService.CreateChannelPartnerLink]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CreateChannelPartnerLinkRequest = src.CreateChannelPartnerLinkRequest

// Request message for
// [CloudChannelService.CreateChannelPartnerRepricingConfig][google.cloud.channel.v1.CloudChannelService.CreateChannelPartnerRepricingConfig].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CreateChannelPartnerRepricingConfigRequest = src.CreateChannelPartnerRepricingConfigRequest

// Request message for
// [CloudChannelService.CreateCustomerRepricingConfig][google.cloud.channel.v1.CloudChannelService.CreateCustomerRepricingConfig].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CreateCustomerRepricingConfigRequest = src.CreateCustomerRepricingConfigRequest

// Request message for
// [CloudChannelService.CreateCustomer][google.cloud.channel.v1.CloudChannelService.CreateCustomer]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CreateCustomerRequest = src.CreateCustomerRequest

// Request message for
// [CloudChannelService.CreateEntitlement][google.cloud.channel.v1.CloudChannelService.CreateEntitlement]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CreateEntitlementRequest = src.CreateEntitlementRequest

// Entity representing a customer of a reseller or distributor.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Customer = src.Customer

// Represents constraints required to purchase the Offer for a customer.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CustomerConstraints = src.CustomerConstraints

// Represents Pub/Sub message content describing customer update.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CustomerEvent = src.CustomerEvent

// Type of customer event.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CustomerEvent_Type = src.CustomerEvent_Type

// Configuration for how a reseller will reprice a Customer.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type CustomerRepricingConfig = src.CustomerRepricingConfig

// A representation of usage or invoice date ranges.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type DateRange = src.DateRange

// Request message for DeleteChannelPartnerRepricingConfig.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type DeleteChannelPartnerRepricingConfigRequest = src.DeleteChannelPartnerRepricingConfigRequest

// Request message for
// [CloudChannelService.DeleteCustomerRepricingConfig][google.cloud.channel.v1.CloudChannelService.DeleteCustomerRepricingConfig].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type DeleteCustomerRepricingConfigRequest = src.DeleteCustomerRepricingConfigRequest

// Request message for
// [CloudChannelService.DeleteCustomer][google.cloud.channel.v1.CloudChannelService.DeleteCustomer].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type DeleteCustomerRequest = src.DeleteCustomerRequest

// Required Edu Attributes
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type EduData = src.EduData

// Number of students and staff the institute has.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type EduData_InstituteSize = src.EduData_InstituteSize

// Enum to specify the institute type.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type EduData_InstituteType = src.EduData_InstituteType

// An entitlement is a representation of a customer's ability to use a
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Entitlement = src.Entitlement

// Represents Pub/Sub message content describing entitlement update.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type EntitlementEvent = src.EntitlementEvent

// Type of entitlement event.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type EntitlementEvent_Type = src.EntitlementEvent_Type

// Indicates the current provisioning state of the entitlement.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Entitlement_ProvisioningState = src.Entitlement_ProvisioningState

// Suspension reason for an entitlement if
// [provisioning_state][google.cloud.channel.v1.Entitlement.provisioning_state]
// = SUSPENDED.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Entitlement_SuspensionReason = src.Entitlement_SuspensionReason

// Request message for
// [CloudChannelReportsService.FetchReportResults][google.cloud.channel.v1.CloudChannelReportsService.FetchReportResults].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type FetchReportResultsRequest = src.FetchReportResultsRequest

// Response message for
// [CloudChannelReportsService.FetchReportResults][google.cloud.channel.v1.CloudChannelReportsService.FetchReportResults].
// Contains a tabular representation of the report results.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type FetchReportResultsResponse = src.FetchReportResultsResponse

// Request message for
// [CloudChannelService.GetChannelPartnerLink][google.cloud.channel.v1.CloudChannelService.GetChannelPartnerLink].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type GetChannelPartnerLinkRequest = src.GetChannelPartnerLinkRequest

// Request message for
// [CloudChannelService.GetChannelPartnerRepricingConfig][google.cloud.channel.v1.CloudChannelService.GetChannelPartnerRepricingConfig]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type GetChannelPartnerRepricingConfigRequest = src.GetChannelPartnerRepricingConfigRequest

// Request message for
// [CloudChannelService.GetCustomerRepricingConfig][google.cloud.channel.v1.CloudChannelService.GetCustomerRepricingConfig].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type GetCustomerRepricingConfigRequest = src.GetCustomerRepricingConfigRequest

// Request message for
// [CloudChannelService.GetCustomer][google.cloud.channel.v1.CloudChannelService.GetCustomer].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type GetCustomerRequest = src.GetCustomerRequest

// Request message for
// [CloudChannelService.GetEntitlement][google.cloud.channel.v1.CloudChannelService.GetEntitlement].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type GetEntitlementRequest = src.GetEntitlementRequest

// Request message for
// [CloudChannelService.ImportCustomer][google.cloud.channel.v1.CloudChannelService.ImportCustomer]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ImportCustomerRequest = src.ImportCustomerRequest
type ImportCustomerRequest_CloudIdentityId = src.ImportCustomerRequest_CloudIdentityId
type ImportCustomerRequest_Domain = src.ImportCustomerRequest_Domain

// Request message for
// [CloudChannelService.ListChannelPartnerLinks][google.cloud.channel.v1.CloudChannelService.ListChannelPartnerLinks]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListChannelPartnerLinksRequest = src.ListChannelPartnerLinksRequest

// Response message for
// [CloudChannelService.ListChannelPartnerLinks][google.cloud.channel.v1.CloudChannelService.ListChannelPartnerLinks].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListChannelPartnerLinksResponse = src.ListChannelPartnerLinksResponse

// Request message for
// [CloudChannelService.ListChannelPartnerRepricingConfigs][google.cloud.channel.v1.CloudChannelService.ListChannelPartnerRepricingConfigs].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListChannelPartnerRepricingConfigsRequest = src.ListChannelPartnerRepricingConfigsRequest

// Response message for
// [CloudChannelService.ListChannelPartnerRepricingConfigs][google.cloud.channel.v1.CloudChannelService.ListChannelPartnerRepricingConfigs].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListChannelPartnerRepricingConfigsResponse = src.ListChannelPartnerRepricingConfigsResponse

// Request message for
// [CloudChannelService.ListCustomerRepricingConfigs][google.cloud.channel.v1.CloudChannelService.ListCustomerRepricingConfigs].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListCustomerRepricingConfigsRequest = src.ListCustomerRepricingConfigsRequest

// Response message for
// [CloudChannelService.ListCustomerRepricingConfigs][google.cloud.channel.v1.CloudChannelService.ListCustomerRepricingConfigs].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListCustomerRepricingConfigsResponse = src.ListCustomerRepricingConfigsResponse

// Request message for
// [CloudChannelService.ListCustomers][google.cloud.channel.v1.CloudChannelService.ListCustomers]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListCustomersRequest = src.ListCustomersRequest

// Response message for
// [CloudChannelService.ListCustomers][google.cloud.channel.v1.CloudChannelService.ListCustomers].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListCustomersResponse = src.ListCustomersResponse

// Request message for
// [CloudChannelService.ListEntitlements][google.cloud.channel.v1.CloudChannelService.ListEntitlements]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListEntitlementsRequest = src.ListEntitlementsRequest

// Response message for
// [CloudChannelService.ListEntitlements][google.cloud.channel.v1.CloudChannelService.ListEntitlements].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListEntitlementsResponse = src.ListEntitlementsResponse

// Request message for ListOffers.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListOffersRequest = src.ListOffersRequest

// Response message for ListOffers.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListOffersResponse = src.ListOffersResponse

// Request message for ListProducts.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListProductsRequest = src.ListProductsRequest

// Response message for ListProducts.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListProductsResponse = src.ListProductsResponse

// Request message for ListPurchasableOffers.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListPurchasableOffersRequest = src.ListPurchasableOffersRequest

// List Offers for ChangeOffer purchase.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListPurchasableOffersRequest_ChangeOfferPurchase = src.ListPurchasableOffersRequest_ChangeOfferPurchase
type ListPurchasableOffersRequest_ChangeOfferPurchase_ = src.ListPurchasableOffersRequest_ChangeOfferPurchase_

// List Offers for CreateEntitlement purchase.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListPurchasableOffersRequest_CreateEntitlementPurchase = src.ListPurchasableOffersRequest_CreateEntitlementPurchase
type ListPurchasableOffersRequest_CreateEntitlementPurchase_ = src.ListPurchasableOffersRequest_CreateEntitlementPurchase_

// Response message for ListPurchasableOffers.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListPurchasableOffersResponse = src.ListPurchasableOffersResponse

// Request message for ListPurchasableSkus.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListPurchasableSkusRequest = src.ListPurchasableSkusRequest

// List SKUs for upgrading or downgrading an entitlement. Make the purchase
// using
// [CloudChannelService.ChangeOffer][google.cloud.channel.v1.CloudChannelService.ChangeOffer].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListPurchasableSkusRequest_ChangeOfferPurchase = src.ListPurchasableSkusRequest_ChangeOfferPurchase
type ListPurchasableSkusRequest_ChangeOfferPurchase_ = src.ListPurchasableSkusRequest_ChangeOfferPurchase_

// Change Type enum.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListPurchasableSkusRequest_ChangeOfferPurchase_ChangeType = src.ListPurchasableSkusRequest_ChangeOfferPurchase_ChangeType

// List SKUs for a new entitlement. Make the purchase using
// [CloudChannelService.CreateEntitlement][google.cloud.channel.v1.CloudChannelService.CreateEntitlement].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListPurchasableSkusRequest_CreateEntitlementPurchase = src.ListPurchasableSkusRequest_CreateEntitlementPurchase
type ListPurchasableSkusRequest_CreateEntitlementPurchase_ = src.ListPurchasableSkusRequest_CreateEntitlementPurchase_

// Response message for ListPurchasableSkus.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListPurchasableSkusResponse = src.ListPurchasableSkusResponse

// Request message for
// [CloudChannelReportsService.ListReports][google.cloud.channel.v1.CloudChannelReportsService.ListReports].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListReportsRequest = src.ListReportsRequest

// Response message for
// [CloudChannelReportsService.ListReports][google.cloud.channel.v1.CloudChannelReportsService.ListReports].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListReportsResponse = src.ListReportsResponse

// Request message for ListSkus.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListSkusRequest = src.ListSkusRequest

// Response message for ListSkus.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListSkusResponse = src.ListSkusResponse

// Request Message for ListSubscribers.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListSubscribersRequest = src.ListSubscribersRequest

// Response Message for ListSubscribers.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListSubscribersResponse = src.ListSubscribersResponse

// Request message for
// [CloudChannelService.ListTransferableOffers][google.cloud.channel.v1.CloudChannelService.ListTransferableOffers]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListTransferableOffersRequest = src.ListTransferableOffersRequest
type ListTransferableOffersRequest_CloudIdentityId = src.ListTransferableOffersRequest_CloudIdentityId
type ListTransferableOffersRequest_CustomerName = src.ListTransferableOffersRequest_CustomerName

// Response message for
// [CloudChannelService.ListTransferableOffers][google.cloud.channel.v1.CloudChannelService.ListTransferableOffers].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListTransferableOffersResponse = src.ListTransferableOffersResponse

// Request message for
// [CloudChannelService.ListTransferableSkus][google.cloud.channel.v1.CloudChannelService.ListTransferableSkus]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListTransferableSkusRequest = src.ListTransferableSkusRequest
type ListTransferableSkusRequest_CloudIdentityId = src.ListTransferableSkusRequest_CloudIdentityId
type ListTransferableSkusRequest_CustomerName = src.ListTransferableSkusRequest_CustomerName

// Response message for
// [CloudChannelService.ListTransferableSkus][google.cloud.channel.v1.CloudChannelService.ListTransferableSkus].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ListTransferableSkusResponse = src.ListTransferableSkusResponse

// Request message for LookupOffer.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type LookupOfferRequest = src.LookupOfferRequest

// Represents the marketing information for a Product, SKU or Offer.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type MarketingInfo = src.MarketingInfo

// Represents media information.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Media = src.Media

// Type of media used.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type MediaType = src.MediaType

// Represents an offer made to resellers for purchase. An offer is associated
// with a [Sku][google.cloud.channel.v1.Sku], has a plan for payment, a price,
// and defines the constraints for buying.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Offer = src.Offer

// Provides contextual information about a
// [google.longrunning.Operation][google.longrunning.Operation].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type OperationMetadata = src.OperationMetadata

// RPCs that return a Long Running Operation.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type OperationMetadata_OperationType = src.OperationMetadata_OperationType

// Definition for extended entitlement parameters.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Parameter = src.Parameter

// Parameter's definition. Specifies what parameter is required to use the
// current Offer to purchase.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ParameterDefinition = src.ParameterDefinition

// Data type of the parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ParameterDefinition_ParameterType = src.ParameterDefinition_ParameterType

// Describes how the reseller will be billed.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type PaymentPlan = src.PaymentPlan

// Specifies when the payment needs to happen.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type PaymentType = src.PaymentType

// An adjustment that applies a flat markup or markdown to an entire bill.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type PercentageAdjustment = src.PercentageAdjustment

// Represents period in days/months/years.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Period = src.Period

// Period Type.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type PeriodType = src.PeriodType

// The payment plan for the Offer. Describes how to make a payment.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Plan = src.Plan

// Represents the price of the Offer.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Price = src.Price

// Represents price by resource type.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type PriceByResource = src.PriceByResource

// Specifies the price by the duration of months. For example, a 20% discount
// for the first six months, then a 10% discount starting on the seventh month.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type PricePhase = src.PricePhase

// Defines price at resource tier level. For example, an offer with following
// definition : * Tier 1: Provide 25% discount for all seats between 1 and 25.
// * Tier 2: Provide 10% discount for all seats between 26 and 100. * Tier 3:
// Provide flat 15% discount for all seats above 100. Each of these tiers is
// represented as a PriceTier.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type PriceTier = src.PriceTier

// A Product is the entity a customer uses when placing an order. For example,
// Google Workspace, Google Voice, etc.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Product = src.Product

// Constraints type for Promotional offers.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type PromotionalOrderType = src.PromotionalOrderType

// Request message for
// [CloudChannelService.ProvisionCloudIdentity][google.cloud.channel.v1.CloudChannelService.ProvisionCloudIdentity]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ProvisionCloudIdentityRequest = src.ProvisionCloudIdentityRequest

// Service provisioned for an entitlement.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ProvisionedService = src.ProvisionedService

// Offer that you can purchase for a customer. This is used in the
// ListPurchasableOffer API response.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type PurchasableOffer = src.PurchasableOffer

// SKU that you can purchase. This is used in ListPurchasableSku API response.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type PurchasableSku = src.PurchasableSku

// Specifies the different costs that the modified bill can be based on.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type RebillingBasis = src.RebillingBasis

// Request Message for RegisterSubscriber.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type RegisterSubscriberRequest = src.RegisterSubscriberRequest

// Response Message for RegisterSubscriber.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type RegisterSubscriberResponse = src.RegisterSubscriberResponse

// Renewal settings for renewable Offers.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type RenewalSettings = src.RenewalSettings

// The ID and description of a report that was used to generate report data.
// For example, "GCP Daily Spend", "Google Workspace License Activity", etc.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Report = src.Report

// The result of a [RunReportJob][] operation. Contains the name to use in
// [FetchReportResultsRequest.report_job][google.cloud.channel.v1.FetchReportResultsRequest.report_job]
// and the status of the operation.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ReportJob = src.ReportJob

// The features describing the data. Returned by
// [CloudChannelReportsService.RunReportJob][google.cloud.channel.v1.CloudChannelReportsService.RunReportJob]
// and
// [CloudChannelReportsService.FetchReportResults][google.cloud.channel.v1.CloudChannelReportsService.FetchReportResults].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ReportResultsMetadata = src.ReportResultsMetadata

// Status of a report generation process.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ReportStatus = src.ReportStatus

// Available states of report generation.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ReportStatus_State = src.ReportStatus_State

// A single report value.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ReportValue = src.ReportValue
type ReportValue_DateTimeValue = src.ReportValue_DateTimeValue
type ReportValue_DateValue = src.ReportValue_DateValue
type ReportValue_DecimalValue = src.ReportValue_DecimalValue
type ReportValue_IntValue = src.ReportValue_IntValue
type ReportValue_MoneyValue = src.ReportValue_MoneyValue
type ReportValue_StringValue = src.ReportValue_StringValue

// A type that represents the various adjustments you can apply to a bill.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type RepricingAdjustment = src.RepricingAdjustment
type RepricingAdjustment_PercentageAdjustment = src.RepricingAdjustment_PercentageAdjustment

// Configuration for repricing a Google bill over a period of time.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type RepricingConfig = src.RepricingConfig

// Applies the repricing configuration at the channel partner level. The
// channel partner value is derived from the resource name. Takes an empty json
// object.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type RepricingConfig_ChannelPartnerGranularity = src.RepricingConfig_ChannelPartnerGranularity
type RepricingConfig_ChannelPartnerGranularity_ = src.RepricingConfig_ChannelPartnerGranularity_

// Applies the repricing configuration at the entitlement level.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type RepricingConfig_EntitlementGranularity = src.RepricingConfig_EntitlementGranularity
type RepricingConfig_EntitlementGranularity_ = src.RepricingConfig_EntitlementGranularity_

// Represents the type for a monetizable resource(any entity on which billing
// happens). For example, this could be MINUTES for Google Voice and GB for
// Google Drive. One SKU can map to multiple monetizable resources.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type ResourceType = src.ResourceType

// A row of report values.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Row = src.Row

// Request message for
// [CloudChannelReportsService.RunReportJob][google.cloud.channel.v1.CloudChannelReportsService.RunReportJob].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type RunReportJobRequest = src.RunReportJobRequest

// Response message for
// [CloudChannelReportsService.RunReportJob][google.cloud.channel.v1.CloudChannelReportsService.RunReportJob].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type RunReportJobResponse = src.RunReportJobResponse

// Represents a product's purchasable Stock Keeping Unit (SKU). SKUs represent
// the different variations of the product. For example, Google Workspace
// Business Standard and Google Workspace Business Plus are Google Workspace
// product SKUs.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Sku = src.Sku

// Request message for
// [CloudChannelService.StartPaidService][google.cloud.channel.v1.CloudChannelService.StartPaidService].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type StartPaidServiceRequest = src.StartPaidServiceRequest

// Represents information which resellers will get as part of notification
// from Pub/Sub.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type SubscriberEvent = src.SubscriberEvent
type SubscriberEvent_CustomerEvent = src.SubscriberEvent_CustomerEvent
type SubscriberEvent_EntitlementEvent = src.SubscriberEvent_EntitlementEvent

// Request message for
// [CloudChannelService.SuspendEntitlement][google.cloud.channel.v1.CloudChannelService.SuspendEntitlement].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type SuspendEntitlementRequest = src.SuspendEntitlementRequest

// Specifies transfer eligibility of a SKU.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type TransferEligibility = src.TransferEligibility

// Reason of ineligibility.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type TransferEligibility_Reason = src.TransferEligibility_Reason

// Request message for
// [CloudChannelService.TransferEntitlements][google.cloud.channel.v1.CloudChannelService.TransferEntitlements].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type TransferEntitlementsRequest = src.TransferEntitlementsRequest

// Response message for
// [CloudChannelService.TransferEntitlements][google.cloud.channel.v1.CloudChannelService.TransferEntitlements].
// This is put in the response field of google.longrunning.Operation.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type TransferEntitlementsResponse = src.TransferEntitlementsResponse

// Request message for
// [CloudChannelService.TransferEntitlementsToGoogle][google.cloud.channel.v1.CloudChannelService.TransferEntitlementsToGoogle].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type TransferEntitlementsToGoogleRequest = src.TransferEntitlementsToGoogleRequest

// TransferableOffer represents an Offer that can be used in Transfer.
// Read-only.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type TransferableOffer = src.TransferableOffer

// TransferableSku represents information a reseller needs to view existing
// provisioned services for a customer that they do not own. Read-only.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type TransferableSku = src.TransferableSku

// Settings for trial offers.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type TrialSettings = src.TrialSettings

// UnimplementedCloudChannelReportsServiceServer can be embedded to have
// forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type UnimplementedCloudChannelReportsServiceServer = src.UnimplementedCloudChannelReportsServiceServer

// UnimplementedCloudChannelServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type UnimplementedCloudChannelServiceServer = src.UnimplementedCloudChannelServiceServer

// Request Message for UnregisterSubscriber.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type UnregisterSubscriberRequest = src.UnregisterSubscriberRequest

// Response Message for UnregisterSubscriber.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type UnregisterSubscriberResponse = src.UnregisterSubscriberResponse

// Request message for
// [CloudChannelService.UpdateChannelPartnerLink][google.cloud.channel.v1.CloudChannelService.UpdateChannelPartnerLink]
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type UpdateChannelPartnerLinkRequest = src.UpdateChannelPartnerLinkRequest

// Request message for
// [CloudChannelService.UpdateChannelPartnerRepricingConfig][google.cloud.channel.v1.CloudChannelService.UpdateChannelPartnerRepricingConfig].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type UpdateChannelPartnerRepricingConfigRequest = src.UpdateChannelPartnerRepricingConfigRequest

// Request message for
// [CloudChannelService.UpdateCustomerRepricingConfig][google.cloud.channel.v1.CloudChannelService.UpdateCustomerRepricingConfig].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type UpdateCustomerRepricingConfigRequest = src.UpdateCustomerRepricingConfigRequest

// Request message for
// [CloudChannelService.UpdateCustomer][google.cloud.channel.v1.CloudChannelService.UpdateCustomer].
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type UpdateCustomerRequest = src.UpdateCustomerRequest

// Data type and value of a parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/channel/apiv1/channelpb
type Value = src.Value
type Value_BoolValue = src.Value_BoolValue
type Value_DoubleValue = src.Value_DoubleValue
type Value_Int64Value = src.Value_Int64Value
type Value_ProtoValue = src.Value_ProtoValue
type Value_StringValue = src.Value_StringValue

// Deprecated: Please use funcs in: cloud.google.com/go/channel/apiv1/channelpb
func NewCloudChannelReportsServiceClient(cc grpc.ClientConnInterface) CloudChannelReportsServiceClient {
	return src.NewCloudChannelReportsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/channel/apiv1/channelpb
func NewCloudChannelServiceClient(cc grpc.ClientConnInterface) CloudChannelServiceClient {
	return src.NewCloudChannelServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/channel/apiv1/channelpb
func RegisterCloudChannelReportsServiceServer(s *grpc.Server, srv CloudChannelReportsServiceServer) {
	src.RegisterCloudChannelReportsServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/channel/apiv1/channelpb
func RegisterCloudChannelServiceServer(s *grpc.Server, srv CloudChannelServiceServer) {
	src.RegisterCloudChannelServiceServer(s, srv)
}
