// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package storagetransfer aliases all exported identifiers in package
// "cloud.google.com/go/storagetransfer/apiv1/storagetransferpb".
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package storagetransfer

import (
	src "cloud.google.com/go/storagetransfer/apiv1/storagetransferpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
const (
	AgentPool_CREATED                                        = src.AgentPool_CREATED
	AgentPool_CREATING                                       = src.AgentPool_CREATING
	AgentPool_DELETING                                       = src.AgentPool_DELETING
	AgentPool_STATE_UNSPECIFIED                              = src.AgentPool_STATE_UNSPECIFIED
	LoggingConfig_COPY                                       = src.LoggingConfig_COPY
	LoggingConfig_DELETE                                     = src.LoggingConfig_DELETE
	LoggingConfig_FAILED                                     = src.LoggingConfig_FAILED
	LoggingConfig_FIND                                       = src.LoggingConfig_FIND
	LoggingConfig_LOGGABLE_ACTION_STATE_UNSPECIFIED          = src.LoggingConfig_LOGGABLE_ACTION_STATE_UNSPECIFIED
	LoggingConfig_LOGGABLE_ACTION_UNSPECIFIED                = src.LoggingConfig_LOGGABLE_ACTION_UNSPECIFIED
	LoggingConfig_SUCCEEDED                                  = src.LoggingConfig_SUCCEEDED
	MetadataOptions_ACL_DESTINATION_BUCKET_DEFAULT           = src.MetadataOptions_ACL_DESTINATION_BUCKET_DEFAULT
	MetadataOptions_ACL_PRESERVE                             = src.MetadataOptions_ACL_PRESERVE
	MetadataOptions_ACL_UNSPECIFIED                          = src.MetadataOptions_ACL_UNSPECIFIED
	MetadataOptions_GID_NUMBER                               = src.MetadataOptions_GID_NUMBER
	MetadataOptions_GID_SKIP                                 = src.MetadataOptions_GID_SKIP
	MetadataOptions_GID_UNSPECIFIED                          = src.MetadataOptions_GID_UNSPECIFIED
	MetadataOptions_KMS_KEY_DESTINATION_BUCKET_DEFAULT       = src.MetadataOptions_KMS_KEY_DESTINATION_BUCKET_DEFAULT
	MetadataOptions_KMS_KEY_PRESERVE                         = src.MetadataOptions_KMS_KEY_PRESERVE
	MetadataOptions_KMS_KEY_UNSPECIFIED                      = src.MetadataOptions_KMS_KEY_UNSPECIFIED
	MetadataOptions_MODE_PRESERVE                            = src.MetadataOptions_MODE_PRESERVE
	MetadataOptions_MODE_SKIP                                = src.MetadataOptions_MODE_SKIP
	MetadataOptions_MODE_UNSPECIFIED                         = src.MetadataOptions_MODE_UNSPECIFIED
	MetadataOptions_STORAGE_CLASS_ARCHIVE                    = src.MetadataOptions_STORAGE_CLASS_ARCHIVE
	MetadataOptions_STORAGE_CLASS_COLDLINE                   = src.MetadataOptions_STORAGE_CLASS_COLDLINE
	MetadataOptions_STORAGE_CLASS_DESTINATION_BUCKET_DEFAULT = src.MetadataOptions_STORAGE_CLASS_DESTINATION_BUCKET_DEFAULT
	MetadataOptions_STORAGE_CLASS_NEARLINE                   = src.MetadataOptions_STORAGE_CLASS_NEARLINE
	MetadataOptions_STORAGE_CLASS_PRESERVE                   = src.MetadataOptions_STORAGE_CLASS_PRESERVE
	MetadataOptions_STORAGE_CLASS_STANDARD                   = src.MetadataOptions_STORAGE_CLASS_STANDARD
	MetadataOptions_STORAGE_CLASS_UNSPECIFIED                = src.MetadataOptions_STORAGE_CLASS_UNSPECIFIED
	MetadataOptions_SYMLINK_PRESERVE                         = src.MetadataOptions_SYMLINK_PRESERVE
	MetadataOptions_SYMLINK_SKIP                             = src.MetadataOptions_SYMLINK_SKIP
	MetadataOptions_SYMLINK_UNSPECIFIED                      = src.MetadataOptions_SYMLINK_UNSPECIFIED
	MetadataOptions_TEMPORARY_HOLD_PRESERVE                  = src.MetadataOptions_TEMPORARY_HOLD_PRESERVE
	MetadataOptions_TEMPORARY_HOLD_SKIP                      = src.MetadataOptions_TEMPORARY_HOLD_SKIP
	MetadataOptions_TEMPORARY_HOLD_UNSPECIFIED               = src.MetadataOptions_TEMPORARY_HOLD_UNSPECIFIED
	MetadataOptions_TIME_CREATED_PRESERVE_AS_CUSTOM_TIME     = src.MetadataOptions_TIME_CREATED_PRESERVE_AS_CUSTOM_TIME
	MetadataOptions_TIME_CREATED_SKIP                        = src.MetadataOptions_TIME_CREATED_SKIP
	MetadataOptions_TIME_CREATED_UNSPECIFIED                 = src.MetadataOptions_TIME_CREATED_UNSPECIFIED
	MetadataOptions_UID_NUMBER                               = src.MetadataOptions_UID_NUMBER
	MetadataOptions_UID_SKIP                                 = src.MetadataOptions_UID_SKIP
	MetadataOptions_UID_UNSPECIFIED                          = src.MetadataOptions_UID_UNSPECIFIED
	NotificationConfig_EVENT_TYPE_UNSPECIFIED                = src.NotificationConfig_EVENT_TYPE_UNSPECIFIED
	NotificationConfig_JSON                                  = src.NotificationConfig_JSON
	NotificationConfig_NONE                                  = src.NotificationConfig_NONE
	NotificationConfig_PAYLOAD_FORMAT_UNSPECIFIED            = src.NotificationConfig_PAYLOAD_FORMAT_UNSPECIFIED
	NotificationConfig_TRANSFER_OPERATION_ABORTED            = src.NotificationConfig_TRANSFER_OPERATION_ABORTED
	NotificationConfig_TRANSFER_OPERATION_FAILED             = src.NotificationConfig_TRANSFER_OPERATION_FAILED
	NotificationConfig_TRANSFER_OPERATION_SUCCESS            = src.NotificationConfig_TRANSFER_OPERATION_SUCCESS
	S3CompatibleMetadata_AUTH_METHOD_AWS_SIGNATURE_V2        = src.S3CompatibleMetadata_AUTH_METHOD_AWS_SIGNATURE_V2
	S3CompatibleMetadata_AUTH_METHOD_AWS_SIGNATURE_V4        = src.S3CompatibleMetadata_AUTH_METHOD_AWS_SIGNATURE_V4
	S3CompatibleMetadata_AUTH_METHOD_UNSPECIFIED             = src.S3CompatibleMetadata_AUTH_METHOD_UNSPECIFIED
	S3CompatibleMetadata_LIST_API_UNSPECIFIED                = src.S3CompatibleMetadata_LIST_API_UNSPECIFIED
	S3CompatibleMetadata_LIST_OBJECTS                        = src.S3CompatibleMetadata_LIST_OBJECTS
	S3CompatibleMetadata_LIST_OBJECTS_V2                     = src.S3CompatibleMetadata_LIST_OBJECTS_V2
	S3CompatibleMetadata_NETWORK_PROTOCOL_HTTP               = src.S3CompatibleMetadata_NETWORK_PROTOCOL_HTTP
	S3CompatibleMetadata_NETWORK_PROTOCOL_HTTPS              = src.S3CompatibleMetadata_NETWORK_PROTOCOL_HTTPS
	S3CompatibleMetadata_NETWORK_PROTOCOL_UNSPECIFIED        = src.S3CompatibleMetadata_NETWORK_PROTOCOL_UNSPECIFIED
	S3CompatibleMetadata_REQUEST_MODEL_PATH_STYLE            = src.S3CompatibleMetadata_REQUEST_MODEL_PATH_STYLE
	S3CompatibleMetadata_REQUEST_MODEL_UNSPECIFIED           = src.S3CompatibleMetadata_REQUEST_MODEL_UNSPECIFIED
	S3CompatibleMetadata_REQUEST_MODEL_VIRTUAL_HOSTED_STYLE  = src.S3CompatibleMetadata_REQUEST_MODEL_VIRTUAL_HOSTED_STYLE
	TransferJob_DELETED                                      = src.TransferJob_DELETED
	TransferJob_DISABLED                                     = src.TransferJob_DISABLED
	TransferJob_ENABLED                                      = src.TransferJob_ENABLED
	TransferJob_STATUS_UNSPECIFIED                           = src.TransferJob_STATUS_UNSPECIFIED
	TransferOperation_ABORTED                                = src.TransferOperation_ABORTED
	TransferOperation_FAILED                                 = src.TransferOperation_FAILED
	TransferOperation_IN_PROGRESS                            = src.TransferOperation_IN_PROGRESS
	TransferOperation_PAUSED                                 = src.TransferOperation_PAUSED
	TransferOperation_QUEUED                                 = src.TransferOperation_QUEUED
	TransferOperation_STATUS_UNSPECIFIED                     = src.TransferOperation_STATUS_UNSPECIFIED
	TransferOperation_SUCCESS                                = src.TransferOperation_SUCCESS
	TransferOptions_ALWAYS                                   = src.TransferOptions_ALWAYS
	TransferOptions_DIFFERENT                                = src.TransferOptions_DIFFERENT
	TransferOptions_NEVER                                    = src.TransferOptions_NEVER
	TransferOptions_OVERWRITE_WHEN_UNSPECIFIED               = src.TransferOptions_OVERWRITE_WHEN_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
var (
	AgentPool_State_name                                = src.AgentPool_State_name
	AgentPool_State_value                               = src.AgentPool_State_value
	File_google_storagetransfer_v1_transfer_proto       = src.File_google_storagetransfer_v1_transfer_proto
	File_google_storagetransfer_v1_transfer_types_proto = src.File_google_storagetransfer_v1_transfer_types_proto
	LoggingConfig_LoggableActionState_name              = src.LoggingConfig_LoggableActionState_name
	LoggingConfig_LoggableActionState_value             = src.LoggingConfig_LoggableActionState_value
	LoggingConfig_LoggableAction_name                   = src.LoggingConfig_LoggableAction_name
	LoggingConfig_LoggableAction_value                  = src.LoggingConfig_LoggableAction_value
	MetadataOptions_Acl_name                            = src.MetadataOptions_Acl_name
	MetadataOptions_Acl_value                           = src.MetadataOptions_Acl_value
	MetadataOptions_GID_name                            = src.MetadataOptions_GID_name
	MetadataOptions_GID_value                           = src.MetadataOptions_GID_value
	MetadataOptions_KmsKey_name                         = src.MetadataOptions_KmsKey_name
	MetadataOptions_KmsKey_value                        = src.MetadataOptions_KmsKey_value
	MetadataOptions_Mode_name                           = src.MetadataOptions_Mode_name
	MetadataOptions_Mode_value                          = src.MetadataOptions_Mode_value
	MetadataOptions_StorageClass_name                   = src.MetadataOptions_StorageClass_name
	MetadataOptions_StorageClass_value                  = src.MetadataOptions_StorageClass_value
	MetadataOptions_Symlink_name                        = src.MetadataOptions_Symlink_name
	MetadataOptions_Symlink_value                       = src.MetadataOptions_Symlink_value
	MetadataOptions_TemporaryHold_name                  = src.MetadataOptions_TemporaryHold_name
	MetadataOptions_TemporaryHold_value                 = src.MetadataOptions_TemporaryHold_value
	MetadataOptions_TimeCreated_name                    = src.MetadataOptions_TimeCreated_name
	MetadataOptions_TimeCreated_value                   = src.MetadataOptions_TimeCreated_value
	MetadataOptions_UID_name                            = src.MetadataOptions_UID_name
	MetadataOptions_UID_value                           = src.MetadataOptions_UID_value
	NotificationConfig_EventType_name                   = src.NotificationConfig_EventType_name
	NotificationConfig_EventType_value                  = src.NotificationConfig_EventType_value
	NotificationConfig_PayloadFormat_name               = src.NotificationConfig_PayloadFormat_name
	NotificationConfig_PayloadFormat_value              = src.NotificationConfig_PayloadFormat_value
	S3CompatibleMetadata_AuthMethod_name                = src.S3CompatibleMetadata_AuthMethod_name
	S3CompatibleMetadata_AuthMethod_value               = src.S3CompatibleMetadata_AuthMethod_value
	S3CompatibleMetadata_ListApi_name                   = src.S3CompatibleMetadata_ListApi_name
	S3CompatibleMetadata_ListApi_value                  = src.S3CompatibleMetadata_ListApi_value
	S3CompatibleMetadata_NetworkProtocol_name           = src.S3CompatibleMetadata_NetworkProtocol_name
	S3CompatibleMetadata_NetworkProtocol_value          = src.S3CompatibleMetadata_NetworkProtocol_value
	S3CompatibleMetadata_RequestModel_name              = src.S3CompatibleMetadata_RequestModel_name
	S3CompatibleMetadata_RequestModel_value             = src.S3CompatibleMetadata_RequestModel_value
	TransferJob_Status_name                             = src.TransferJob_Status_name
	TransferJob_Status_value                            = src.TransferJob_Status_value
	TransferOperation_Status_name                       = src.TransferOperation_Status_name
	TransferOperation_Status_value                      = src.TransferOperation_Status_value
	TransferOptions_OverwriteWhen_name                  = src.TransferOptions_OverwriteWhen_name
	TransferOptions_OverwriteWhen_value                 = src.TransferOptions_OverwriteWhen_value
)

// Represents an On-Premises Agent pool.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type AgentPool = src.AgentPool

// Specifies a bandwidth limit for an agent pool.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type AgentPool_BandwidthLimit = src.AgentPool_BandwidthLimit

// The state of an AgentPool.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type AgentPool_State = src.AgentPool_State

// AWS access key (see [AWS Security
// Credentials](https://docs.aws.amazon.com/general/latest/gr/aws-security-credentials.html)).
// For information on our data retention policy for user credentials, see [User
// credentials](/storage-transfer/docs/data-retention#user-credentials).
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type AwsAccessKey = src.AwsAccessKey

// An AwsS3CompatibleData resource.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type AwsS3CompatibleData = src.AwsS3CompatibleData
type AwsS3CompatibleData_S3Metadata = src.AwsS3CompatibleData_S3Metadata

// An AwsS3Data resource can be a data source, but not a data sink. In an
// AwsS3Data resource, an object's name is the S3 object's key name.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type AwsS3Data = src.AwsS3Data

// An AzureBlobStorageData resource can be a data source, but not a data sink.
// An AzureBlobStorageData resource represents one Azure container. The storage
// account determines the [Azure
// endpoint](https://docs.microsoft.com/en-us/azure/storage/common/storage-create-storage-account#storage-account-endpoints).
// In an AzureBlobStorageData resource, a blobs's name is the [Azure Blob
// Storage blob's key
// name](https://docs.microsoft.com/en-us/rest/api/storageservices/naming-and-referencing-containers--blobs--and-metadata#blob-names).
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type AzureBlobStorageData = src.AzureBlobStorageData

// Azure credentials For information on our data retention policy for user
// credentials, see [User
// credentials](/storage-transfer/docs/data-retention#user-credentials).
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type AzureCredentials = src.AzureCredentials

// Specifies the request passed to CreateAgentPool.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type CreateAgentPoolRequest = src.CreateAgentPoolRequest

// Request passed to CreateTransferJob.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type CreateTransferJobRequest = src.CreateTransferJobRequest

// Specifies the request passed to DeleteAgentPool.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type DeleteAgentPoolRequest = src.DeleteAgentPoolRequest

// Request passed to DeleteTransferJob.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type DeleteTransferJobRequest = src.DeleteTransferJobRequest

// An entry describing an error that has occurred.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type ErrorLogEntry = src.ErrorLogEntry

// A summary of errors by error code, plus a count and sample error log
// entries.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type ErrorSummary = src.ErrorSummary

// In a GcsData resource, an object's name is the Cloud Storage object's name
// and its "last modification time" refers to the object's `updated` property
// of Cloud Storage objects, which changes when the content or the metadata of
// the object is updated.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type GcsData = src.GcsData

// Specifies the request passed to GetAgentPool.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type GetAgentPoolRequest = src.GetAgentPoolRequest

// Request passed to GetGoogleServiceAccount.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type GetGoogleServiceAccountRequest = src.GetGoogleServiceAccountRequest

// Request passed to GetTransferJob.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type GetTransferJobRequest = src.GetTransferJobRequest

// Google service account
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type GoogleServiceAccount = src.GoogleServiceAccount

// An HttpData resource specifies a list of objects on the web to be
// transferred over HTTP. The information of the objects to be transferred is
// contained in a file referenced by a URL. The first line in the file must be
// `"TsvHttpData-1.0"`, which specifies the format of the file. Subsequent
// lines specify the information of the list of objects, one object per list
// entry. Each entry has the following tab-delimited fields: * **HTTP URL** —
// The location of the object. * **Length** — The size of the object in
// bytes. * **MD5** — The base64-encoded MD5 hash of the object. For an
// example of a valid TSV file, see [Transferring data from
// URLs](https://cloud.google.com/storage-transfer/docs/create-url-list). When
// transferring data based on a URL list, keep the following in mind: * When an
// object located at `http(s)://hostname:port/<URL-path>` is transferred to a
// data sink, the name of the object at the data sink is
// `<hostname>/<URL-path>`. * If the specified size of an object does not match
// the actual size of the object fetched, the object is not transferred. * If
// the specified MD5 does not match the MD5 computed from the transferred
// bytes, the object transfer fails. * Ensure that each URL you specify is
// publicly accessible. For example, in Cloud Storage you can [share an object
// publicly] (/storage/docs/cloud-console#_sharingdata) and get a link to it. *
// Storage Transfer Service obeys `robots.txt` rules and requires the source
// HTTP server to support `Range` requests and to return a `Content-Length`
// header in each response. *
// [ObjectConditions][google.storagetransfer.v1.ObjectConditions] have no
// effect when filtering objects to transfer.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type HttpData = src.HttpData

// The request passed to ListAgentPools.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type ListAgentPoolsRequest = src.ListAgentPoolsRequest

// Response from ListAgentPools.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type ListAgentPoolsResponse = src.ListAgentPoolsResponse

// `projectId`, `jobNames`, and `jobStatuses` are query parameters that can be
// specified when listing transfer jobs.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type ListTransferJobsRequest = src.ListTransferJobsRequest

// Response from ListTransferJobs.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type ListTransferJobsResponse = src.ListTransferJobsResponse

// Specifies the logging behavior for transfer operations. For cloud-to-cloud
// transfers, logs are sent to Cloud Logging. See [Read transfer
// logs](https://cloud.google.com/storage-transfer/docs/read-transfer-logs) for
// details. For transfers to or from a POSIX file system, logs are stored in
// the Cloud Storage bucket that is the source or sink of the transfer. See
// [Managing Transfer for on-premises jobs]
// (https://cloud.google.com/storage-transfer/docs/managing-on-prem-jobs#viewing-logs)
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type LoggingConfig = src.LoggingConfig

// Loggable actions.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type LoggingConfig_LoggableAction = src.LoggingConfig_LoggableAction

// Loggable action states.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type LoggingConfig_LoggableActionState = src.LoggingConfig_LoggableActionState

// Specifies the metadata options for running a transfer.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type MetadataOptions = src.MetadataOptions

// Options for handling Cloud Storage object ACLs.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type MetadataOptions_Acl = src.MetadataOptions_Acl

// Options for handling file GID attribute.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type MetadataOptions_GID = src.MetadataOptions_GID

// Options for handling the KmsKey setting for Google Cloud Storage objects.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type MetadataOptions_KmsKey = src.MetadataOptions_KmsKey

// Options for handling file mode attribute.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type MetadataOptions_Mode = src.MetadataOptions_Mode

// Options for handling Google Cloud Storage object storage class.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type MetadataOptions_StorageClass = src.MetadataOptions_StorageClass

// Whether symlinks should be skipped or preserved during a transfer job.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type MetadataOptions_Symlink = src.MetadataOptions_Symlink

// Options for handling temporary holds for Google Cloud Storage objects.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type MetadataOptions_TemporaryHold = src.MetadataOptions_TemporaryHold

// Options for handling `timeCreated` metadata for Google Cloud Storage
// objects.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type MetadataOptions_TimeCreated = src.MetadataOptions_TimeCreated

// Options for handling file UID attribute.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type MetadataOptions_UID = src.MetadataOptions_UID

// Specification to configure notifications published to Pub/Sub.
// Notifications are published to the customer-provided topic using the
// following `PubsubMessage.attributes`: * `"eventType"`: one of the
// [EventType][google.storagetransfer.v1.NotificationConfig.EventType] values *
// `"payloadFormat"`: one of the
// [PayloadFormat][google.storagetransfer.v1.NotificationConfig.PayloadFormat]
// values * `"projectId"`: the
// [project_id][google.storagetransfer.v1.TransferOperation.project_id] of the
// `TransferOperation` * `"transferJobName"`: the
// [transfer_job_name][google.storagetransfer.v1.TransferOperation.transfer_job_name]
// of the `TransferOperation` * `"transferOperationName"`: the
// [name][google.storagetransfer.v1.TransferOperation.name] of the
// `TransferOperation` The `PubsubMessage.data` contains a
// [TransferOperation][google.storagetransfer.v1.TransferOperation] resource
// formatted according to the specified `PayloadFormat`.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type NotificationConfig = src.NotificationConfig

// Enum for specifying event types for which notifications are to be
// published. Additional event types may be added in the future. Clients should
// either safely ignore unrecognized event types or explicitly specify which
// event types they are prepared to accept.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type NotificationConfig_EventType = src.NotificationConfig_EventType

// Enum for specifying the format of a notification message's payload.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type NotificationConfig_PayloadFormat = src.NotificationConfig_PayloadFormat

// Conditions that determine which objects are transferred. Applies only to
// Cloud Data Sources such as S3, Azure, and Cloud Storage. The "last
// modification time" refers to the time of the last change to the object's
// content or metadata — specifically, this is the `updated` property of
// Cloud Storage objects, the `LastModified` field of S3 objects, and the
// `Last-Modified` header of Azure blobs. Transfers with a
// [PosixFilesystem][google.storagetransfer.v1.PosixFilesystem] source or
// destination don't support `ObjectConditions`.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type ObjectConditions = src.ObjectConditions

// Request passed to PauseTransferOperation.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type PauseTransferOperationRequest = src.PauseTransferOperationRequest

// A POSIX filesystem resource.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type PosixFilesystem = src.PosixFilesystem

// Request passed to ResumeTransferOperation.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type ResumeTransferOperationRequest = src.ResumeTransferOperationRequest

// Request passed to RunTransferJob.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type RunTransferJobRequest = src.RunTransferJobRequest

// S3CompatibleMetadata contains the metadata fields that apply to the basic
// types of S3-compatible data providers.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type S3CompatibleMetadata = src.S3CompatibleMetadata

// The authentication and authorization method used by the storage service.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type S3CompatibleMetadata_AuthMethod = src.S3CompatibleMetadata_AuthMethod

// The Listing API to use for discovering objects.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type S3CompatibleMetadata_ListApi = src.S3CompatibleMetadata_ListApi

// The agent network protocol to access the storage service.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type S3CompatibleMetadata_NetworkProtocol = src.S3CompatibleMetadata_NetworkProtocol

// The request model of the API.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type S3CompatibleMetadata_RequestModel = src.S3CompatibleMetadata_RequestModel

// Transfers can be scheduled to recur or to run just once.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type Schedule = src.Schedule

// StorageTransferServiceClient is the client API for StorageTransferService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type StorageTransferServiceClient = src.StorageTransferServiceClient

// StorageTransferServiceServer is the server API for StorageTransferService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type StorageTransferServiceServer = src.StorageTransferServiceServer

// A collection of counters that report the progress of a transfer operation.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type TransferCounters = src.TransferCounters

// This resource represents the configuration of a transfer job that runs
// periodically.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type TransferJob = src.TransferJob

// The status of the transfer job.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type TransferJob_Status = src.TransferJob_Status

// Specifies where the manifest is located.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type TransferManifest = src.TransferManifest

// A description of the execution of a transfer.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type TransferOperation = src.TransferOperation

// The status of a TransferOperation.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type TransferOperation_Status = src.TransferOperation_Status

// TransferOptions define the actions to be performed on objects in a
// transfer.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type TransferOptions = src.TransferOptions

// Specifies when to overwrite an object in the sink when an object with
// matching name is found in the source.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type TransferOptions_OverwriteWhen = src.TransferOptions_OverwriteWhen

// Configuration for running a transfer.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type TransferSpec = src.TransferSpec
type TransferSpec_AwsS3CompatibleDataSource = src.TransferSpec_AwsS3CompatibleDataSource
type TransferSpec_AwsS3DataSource = src.TransferSpec_AwsS3DataSource
type TransferSpec_AzureBlobStorageDataSource = src.TransferSpec_AzureBlobStorageDataSource
type TransferSpec_GcsDataSink = src.TransferSpec_GcsDataSink
type TransferSpec_GcsDataSource = src.TransferSpec_GcsDataSource
type TransferSpec_GcsIntermediateDataLocation = src.TransferSpec_GcsIntermediateDataLocation
type TransferSpec_HttpDataSource = src.TransferSpec_HttpDataSource
type TransferSpec_PosixDataSink = src.TransferSpec_PosixDataSink
type TransferSpec_PosixDataSource = src.TransferSpec_PosixDataSource

// UnimplementedStorageTransferServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type UnimplementedStorageTransferServiceServer = src.UnimplementedStorageTransferServiceServer

// Specifies the request passed to UpdateAgentPool.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type UpdateAgentPoolRequest = src.UpdateAgentPoolRequest

// Request passed to UpdateTransferJob.
//
// Deprecated: Please use types in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
type UpdateTransferJobRequest = src.UpdateTransferJobRequest

// Deprecated: Please use funcs in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
func NewStorageTransferServiceClient(cc grpc.ClientConnInterface) StorageTransferServiceClient {
	return src.NewStorageTransferServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/storagetransfer/apiv1/storagetransferpb
func RegisterStorageTransferServiceServer(s *grpc.Server, srv StorageTransferServiceServer) {
	src.RegisterStorageTransferServiceServer(s, srv)
}
