// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package artifactregistry aliases all exported identifiers in package
// "cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb".
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package artifactregistry

import (
	src "cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
const (
	AptArtifact_BINARY                                          = src.AptArtifact_BINARY
	AptArtifact_PACKAGE_TYPE_UNSPECIFIED                        = src.AptArtifact_PACKAGE_TYPE_UNSPECIFIED
	AptArtifact_SOURCE                                          = src.AptArtifact_SOURCE
	Hash_HASH_TYPE_UNSPECIFIED                                  = src.Hash_HASH_TYPE_UNSPECIFIED
	Hash_MD5                                                    = src.Hash_MD5
	Hash_SHA256                                                 = src.Hash_SHA256
	ProjectSettings_REDIRECTION_FROM_GCR_IO_DISABLED            = src.ProjectSettings_REDIRECTION_FROM_GCR_IO_DISABLED
	ProjectSettings_REDIRECTION_FROM_GCR_IO_ENABLED             = src.ProjectSettings_REDIRECTION_FROM_GCR_IO_ENABLED
	ProjectSettings_REDIRECTION_FROM_GCR_IO_FINALIZED           = src.ProjectSettings_REDIRECTION_FROM_GCR_IO_FINALIZED
	ProjectSettings_REDIRECTION_STATE_UNSPECIFIED               = src.ProjectSettings_REDIRECTION_STATE_UNSPECIFIED
	Repository_APT                                              = src.Repository_APT
	Repository_DOCKER                                           = src.Repository_DOCKER
	Repository_FORMAT_UNSPECIFIED                               = src.Repository_FORMAT_UNSPECIFIED
	Repository_MAVEN                                            = src.Repository_MAVEN
	Repository_MavenRepositoryConfig_RELEASE                    = src.Repository_MavenRepositoryConfig_RELEASE
	Repository_MavenRepositoryConfig_SNAPSHOT                   = src.Repository_MavenRepositoryConfig_SNAPSHOT
	Repository_MavenRepositoryConfig_VERSION_POLICY_UNSPECIFIED = src.Repository_MavenRepositoryConfig_VERSION_POLICY_UNSPECIFIED
	Repository_NPM                                              = src.Repository_NPM
	Repository_PYTHON                                           = src.Repository_PYTHON
	Repository_YUM                                              = src.Repository_YUM
	VersionView_BASIC                                           = src.VersionView_BASIC
	VersionView_FULL                                            = src.VersionView_FULL
	VersionView_VERSION_VIEW_UNSPECIFIED                        = src.VersionView_VERSION_VIEW_UNSPECIFIED
	YumArtifact_BINARY                                          = src.YumArtifact_BINARY
	YumArtifact_PACKAGE_TYPE_UNSPECIFIED                        = src.YumArtifact_PACKAGE_TYPE_UNSPECIFIED
	YumArtifact_SOURCE                                          = src.YumArtifact_SOURCE
)

// Deprecated: Please use vars in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
var (
	AptArtifact_PackageType_name                                = src.AptArtifact_PackageType_name
	AptArtifact_PackageType_value                               = src.AptArtifact_PackageType_value
	File_google_devtools_artifactregistry_v1_apt_artifact_proto = src.File_google_devtools_artifactregistry_v1_apt_artifact_proto
	File_google_devtools_artifactregistry_v1_artifact_proto     = src.File_google_devtools_artifactregistry_v1_artifact_proto
	File_google_devtools_artifactregistry_v1_file_proto         = src.File_google_devtools_artifactregistry_v1_file_proto
	File_google_devtools_artifactregistry_v1_package_proto      = src.File_google_devtools_artifactregistry_v1_package_proto
	File_google_devtools_artifactregistry_v1_repository_proto   = src.File_google_devtools_artifactregistry_v1_repository_proto
	File_google_devtools_artifactregistry_v1_service_proto      = src.File_google_devtools_artifactregistry_v1_service_proto
	File_google_devtools_artifactregistry_v1_settings_proto     = src.File_google_devtools_artifactregistry_v1_settings_proto
	File_google_devtools_artifactregistry_v1_tag_proto          = src.File_google_devtools_artifactregistry_v1_tag_proto
	File_google_devtools_artifactregistry_v1_version_proto      = src.File_google_devtools_artifactregistry_v1_version_proto
	File_google_devtools_artifactregistry_v1_yum_artifact_proto = src.File_google_devtools_artifactregistry_v1_yum_artifact_proto
	Hash_HashType_name                                          = src.Hash_HashType_name
	Hash_HashType_value                                         = src.Hash_HashType_value
	ProjectSettings_RedirectionState_name                       = src.ProjectSettings_RedirectionState_name
	ProjectSettings_RedirectionState_value                      = src.ProjectSettings_RedirectionState_value
	Repository_Format_name                                      = src.Repository_Format_name
	Repository_Format_value                                     = src.Repository_Format_value
	Repository_MavenRepositoryConfig_VersionPolicy_name         = src.Repository_MavenRepositoryConfig_VersionPolicy_name
	Repository_MavenRepositoryConfig_VersionPolicy_value        = src.Repository_MavenRepositoryConfig_VersionPolicy_value
	VersionView_name                                            = src.VersionView_name
	VersionView_value                                           = src.VersionView_value
	YumArtifact_PackageType_name                                = src.YumArtifact_PackageType_name
	YumArtifact_PackageType_value                               = src.YumArtifact_PackageType_value
)

// A detailed representation of an Apt artifact. Information in the record is
// derived from the archive's control file. See
// https://www.debian.org/doc/debian-policy/ch-controlfields.html
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type AptArtifact = src.AptArtifact

// Package type is either binary or source.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type AptArtifact_PackageType = src.AptArtifact_PackageType

// ArtifactRegistryClient is the client API for ArtifactRegistry service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ArtifactRegistryClient = src.ArtifactRegistryClient

// ArtifactRegistryServer is the server API for ArtifactRegistry service.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ArtifactRegistryServer = src.ArtifactRegistryServer

// The request to create a new repository.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type CreateRepositoryRequest = src.CreateRepositoryRequest

// The request to create a new tag.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type CreateTagRequest = src.CreateTagRequest

// The request to delete a package.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type DeletePackageRequest = src.DeletePackageRequest

// The request to delete a repository.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type DeleteRepositoryRequest = src.DeleteRepositoryRequest

// The request to delete a tag.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type DeleteTagRequest = src.DeleteTagRequest

// The request to delete a version.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type DeleteVersionRequest = src.DeleteVersionRequest

// DockerImage represents a docker artifact. The following fields are returned
// as untyped metadata in the Version resource, using camelcase keys (i.e.
// metadata.imageSizeBytes): * imageSizeBytes * mediaType * buildTime
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type DockerImage = src.DockerImage

// Files store content that is potentially associated with Packages or
// Versions.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type File = src.File

// The request to get docker images.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type GetDockerImageRequest = src.GetDockerImageRequest

// The request to retrieve a file.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type GetFileRequest = src.GetFileRequest

// The request to retrieve a package.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type GetPackageRequest = src.GetPackageRequest

// Gets the redirection status for a project.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type GetProjectSettingsRequest = src.GetProjectSettingsRequest

// The request to retrieve a repository.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type GetRepositoryRequest = src.GetRepositoryRequest

// The request to retrieve a tag.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type GetTagRequest = src.GetTagRequest

// The request to retrieve a version.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type GetVersionRequest = src.GetVersionRequest

// A hash of file content.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type Hash = src.Hash

// The algorithm used to compute the hash.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type Hash_HashType = src.Hash_HashType

// Error information explaining why a package was not imported.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ImportAptArtifactsErrorInfo = src.ImportAptArtifactsErrorInfo
type ImportAptArtifactsErrorInfo_GcsSource = src.ImportAptArtifactsErrorInfo_GcsSource

// Google Cloud Storage location where the artifacts currently reside.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ImportAptArtifactsGcsSource = src.ImportAptArtifactsGcsSource

// The operation metadata for importing artifacts.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ImportAptArtifactsMetadata = src.ImportAptArtifactsMetadata

// The request to import new apt artifacts.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ImportAptArtifactsRequest = src.ImportAptArtifactsRequest
type ImportAptArtifactsRequest_GcsSource = src.ImportAptArtifactsRequest_GcsSource

// The response message from importing APT artifacts.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ImportAptArtifactsResponse = src.ImportAptArtifactsResponse

// Error information explaining why a package was not imported.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ImportYumArtifactsErrorInfo = src.ImportYumArtifactsErrorInfo
type ImportYumArtifactsErrorInfo_GcsSource = src.ImportYumArtifactsErrorInfo_GcsSource

// Google Cloud Storage location where the artifacts currently reside.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ImportYumArtifactsGcsSource = src.ImportYumArtifactsGcsSource

// The operation metadata for importing artifacts.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ImportYumArtifactsMetadata = src.ImportYumArtifactsMetadata

// The request to import new yum artifacts.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ImportYumArtifactsRequest = src.ImportYumArtifactsRequest
type ImportYumArtifactsRequest_GcsSource = src.ImportYumArtifactsRequest_GcsSource

// The response message from importing YUM artifacts.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ImportYumArtifactsResponse = src.ImportYumArtifactsResponse

// The request to list docker images.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListDockerImagesRequest = src.ListDockerImagesRequest

// The response from listing docker images.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListDockerImagesResponse = src.ListDockerImagesResponse

// The request to list files.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListFilesRequest = src.ListFilesRequest

// The response from listing files.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListFilesResponse = src.ListFilesResponse

// The request to list packages.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListPackagesRequest = src.ListPackagesRequest

// The response from listing packages.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListPackagesResponse = src.ListPackagesResponse

// The request to list repositories.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListRepositoriesRequest = src.ListRepositoriesRequest

// The response from listing repositories.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListRepositoriesResponse = src.ListRepositoriesResponse

// The request to list tags.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListTagsRequest = src.ListTagsRequest

// The response from listing tags.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListTagsResponse = src.ListTagsResponse

// The request to list versions.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListVersionsRequest = src.ListVersionsRequest

// The response from listing versions.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ListVersionsResponse = src.ListVersionsResponse

// Metadata type for longrunning-operations, currently empty.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type OperationMetadata = src.OperationMetadata

// Packages are named collections of versions.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type Package = src.Package

// The Artifact Registry settings that apply to a Project.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ProjectSettings = src.ProjectSettings

// The possible redirection states for legacy repositories.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type ProjectSettings_RedirectionState = src.ProjectSettings_RedirectionState

// A Repository for storing artifacts with a specific format.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type Repository = src.Repository

// A package format.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type Repository_Format = src.Repository_Format
type Repository_MavenConfig = src.Repository_MavenConfig

// MavenRepositoryConfig is maven related repository details. Provides
// additional configuration details for repositories of the maven format type.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type Repository_MavenRepositoryConfig = src.Repository_MavenRepositoryConfig

// VersionPolicy is the version policy for the repository.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type Repository_MavenRepositoryConfig_VersionPolicy = src.Repository_MavenRepositoryConfig_VersionPolicy

// Tags point to a version and represent an alternative name that can be used
// to access the version.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type Tag = src.Tag

// UnimplementedArtifactRegistryServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type UnimplementedArtifactRegistryServer = src.UnimplementedArtifactRegistryServer

// Sets the settings of the project.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type UpdateProjectSettingsRequest = src.UpdateProjectSettingsRequest

// The request to update a repository.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type UpdateRepositoryRequest = src.UpdateRepositoryRequest

// The request to create or update a tag.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type UpdateTagRequest = src.UpdateTagRequest

// The body of a version resource. A version resource represents a collection
// of components, such as files and other data. This may correspond to a
// version in many package management schemes.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type Version = src.Version

// The view, which determines what version information is returned in a
// response.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type VersionView = src.VersionView

// A detailed representation of a Yum artifact.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type YumArtifact = src.YumArtifact

// Package type is either binary or source.
//
// Deprecated: Please use types in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
type YumArtifact_PackageType = src.YumArtifact_PackageType

// Deprecated: Please use funcs in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
func NewArtifactRegistryClient(cc grpc.ClientConnInterface) ArtifactRegistryClient {
	return src.NewArtifactRegistryClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/artifactregistry/apiv1/artifactregistrypb
func RegisterArtifactRegistryServer(s *grpc.Server, srv ArtifactRegistryServer) {
	src.RegisterArtifactRegistryServer(s, srv)
}
