// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package assuredworkloads aliases all exported identifiers in package
// "cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb".
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package assuredworkloads

import (
	src "cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
const (
	RestrictAllowedResourcesRequest_ALLOW_ALL_GCP_RESOURCES           = src.RestrictAllowedResourcesRequest_ALLOW_ALL_GCP_RESOURCES
	RestrictAllowedResourcesRequest_ALLOW_COMPLIANT_RESOURCES         = src.RestrictAllowedResourcesRequest_ALLOW_COMPLIANT_RESOURCES
	RestrictAllowedResourcesRequest_RESTRICTION_TYPE_UNSPECIFIED      = src.RestrictAllowedResourcesRequest_RESTRICTION_TYPE_UNSPECIFIED
	Workload_AU_REGIONS_AND_US_SUPPORT                                = src.Workload_AU_REGIONS_AND_US_SUPPORT
	Workload_CA_REGIONS_AND_SUPPORT                                   = src.Workload_CA_REGIONS_AND_SUPPORT
	Workload_CJIS                                                     = src.Workload_CJIS
	Workload_COMPLIANCE_REGIME_UNSPECIFIED                            = src.Workload_COMPLIANCE_REGIME_UNSPECIFIED
	Workload_EU_REGIONS_AND_SUPPORT                                   = src.Workload_EU_REGIONS_AND_SUPPORT
	Workload_FEDRAMP_HIGH                                             = src.Workload_FEDRAMP_HIGH
	Workload_FEDRAMP_MODERATE                                         = src.Workload_FEDRAMP_MODERATE
	Workload_HIPAA                                                    = src.Workload_HIPAA
	Workload_HITRUST                                                  = src.Workload_HITRUST
	Workload_IL4                                                      = src.Workload_IL4
	Workload_ITAR                                                     = src.Workload_ITAR
	Workload_KAJ_ENROLLMENT_STATE_COMPLETE                            = src.Workload_KAJ_ENROLLMENT_STATE_COMPLETE
	Workload_KAJ_ENROLLMENT_STATE_PENDING                             = src.Workload_KAJ_ENROLLMENT_STATE_PENDING
	Workload_KAJ_ENROLLMENT_STATE_UNSPECIFIED                         = src.Workload_KAJ_ENROLLMENT_STATE_UNSPECIFIED
	Workload_ResourceInfo_CONSUMER_FOLDER                             = src.Workload_ResourceInfo_CONSUMER_FOLDER
	Workload_ResourceInfo_CONSUMER_PROJECT                            = src.Workload_ResourceInfo_CONSUMER_PROJECT
	Workload_ResourceInfo_ENCRYPTION_KEYS_PROJECT                     = src.Workload_ResourceInfo_ENCRYPTION_KEYS_PROJECT
	Workload_ResourceInfo_KEYRING                                     = src.Workload_ResourceInfo_KEYRING
	Workload_ResourceInfo_RESOURCE_TYPE_UNSPECIFIED                   = src.Workload_ResourceInfo_RESOURCE_TYPE_UNSPECIFIED
	Workload_SaaEnrollmentResponse_ERROR_INVALID_BASE_SETUP           = src.Workload_SaaEnrollmentResponse_ERROR_INVALID_BASE_SETUP
	Workload_SaaEnrollmentResponse_ERROR_MISSING_EXTERNAL_SIGNING_KEY = src.Workload_SaaEnrollmentResponse_ERROR_MISSING_EXTERNAL_SIGNING_KEY
	Workload_SaaEnrollmentResponse_ERROR_NOT_ALL_SERVICES_ENROLLED    = src.Workload_SaaEnrollmentResponse_ERROR_NOT_ALL_SERVICES_ENROLLED
	Workload_SaaEnrollmentResponse_ERROR_SETUP_CHECK_FAILED           = src.Workload_SaaEnrollmentResponse_ERROR_SETUP_CHECK_FAILED
	Workload_SaaEnrollmentResponse_SETUP_ERROR_UNSPECIFIED            = src.Workload_SaaEnrollmentResponse_SETUP_ERROR_UNSPECIFIED
	Workload_SaaEnrollmentResponse_SETUP_STATE_UNSPECIFIED            = src.Workload_SaaEnrollmentResponse_SETUP_STATE_UNSPECIFIED
	Workload_SaaEnrollmentResponse_STATUS_COMPLETE                    = src.Workload_SaaEnrollmentResponse_STATUS_COMPLETE
	Workload_SaaEnrollmentResponse_STATUS_PENDING                     = src.Workload_SaaEnrollmentResponse_STATUS_PENDING
	Workload_US_REGIONAL_ACCESS                                       = src.Workload_US_REGIONAL_ACCESS
)

// Deprecated: Please use vars in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
var (
	File_google_cloud_assuredworkloads_v1beta1_assuredworkloads_proto         = src.File_google_cloud_assuredworkloads_v1beta1_assuredworkloads_proto
	File_google_cloud_assuredworkloads_v1beta1_assuredworkloads_service_proto = src.File_google_cloud_assuredworkloads_v1beta1_assuredworkloads_service_proto
	RestrictAllowedResourcesRequest_RestrictionType_name                      = src.RestrictAllowedResourcesRequest_RestrictionType_name
	RestrictAllowedResourcesRequest_RestrictionType_value                     = src.RestrictAllowedResourcesRequest_RestrictionType_value
	Workload_ComplianceRegime_name                                            = src.Workload_ComplianceRegime_name
	Workload_ComplianceRegime_value                                           = src.Workload_ComplianceRegime_value
	Workload_KajEnrollmentState_name                                          = src.Workload_KajEnrollmentState_name
	Workload_KajEnrollmentState_value                                         = src.Workload_KajEnrollmentState_value
	Workload_ResourceInfo_ResourceType_name                                   = src.Workload_ResourceInfo_ResourceType_name
	Workload_ResourceInfo_ResourceType_value                                  = src.Workload_ResourceInfo_ResourceType_value
	Workload_SaaEnrollmentResponse_SetupError_name                            = src.Workload_SaaEnrollmentResponse_SetupError_name
	Workload_SaaEnrollmentResponse_SetupError_value                           = src.Workload_SaaEnrollmentResponse_SetupError_value
	Workload_SaaEnrollmentResponse_SetupState_name                            = src.Workload_SaaEnrollmentResponse_SetupState_name
	Workload_SaaEnrollmentResponse_SetupState_value                           = src.Workload_SaaEnrollmentResponse_SetupState_value
)

// A request to analyze a hypothetical move of a source project or
// project-based workload to a target (destination) folder-based workload.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type AnalyzeWorkloadMoveRequest = src.AnalyzeWorkloadMoveRequest
type AnalyzeWorkloadMoveRequest_Project = src.AnalyzeWorkloadMoveRequest_Project
type AnalyzeWorkloadMoveRequest_Source = src.AnalyzeWorkloadMoveRequest_Source

// A response that includes the analysis of the hypothetical resource move.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type AnalyzeWorkloadMoveResponse = src.AnalyzeWorkloadMoveResponse

// AssuredWorkloadsServiceClient is the client API for AssuredWorkloadsService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type AssuredWorkloadsServiceClient = src.AssuredWorkloadsServiceClient

// AssuredWorkloadsServiceServer is the server API for AssuredWorkloadsService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type AssuredWorkloadsServiceServer = src.AssuredWorkloadsServiceServer

// Operation metadata to give request details of CreateWorkload.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type CreateWorkloadOperationMetadata = src.CreateWorkloadOperationMetadata

// Request for creating a workload.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type CreateWorkloadRequest = src.CreateWorkloadRequest

// Request for deleting a Workload.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type DeleteWorkloadRequest = src.DeleteWorkloadRequest

// Request for fetching a workload.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type GetWorkloadRequest = src.GetWorkloadRequest

// Request for fetching workloads in an organization.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type ListWorkloadsRequest = src.ListWorkloadsRequest

// Response of ListWorkloads endpoint.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type ListWorkloadsResponse = src.ListWorkloadsResponse

// Request for restricting list of available resources in Workload
// environment.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type RestrictAllowedResourcesRequest = src.RestrictAllowedResourcesRequest

// The type of restriction.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type RestrictAllowedResourcesRequest_RestrictionType = src.RestrictAllowedResourcesRequest_RestrictionType

// Response for restricting the list of allowed resources.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type RestrictAllowedResourcesResponse = src.RestrictAllowedResourcesResponse

// UnimplementedAssuredWorkloadsServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type UnimplementedAssuredWorkloadsServiceServer = src.UnimplementedAssuredWorkloadsServiceServer

// Request for Updating a workload.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type UpdateWorkloadRequest = src.UpdateWorkloadRequest

// An Workload object for managing highly regulated workloads of cloud
// customers.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload = src.Workload

// Settings specific to resources needed for CJIS. Deprecated: Do not use.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_CJISSettings = src.Workload_CJISSettings
type Workload_CjisSettings = src.Workload_CjisSettings

// Supported Compliance Regimes.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_ComplianceRegime = src.Workload_ComplianceRegime

// Settings specific to resources needed for FedRAMP High. Deprecated: Do not
// use.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_FedrampHighSettings = src.Workload_FedrampHighSettings
type Workload_FedrampHighSettings_ = src.Workload_FedrampHighSettings_

// Settings specific to resources needed for FedRAMP Moderate. Deprecated: Do
// not use.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_FedrampModerateSettings = src.Workload_FedrampModerateSettings
type Workload_FedrampModerateSettings_ = src.Workload_FedrampModerateSettings_

// Settings specific to resources needed for IL4. Deprecated: Do not use.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_IL4Settings = src.Workload_IL4Settings
type Workload_Il4Settings = src.Workload_Il4Settings

// Settings specific to the Key Management Service. Deprecated: Do not use.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_KMSSettings = src.Workload_KMSSettings

// Key Access Justifications(KAJ) Enrollment State.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_KajEnrollmentState = src.Workload_KajEnrollmentState

// Represent the resources that are children of this Workload.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_ResourceInfo = src.Workload_ResourceInfo

// The type of resource.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_ResourceInfo_ResourceType = src.Workload_ResourceInfo_ResourceType

// Represent the custom settings for the resources to be created.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_ResourceSettings = src.Workload_ResourceSettings

// Signed Access Approvals (SAA) enrollment response.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_SaaEnrollmentResponse = src.Workload_SaaEnrollmentResponse

// Setup error of SAA enrollment.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_SaaEnrollmentResponse_SetupError = src.Workload_SaaEnrollmentResponse_SetupError

// Setup state of SAA enrollment.
//
// Deprecated: Please use types in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
type Workload_SaaEnrollmentResponse_SetupState = src.Workload_SaaEnrollmentResponse_SetupState

// Deprecated: Please use funcs in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
func NewAssuredWorkloadsServiceClient(cc grpc.ClientConnInterface) AssuredWorkloadsServiceClient {
	return src.NewAssuredWorkloadsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/assuredworkloads/apiv1beta1/assuredworkloadspb
func RegisterAssuredWorkloadsServiceServer(s *grpc.Server, srv AssuredWorkloadsServiceServer) {
	src.RegisterAssuredWorkloadsServiceServer(s, srv)
}
