// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package migration aliases all exported identifiers in package
// "cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb".
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package migration

import (
	src "cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
const (
	IdentifierSettings_IDENTIFIER_CASE_UNSPECIFIED         = src.IdentifierSettings_IDENTIFIER_CASE_UNSPECIFIED
	IdentifierSettings_IDENTIFIER_REWRITE_MODE_UNSPECIFIED = src.IdentifierSettings_IDENTIFIER_REWRITE_MODE_UNSPECIFIED
	IdentifierSettings_LOWER                               = src.IdentifierSettings_LOWER
	IdentifierSettings_NONE                                = src.IdentifierSettings_NONE
	IdentifierSettings_ORIGINAL                            = src.IdentifierSettings_ORIGINAL
	IdentifierSettings_REWRITE_ALL                         = src.IdentifierSettings_REWRITE_ALL
	IdentifierSettings_UPPER                               = src.IdentifierSettings_UPPER
	MigrationSubtask_ACTIVE                                = src.MigrationSubtask_ACTIVE
	MigrationSubtask_FAILED                                = src.MigrationSubtask_FAILED
	MigrationSubtask_PAUSED                                = src.MigrationSubtask_PAUSED
	MigrationSubtask_RUNNING                               = src.MigrationSubtask_RUNNING
	MigrationSubtask_STATE_UNSPECIFIED                     = src.MigrationSubtask_STATE_UNSPECIFIED
	MigrationSubtask_SUCCEEDED                             = src.MigrationSubtask_SUCCEEDED
	MigrationTask_FAILED                                   = src.MigrationTask_FAILED
	MigrationTask_ORCHESTRATING                            = src.MigrationTask_ORCHESTRATING
	MigrationTask_PAUSED                                   = src.MigrationTask_PAUSED
	MigrationTask_PENDING                                  = src.MigrationTask_PENDING
	MigrationTask_RUNNING                                  = src.MigrationTask_RUNNING
	MigrationTask_STATE_UNSPECIFIED                        = src.MigrationTask_STATE_UNSPECIFIED
	MigrationTask_SUCCEEDED                                = src.MigrationTask_SUCCEEDED
	MigrationWorkflow_COMPLETED                            = src.MigrationWorkflow_COMPLETED
	MigrationWorkflow_DRAFT                                = src.MigrationWorkflow_DRAFT
	MigrationWorkflow_PAUSED                               = src.MigrationWorkflow_PAUSED
	MigrationWorkflow_RUNNING                              = src.MigrationWorkflow_RUNNING
	MigrationWorkflow_STATE_UNSPECIFIED                    = src.MigrationWorkflow_STATE_UNSPECIFIED
	TranslationTaskDetails_BOOL                            = src.TranslationTaskDetails_BOOL
	TranslationTaskDetails_DATE                            = src.TranslationTaskDetails_DATE
	TranslationTaskDetails_FILE_ENCODING_UNSPECIFIED       = src.TranslationTaskDetails_FILE_ENCODING_UNSPECIFIED
	TranslationTaskDetails_FLOAT64                         = src.TranslationTaskDetails_FLOAT64
	TranslationTaskDetails_INT64                           = src.TranslationTaskDetails_INT64
	TranslationTaskDetails_ISO_8859_1                      = src.TranslationTaskDetails_ISO_8859_1
	TranslationTaskDetails_NUMERIC                         = src.TranslationTaskDetails_NUMERIC
	TranslationTaskDetails_STRING                          = src.TranslationTaskDetails_STRING
	TranslationTaskDetails_TIMESTAMP                       = src.TranslationTaskDetails_TIMESTAMP
	TranslationTaskDetails_TOKEN_TYPE_UNSPECIFIED          = src.TranslationTaskDetails_TOKEN_TYPE_UNSPECIFIED
	TranslationTaskDetails_US_ASCII                        = src.TranslationTaskDetails_US_ASCII
	TranslationTaskDetails_UTF_16                          = src.TranslationTaskDetails_UTF_16
	TranslationTaskDetails_UTF_16BE                        = src.TranslationTaskDetails_UTF_16BE
	TranslationTaskDetails_UTF_16LE                        = src.TranslationTaskDetails_UTF_16LE
	TranslationTaskDetails_UTF_8                           = src.TranslationTaskDetails_UTF_8
)

// Deprecated: Please use vars in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
var (
	File_google_cloud_bigquery_migration_v2alpha_assessment_task_proto         = src.File_google_cloud_bigquery_migration_v2alpha_assessment_task_proto
	File_google_cloud_bigquery_migration_v2alpha_migration_entities_proto      = src.File_google_cloud_bigquery_migration_v2alpha_migration_entities_proto
	File_google_cloud_bigquery_migration_v2alpha_migration_error_details_proto = src.File_google_cloud_bigquery_migration_v2alpha_migration_error_details_proto
	File_google_cloud_bigquery_migration_v2alpha_migration_metrics_proto       = src.File_google_cloud_bigquery_migration_v2alpha_migration_metrics_proto
	File_google_cloud_bigquery_migration_v2alpha_migration_service_proto       = src.File_google_cloud_bigquery_migration_v2alpha_migration_service_proto
	File_google_cloud_bigquery_migration_v2alpha_translation_task_proto        = src.File_google_cloud_bigquery_migration_v2alpha_translation_task_proto
	IdentifierSettings_IdentifierCase_name                                     = src.IdentifierSettings_IdentifierCase_name
	IdentifierSettings_IdentifierCase_value                                    = src.IdentifierSettings_IdentifierCase_value
	IdentifierSettings_IdentifierRewriteMode_name                              = src.IdentifierSettings_IdentifierRewriteMode_name
	IdentifierSettings_IdentifierRewriteMode_value                             = src.IdentifierSettings_IdentifierRewriteMode_value
	MigrationSubtask_State_name                                                = src.MigrationSubtask_State_name
	MigrationSubtask_State_value                                               = src.MigrationSubtask_State_value
	MigrationTask_State_name                                                   = src.MigrationTask_State_name
	MigrationTask_State_value                                                  = src.MigrationTask_State_value
	MigrationWorkflow_State_name                                               = src.MigrationWorkflow_State_name
	MigrationWorkflow_State_value                                              = src.MigrationWorkflow_State_value
	TranslationTaskDetails_FileEncoding_name                                   = src.TranslationTaskDetails_FileEncoding_name
	TranslationTaskDetails_FileEncoding_value                                  = src.TranslationTaskDetails_FileEncoding_value
	TranslationTaskDetails_TokenType_name                                      = src.TranslationTaskDetails_TokenType_name
	TranslationTaskDetails_TokenType_value                                     = src.TranslationTaskDetails_TokenType_value
)

// Details for an assessment task orchestration result.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type AssessmentOrchestrationResultDetails = src.AssessmentOrchestrationResultDetails

// Assessment task config.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type AssessmentTaskDetails = src.AssessmentTaskDetails

// BTEQ translation task related settings.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type BteqOptions = src.BteqOptions

// Request to create a migration workflow resource.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type CreateMigrationWorkflowRequest = src.CreateMigrationWorkflowRequest

// Reference to a BigQuery dataset.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type DatasetReference = src.DatasetReference

// A request to delete a previously created migration workflow.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type DeleteMigrationWorkflowRequest = src.DeleteMigrationWorkflowRequest

// Provides details for errors, e.g. issues that where encountered when
// processing a subtask.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type ErrorDetail = src.ErrorDetail

// Holds information about where the error is located.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type ErrorLocation = src.ErrorLocation

// The filter applied to fields of translation details.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type Filter = src.Filter

// A request to get a previously created migration subtasks.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type GetMigrationSubtaskRequest = src.GetMigrationSubtaskRequest

// A request to get a previously created migration workflow.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type GetMigrationWorkflowRequest = src.GetMigrationWorkflowRequest

// Settings related to SQL identifiers.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type IdentifierSettings = src.IdentifierSettings

// The identifier case type.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type IdentifierSettings_IdentifierCase = src.IdentifierSettings_IdentifierCase

// The SQL identifier rewrite mode.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type IdentifierSettings_IdentifierRewriteMode = src.IdentifierSettings_IdentifierRewriteMode

// A request to list previously created migration subtasks.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type ListMigrationSubtasksRequest = src.ListMigrationSubtasksRequest

// Response object for a `ListMigrationSubtasks` call.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type ListMigrationSubtasksResponse = src.ListMigrationSubtasksResponse

// A request to list previously created migration workflows.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type ListMigrationWorkflowsRequest = src.ListMigrationWorkflowsRequest

// Response object for a `ListMigrationWorkflows` call.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type ListMigrationWorkflowsResponse = src.ListMigrationWorkflowsResponse

// MigrationServiceClient is the client API for MigrationService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type MigrationServiceClient = src.MigrationServiceClient

// MigrationServiceServer is the server API for MigrationService service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type MigrationServiceServer = src.MigrationServiceServer

// A subtask for a migration which carries details about the configuration of
// the subtask. The content of the details should not matter to the end user,
// but is a contract between the subtask creator and subtask worker.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type MigrationSubtask = src.MigrationSubtask

// Possible states of a migration subtask.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type MigrationSubtask_State = src.MigrationSubtask_State

// A single task for a migration which has details about the configuration of
// the task.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type MigrationTask = src.MigrationTask

// Additional information from the orchestrator when it is done with the task
// orchestration.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type MigrationTaskOrchestrationResult = src.MigrationTaskOrchestrationResult
type MigrationTaskOrchestrationResult_AssessmentDetails = src.MigrationTaskOrchestrationResult_AssessmentDetails
type MigrationTask_AssessmentTaskDetails = src.MigrationTask_AssessmentTaskDetails

// Possible states of a migration task.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type MigrationTask_State = src.MigrationTask_State
type MigrationTask_TranslationTaskDetails = src.MigrationTask_TranslationTaskDetails

// A migration workflow which specifies what needs to be done for an EDW
// migration.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type MigrationWorkflow = src.MigrationWorkflow

// Possible migration workflow states.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type MigrationWorkflow_State = src.MigrationWorkflow_State

// A single data point in a time series.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type Point = src.Point

// Provides details for errors and the corresponding resources.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type ResourceErrorDetail = src.ResourceErrorDetail

// A request to start a previously created migration workflow.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type StartMigrationWorkflowRequest = src.StartMigrationWorkflowRequest

// Teradata SQL specific translation task related settings.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type TeradataOptions = src.TeradataOptions

// A time interval extending just after a start time through an end time. If
// the start time is the same as the end time, then the interval represents a
// single point in time.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type TimeInterval = src.TimeInterval

// The metrics object for a SubTask.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type TimeSeries = src.TimeSeries

// Mapping between an input and output file to be translated in a subtask.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type TranslationFileMapping = src.TranslationFileMapping

// The translation task config to capture necessary settings for a translation
// task and subtask.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type TranslationTaskDetails = src.TranslationTaskDetails
type TranslationTaskDetails_BteqOptions = src.TranslationTaskDetails_BteqOptions

// The file encoding types.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type TranslationTaskDetails_FileEncoding = src.TranslationTaskDetails_FileEncoding
type TranslationTaskDetails_TeradataOptions = src.TranslationTaskDetails_TeradataOptions

// The special token data type.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type TranslationTaskDetails_TokenType = src.TranslationTaskDetails_TokenType

// A single strongly-typed value.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type TypedValue = src.TypedValue
type TypedValue_BoolValue = src.TypedValue_BoolValue
type TypedValue_DistributionValue = src.TypedValue_DistributionValue
type TypedValue_DoubleValue = src.TypedValue_DoubleValue
type TypedValue_Int64Value = src.TypedValue_Int64Value
type TypedValue_StringValue = src.TypedValue_StringValue

// UnimplementedMigrationServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
type UnimplementedMigrationServiceServer = src.UnimplementedMigrationServiceServer

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
func NewMigrationServiceClient(cc grpc.ClientConnInterface) MigrationServiceClient {
	return src.NewMigrationServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/migration/apiv2alpha/migrationpb
func RegisterMigrationServiceServer(s *grpc.Server, srv MigrationServiceServer) {
	src.RegisterMigrationServiceServer(s, srv)
}
