// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package settings aliases all exported identifiers in package
// "cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb".
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package settings

import (
	src "cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
const (
	BillingTier_BILLING_TIER_UNSPECIFIED                            = src.BillingTier_BILLING_TIER_UNSPECIFIED
	BillingTier_PREMIUM                                             = src.BillingTier_PREMIUM
	BillingTier_STANDARD                                            = src.BillingTier_STANDARD
	BillingType_ALPHA                                               = src.BillingType_ALPHA
	BillingType_BILLING_TYPE_UNSPECIFIED                            = src.BillingType_BILLING_TYPE_UNSPECIFIED
	BillingType_SUBSCRIPTION                                        = src.BillingType_SUBSCRIPTION
	BillingType_TRIAL_SUBSCRIPTION                                  = src.BillingType_TRIAL_SUBSCRIPTION
	ComponentEnablementState_COMPONENT_ENABLEMENT_STATE_UNSPECIFIED = src.ComponentEnablementState_COMPONENT_ENABLEMENT_STATE_UNSPECIFIED
	ComponentEnablementState_DISABLE                                = src.ComponentEnablementState_DISABLE
	ComponentEnablementState_ENABLE                                 = src.ComponentEnablementState_ENABLE
	ComponentEnablementState_INHERIT                                = src.ComponentEnablementState_INHERIT
	Settings_BILLING_SELECTED                                       = src.Settings_BILLING_SELECTED
	Settings_DISABLED                                               = src.Settings_DISABLED
	Settings_ENABLED                                                = src.Settings_ENABLED
	Settings_ONBOARDING_STATE_UNSPECIFIED                           = src.Settings_ONBOARDING_STATE_UNSPECIFIED
	Settings_ORG_SERVICE_ACCOUNT_CREATED                            = src.Settings_ORG_SERVICE_ACCOUNT_CREATED
	Settings_PROVIDERS_SELECTED                                     = src.Settings_PROVIDERS_SELECTED
	Settings_RESOURCES_SELECTED                                     = src.Settings_RESOURCES_SELECTED
)

// Deprecated: Please use vars in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
var (
	BillingTier_name                                                                        = src.BillingTier_name
	BillingTier_value                                                                       = src.BillingTier_value
	BillingType_name                                                                        = src.BillingType_name
	BillingType_value                                                                       = src.BillingType_value
	ComponentEnablementState_name                                                           = src.ComponentEnablementState_name
	ComponentEnablementState_value                                                          = src.ComponentEnablementState_value
	File_google_cloud_securitycenter_settings_v1beta1_billing_settings_proto                = src.File_google_cloud_securitycenter_settings_v1beta1_billing_settings_proto
	File_google_cloud_securitycenter_settings_v1beta1_component_settings_proto              = src.File_google_cloud_securitycenter_settings_v1beta1_component_settings_proto
	File_google_cloud_securitycenter_settings_v1beta1_detector_proto                        = src.File_google_cloud_securitycenter_settings_v1beta1_detector_proto
	File_google_cloud_securitycenter_settings_v1beta1_securitycenter_settings_service_proto = src.File_google_cloud_securitycenter_settings_v1beta1_securitycenter_settings_service_proto
	File_google_cloud_securitycenter_settings_v1beta1_settings_proto                        = src.File_google_cloud_securitycenter_settings_v1beta1_settings_proto
	File_google_cloud_securitycenter_settings_v1beta1_sink_settings_proto                   = src.File_google_cloud_securitycenter_settings_v1beta1_sink_settings_proto
	Settings_OnboardingState_name                                                           = src.Settings_OnboardingState_name
	Settings_OnboardingState_value                                                          = src.Settings_OnboardingState_value
)

// Request message for BatchGetEffectiveSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type BatchCalculateEffectiveSettingsRequest = src.BatchCalculateEffectiveSettingsRequest

// Response message for BatchGetEffectiveSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type BatchCalculateEffectiveSettingsResponse = src.BatchCalculateEffectiveSettingsResponse

// Request message for BatchGetSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type BatchGetSettingsRequest = src.BatchGetSettingsRequest

// Response message for BatchGetSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type BatchGetSettingsResponse = src.BatchGetSettingsResponse

// Billing settings
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type BillingSettings = src.BillingSettings

// Billing tier options
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type BillingTier = src.BillingTier

// Billing type
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type BillingType = src.BillingType

// Request message for CalculateEffectiveComponentSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type CalculateEffectiveComponentSettingsRequest = src.CalculateEffectiveComponentSettingsRequest

// Request message for CalculateEffectiveSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type CalculateEffectiveSettingsRequest = src.CalculateEffectiveSettingsRequest

// Valid states for a component
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ComponentEnablementState = src.ComponentEnablementState

// Component Settings for Security Command Center
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ComponentSettings = src.ComponentSettings
type ComponentSettings_ContainerThreatDetectionSettings = src.ComponentSettings_ContainerThreatDetectionSettings

// Settings for each detector.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ComponentSettings_DetectorSettings = src.ComponentSettings_DetectorSettings
type ComponentSettings_EventThreatDetectionSettings = src.ComponentSettings_EventThreatDetectionSettings
type ComponentSettings_SecurityHealthAnalyticsSettings = src.ComponentSettings_SecurityHealthAnalyticsSettings
type ComponentSettings_WebSecurityScannerSettings = src.ComponentSettings_WebSecurityScannerSettings

// User specified settings for KTD
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ContainerThreatDetectionSettings = src.ContainerThreatDetectionSettings

// Detector is a set of detectors or scanners act as individual checks done
// within a component e.g. bad IP, bad domains, IAM anomaly, cryptomining, open
// firewall, etc. Detector is independent of Organization, meaning each
// detector must be defined for a given Security Center component under a
// specified billing tier. Organizations can configure the list of detectors
// based on their subscribed billing tier. Defines a detector, its billing tier
// and any applicable labels.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type Detector = src.Detector

// User specified settings for ETD
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type EventThreatDetectionSettings = src.EventThreatDetectionSettings

// Request message for GetComponentSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type GetComponentSettingsRequest = src.GetComponentSettingsRequest

// Request message for GetServiceAccount.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type GetServiceAccountRequest = src.GetServiceAccountRequest

// Request message for GetSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type GetSettingsRequest = src.GetSettingsRequest

// Request message for ListComponents.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ListComponentsRequest = src.ListComponentsRequest

// Response message for ListComponents.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ListComponentsResponse = src.ListComponentsResponse

// Request message for ListDetectors.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ListDetectorsRequest = src.ListDetectorsRequest

// Response message for ListDetectors.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ListDetectorsResponse = src.ListDetectorsResponse

// Request message for ResetComponentSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ResetComponentSettingsRequest = src.ResetComponentSettingsRequest

// Request message for ResetSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ResetSettingsRequest = src.ResetSettingsRequest

// SecurityCenterSettingsServiceClient is the client API for
// SecurityCenterSettingsService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type SecurityCenterSettingsServiceClient = src.SecurityCenterSettingsServiceClient

// SecurityCenterSettingsServiceServer is the server API for
// SecurityCenterSettingsService service.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type SecurityCenterSettingsServiceServer = src.SecurityCenterSettingsServiceServer

// User specified settings for Security Health Analytics
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type SecurityHealthAnalyticsSettings = src.SecurityHealthAnalyticsSettings

// Settings for "ADMIN_SERVICE_ACCOUNT" scanner.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type SecurityHealthAnalyticsSettings_AdminServiceAccountSettings = src.SecurityHealthAnalyticsSettings_AdminServiceAccountSettings

// Settings for "NON_ORG_IAM_MEMBER" scanner.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type SecurityHealthAnalyticsSettings_NonOrgIamMemberSettings = src.SecurityHealthAnalyticsSettings_NonOrgIamMemberSettings

// An organization-level service account to be used by threat detection
// components.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type ServiceAccount = src.ServiceAccount

// Common configuration settings for all of Security Center.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type Settings = src.Settings

// The DetectorGroupSettings define the configuration for a detector group.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type Settings_DetectorGroupSettings = src.Settings_DetectorGroupSettings

// Defines the onboarding states for SCC Potentially is just an indicator that
// a user has reviewed some subset of our configuration surface, even if it's
// still currently set to its API-default state.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type Settings_OnboardingState = src.Settings_OnboardingState

// Sink Settings for Security Command Center
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type SinkSettings = src.SinkSettings

// UnimplementedSecurityCenterSettingsServiceServer can be embedded to have
// forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type UnimplementedSecurityCenterSettingsServiceServer = src.UnimplementedSecurityCenterSettingsServiceServer

// Request message for UpdateComponentSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type UpdateComponentSettingsRequest = src.UpdateComponentSettingsRequest

// Request message for UpdateSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type UpdateSettingsRequest = src.UpdateSettingsRequest

// User specified settings for Web Security Scanner
//
// Deprecated: Please use types in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
type WebSecurityScanner = src.WebSecurityScanner

// Deprecated: Please use funcs in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
func NewSecurityCenterSettingsServiceClient(cc grpc.ClientConnInterface) SecurityCenterSettingsServiceClient {
	return src.NewSecurityCenterSettingsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/securitycenter/settings/apiv1beta1/settingspb
func RegisterSecurityCenterSettingsServiceServer(s *grpc.Server, srv SecurityCenterSettingsServiceServer) {
	src.RegisterSecurityCenterSettingsServiceServer(s, srv)
}
