// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package datapolicies aliases all exported identifiers in package
// "cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb".
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package datapolicies

import (
	src "cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
const (
	DataMaskingPolicy_ALWAYS_NULL                       = src.DataMaskingPolicy_ALWAYS_NULL
	DataMaskingPolicy_DEFAULT_MASKING_VALUE             = src.DataMaskingPolicy_DEFAULT_MASKING_VALUE
	DataMaskingPolicy_PREDEFINED_EXPRESSION_UNSPECIFIED = src.DataMaskingPolicy_PREDEFINED_EXPRESSION_UNSPECIFIED
	DataMaskingPolicy_SHA256                            = src.DataMaskingPolicy_SHA256
	DataPolicy_COLUMN_LEVEL_SECURITY_POLICY             = src.DataPolicy_COLUMN_LEVEL_SECURITY_POLICY
	DataPolicy_DATA_MASKING_POLICY                      = src.DataPolicy_DATA_MASKING_POLICY
	DataPolicy_DATA_POLICY_TYPE_UNSPECIFIED             = src.DataPolicy_DATA_POLICY_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
var (
	DataMaskingPolicy_PredefinedExpression_name                      = src.DataMaskingPolicy_PredefinedExpression_name
	DataMaskingPolicy_PredefinedExpression_value                     = src.DataMaskingPolicy_PredefinedExpression_value
	DataPolicy_DataPolicyType_name                                   = src.DataPolicy_DataPolicyType_name
	DataPolicy_DataPolicyType_value                                  = src.DataPolicy_DataPolicyType_value
	File_google_cloud_bigquery_datapolicies_v1beta1_datapolicy_proto = src.File_google_cloud_bigquery_datapolicies_v1beta1_datapolicy_proto
)

// Request message for the CreateDataPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type CreateDataPolicyRequest = src.CreateDataPolicyRequest

// The data masking policy that is used to specify data masking rule.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type DataMaskingPolicy = src.DataMaskingPolicy

// The available masking rules. Learn more here:
// https://cloud.google.com/bigquery/docs/column-data-masking-intro#masking_options.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type DataMaskingPolicy_PredefinedExpression = src.DataMaskingPolicy_PredefinedExpression
type DataMaskingPolicy_PredefinedExpression_ = src.DataMaskingPolicy_PredefinedExpression_

// Represents the label-policy binding.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type DataPolicy = src.DataPolicy

// DataPolicyServiceClient is the client API for DataPolicyService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type DataPolicyServiceClient = src.DataPolicyServiceClient

// DataPolicyServiceServer is the server API for DataPolicyService service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type DataPolicyServiceServer = src.DataPolicyServiceServer
type DataPolicy_DataMaskingPolicy = src.DataPolicy_DataMaskingPolicy

// A list of supported data policy types.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type DataPolicy_DataPolicyType = src.DataPolicy_DataPolicyType
type DataPolicy_PolicyTag = src.DataPolicy_PolicyTag

// Request message for the DeleteDataPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type DeleteDataPolicyRequest = src.DeleteDataPolicyRequest

// Request message for the GetDataPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type GetDataPolicyRequest = src.GetDataPolicyRequest

// Request message for the ListDataPolicies method.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type ListDataPoliciesRequest = src.ListDataPoliciesRequest

// Response message for the ListDataPolicies method.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type ListDataPoliciesResponse = src.ListDataPoliciesResponse

// UnimplementedDataPolicyServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type UnimplementedDataPolicyServiceServer = src.UnimplementedDataPolicyServiceServer

// Response message for the UpdateDataPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
type UpdateDataPolicyRequest = src.UpdateDataPolicyRequest

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
func NewDataPolicyServiceClient(cc grpc.ClientConnInterface) DataPolicyServiceClient {
	return src.NewDataPolicyServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/datapolicies/apiv1beta1/datapoliciespb
func RegisterDataPolicyServiceServer(s *grpc.Server, srv DataPolicyServiceServer) {
	src.RegisterDataPolicyServiceServer(s, srv)
}
