// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package routing aliases all exported identifiers in package
// "cloud.google.com/go/maps/routing/apiv2/routingpb".
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package routing

import (
	src "cloud.google.com/go/maps/routing/apiv2/routingpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/maps/routing/apiv2/routingpb
const (
	ComputeRoutesRequest_FUEL_EFFICIENT                                    = src.ComputeRoutesRequest_FUEL_EFFICIENT
	ComputeRoutesRequest_REFERENCE_ROUTE_UNSPECIFIED                       = src.ComputeRoutesRequest_REFERENCE_ROUTE_UNSPECIFIED
	FallbackReason_FALLBACK_REASON_UNSPECIFIED                             = src.FallbackReason_FALLBACK_REASON_UNSPECIFIED
	FallbackReason_LATENCY_EXCEEDED                                        = src.FallbackReason_LATENCY_EXCEEDED
	FallbackReason_SERVER_ERROR                                            = src.FallbackReason_SERVER_ERROR
	FallbackRoutingMode_FALLBACK_ROUTING_MODE_UNSPECIFIED                  = src.FallbackRoutingMode_FALLBACK_ROUTING_MODE_UNSPECIFIED
	FallbackRoutingMode_FALLBACK_TRAFFIC_AWARE                             = src.FallbackRoutingMode_FALLBACK_TRAFFIC_AWARE
	FallbackRoutingMode_FALLBACK_TRAFFIC_UNAWARE                           = src.FallbackRoutingMode_FALLBACK_TRAFFIC_UNAWARE
	Maneuver_FERRY                                                         = src.Maneuver_FERRY
	Maneuver_FERRY_TRAIN                                                   = src.Maneuver_FERRY_TRAIN
	Maneuver_FORK_LEFT                                                     = src.Maneuver_FORK_LEFT
	Maneuver_FORK_RIGHT                                                    = src.Maneuver_FORK_RIGHT
	Maneuver_MANEUVER_UNSPECIFIED                                          = src.Maneuver_MANEUVER_UNSPECIFIED
	Maneuver_MERGE                                                         = src.Maneuver_MERGE
	Maneuver_RAMP_LEFT                                                     = src.Maneuver_RAMP_LEFT
	Maneuver_RAMP_RIGHT                                                    = src.Maneuver_RAMP_RIGHT
	Maneuver_ROUNDABOUT_LEFT                                               = src.Maneuver_ROUNDABOUT_LEFT
	Maneuver_ROUNDABOUT_RIGHT                                              = src.Maneuver_ROUNDABOUT_RIGHT
	Maneuver_STRAIGHT                                                      = src.Maneuver_STRAIGHT
	Maneuver_TURN_LEFT                                                     = src.Maneuver_TURN_LEFT
	Maneuver_TURN_RIGHT                                                    = src.Maneuver_TURN_RIGHT
	Maneuver_TURN_SHARP_LEFT                                               = src.Maneuver_TURN_SHARP_LEFT
	Maneuver_TURN_SHARP_RIGHT                                              = src.Maneuver_TURN_SHARP_RIGHT
	Maneuver_TURN_SLIGHT_LEFT                                              = src.Maneuver_TURN_SLIGHT_LEFT
	Maneuver_TURN_SLIGHT_RIGHT                                             = src.Maneuver_TURN_SLIGHT_RIGHT
	Maneuver_UTURN_LEFT                                                    = src.Maneuver_UTURN_LEFT
	Maneuver_UTURN_RIGHT                                                   = src.Maneuver_UTURN_RIGHT
	PolylineEncoding_ENCODED_POLYLINE                                      = src.PolylineEncoding_ENCODED_POLYLINE
	PolylineEncoding_GEO_JSON_LINESTRING                                   = src.PolylineEncoding_GEO_JSON_LINESTRING
	PolylineEncoding_POLYLINE_ENCODING_UNSPECIFIED                         = src.PolylineEncoding_POLYLINE_ENCODING_UNSPECIFIED
	PolylineQuality_HIGH_QUALITY                                           = src.PolylineQuality_HIGH_QUALITY
	PolylineQuality_OVERVIEW                                               = src.PolylineQuality_OVERVIEW
	PolylineQuality_POLYLINE_QUALITY_UNSPECIFIED                           = src.PolylineQuality_POLYLINE_QUALITY_UNSPECIFIED
	RouteLabel_DEFAULT_ROUTE                                               = src.RouteLabel_DEFAULT_ROUTE
	RouteLabel_DEFAULT_ROUTE_ALTERNATE                                     = src.RouteLabel_DEFAULT_ROUTE_ALTERNATE
	RouteLabel_FUEL_EFFICIENT                                              = src.RouteLabel_FUEL_EFFICIENT
	RouteLabel_ROUTE_LABEL_UNSPECIFIED                                     = src.RouteLabel_ROUTE_LABEL_UNSPECIFIED
	RouteMatrixElementCondition_ROUTE_EXISTS                               = src.RouteMatrixElementCondition_ROUTE_EXISTS
	RouteMatrixElementCondition_ROUTE_MATRIX_ELEMENT_CONDITION_UNSPECIFIED = src.RouteMatrixElementCondition_ROUTE_MATRIX_ELEMENT_CONDITION_UNSPECIFIED
	RouteMatrixElementCondition_ROUTE_NOT_FOUND                            = src.RouteMatrixElementCondition_ROUTE_NOT_FOUND
	RouteTravelMode_BICYCLE                                                = src.RouteTravelMode_BICYCLE
	RouteTravelMode_DRIVE                                                  = src.RouteTravelMode_DRIVE
	RouteTravelMode_TRAVEL_MODE_UNSPECIFIED                                = src.RouteTravelMode_TRAVEL_MODE_UNSPECIFIED
	RouteTravelMode_TWO_WHEELER                                            = src.RouteTravelMode_TWO_WHEELER
	RouteTravelMode_WALK                                                   = src.RouteTravelMode_WALK
	RoutingPreference_ROUTING_PREFERENCE_UNSPECIFIED                       = src.RoutingPreference_ROUTING_PREFERENCE_UNSPECIFIED
	RoutingPreference_TRAFFIC_AWARE                                        = src.RoutingPreference_TRAFFIC_AWARE
	RoutingPreference_TRAFFIC_AWARE_OPTIMAL                                = src.RoutingPreference_TRAFFIC_AWARE_OPTIMAL
	RoutingPreference_TRAFFIC_UNAWARE                                      = src.RoutingPreference_TRAFFIC_UNAWARE
	SpeedReadingInterval_NORMAL                                            = src.SpeedReadingInterval_NORMAL
	SpeedReadingInterval_SLOW                                              = src.SpeedReadingInterval_SLOW
	SpeedReadingInterval_SPEED_UNSPECIFIED                                 = src.SpeedReadingInterval_SPEED_UNSPECIFIED
	SpeedReadingInterval_TRAFFIC_JAM                                       = src.SpeedReadingInterval_TRAFFIC_JAM
	TollPass_AR_TELEPASE                                                   = src.TollPass_AR_TELEPASE
	TollPass_AU_ETOLL_TAG                                                  = src.TollPass_AU_ETOLL_TAG
	TollPass_AU_EWAY_TAG                                                   = src.TollPass_AU_EWAY_TAG
	TollPass_AU_LINKT                                                      = src.TollPass_AU_LINKT
	TollPass_BR_AUTO_EXPRESO                                               = src.TollPass_BR_AUTO_EXPRESO
	TollPass_BR_CONECTCAR                                                  = src.TollPass_BR_CONECTCAR
	TollPass_BR_MOVE_MAIS                                                  = src.TollPass_BR_MOVE_MAIS
	TollPass_BR_PASSA_RAPIDO                                               = src.TollPass_BR_PASSA_RAPIDO
	TollPass_BR_SEM_PARAR                                                  = src.TollPass_BR_SEM_PARAR
	TollPass_BR_TAGGY                                                      = src.TollPass_BR_TAGGY
	TollPass_BR_VELOE                                                      = src.TollPass_BR_VELOE
	TollPass_CA_US_AKWASASNE_SEAWAY_CORPORATE_CARD                         = src.TollPass_CA_US_AKWASASNE_SEAWAY_CORPORATE_CARD
	TollPass_CA_US_AKWASASNE_SEAWAY_TRANSIT_CARD                           = src.TollPass_CA_US_AKWASASNE_SEAWAY_TRANSIT_CARD
	TollPass_CA_US_BLUE_WATER_EDGE_PASS                                    = src.TollPass_CA_US_BLUE_WATER_EDGE_PASS
	TollPass_CA_US_CONNEXION                                               = src.TollPass_CA_US_CONNEXION
	TollPass_CA_US_NEXUS_CARD                                              = src.TollPass_CA_US_NEXUS_CARD
	TollPass_ID_E_TOLL                                                     = src.TollPass_ID_E_TOLL
	TollPass_IN_FASTAG                                                     = src.TollPass_IN_FASTAG
	TollPass_IN_LOCAL_HP_PLATE_EXEMPT                                      = src.TollPass_IN_LOCAL_HP_PLATE_EXEMPT
	TollPass_MX_IAVE                                                       = src.TollPass_MX_IAVE
	TollPass_MX_PASE                                                       = src.TollPass_MX_PASE
	TollPass_MX_QUICKPASS                                                  = src.TollPass_MX_QUICKPASS
	TollPass_MX_SISTEMA_TELEPEAJE_CHIHUAHUA                                = src.TollPass_MX_SISTEMA_TELEPEAJE_CHIHUAHUA
	TollPass_MX_TAG_IAVE                                                   = src.TollPass_MX_TAG_IAVE
	TollPass_MX_TAG_TELEVIA                                                = src.TollPass_MX_TAG_TELEVIA
	TollPass_MX_TELEVIA                                                    = src.TollPass_MX_TELEVIA
	TollPass_MX_VIAPASS                                                    = src.TollPass_MX_VIAPASS
	TollPass_TOLL_PASS_UNSPECIFIED                                         = src.TollPass_TOLL_PASS_UNSPECIFIED
	TollPass_US_AK_ANTON_ANDERSON_TUNNEL_BOOK_OF_10_TICKETS                = src.TollPass_US_AK_ANTON_ANDERSON_TUNNEL_BOOK_OF_10_TICKETS
	TollPass_US_AL_FREEDOM_PASS                                            = src.TollPass_US_AL_FREEDOM_PASS
	TollPass_US_CA_FASTRAK                                                 = src.TollPass_US_CA_FASTRAK
	TollPass_US_CA_FASTRAK_CAV_STICKER                                     = src.TollPass_US_CA_FASTRAK_CAV_STICKER
	TollPass_US_CO_EXPRESSTOLL                                             = src.TollPass_US_CO_EXPRESSTOLL
	TollPass_US_CO_GO_PASS                                                 = src.TollPass_US_CO_GO_PASS
	TollPass_US_DE_EZPASSDE                                                = src.TollPass_US_DE_EZPASSDE
	TollPass_US_FL_BOB_SIKES_TOLL_BRIDGE_PASS                              = src.TollPass_US_FL_BOB_SIKES_TOLL_BRIDGE_PASS
	TollPass_US_FL_DUNES_COMMUNITY_DEVELOPMENT_DISTRICT_EXPRESSCARD        = src.TollPass_US_FL_DUNES_COMMUNITY_DEVELOPMENT_DISTRICT_EXPRESSCARD
	TollPass_US_FL_EPASS                                                   = src.TollPass_US_FL_EPASS
	TollPass_US_FL_GIBA_TOLL_PASS                                          = src.TollPass_US_FL_GIBA_TOLL_PASS
	TollPass_US_FL_LEEWAY                                                  = src.TollPass_US_FL_LEEWAY
	TollPass_US_FL_SUNPASS                                                 = src.TollPass_US_FL_SUNPASS
	TollPass_US_FL_SUNPASS_PRO                                             = src.TollPass_US_FL_SUNPASS_PRO
	TollPass_US_IL_EZPASSIL                                                = src.TollPass_US_IL_EZPASSIL
	TollPass_US_IL_IPASS                                                   = src.TollPass_US_IL_IPASS
	TollPass_US_IN_EZPASSIN                                                = src.TollPass_US_IN_EZPASSIN
	TollPass_US_KS_BESTPASS_HORIZON                                        = src.TollPass_US_KS_BESTPASS_HORIZON
	TollPass_US_KS_KTAG                                                    = src.TollPass_US_KS_KTAG
	TollPass_US_KS_NATIONALPASS                                            = src.TollPass_US_KS_NATIONALPASS
	TollPass_US_KS_PREPASS_ELITEPASS                                       = src.TollPass_US_KS_PREPASS_ELITEPASS
	TollPass_US_KY_RIVERLINK                                               = src.TollPass_US_KY_RIVERLINK
	TollPass_US_LA_GEAUXPASS                                               = src.TollPass_US_LA_GEAUXPASS
	TollPass_US_LA_TOLL_TAG                                                = src.TollPass_US_LA_TOLL_TAG
	TollPass_US_MA_EZPASSMA                                                = src.TollPass_US_MA_EZPASSMA
	TollPass_US_MD_EZPASSMD                                                = src.TollPass_US_MD_EZPASSMD
	TollPass_US_ME_EZPASSME                                                = src.TollPass_US_ME_EZPASSME
	TollPass_US_MI_AMBASSADOR_BRIDGE_PREMIER_COMMUTER_CARD                 = src.TollPass_US_MI_AMBASSADOR_BRIDGE_PREMIER_COMMUTER_CARD
	TollPass_US_MI_GROSSE_ILE_TOLL_BRIDGE_PASS_TAG                         = src.TollPass_US_MI_GROSSE_ILE_TOLL_BRIDGE_PASS_TAG
	TollPass_US_MI_IQ_PROX_CARD                                            = src.TollPass_US_MI_IQ_PROX_CARD
	TollPass_US_MI_MACKINAC_BRIDGE_MAC_PASS                                = src.TollPass_US_MI_MACKINAC_BRIDGE_MAC_PASS
	TollPass_US_MI_NEXPRESS_TOLL                                           = src.TollPass_US_MI_NEXPRESS_TOLL
	TollPass_US_MN_EZPASSMN                                                = src.TollPass_US_MN_EZPASSMN
	TollPass_US_NC_EZPASSNC                                                = src.TollPass_US_NC_EZPASSNC
	TollPass_US_NC_PEACH_PASS                                              = src.TollPass_US_NC_PEACH_PASS
	TollPass_US_NC_QUICK_PASS                                              = src.TollPass_US_NC_QUICK_PASS
	TollPass_US_NH_EZPASSNH                                                = src.TollPass_US_NH_EZPASSNH
	TollPass_US_NJ_DOWNBEACH_EXPRESS_PASS                                  = src.TollPass_US_NJ_DOWNBEACH_EXPRESS_PASS
	TollPass_US_NJ_EZPASSNJ                                                = src.TollPass_US_NJ_EZPASSNJ
	TollPass_US_NY_EXPRESSPASS                                             = src.TollPass_US_NY_EXPRESSPASS
	TollPass_US_NY_EZPASSNY                                                = src.TollPass_US_NY_EZPASSNY
	TollPass_US_OH_EZPASSOH                                                = src.TollPass_US_OH_EZPASSOH
	TollPass_US_PA_EZPASSPA                                                = src.TollPass_US_PA_EZPASSPA
	TollPass_US_RI_EZPASSRI                                                = src.TollPass_US_RI_EZPASSRI
	TollPass_US_SC_PALPASS                                                 = src.TollPass_US_SC_PALPASS
	TollPass_US_TX_BANCPASS                                                = src.TollPass_US_TX_BANCPASS
	TollPass_US_TX_DEL_RIO_PASS                                            = src.TollPass_US_TX_DEL_RIO_PASS
	TollPass_US_TX_EAGLE_PASS_EXPRESS_CARD                                 = src.TollPass_US_TX_EAGLE_PASS_EXPRESS_CARD
	TollPass_US_TX_EFAST_PASS                                              = src.TollPass_US_TX_EFAST_PASS
	TollPass_US_TX_EPTOLL                                                  = src.TollPass_US_TX_EPTOLL
	TollPass_US_TX_EZTAG                                                   = src.TollPass_US_TX_EZTAG
	TollPass_US_TX_EZ_CROSS                                                = src.TollPass_US_TX_EZ_CROSS
	TollPass_US_TX_LAREDO_TRADE_TAG                                        = src.TollPass_US_TX_LAREDO_TRADE_TAG
	TollPass_US_TX_PLUSPASS                                                = src.TollPass_US_TX_PLUSPASS
	TollPass_US_TX_TOLLTAG                                                 = src.TollPass_US_TX_TOLLTAG
	TollPass_US_TX_TXTAG                                                   = src.TollPass_US_TX_TXTAG
	TollPass_US_TX_XPRESS_CARD                                             = src.TollPass_US_TX_XPRESS_CARD
	TollPass_US_UT_ADAMS_AVE_PARKWAY_EXPRESSCARD                           = src.TollPass_US_UT_ADAMS_AVE_PARKWAY_EXPRESSCARD
	TollPass_US_VA_EZPASSVA                                                = src.TollPass_US_VA_EZPASSVA
	TollPass_US_WA_BREEZEBY                                                = src.TollPass_US_WA_BREEZEBY
	TollPass_US_WA_GOOD_TO_GO                                              = src.TollPass_US_WA_GOOD_TO_GO
	TollPass_US_WV_EZPASSWV                                                = src.TollPass_US_WV_EZPASSWV
	TollPass_US_WV_MEMORIAL_BRIDGE_TICKETS                                 = src.TollPass_US_WV_MEMORIAL_BRIDGE_TICKETS
	TollPass_US_WV_NEWELL_TOLL_BRIDGE_TICKET                               = src.TollPass_US_WV_NEWELL_TOLL_BRIDGE_TICKET
	Units_IMPERIAL                                                         = src.Units_IMPERIAL
	Units_METRIC                                                           = src.Units_METRIC
	Units_UNITS_UNSPECIFIED                                                = src.Units_UNITS_UNSPECIFIED
	VehicleEmissionType_DIESEL                                             = src.VehicleEmissionType_DIESEL
	VehicleEmissionType_ELECTRIC                                           = src.VehicleEmissionType_ELECTRIC
	VehicleEmissionType_GASOLINE                                           = src.VehicleEmissionType_GASOLINE
	VehicleEmissionType_HYBRID                                             = src.VehicleEmissionType_HYBRID
	VehicleEmissionType_VEHICLE_EMISSION_TYPE_UNSPECIFIED                  = src.VehicleEmissionType_VEHICLE_EMISSION_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/maps/routing/apiv2/routingpb
var (
	ComputeRoutesRequest_ReferenceRoute_name                 = src.ComputeRoutesRequest_ReferenceRoute_name
	ComputeRoutesRequest_ReferenceRoute_value                = src.ComputeRoutesRequest_ReferenceRoute_value
	FallbackReason_name                                      = src.FallbackReason_name
	FallbackReason_value                                     = src.FallbackReason_value
	FallbackRoutingMode_name                                 = src.FallbackRoutingMode_name
	FallbackRoutingMode_value                                = src.FallbackRoutingMode_value
	File_google_maps_routing_v2_fallback_info_proto          = src.File_google_maps_routing_v2_fallback_info_proto
	File_google_maps_routing_v2_location_proto               = src.File_google_maps_routing_v2_location_proto
	File_google_maps_routing_v2_maneuver_proto               = src.File_google_maps_routing_v2_maneuver_proto
	File_google_maps_routing_v2_navigation_instruction_proto = src.File_google_maps_routing_v2_navigation_instruction_proto
	File_google_maps_routing_v2_polyline_proto               = src.File_google_maps_routing_v2_polyline_proto
	File_google_maps_routing_v2_route_label_proto            = src.File_google_maps_routing_v2_route_label_proto
	File_google_maps_routing_v2_route_modifiers_proto        = src.File_google_maps_routing_v2_route_modifiers_proto
	File_google_maps_routing_v2_route_proto                  = src.File_google_maps_routing_v2_route_proto
	File_google_maps_routing_v2_route_travel_mode_proto      = src.File_google_maps_routing_v2_route_travel_mode_proto
	File_google_maps_routing_v2_routes_service_proto         = src.File_google_maps_routing_v2_routes_service_proto
	File_google_maps_routing_v2_routing_preference_proto     = src.File_google_maps_routing_v2_routing_preference_proto
	File_google_maps_routing_v2_speed_reading_interval_proto = src.File_google_maps_routing_v2_speed_reading_interval_proto
	File_google_maps_routing_v2_toll_info_proto              = src.File_google_maps_routing_v2_toll_info_proto
	File_google_maps_routing_v2_toll_passes_proto            = src.File_google_maps_routing_v2_toll_passes_proto
	File_google_maps_routing_v2_units_proto                  = src.File_google_maps_routing_v2_units_proto
	File_google_maps_routing_v2_vehicle_emission_type_proto  = src.File_google_maps_routing_v2_vehicle_emission_type_proto
	File_google_maps_routing_v2_vehicle_info_proto           = src.File_google_maps_routing_v2_vehicle_info_proto
	File_google_maps_routing_v2_waypoint_proto               = src.File_google_maps_routing_v2_waypoint_proto
	Maneuver_name                                            = src.Maneuver_name
	Maneuver_value                                           = src.Maneuver_value
	PolylineEncoding_name                                    = src.PolylineEncoding_name
	PolylineEncoding_value                                   = src.PolylineEncoding_value
	PolylineQuality_name                                     = src.PolylineQuality_name
	PolylineQuality_value                                    = src.PolylineQuality_value
	RouteLabel_name                                          = src.RouteLabel_name
	RouteLabel_value                                         = src.RouteLabel_value
	RouteMatrixElementCondition_name                         = src.RouteMatrixElementCondition_name
	RouteMatrixElementCondition_value                        = src.RouteMatrixElementCondition_value
	RouteTravelMode_name                                     = src.RouteTravelMode_name
	RouteTravelMode_value                                    = src.RouteTravelMode_value
	RoutingPreference_name                                   = src.RoutingPreference_name
	RoutingPreference_value                                  = src.RoutingPreference_value
	SpeedReadingInterval_Speed_name                          = src.SpeedReadingInterval_Speed_name
	SpeedReadingInterval_Speed_value                         = src.SpeedReadingInterval_Speed_value
	TollPass_name                                            = src.TollPass_name
	TollPass_value                                           = src.TollPass_value
	Units_name                                               = src.Units_name
	Units_value                                              = src.Units_value
	VehicleEmissionType_name                                 = src.VehicleEmissionType_name
	VehicleEmissionType_value                                = src.VehicleEmissionType_value
)

// ComputeRouteMatrix request message
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type ComputeRouteMatrixRequest = src.ComputeRouteMatrixRequest

// ComputeRoutes request message.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type ComputeRoutesRequest = src.ComputeRoutesRequest

// A supported reference route on the ComputeRoutesRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type ComputeRoutesRequest_ReferenceRoute = src.ComputeRoutesRequest_ReferenceRoute

// ComputeRoutes the response message.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type ComputeRoutesResponse = src.ComputeRoutesResponse

// Information related to how and why a fallback result was used. If this
// field is set, then it means the server used a different routing mode from
// your preferred mode as fallback.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type FallbackInfo = src.FallbackInfo

// Reasons for using fallback response.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type FallbackReason = src.FallbackReason

// Actual routing mode used for returned fallback response.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type FallbackRoutingMode = src.FallbackRoutingMode

// Encapsulates a location (a geographic point, and an optional heading).
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type Location = src.Location

// A set of values that specify the navigation action to take for the current
// step (e.g., turn left, merge, straight, etc.).
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type Maneuver = src.Maneuver

// Encapsulates navigation instructions for a
// [RouteLegStep][google.maps.routing.v2.RouteLegStep]
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type NavigationInstruction = src.NavigationInstruction

// Encapsulates an encoded polyline.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type Polyline = src.Polyline

// Specifies the preferred type of polyline to be returned.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type PolylineEncoding = src.PolylineEncoding

// A set of values that specify the quality of the polyline.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type PolylineQuality = src.PolylineQuality
type Polyline_EncodedPolyline = src.Polyline_EncodedPolyline
type Polyline_GeoJsonLinestring = src.Polyline_GeoJsonLinestring

// Encapsulates a route, which consists of a series of connected road segments
// that join beginning, ending, and intermediate waypoints.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type Route = src.Route

// Labels for the `Route` that are useful to identify specific properties of
// the route to compare against others.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteLabel = src.RouteLabel

// Encapsulates a segment between non-`via` waypoints.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteLeg = src.RouteLeg

// Encapsulates a segment of a `RouteLeg`. A step corresponds to a single
// navigation instruction. Route legs are made up of steps.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteLegStep = src.RouteLegStep

// Encapsulates the additional information that the user should be informed
// about, such as possible traffic zone restriction on a leg step.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteLegStepTravelAdvisory = src.RouteLegStepTravelAdvisory

// Encapsulates the additional information that the user should be informed
// about, such as possible traffic zone restriction etc. on a route leg.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteLegTravelAdvisory = src.RouteLegTravelAdvisory

// A single destination for ComputeRouteMatrixRequest
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteMatrixDestination = src.RouteMatrixDestination

// Encapsulates route information computed for an origin/destination pair in
// the ComputeRouteMatrix API. This proto can be streamed to the client.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteMatrixElement = src.RouteMatrixElement

// The condition of the route being returned.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteMatrixElementCondition = src.RouteMatrixElementCondition

// A single origin for ComputeRouteMatrixRequest
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteMatrixOrigin = src.RouteMatrixOrigin

// Encapsulates a set of optional conditions to satisfy when calculating the
// routes.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteModifiers = src.RouteModifiers

// Encapsulates the additional information that the user should be informed
// about, such as possible traffic zone restriction etc.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteTravelAdvisory = src.RouteTravelAdvisory

// A set of values used to specify the mode of travel.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RouteTravelMode = src.RouteTravelMode

// RoutesClient is the client API for Routes service. For semantics around ctx
// use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RoutesClient = src.RoutesClient

// RoutesServer is the server API for Routes service.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RoutesServer = src.RoutesServer
type Routes_ComputeRouteMatrixClient = src.Routes_ComputeRouteMatrixClient
type Routes_ComputeRouteMatrixServer = src.Routes_ComputeRouteMatrixServer

// A set of values that specify factors to take into consideration when
// calculating the route.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type RoutingPreference = src.RoutingPreference

// Traffic density indicator on a contiguous segment of a polyline or path.
// Given a path with points P_0, P_1, ... , P_N (zero-based index), the
// SpeedReadingInterval defines an interval and describes its traffic using the
// following categories.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type SpeedReadingInterval = src.SpeedReadingInterval

// The classification of polyline speed based on traffic data.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type SpeedReadingInterval_Speed = src.SpeedReadingInterval_Speed

// Encapsulates toll information on a `Route` or on a `RouteLeg`.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type TollInfo = src.TollInfo

// List of toll passes around the world that we support.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type TollPass = src.TollPass

// UnimplementedRoutesServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type UnimplementedRoutesServer = src.UnimplementedRoutesServer

// A set of values that specify the unit of measure used in the display.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type Units = src.Units

// A set of values describing the vehicle's emission type. Applies only to the
// DRIVE travel mode.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type VehicleEmissionType = src.VehicleEmissionType

// Encapsulates the vehicle information, such as the license plate last
// character.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type VehicleInfo = src.VehicleInfo

// Encapsulates a waypoint. Waypoints mark both the beginning and end of a
// route, and include intermediate stops along the route.
//
// Deprecated: Please use types in: cloud.google.com/go/maps/routing/apiv2/routingpb
type Waypoint = src.Waypoint
type Waypoint_Location = src.Waypoint_Location
type Waypoint_PlaceId = src.Waypoint_PlaceId

// Deprecated: Please use funcs in: cloud.google.com/go/maps/routing/apiv2/routingpb
func NewRoutesClient(cc grpc.ClientConnInterface) RoutesClient { return src.NewRoutesClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/maps/routing/apiv2/routingpb
func RegisterRoutesServer(s *grpc.Server, srv RoutesServer) { src.RegisterRoutesServer(s, srv) }
