// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package networkconnectivity aliases all exported identifiers in package
// "cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb".
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package networkconnectivity

import (
	src "cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
const (
	State_ACTIVE            = src.State_ACTIVE
	State_CREATING          = src.State_CREATING
	State_DELETING          = src.State_DELETING
	State_STATE_UNSPECIFIED = src.State_STATE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
var (
	File_google_cloud_networkconnectivity_v1alpha1_common_proto = src.File_google_cloud_networkconnectivity_v1alpha1_common_proto
	File_google_cloud_networkconnectivity_v1alpha1_hub_proto    = src.File_google_cloud_networkconnectivity_v1alpha1_hub_proto
	State_name                                                  = src.State_name
	State_value                                                 = src.State_value
)

// Request for
// [HubService.CreateHub][google.cloud.networkconnectivity.v1alpha1.HubService.CreateHub]
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type CreateHubRequest = src.CreateHubRequest

// The request for
// [HubService.CreateSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.CreateSpoke].
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type CreateSpokeRequest = src.CreateSpokeRequest

// The request for
// [HubService.DeleteHub][google.cloud.networkconnectivity.v1alpha1.HubService.DeleteHub].
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type DeleteHubRequest = src.DeleteHubRequest

// The request for
// [HubService.DeleteSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.DeleteSpoke].
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type DeleteSpokeRequest = src.DeleteSpokeRequest

// Request for
// [HubService.GetHub][google.cloud.networkconnectivity.v1alpha1.HubService.GetHub]
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type GetHubRequest = src.GetHubRequest

// The request for
// [HubService.GetSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.GetSpoke].
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type GetSpokeRequest = src.GetSpokeRequest

// Network Connectivity Center is a hub-and-spoke abstraction for network
// connectivity management in Google Cloud. It reduces operational complexity
// through a simple, centralized connectivity management model. Following is
// the resource message of a hub.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type Hub = src.Hub

// HubServiceClient is the client API for HubService service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type HubServiceClient = src.HubServiceClient

// HubServiceServer is the server API for HubService service.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type HubServiceServer = src.HubServiceServer

// Request for
// [HubService.ListHubs][google.cloud.networkconnectivity.v1alpha1.HubService.ListHubs]
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type ListHubsRequest = src.ListHubsRequest

// Response for
// [HubService.ListHubs][google.cloud.networkconnectivity.v1alpha1.HubService.ListHubs]
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type ListHubsResponse = src.ListHubsResponse

// The request for
// [HubService.ListSpokes][google.cloud.networkconnectivity.v1alpha1.HubService.ListSpokes].
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type ListSpokesRequest = src.ListSpokesRequest

// The response for
// [HubService.ListSpokes][google.cloud.networkconnectivity.v1alpha1.HubService.ListSpokes].
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type ListSpokesResponse = src.ListSpokesResponse

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type OperationMetadata = src.OperationMetadata

// RouterAppliance represents a Router appliance which is specified by a VM
// URI and a NIC address.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type RouterApplianceInstance = src.RouterApplianceInstance

// A Spoke is an abstraction of a network attachment being attached to a Hub.
// A Spoke can be underlying a VPN tunnel, a VLAN (interconnect) attachment, a
// Router appliance, etc.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type Spoke = src.Spoke

// The State enum represents the lifecycle of a Network Connectivity Center
// resource.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type State = src.State

// UnimplementedHubServiceServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type UnimplementedHubServiceServer = src.UnimplementedHubServiceServer

// Request for
// [HubService.UpdateHub][google.cloud.networkconnectivity.v1alpha1.HubService.UpdateHub]
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type UpdateHubRequest = src.UpdateHubRequest

// Request for
// [HubService.UpdateSpoke][google.cloud.networkconnectivity.v1alpha1.HubService.UpdateSpoke]
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
type UpdateSpokeRequest = src.UpdateSpokeRequest

// Deprecated: Please use funcs in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
func NewHubServiceClient(cc grpc.ClientConnInterface) HubServiceClient {
	return src.NewHubServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/networkconnectivity/apiv1alpha1/networkconnectivitypb
func RegisterHubServiceServer(s *grpc.Server, srv HubServiceServer) {
	src.RegisterHubServiceServer(s, srv)
}
