// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package agentendpoint aliases all exported identifiers in package
// "cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb".
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package agentendpoint

import (
	src "cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
const (
	ApplyPatchesTaskOutput_FAILED                               = src.ApplyPatchesTaskOutput_FAILED
	ApplyPatchesTaskOutput_STATE_UNSPECIFIED                    = src.ApplyPatchesTaskOutput_STATE_UNSPECIFIED
	ApplyPatchesTaskOutput_SUCCEEDED                            = src.ApplyPatchesTaskOutput_SUCCEEDED
	ApplyPatchesTaskOutput_SUCCEEDED_REBOOT_REQUIRED            = src.ApplyPatchesTaskOutput_SUCCEEDED_REBOOT_REQUIRED
	ApplyPatchesTaskProgress_APPLYING_PATCHES                   = src.ApplyPatchesTaskProgress_APPLYING_PATCHES
	ApplyPatchesTaskProgress_DOWNLOADING_PATCHES                = src.ApplyPatchesTaskProgress_DOWNLOADING_PATCHES
	ApplyPatchesTaskProgress_REBOOTING                          = src.ApplyPatchesTaskProgress_REBOOTING
	ApplyPatchesTaskProgress_STARTED                            = src.ApplyPatchesTaskProgress_STARTED
	ApplyPatchesTaskProgress_STATE_UNSPECIFIED                  = src.ApplyPatchesTaskProgress_STATE_UNSPECIFIED
	AptRepository_ARCHIVE_TYPE_UNSPECIFIED                      = src.AptRepository_ARCHIVE_TYPE_UNSPECIFIED
	AptRepository_DEB                                           = src.AptRepository_DEB
	AptRepository_DEB_SRC                                       = src.AptRepository_DEB_SRC
	AptSettings_DIST                                            = src.AptSettings_DIST
	AptSettings_TYPE_UNSPECIFIED                                = src.AptSettings_TYPE_UNSPECIFIED
	AptSettings_UPGRADE                                         = src.AptSettings_UPGRADE
	DesiredState_DESIRED_STATE_UNSPECIFIED                      = src.DesiredState_DESIRED_STATE_UNSPECIFIED
	DesiredState_INSTALLED                                      = src.DesiredState_INSTALLED
	DesiredState_REMOVED                                        = src.DesiredState_REMOVED
	DesiredState_UPDATED                                        = src.DesiredState_UPDATED
	ExecStepConfig_INTERPRETER_UNSPECIFIED                      = src.ExecStepConfig_INTERPRETER_UNSPECIFIED
	ExecStepConfig_NONE                                         = src.ExecStepConfig_NONE
	ExecStepConfig_POWERSHELL                                   = src.ExecStepConfig_POWERSHELL
	ExecStepConfig_SHELL                                        = src.ExecStepConfig_SHELL
	ExecStepTaskOutput_CANCELLED                                = src.ExecStepTaskOutput_CANCELLED
	ExecStepTaskOutput_COMPLETED                                = src.ExecStepTaskOutput_COMPLETED
	ExecStepTaskOutput_STATE_UNSPECIFIED                        = src.ExecStepTaskOutput_STATE_UNSPECIFIED
	ExecStepTaskOutput_TIMED_OUT                                = src.ExecStepTaskOutput_TIMED_OUT
	ExecStepTaskProgress_STARTED                                = src.ExecStepTaskProgress_STARTED
	ExecStepTaskProgress_STATE_UNSPECIFIED                      = src.ExecStepTaskProgress_STATE_UNSPECIFIED
	Package_ANY                                                 = src.Package_ANY
	Package_APT                                                 = src.Package_APT
	Package_GOO                                                 = src.Package_GOO
	Package_MANAGER_UNSPECIFIED                                 = src.Package_MANAGER_UNSPECIFIED
	Package_YUM                                                 = src.Package_YUM
	Package_ZYPPER                                              = src.Package_ZYPPER
	PatchConfig_ALWAYS                                          = src.PatchConfig_ALWAYS
	PatchConfig_DEFAULT                                         = src.PatchConfig_DEFAULT
	PatchConfig_NEVER                                           = src.PatchConfig_NEVER
	PatchConfig_REBOOT_CONFIG_UNSPECIFIED                       = src.PatchConfig_REBOOT_CONFIG_UNSPECIFIED
	SoftwareRecipe_Step_ExtractArchive_ARCHIVE_TYPE_UNSPECIFIED = src.SoftwareRecipe_Step_ExtractArchive_ARCHIVE_TYPE_UNSPECIFIED
	SoftwareRecipe_Step_ExtractArchive_TAR                      = src.SoftwareRecipe_Step_ExtractArchive_TAR
	SoftwareRecipe_Step_ExtractArchive_TAR_BZIP                 = src.SoftwareRecipe_Step_ExtractArchive_TAR_BZIP
	SoftwareRecipe_Step_ExtractArchive_TAR_GZIP                 = src.SoftwareRecipe_Step_ExtractArchive_TAR_GZIP
	SoftwareRecipe_Step_ExtractArchive_TAR_LZMA                 = src.SoftwareRecipe_Step_ExtractArchive_TAR_LZMA
	SoftwareRecipe_Step_ExtractArchive_TAR_XZ                   = src.SoftwareRecipe_Step_ExtractArchive_TAR_XZ
	SoftwareRecipe_Step_ExtractArchive_ZIP                      = src.SoftwareRecipe_Step_ExtractArchive_ZIP
	SoftwareRecipe_Step_RunScript_INTERPRETER_UNSPECIFIED       = src.SoftwareRecipe_Step_RunScript_INTERPRETER_UNSPECIFIED
	SoftwareRecipe_Step_RunScript_POWERSHELL                    = src.SoftwareRecipe_Step_RunScript_POWERSHELL
	SoftwareRecipe_Step_RunScript_SHELL                         = src.SoftwareRecipe_Step_RunScript_SHELL
	TaskDirective_CONTINUE                                      = src.TaskDirective_CONTINUE
	TaskDirective_STOP                                          = src.TaskDirective_STOP
	TaskDirective_TASK_DIRECTIVE_UNSPECIFIED                    = src.TaskDirective_TASK_DIRECTIVE_UNSPECIFIED
	TaskType_APPLY_PATCHES                                      = src.TaskType_APPLY_PATCHES
	TaskType_EXEC_STEP_TASK                                     = src.TaskType_EXEC_STEP_TASK
	TaskType_TASK_TYPE_UNSPECIFIED                              = src.TaskType_TASK_TYPE_UNSPECIFIED
	WindowsUpdateSettings_CLASSIFICATION_UNSPECIFIED            = src.WindowsUpdateSettings_CLASSIFICATION_UNSPECIFIED
	WindowsUpdateSettings_CRITICAL                              = src.WindowsUpdateSettings_CRITICAL
	WindowsUpdateSettings_DEFINITION                            = src.WindowsUpdateSettings_DEFINITION
	WindowsUpdateSettings_DRIVER                                = src.WindowsUpdateSettings_DRIVER
	WindowsUpdateSettings_FEATURE_PACK                          = src.WindowsUpdateSettings_FEATURE_PACK
	WindowsUpdateSettings_SECURITY                              = src.WindowsUpdateSettings_SECURITY
	WindowsUpdateSettings_SERVICE_PACK                          = src.WindowsUpdateSettings_SERVICE_PACK
	WindowsUpdateSettings_TOOL                                  = src.WindowsUpdateSettings_TOOL
	WindowsUpdateSettings_UPDATE                                = src.WindowsUpdateSettings_UPDATE
	WindowsUpdateSettings_UPDATE_ROLLUP                         = src.WindowsUpdateSettings_UPDATE_ROLLUP
)

// Deprecated: Please use vars in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
var (
	ApplyPatchesTaskOutput_State_name                                    = src.ApplyPatchesTaskOutput_State_name
	ApplyPatchesTaskOutput_State_value                                   = src.ApplyPatchesTaskOutput_State_value
	ApplyPatchesTaskProgress_State_name                                  = src.ApplyPatchesTaskProgress_State_name
	ApplyPatchesTaskProgress_State_value                                 = src.ApplyPatchesTaskProgress_State_value
	AptRepository_ArchiveType_name                                       = src.AptRepository_ArchiveType_name
	AptRepository_ArchiveType_value                                      = src.AptRepository_ArchiveType_value
	AptSettings_Type_name                                                = src.AptSettings_Type_name
	AptSettings_Type_value                                               = src.AptSettings_Type_value
	DesiredState_name                                                    = src.DesiredState_name
	DesiredState_value                                                   = src.DesiredState_value
	ExecStepConfig_Interpreter_name                                      = src.ExecStepConfig_Interpreter_name
	ExecStepConfig_Interpreter_value                                     = src.ExecStepConfig_Interpreter_value
	ExecStepTaskOutput_State_name                                        = src.ExecStepTaskOutput_State_name
	ExecStepTaskOutput_State_value                                       = src.ExecStepTaskOutput_State_value
	ExecStepTaskProgress_State_name                                      = src.ExecStepTaskProgress_State_name
	ExecStepTaskProgress_State_value                                     = src.ExecStepTaskProgress_State_value
	File_google_cloud_osconfig_agentendpoint_v1beta_agentendpoint_proto  = src.File_google_cloud_osconfig_agentendpoint_v1beta_agentendpoint_proto
	File_google_cloud_osconfig_agentendpoint_v1beta_guest_policies_proto = src.File_google_cloud_osconfig_agentendpoint_v1beta_guest_policies_proto
	File_google_cloud_osconfig_agentendpoint_v1beta_patch_jobs_proto     = src.File_google_cloud_osconfig_agentendpoint_v1beta_patch_jobs_proto
	File_google_cloud_osconfig_agentendpoint_v1beta_tasks_proto          = src.File_google_cloud_osconfig_agentendpoint_v1beta_tasks_proto
	Package_Manager_name                                                 = src.Package_Manager_name
	Package_Manager_value                                                = src.Package_Manager_value
	PatchConfig_RebootConfig_name                                        = src.PatchConfig_RebootConfig_name
	PatchConfig_RebootConfig_value                                       = src.PatchConfig_RebootConfig_value
	SoftwareRecipe_Step_ExtractArchive_ArchiveType_name                  = src.SoftwareRecipe_Step_ExtractArchive_ArchiveType_name
	SoftwareRecipe_Step_ExtractArchive_ArchiveType_value                 = src.SoftwareRecipe_Step_ExtractArchive_ArchiveType_value
	SoftwareRecipe_Step_RunScript_Interpreter_name                       = src.SoftwareRecipe_Step_RunScript_Interpreter_name
	SoftwareRecipe_Step_RunScript_Interpreter_value                      = src.SoftwareRecipe_Step_RunScript_Interpreter_value
	TaskDirective_name                                                   = src.TaskDirective_name
	TaskDirective_value                                                  = src.TaskDirective_value
	TaskType_name                                                        = src.TaskType_name
	TaskType_value                                                       = src.TaskType_value
	WindowsUpdateSettings_Classification_name                            = src.WindowsUpdateSettings_Classification_name
	WindowsUpdateSettings_Classification_value                           = src.WindowsUpdateSettings_Classification_value
)

// AgentEndpointServiceClient is the client API for AgentEndpointService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type AgentEndpointServiceClient = src.AgentEndpointServiceClient

// AgentEndpointServiceServer is the server API for AgentEndpointService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type AgentEndpointServiceServer = src.AgentEndpointServiceServer
type AgentEndpointService_ReceiveTaskNotificationClient = src.AgentEndpointService_ReceiveTaskNotificationClient
type AgentEndpointService_ReceiveTaskNotificationServer = src.AgentEndpointService_ReceiveTaskNotificationServer

// Message which instructs agent to apply patches.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ApplyPatchesTask = src.ApplyPatchesTask

// Information reported from the agent about applying patches execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ApplyPatchesTaskOutput = src.ApplyPatchesTaskOutput

// The final states of applying patches.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ApplyPatchesTaskOutput_State = src.ApplyPatchesTaskOutput_State

// Information reported from the agent about applying patches execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ApplyPatchesTaskProgress = src.ApplyPatchesTaskProgress

// The intermediate states of applying patches.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ApplyPatchesTaskProgress_State = src.ApplyPatchesTaskProgress_State

// Represents a single Apt package repository. This repository is added to a
// repo file that is stored at `/etc/apt/sources.list.d/google_osconfig.list`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type AptRepository = src.AptRepository

// Type of archive.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type AptRepository_ArchiveType = src.AptRepository_ArchiveType

// Apt patching will be performed by executing `apt-get update && apt-get
// upgrade`. Additional options can be set to control how this is executed.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type AptSettings = src.AptSettings

// Apt patch type.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type AptSettings_Type = src.AptSettings_Type

// The desired state that the OS Config agent will maintain on the VM.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type DesiredState = src.DesiredState

// The effective guest policy assigned to the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type EffectiveGuestPolicy = src.EffectiveGuestPolicy

// A guest policy package including its source.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type EffectiveGuestPolicy_SourcedPackage = src.EffectiveGuestPolicy_SourcedPackage

// A guest policy package repository including its source.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type EffectiveGuestPolicy_SourcedPackageRepository = src.EffectiveGuestPolicy_SourcedPackageRepository

// A guest policy recipe including its source.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type EffectiveGuestPolicy_SourcedSoftwareRecipe = src.EffectiveGuestPolicy_SourcedSoftwareRecipe

// A step that runs an executable for a PatchJob.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ExecStep = src.ExecStep

// Common configurations for an ExecStep.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ExecStepConfig = src.ExecStepConfig
type ExecStepConfig_GcsObject = src.ExecStepConfig_GcsObject

// The interpreter used to execute the a file.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ExecStepConfig_Interpreter = src.ExecStepConfig_Interpreter
type ExecStepConfig_LocalPath = src.ExecStepConfig_LocalPath

// Message which instructs agent to execute the following command.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ExecStepTask = src.ExecStepTask

// Information reported from the agent about the exec step execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ExecStepTaskOutput = src.ExecStepTaskOutput

// The final states of exec steps.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ExecStepTaskOutput_State = src.ExecStepTaskOutput_State

// Information reported from the agent about the exec step execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ExecStepTaskProgress = src.ExecStepTaskProgress

// The intermediate states of exec steps.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ExecStepTaskProgress_State = src.ExecStepTaskProgress_State

// GCS object representation.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type GcsObject = src.GcsObject

// Represents a Goo package repository. These is added to a repo file that is
// stored at C:/ProgramData/GooGet/repos/google_osconfig.repo.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type GooRepository = src.GooRepository

// Googet patching is performed by running `googet update`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type GooSettings = src.GooSettings

// A request message for getting effective policy assigned to the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type LookupEffectiveGuestPolicyRequest = src.LookupEffectiveGuestPolicyRequest

// Package is a reference to the software package to be installed or removed.
// The agent on the VM instance uses the system package manager to apply the
// config. These are the commands that the agent uses to install or remove
// packages. Apt install: `apt-get update && apt-get -y install package1
// package2 package3` remove: `apt-get -y remove package1 package2 package3`
// Yum install: `yum -y install package1 package2 package3` remove: `yum -y
// remove package1 package2 package3` Zypper install: `zypper install package1
// package2 package3` remove: `zypper rm package1 package2` Googet install:
// `googet -noconfirm install package1 package2 package3` remove: `googet
// -noconfirm remove package1 package2 package3`
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type Package = src.Package

// A package repository.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type PackageRepository = src.PackageRepository
type PackageRepository_Apt = src.PackageRepository_Apt
type PackageRepository_Goo = src.PackageRepository_Goo
type PackageRepository_Yum = src.PackageRepository_Yum
type PackageRepository_Zypper = src.PackageRepository_Zypper

// Types of package managers that may be used to manage this package.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type Package_Manager = src.Package_Manager

// Patch configuration specifications. Contains details on how to apply
// patches to a VM instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type PatchConfig = src.PatchConfig

// Post-patch reboot settings.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type PatchConfig_RebootConfig = src.PatchConfig_RebootConfig

// A request message to receive task notifications.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ReceiveTaskNotificationRequest = src.ReceiveTaskNotificationRequest

// The streaming rpc message that notifies the agent when it has a task that
// it needs to perform on the VM instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ReceiveTaskNotificationResponse = src.ReceiveTaskNotificationResponse

// The request message for registering the agent.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type RegisterAgentRequest = src.RegisterAgentRequest

// The response message after the agent registered.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type RegisterAgentResponse = src.RegisterAgentResponse

// A request message for signaling the completion of a task execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ReportTaskCompleteRequest = src.ReportTaskCompleteRequest
type ReportTaskCompleteRequest_ApplyPatchesTaskOutput = src.ReportTaskCompleteRequest_ApplyPatchesTaskOutput
type ReportTaskCompleteRequest_ExecStepTaskOutput = src.ReportTaskCompleteRequest_ExecStepTaskOutput

// The response message after the agent signaled the current task complete.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ReportTaskCompleteResponse = src.ReportTaskCompleteResponse

// A request message for reporting the progress of current task.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ReportTaskProgressRequest = src.ReportTaskProgressRequest
type ReportTaskProgressRequest_ApplyPatchesTaskProgress = src.ReportTaskProgressRequest_ApplyPatchesTaskProgress
type ReportTaskProgressRequest_ExecStepTaskProgress = src.ReportTaskProgressRequest_ExecStepTaskProgress

// The response message after the agent reported the current task progress.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ReportTaskProgressResponse = src.ReportTaskProgressResponse

// The strategy for retrying failed patches during the patch window.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type RetryStrategy = src.RetryStrategy

// A software recipe is a set of instructions for installing and configuring a
// piece of software. It consists of a set of artifacts that are downloaded,
// and a set of steps that install, configure, and/or update the software.
// Recipes support installing and updating software from artifacts in the
// following formats: Zip archive, Tar archive, Windows MSI, Debian package,
// and RPM package. Additionally, recipes support executing a script (either
// defined in a file or directly in this api) in bash, sh, cmd, and powershell.
// # Updating a software recipe If a recipe is assigned to an instance and
// there is a recipe with the same name but a lower version already installed
// and the assigned state of the recipe is `INSTALLED_KEEP_UPDATED`, then the
// recipe is updated to the new version. # Script Working Directories Each
// script or execution step is run in its own temporary directory which is
// deleted after completing the step.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe = src.SoftwareRecipe

// Specifies a resource to be used in the recipe.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Artifact = src.SoftwareRecipe_Artifact

// Specifies an artifact available as a Cloud Storage object.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Artifact_Gcs = src.SoftwareRecipe_Artifact_Gcs
type SoftwareRecipe_Artifact_Gcs_ = src.SoftwareRecipe_Artifact_Gcs_

// Specifies an artifact available via some URI.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Artifact_Remote = src.SoftwareRecipe_Artifact_Remote
type SoftwareRecipe_Artifact_Remote_ = src.SoftwareRecipe_Artifact_Remote_

// An action that can be taken as part of installing or updating a recipe.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Step = src.SoftwareRecipe_Step
type SoftwareRecipe_Step_ArchiveExtraction = src.SoftwareRecipe_Step_ArchiveExtraction

// Copies the artifact to the specified path on the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Step_CopyFile = src.SoftwareRecipe_Step_CopyFile
type SoftwareRecipe_Step_DpkgInstallation = src.SoftwareRecipe_Step_DpkgInstallation

// Executes an artifact or local file.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Step_ExecFile = src.SoftwareRecipe_Step_ExecFile
type SoftwareRecipe_Step_ExecFile_ArtifactId = src.SoftwareRecipe_Step_ExecFile_ArtifactId
type SoftwareRecipe_Step_ExecFile_LocalPath = src.SoftwareRecipe_Step_ExecFile_LocalPath

// Extracts an archive of the type specified in the specified directory.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Step_ExtractArchive = src.SoftwareRecipe_Step_ExtractArchive

// Specifying the type of archive.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Step_ExtractArchive_ArchiveType = src.SoftwareRecipe_Step_ExtractArchive_ArchiveType
type SoftwareRecipe_Step_FileCopy = src.SoftwareRecipe_Step_FileCopy
type SoftwareRecipe_Step_FileExec = src.SoftwareRecipe_Step_FileExec

// Installs a deb via dpkg.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Step_InstallDpkg = src.SoftwareRecipe_Step_InstallDpkg

// Installs an MSI file.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Step_InstallMsi = src.SoftwareRecipe_Step_InstallMsi

// Installs an rpm file via the rpm utility.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Step_InstallRpm = src.SoftwareRecipe_Step_InstallRpm
type SoftwareRecipe_Step_MsiInstallation = src.SoftwareRecipe_Step_MsiInstallation
type SoftwareRecipe_Step_RpmInstallation = src.SoftwareRecipe_Step_RpmInstallation

// Runs a script through an interpreter.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Step_RunScript = src.SoftwareRecipe_Step_RunScript

// The interpreter used to execute a script.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type SoftwareRecipe_Step_RunScript_Interpreter = src.SoftwareRecipe_Step_RunScript_Interpreter
type SoftwareRecipe_Step_ScriptRun = src.SoftwareRecipe_Step_ScriptRun

// A request message for signaling the start of a task execution.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type StartNextTaskRequest = src.StartNextTaskRequest

// A response message that contains the details of the task to work on.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type StartNextTaskResponse = src.StartNextTaskResponse

// A unit of work to be performed by the agent.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type Task = src.Task

// Specifies the current agent behavior.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type TaskDirective = src.TaskDirective

// Specifies the type of task to perform.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type TaskType = src.TaskType
type Task_ApplyPatchesTask = src.Task_ApplyPatchesTask
type Task_ExecStepTask = src.Task_ExecStepTask

// UnimplementedAgentEndpointServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type UnimplementedAgentEndpointServiceServer = src.UnimplementedAgentEndpointServiceServer

// Windows patching is performed using the Windows Update Agent.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type WindowsUpdateSettings = src.WindowsUpdateSettings

// Microsoft Windows update classifications as defined in [1]
// https://support.microsoft.com/en-us/help/824684/description-of-the-standard-terminology-that-is-used-to-describe-micro
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type WindowsUpdateSettings_Classification = src.WindowsUpdateSettings_Classification

// Represents a single Yum package repository. This repository is added to a
// repo file that is stored at `/etc/yum.repos.d/google_osconfig.repo`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type YumRepository = src.YumRepository

// Yum patching will be performed by executing `yum update`. Additional
// options can be set to control how this is executed. Note that not all
// settings are supported on all platforms.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type YumSettings = src.YumSettings

// Represents a single Zypper package repository. This repository is added to
// a repo file that is stored at `/etc/zypp/repos.d/google_osconfig.repo`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ZypperRepository = src.ZypperRepository

// Zypper patching is performed by running `zypper patch`. See also
// https://en.opensuse.org/SDB:Zypper_manual.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
type ZypperSettings = src.ZypperSettings

// Deprecated: Please use funcs in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
func NewAgentEndpointServiceClient(cc grpc.ClientConnInterface) AgentEndpointServiceClient {
	return src.NewAgentEndpointServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/osconfig/agentendpoint/apiv1beta/agentendpointpb
func RegisterAgentEndpointServiceServer(s *grpc.Server, srv AgentEndpointServiceServer) {
	src.RegisterAgentEndpointServiceServer(s, srv)
}
