// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package iap aliases all exported identifiers in package
// "cloud.google.com/go/iap/apiv1/iappb".
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package iap

import (
	src "cloud.google.com/go/iap/apiv1/iappb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/iap/apiv1/iappb
const (
	ReauthSettings_DEFAULT                 = src.ReauthSettings_DEFAULT
	ReauthSettings_LOGIN                   = src.ReauthSettings_LOGIN
	ReauthSettings_METHOD_UNSPECIFIED      = src.ReauthSettings_METHOD_UNSPECIFIED
	ReauthSettings_MINIMUM                 = src.ReauthSettings_MINIMUM
	ReauthSettings_PASSWORD                = src.ReauthSettings_PASSWORD
	ReauthSettings_POLICY_TYPE_UNSPECIFIED = src.ReauthSettings_POLICY_TYPE_UNSPECIFIED
	ReauthSettings_SECURE_KEY              = src.ReauthSettings_SECURE_KEY
)

// Deprecated: Please use vars in: cloud.google.com/go/iap/apiv1/iappb
var (
	File_google_cloud_iap_v1_service_proto = src.File_google_cloud_iap_v1_service_proto
	ReauthSettings_Method_name             = src.ReauthSettings_Method_name
	ReauthSettings_Method_value            = src.ReauthSettings_Method_value
	ReauthSettings_PolicyType_name         = src.ReauthSettings_PolicyType_name
	ReauthSettings_PolicyType_value        = src.ReauthSettings_PolicyType_value
)

// Custom content configuration for access denied page. IAP allows customers
// to define a custom URI to use as the error page when access is denied to
// users. If IAP prevents access to this page, the default IAP error page will
// be displayed instead.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type AccessDeniedPageSettings = src.AccessDeniedPageSettings

// Access related settings for IAP protected apps.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type AccessSettings = src.AccessSettings

// Wrapper over application specific settings for IAP.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ApplicationSettings = src.ApplicationSettings

// OAuth brand data. NOTE: Only contains a portion of the data that describes
// a brand.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type Brand = src.Brand

// Allows customers to configure HTTP request paths that'll allow HTTP OPTIONS
// call to bypass authentication and authorization.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type CorsSettings = src.CorsSettings

// The request sent to CreateBrand.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type CreateBrandRequest = src.CreateBrandRequest

// The request sent to CreateIdentityAwareProxyClient.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type CreateIdentityAwareProxyClientRequest = src.CreateIdentityAwareProxyClientRequest

// The request to CreateTunnelDestGroup.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type CreateTunnelDestGroupRequest = src.CreateTunnelDestGroupRequest

// Configuration for RCTokens generated for CSM workloads protected by IAP.
// RCTokens are IAP generated JWTs that can be verified at the application. The
// RCToken is primarily used for ISTIO deployments, and can be scoped to a
// single mesh by configuring the audience field accordingly
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type CsmSettings = src.CsmSettings

// The request sent to DeleteIdentityAwareProxyClient.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type DeleteIdentityAwareProxyClientRequest = src.DeleteIdentityAwareProxyClientRequest

// The request to DeleteTunnelDestGroup.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type DeleteTunnelDestGroupRequest = src.DeleteTunnelDestGroupRequest

// Allows customers to configure tenant_id for GCIP instance per-app.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type GcipSettings = src.GcipSettings

// The request sent to GetBrand.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type GetBrandRequest = src.GetBrandRequest

// The request sent to GetIapSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type GetIapSettingsRequest = src.GetIapSettingsRequest

// The request sent to GetIdentityAwareProxyClient.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type GetIdentityAwareProxyClientRequest = src.GetIdentityAwareProxyClientRequest

// The request to GetTunnelDestGroup.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type GetTunnelDestGroupRequest = src.GetTunnelDestGroupRequest

// The IAP configurable settings.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type IapSettings = src.IapSettings

// IdentityAwareProxyAdminServiceClient is the client API for
// IdentityAwareProxyAdminService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type IdentityAwareProxyAdminServiceClient = src.IdentityAwareProxyAdminServiceClient

// IdentityAwareProxyAdminServiceServer is the server API for
// IdentityAwareProxyAdminService service.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type IdentityAwareProxyAdminServiceServer = src.IdentityAwareProxyAdminServiceServer

// Contains the data that describes an Identity Aware Proxy owned client.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type IdentityAwareProxyClient = src.IdentityAwareProxyClient

// IdentityAwareProxyOAuthServiceClient is the client API for
// IdentityAwareProxyOAuthService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type IdentityAwareProxyOAuthServiceClient = src.IdentityAwareProxyOAuthServiceClient

// IdentityAwareProxyOAuthServiceServer is the server API for
// IdentityAwareProxyOAuthService service.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type IdentityAwareProxyOAuthServiceServer = src.IdentityAwareProxyOAuthServiceServer

// The request sent to ListBrands.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ListBrandsRequest = src.ListBrandsRequest

// Response message for ListBrands.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ListBrandsResponse = src.ListBrandsResponse

// The request sent to ListIdentityAwareProxyClients.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ListIdentityAwareProxyClientsRequest = src.ListIdentityAwareProxyClientsRequest

// Response message for ListIdentityAwareProxyClients.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ListIdentityAwareProxyClientsResponse = src.ListIdentityAwareProxyClientsResponse

// The request to ListTunnelDestGroups.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ListTunnelDestGroupsRequest = src.ListTunnelDestGroupsRequest

// The response from ListTunnelDestGroups.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ListTunnelDestGroupsResponse = src.ListTunnelDestGroupsResponse

// Configuration for OAuth login&consent flow behavior as well as for OAuth
// Credentials.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type OAuthSettings = src.OAuthSettings

// Configuration for IAP reauthentication policies.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ReauthSettings = src.ReauthSettings

// Types of reauthentication methods supported by IAP.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ReauthSettings_Method = src.ReauthSettings_Method

// Type of policy in the case of hierarchial policies.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ReauthSettings_PolicyType = src.ReauthSettings_PolicyType

// The request sent to ResetIdentityAwareProxyClientSecret.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type ResetIdentityAwareProxyClientSecretRequest = src.ResetIdentityAwareProxyClientSecretRequest

// A TunnelDestGroup.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type TunnelDestGroup = src.TunnelDestGroup

// UnimplementedIdentityAwareProxyAdminServiceServer can be embedded to have
// forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type UnimplementedIdentityAwareProxyAdminServiceServer = src.UnimplementedIdentityAwareProxyAdminServiceServer

// UnimplementedIdentityAwareProxyOAuthServiceServer can be embedded to have
// forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type UnimplementedIdentityAwareProxyOAuthServiceServer = src.UnimplementedIdentityAwareProxyOAuthServiceServer

// The request sent to UpdateIapSettings.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type UpdateIapSettingsRequest = src.UpdateIapSettingsRequest

// The request to UpdateTunnelDestGroup.
//
// Deprecated: Please use types in: cloud.google.com/go/iap/apiv1/iappb
type UpdateTunnelDestGroupRequest = src.UpdateTunnelDestGroupRequest

// Deprecated: Please use funcs in: cloud.google.com/go/iap/apiv1/iappb
func NewIdentityAwareProxyAdminServiceClient(cc grpc.ClientConnInterface) IdentityAwareProxyAdminServiceClient {
	return src.NewIdentityAwareProxyAdminServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/iap/apiv1/iappb
func NewIdentityAwareProxyOAuthServiceClient(cc grpc.ClientConnInterface) IdentityAwareProxyOAuthServiceClient {
	return src.NewIdentityAwareProxyOAuthServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/iap/apiv1/iappb
func RegisterIdentityAwareProxyAdminServiceServer(s *grpc.Server, srv IdentityAwareProxyAdminServiceServer) {
	src.RegisterIdentityAwareProxyAdminServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/iap/apiv1/iappb
func RegisterIdentityAwareProxyOAuthServiceServer(s *grpc.Server, srv IdentityAwareProxyOAuthServiceServer) {
	src.RegisterIdentityAwareProxyOAuthServiceServer(s, srv)
}
