// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package asset aliases all exported identifiers in package
// "cloud.google.com/go/asset/apiv1/assetpb".
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package asset

import (
	src "cloud.google.com/go/asset/apiv1/assetpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/asset/apiv1/assetpb
const (
	AnalyzeMoveRequest_ANALYSIS_VIEW_UNSPECIFIED                                = src.AnalyzeMoveRequest_ANALYSIS_VIEW_UNSPECIFIED
	AnalyzeMoveRequest_BASIC                                                    = src.AnalyzeMoveRequest_BASIC
	AnalyzeMoveRequest_FULL                                                     = src.AnalyzeMoveRequest_FULL
	ConditionEvaluation_CONDITIONAL                                             = src.ConditionEvaluation_CONDITIONAL
	ConditionEvaluation_EVALUATION_VALUE_UNSPECIFIED                            = src.ConditionEvaluation_EVALUATION_VALUE_UNSPECIFIED
	ConditionEvaluation_FALSE                                                   = src.ConditionEvaluation_FALSE
	ConditionEvaluation_TRUE                                                    = src.ConditionEvaluation_TRUE
	ContentType_ACCESS_POLICY                                                   = src.ContentType_ACCESS_POLICY
	ContentType_CONTENT_TYPE_UNSPECIFIED                                        = src.ContentType_CONTENT_TYPE_UNSPECIFIED
	ContentType_IAM_POLICY                                                      = src.ContentType_IAM_POLICY
	ContentType_ORG_POLICY                                                      = src.ContentType_ORG_POLICY
	ContentType_OS_INVENTORY                                                    = src.ContentType_OS_INVENTORY
	ContentType_RELATIONSHIP                                                    = src.ContentType_RELATIONSHIP
	ContentType_RESOURCE                                                        = src.ContentType_RESOURCE
	IamPolicyAnalysisOutputConfig_BigQueryDestination_PARTITION_KEY_UNSPECIFIED = src.IamPolicyAnalysisOutputConfig_BigQueryDestination_PARTITION_KEY_UNSPECIFIED
	IamPolicyAnalysisOutputConfig_BigQueryDestination_REQUEST_TIME              = src.IamPolicyAnalysisOutputConfig_BigQueryDestination_REQUEST_TIME
	PartitionSpec_PARTITION_KEY_UNSPECIFIED                                     = src.PartitionSpec_PARTITION_KEY_UNSPECIFIED
	PartitionSpec_READ_TIME                                                     = src.PartitionSpec_READ_TIME
	PartitionSpec_REQUEST_TIME                                                  = src.PartitionSpec_REQUEST_TIME
	TemporalAsset_DELETED                                                       = src.TemporalAsset_DELETED
	TemporalAsset_DOES_NOT_EXIST                                                = src.TemporalAsset_DOES_NOT_EXIST
	TemporalAsset_INVALID                                                       = src.TemporalAsset_INVALID
	TemporalAsset_PRESENT                                                       = src.TemporalAsset_PRESENT
	TemporalAsset_PRIOR_ASSET_STATE_UNSPECIFIED                                 = src.TemporalAsset_PRIOR_ASSET_STATE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/asset/apiv1/assetpb
var (
	AnalyzeMoveRequest_AnalysisView_name                                 = src.AnalyzeMoveRequest_AnalysisView_name
	AnalyzeMoveRequest_AnalysisView_value                                = src.AnalyzeMoveRequest_AnalysisView_value
	ConditionEvaluation_EvaluationValue_name                             = src.ConditionEvaluation_EvaluationValue_name
	ConditionEvaluation_EvaluationValue_value                            = src.ConditionEvaluation_EvaluationValue_value
	ContentType_name                                                     = src.ContentType_name
	ContentType_value                                                    = src.ContentType_value
	File_google_cloud_asset_v1_asset_service_proto                       = src.File_google_cloud_asset_v1_asset_service_proto
	File_google_cloud_asset_v1_assets_proto                              = src.File_google_cloud_asset_v1_assets_proto
	IamPolicyAnalysisOutputConfig_BigQueryDestination_PartitionKey_name  = src.IamPolicyAnalysisOutputConfig_BigQueryDestination_PartitionKey_name
	IamPolicyAnalysisOutputConfig_BigQueryDestination_PartitionKey_value = src.IamPolicyAnalysisOutputConfig_BigQueryDestination_PartitionKey_value
	PartitionSpec_PartitionKey_name                                      = src.PartitionSpec_PartitionKey_name
	PartitionSpec_PartitionKey_value                                     = src.PartitionSpec_PartitionKey_value
	TemporalAsset_PriorAssetState_name                                   = src.TemporalAsset_PriorAssetState_name
	TemporalAsset_PriorAssetState_value                                  = src.TemporalAsset_PriorAssetState_value
)

// Represents the metadata of the longrunning operation for the
// AnalyzeIamPolicyLongrunning rpc.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AnalyzeIamPolicyLongrunningMetadata = src.AnalyzeIamPolicyLongrunningMetadata

// A request message for
// [AssetService.AnalyzeIamPolicyLongrunning][google.cloud.asset.v1.AssetService.AnalyzeIamPolicyLongrunning].
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AnalyzeIamPolicyLongrunningRequest = src.AnalyzeIamPolicyLongrunningRequest

// A response message for
// [AssetService.AnalyzeIamPolicyLongrunning][google.cloud.asset.v1.AssetService.AnalyzeIamPolicyLongrunning].
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AnalyzeIamPolicyLongrunningResponse = src.AnalyzeIamPolicyLongrunningResponse

// A request message for
// [AssetService.AnalyzeIamPolicy][google.cloud.asset.v1.AssetService.AnalyzeIamPolicy].
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AnalyzeIamPolicyRequest = src.AnalyzeIamPolicyRequest

// A response message for
// [AssetService.AnalyzeIamPolicy][google.cloud.asset.v1.AssetService.AnalyzeIamPolicy].
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AnalyzeIamPolicyResponse = src.AnalyzeIamPolicyResponse

// An analysis message to group the query and results.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AnalyzeIamPolicyResponse_IamPolicyAnalysis = src.AnalyzeIamPolicyResponse_IamPolicyAnalysis

// The request message for performing resource move analysis.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AnalyzeMoveRequest = src.AnalyzeMoveRequest

// View enum for supporting partial analysis responses.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AnalyzeMoveRequest_AnalysisView = src.AnalyzeMoveRequest_AnalysisView

// The response message for resource move analysis.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AnalyzeMoveResponse = src.AnalyzeMoveResponse

// An asset in Google Cloud. An asset can be any resource in the Google Cloud
// [resource
// hierarchy](https://cloud.google.com/resource-manager/docs/cloud-platform-resource-hierarchy),
// a resource outside the Google Cloud resource hierarchy (such as Google
// Kubernetes Engine clusters and objects), or a policy (e.g. Cloud IAM
// policy), or a relationship (e.g. an INSTANCE_TO_INSTANCEGROUP relationship).
// See [Supported asset
// types](https://cloud.google.com/asset-inventory/docs/supported-asset-types)
// for more information.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type Asset = src.Asset

// AssetServiceClient is the client API for AssetService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AssetServiceClient = src.AssetServiceClient

// AssetServiceServer is the server API for AssetService service.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AssetServiceServer = src.AssetServiceServer
type Asset_AccessLevel = src.Asset_AccessLevel
type Asset_AccessPolicy = src.Asset_AccessPolicy
type Asset_ServicePerimeter = src.Asset_ServicePerimeter

// Attached resource representation, which is defined by the corresponding
// service provider. It represents an attached resource's payload.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type AttachedResource = src.AttachedResource

// Batch get assets history request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type BatchGetAssetsHistoryRequest = src.BatchGetAssetsHistoryRequest

// Batch get assets history response.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type BatchGetAssetsHistoryResponse = src.BatchGetAssetsHistoryResponse

// A request message for
// [AssetService.BatchGetEffectiveIamPolicies][google.cloud.asset.v1.AssetService.BatchGetEffectiveIamPolicies].
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type BatchGetEffectiveIamPoliciesRequest = src.BatchGetEffectiveIamPoliciesRequest

// A response message for
// [AssetService.BatchGetEffectiveIamPolicies][google.cloud.asset.v1.AssetService.BatchGetEffectiveIamPolicies].
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type BatchGetEffectiveIamPoliciesResponse = src.BatchGetEffectiveIamPoliciesResponse

// The effective IAM policies on one resource.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type BatchGetEffectiveIamPoliciesResponse_EffectiveIamPolicy = src.BatchGetEffectiveIamPoliciesResponse_EffectiveIamPolicy

// The IAM policy and its attached resource.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type BatchGetEffectiveIamPoliciesResponse_EffectiveIamPolicy_PolicyInfo = src.BatchGetEffectiveIamPoliciesResponse_EffectiveIamPolicy_PolicyInfo

// A BigQuery destination for exporting assets to.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type BigQueryDestination = src.BigQueryDestination

// The Condition evaluation.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ConditionEvaluation = src.ConditionEvaluation

// Value of this expression.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ConditionEvaluation_EvaluationValue = src.ConditionEvaluation_EvaluationValue

// Asset content type.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ContentType = src.ContentType

// Create asset feed request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type CreateFeedRequest = src.CreateFeedRequest

// Request to create a saved query.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type CreateSavedQueryRequest = src.CreateSavedQueryRequest
type DeleteFeedRequest = src.DeleteFeedRequest

// Request to delete a saved query.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type DeleteSavedQueryRequest = src.DeleteSavedQueryRequest

// Export asset request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ExportAssetsRequest = src.ExportAssetsRequest

// The export asset response. This message is returned by the
// [google.longrunning.Operations.GetOperation][google.longrunning.Operations.GetOperation]
// method in the returned
// [google.longrunning.Operation.response][google.longrunning.Operation.response]
// field.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ExportAssetsResponse = src.ExportAssetsResponse

// An asset feed used to export asset updates to a destinations. An asset feed
// filter controls what updates are exported. The asset feed must be created
// within a project, organization, or folder. Supported destinations are:
// Pub/Sub topics.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type Feed = src.Feed

// Output configuration for asset feed destination.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type FeedOutputConfig = src.FeedOutputConfig
type FeedOutputConfig_PubsubDestination = src.FeedOutputConfig_PubsubDestination

// A Cloud Storage location.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type GcsDestination = src.GcsDestination
type GcsDestination_Uri = src.GcsDestination_Uri
type GcsDestination_UriPrefix = src.GcsDestination_UriPrefix

// A Cloud Storage output result.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type GcsOutputResult = src.GcsOutputResult

// Get asset feed request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type GetFeedRequest = src.GetFeedRequest

// Request to get a saved query.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type GetSavedQueryRequest = src.GetSavedQueryRequest

// Output configuration for export IAM policy analysis destination.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisOutputConfig = src.IamPolicyAnalysisOutputConfig

// A BigQuery destination.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisOutputConfig_BigQueryDestination = src.IamPolicyAnalysisOutputConfig_BigQueryDestination

// This enum determines the partition key column for the bigquery tables.
// Partitioning can improve query performance and reduce query cost by
// filtering partitions. Refer to
// https://cloud.google.com/bigquery/docs/partitioned-tables for details.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisOutputConfig_BigQueryDestination_PartitionKey = src.IamPolicyAnalysisOutputConfig_BigQueryDestination_PartitionKey
type IamPolicyAnalysisOutputConfig_BigqueryDestination = src.IamPolicyAnalysisOutputConfig_BigqueryDestination

// A Cloud Storage location.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisOutputConfig_GcsDestination = src.IamPolicyAnalysisOutputConfig_GcsDestination
type IamPolicyAnalysisOutputConfig_GcsDestination_ = src.IamPolicyAnalysisOutputConfig_GcsDestination_

// IAM policy analysis query message.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisQuery = src.IamPolicyAnalysisQuery

// Specifies roles and/or permissions to analyze, to determine both the
// identities possessing them and the resources they control. If multiple
// values are specified, results will include roles or permissions matching any
// of them. The total number of roles and permissions should be equal or less
// than 10.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisQuery_AccessSelector = src.IamPolicyAnalysisQuery_AccessSelector

// The IAM conditions context.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisQuery_ConditionContext = src.IamPolicyAnalysisQuery_ConditionContext
type IamPolicyAnalysisQuery_ConditionContext_AccessTime = src.IamPolicyAnalysisQuery_ConditionContext_AccessTime

// Specifies an identity for which to determine resource access, based on
// roles assigned either directly to them or to the groups they belong to,
// directly or indirectly.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisQuery_IdentitySelector = src.IamPolicyAnalysisQuery_IdentitySelector

// Contains query options.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisQuery_Options = src.IamPolicyAnalysisQuery_Options

// Specifies the resource to analyze for access policies, which may be set
// directly on the resource, or on ancestors such as organizations, folders or
// projects.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisQuery_ResourceSelector = src.IamPolicyAnalysisQuery_ResourceSelector

// IAM Policy analysis result, consisting of one IAM policy binding and
// derived access control lists.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisResult = src.IamPolicyAnalysisResult

// An IAM role or permission under analysis.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisResult_Access = src.IamPolicyAnalysisResult_Access

// An access control list, derived from the above IAM policy binding, which
// contains a set of resources and accesses. May include one item from each set
// to compose an access control entry. NOTICE that there could be multiple
// access control lists for one IAM policy binding. The access control lists
// are created based on resource and access combinations. For example, assume
// we have the following cases in one IAM policy binding: - Permission P1 and
// P2 apply to resource R1 and R2; - Permission P3 applies to resource R2 and
// R3; This will result in the following access control lists: -
// AccessControlList 1: [R1, R2], [P1, P2] - AccessControlList 2: [R2, R3],
// [P3]
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisResult_AccessControlList = src.IamPolicyAnalysisResult_AccessControlList
type IamPolicyAnalysisResult_Access_Permission = src.IamPolicyAnalysisResult_Access_Permission
type IamPolicyAnalysisResult_Access_Role = src.IamPolicyAnalysisResult_Access_Role

// A directional edge.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisResult_Edge = src.IamPolicyAnalysisResult_Edge

// An identity under analysis.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisResult_Identity = src.IamPolicyAnalysisResult_Identity

// The identities and group edges.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisResult_IdentityList = src.IamPolicyAnalysisResult_IdentityList

// A Google Cloud resource under analysis.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisResult_Resource = src.IamPolicyAnalysisResult_Resource

// Represents the detailed state of an entity under analysis, such as a
// resource, an identity or an access.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicyAnalysisState = src.IamPolicyAnalysisState

// A result of IAM Policy search, containing information of an IAM policy.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicySearchResult = src.IamPolicySearchResult

// Explanation about the IAM policy search result.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicySearchResult_Explanation = src.IamPolicySearchResult_Explanation

// IAM permissions
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type IamPolicySearchResult_Explanation_Permissions = src.IamPolicySearchResult_Explanation_Permissions

// ListAssets request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ListAssetsRequest = src.ListAssetsRequest

// ListAssets response.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ListAssetsResponse = src.ListAssetsResponse

// List asset feeds request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ListFeedsRequest = src.ListFeedsRequest
type ListFeedsResponse = src.ListFeedsResponse

// Request to list saved queries.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ListSavedQueriesRequest = src.ListSavedQueriesRequest

// Response of listing saved queries.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ListSavedQueriesResponse = src.ListSavedQueriesResponse

// A message to group the analysis information.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type MoveAnalysis = src.MoveAnalysis

// An analysis result including blockers and warnings.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type MoveAnalysisResult = src.MoveAnalysisResult
type MoveAnalysis_Analysis = src.MoveAnalysis_Analysis
type MoveAnalysis_Error = src.MoveAnalysis_Error

// A message to group impacts of moving the target resource.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type MoveImpact = src.MoveImpact

// Output configuration for export assets destination.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type OutputConfig = src.OutputConfig
type OutputConfig_BigqueryDestination = src.OutputConfig_BigqueryDestination
type OutputConfig_GcsDestination = src.OutputConfig_GcsDestination

// Output result of export assets.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type OutputResult = src.OutputResult
type OutputResult_GcsResult = src.OutputResult_GcsResult

// Specifications of BigQuery partitioned table as export destination.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type PartitionSpec = src.PartitionSpec

// This enum is used to determine the partition key column when exporting
// assets to BigQuery partitioned table(s). Note that, if the partition key is
// a timestamp column, the actual partition is based on its date value
// (expressed in UTC. see details in
// https://cloud.google.com/bigquery/docs/partitioned-tables#date_timestamp_partitioned_tables).
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type PartitionSpec_PartitionKey = src.PartitionSpec_PartitionKey

// A Pub/Sub destination.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type PubsubDestination = src.PubsubDestination

// Output configuration query assets.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type QueryAssetsOutputConfig = src.QueryAssetsOutputConfig

// BigQuery destination.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type QueryAssetsOutputConfig_BigQueryDestination = src.QueryAssetsOutputConfig_BigQueryDestination

// QueryAssets request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type QueryAssetsRequest = src.QueryAssetsRequest
type QueryAssetsRequest_JobReference = src.QueryAssetsRequest_JobReference
type QueryAssetsRequest_ReadTime = src.QueryAssetsRequest_ReadTime
type QueryAssetsRequest_ReadTimeWindow = src.QueryAssetsRequest_ReadTimeWindow
type QueryAssetsRequest_Statement = src.QueryAssetsRequest_Statement

// QueryAssets response.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type QueryAssetsResponse = src.QueryAssetsResponse
type QueryAssetsResponse_Error = src.QueryAssetsResponse_Error
type QueryAssetsResponse_OutputConfig = src.QueryAssetsResponse_OutputConfig
type QueryAssetsResponse_QueryResult = src.QueryAssetsResponse_QueryResult

// Execution results of the query. The result is formatted as rows represented
// by BigQuery compatible [schema]. When pagination is necessary, it will
// contains the page token to retrieve the results of following pages.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type QueryResult = src.QueryResult

// An asset identifier in Google Cloud which contains its name, type and
// ancestors. An asset can be any resource in the Google Cloud [resource
// hierarchy](https://cloud.google.com/resource-manager/docs/cloud-platform-resource-hierarchy),
// a resource outside the Google Cloud resource hierarchy (such as Google
// Kubernetes Engine clusters and objects), or a policy (e.g. Cloud IAM
// policy). See [Supported asset
// types](https://cloud.google.com/asset-inventory/docs/supported-asset-types)
// for more information.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type RelatedAsset = src.RelatedAsset

// DEPRECATED. This message only presents for the purpose of
// backward-compatibility. The server will never populate this message in
// responses. The detailed related assets with the `relationship_type`.
// Deprecated: Do not use.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type RelatedAssets = src.RelatedAssets

// The detailed related resource.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type RelatedResource = src.RelatedResource

// The related resources of the primary resource.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type RelatedResources = src.RelatedResources

// DEPRECATED. This message only presents for the purpose of
// backward-compatibility. The server will never populate this message in
// responses. The relationship attributes which include `type`,
// `source_resource_type`, `target_resource_type` and `action`. Deprecated: Do
// not use.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type RelationshipAttributes = src.RelationshipAttributes

// A representation of a Google Cloud resource.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type Resource = src.Resource

// A result of Resource Search, containing information of a cloud resource.
// Next ID: 31
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type ResourceSearchResult = src.ResourceSearchResult

// A saved query which can be shared with others or used later.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type SavedQuery = src.SavedQuery

// The query content.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type SavedQuery_QueryContent = src.SavedQuery_QueryContent
type SavedQuery_QueryContent_IamPolicyAnalysisQuery = src.SavedQuery_QueryContent_IamPolicyAnalysisQuery

// Search all IAM policies request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type SearchAllIamPoliciesRequest = src.SearchAllIamPoliciesRequest

// Search all IAM policies response.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type SearchAllIamPoliciesResponse = src.SearchAllIamPoliciesResponse

// Search all resources request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type SearchAllResourcesRequest = src.SearchAllResourcesRequest

// Search all resources response.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type SearchAllResourcesResponse = src.SearchAllResourcesResponse

// A field in TableSchema.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type TableFieldSchema = src.TableFieldSchema

// BigQuery Compatible table schema.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type TableSchema = src.TableSchema

// An asset in Google Cloud and its temporal metadata, including the time
// window when it was observed and its status during that window.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type TemporalAsset = src.TemporalAsset

// State of prior asset.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type TemporalAsset_PriorAssetState = src.TemporalAsset_PriorAssetState

// A time window specified by its `start_time` and `end_time`.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type TimeWindow = src.TimeWindow

// UnimplementedAssetServiceServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type UnimplementedAssetServiceServer = src.UnimplementedAssetServiceServer

// Update asset feed request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type UpdateFeedRequest = src.UpdateFeedRequest

// Request to update a saved query.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type UpdateSavedQueryRequest = src.UpdateSavedQueryRequest

// Resource representation as defined by the corresponding service providing
// the resource for a given API version.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1/assetpb
type VersionedResource = src.VersionedResource

// Deprecated: Please use funcs in: cloud.google.com/go/asset/apiv1/assetpb
func NewAssetServiceClient(cc grpc.ClientConnInterface) AssetServiceClient {
	return src.NewAssetServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/asset/apiv1/assetpb
func RegisterAssetServiceServer(s *grpc.Server, srv AssetServiceServer) {
	src.RegisterAssetServiceServer(s, srv)
}
