// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package osconfig aliases all exported identifiers in package
// "cloud.google.com/go/osconfig/apiv1beta/osconfigpb".
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package osconfig

import (
	src "cloud.google.com/go/osconfig/apiv1beta/osconfigpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
const (
	AptRepository_ARCHIVE_TYPE_UNSPECIFIED                      = src.AptRepository_ARCHIVE_TYPE_UNSPECIFIED
	AptRepository_DEB                                           = src.AptRepository_DEB
	AptRepository_DEB_SRC                                       = src.AptRepository_DEB_SRC
	AptSettings_DIST                                            = src.AptSettings_DIST
	AptSettings_TYPE_UNSPECIFIED                                = src.AptSettings_TYPE_UNSPECIFIED
	AptSettings_UPGRADE                                         = src.AptSettings_UPGRADE
	DesiredState_DESIRED_STATE_UNSPECIFIED                      = src.DesiredState_DESIRED_STATE_UNSPECIFIED
	DesiredState_INSTALLED                                      = src.DesiredState_INSTALLED
	DesiredState_REMOVED                                        = src.DesiredState_REMOVED
	DesiredState_UPDATED                                        = src.DesiredState_UPDATED
	ExecStepConfig_INTERPRETER_UNSPECIFIED                      = src.ExecStepConfig_INTERPRETER_UNSPECIFIED
	ExecStepConfig_POWERSHELL                                   = src.ExecStepConfig_POWERSHELL
	ExecStepConfig_SHELL                                        = src.ExecStepConfig_SHELL
	Instance_ACKED                                              = src.Instance_ACKED
	Instance_APPLYING_PATCHES                                   = src.Instance_APPLYING_PATCHES
	Instance_DOWNLOADING_PATCHES                                = src.Instance_DOWNLOADING_PATCHES
	Instance_FAILED                                             = src.Instance_FAILED
	Instance_INACTIVE                                           = src.Instance_INACTIVE
	Instance_NOTIFIED                                           = src.Instance_NOTIFIED
	Instance_NO_AGENT_DETECTED                                  = src.Instance_NO_AGENT_DETECTED
	Instance_PATCH_STATE_UNSPECIFIED                            = src.Instance_PATCH_STATE_UNSPECIFIED
	Instance_PENDING                                            = src.Instance_PENDING
	Instance_REBOOTING                                          = src.Instance_REBOOTING
	Instance_RUNNING_POST_PATCH_STEP                            = src.Instance_RUNNING_POST_PATCH_STEP
	Instance_RUNNING_PRE_PATCH_STEP                             = src.Instance_RUNNING_PRE_PATCH_STEP
	Instance_STARTED                                            = src.Instance_STARTED
	Instance_SUCCEEDED                                          = src.Instance_SUCCEEDED
	Instance_SUCCEEDED_REBOOT_REQUIRED                          = src.Instance_SUCCEEDED_REBOOT_REQUIRED
	Instance_TIMED_OUT                                          = src.Instance_TIMED_OUT
	Package_ANY                                                 = src.Package_ANY
	Package_APT                                                 = src.Package_APT
	Package_GOO                                                 = src.Package_GOO
	Package_MANAGER_UNSPECIFIED                                 = src.Package_MANAGER_UNSPECIFIED
	Package_YUM                                                 = src.Package_YUM
	Package_ZYPPER                                              = src.Package_ZYPPER
	PatchConfig_ALWAYS                                          = src.PatchConfig_ALWAYS
	PatchConfig_DEFAULT                                         = src.PatchConfig_DEFAULT
	PatchConfig_NEVER                                           = src.PatchConfig_NEVER
	PatchConfig_REBOOT_CONFIG_UNSPECIFIED                       = src.PatchConfig_REBOOT_CONFIG_UNSPECIFIED
	PatchDeployment_ACTIVE                                      = src.PatchDeployment_ACTIVE
	PatchDeployment_PAUSED                                      = src.PatchDeployment_PAUSED
	PatchDeployment_STATE_UNSPECIFIED                           = src.PatchDeployment_STATE_UNSPECIFIED
	PatchJob_CANCELED                                           = src.PatchJob_CANCELED
	PatchJob_COMPLETED_WITH_ERRORS                              = src.PatchJob_COMPLETED_WITH_ERRORS
	PatchJob_INSTANCE_LOOKUP                                    = src.PatchJob_INSTANCE_LOOKUP
	PatchJob_PATCHING                                           = src.PatchJob_PATCHING
	PatchJob_STARTED                                            = src.PatchJob_STARTED
	PatchJob_STATE_UNSPECIFIED                                  = src.PatchJob_STATE_UNSPECIFIED
	PatchJob_SUCCEEDED                                          = src.PatchJob_SUCCEEDED
	PatchJob_TIMED_OUT                                          = src.PatchJob_TIMED_OUT
	PatchRollout_CONCURRENT_ZONES                               = src.PatchRollout_CONCURRENT_ZONES
	PatchRollout_MODE_UNSPECIFIED                               = src.PatchRollout_MODE_UNSPECIFIED
	PatchRollout_ZONE_BY_ZONE                                   = src.PatchRollout_ZONE_BY_ZONE
	RecurringSchedule_DAILY                                     = src.RecurringSchedule_DAILY
	RecurringSchedule_FREQUENCY_UNSPECIFIED                     = src.RecurringSchedule_FREQUENCY_UNSPECIFIED
	RecurringSchedule_MONTHLY                                   = src.RecurringSchedule_MONTHLY
	RecurringSchedule_WEEKLY                                    = src.RecurringSchedule_WEEKLY
	SoftwareRecipe_Step_ExtractArchive_ARCHIVE_TYPE_UNSPECIFIED = src.SoftwareRecipe_Step_ExtractArchive_ARCHIVE_TYPE_UNSPECIFIED
	SoftwareRecipe_Step_ExtractArchive_TAR                      = src.SoftwareRecipe_Step_ExtractArchive_TAR
	SoftwareRecipe_Step_ExtractArchive_TAR_BZIP                 = src.SoftwareRecipe_Step_ExtractArchive_TAR_BZIP
	SoftwareRecipe_Step_ExtractArchive_TAR_GZIP                 = src.SoftwareRecipe_Step_ExtractArchive_TAR_GZIP
	SoftwareRecipe_Step_ExtractArchive_TAR_LZMA                 = src.SoftwareRecipe_Step_ExtractArchive_TAR_LZMA
	SoftwareRecipe_Step_ExtractArchive_TAR_XZ                   = src.SoftwareRecipe_Step_ExtractArchive_TAR_XZ
	SoftwareRecipe_Step_ExtractArchive_ZIP                      = src.SoftwareRecipe_Step_ExtractArchive_ZIP
	SoftwareRecipe_Step_RunScript_INTERPRETER_UNSPECIFIED       = src.SoftwareRecipe_Step_RunScript_INTERPRETER_UNSPECIFIED
	SoftwareRecipe_Step_RunScript_POWERSHELL                    = src.SoftwareRecipe_Step_RunScript_POWERSHELL
	SoftwareRecipe_Step_RunScript_SHELL                         = src.SoftwareRecipe_Step_RunScript_SHELL
	WindowsUpdateSettings_CLASSIFICATION_UNSPECIFIED            = src.WindowsUpdateSettings_CLASSIFICATION_UNSPECIFIED
	WindowsUpdateSettings_CRITICAL                              = src.WindowsUpdateSettings_CRITICAL
	WindowsUpdateSettings_DEFINITION                            = src.WindowsUpdateSettings_DEFINITION
	WindowsUpdateSettings_DRIVER                                = src.WindowsUpdateSettings_DRIVER
	WindowsUpdateSettings_FEATURE_PACK                          = src.WindowsUpdateSettings_FEATURE_PACK
	WindowsUpdateSettings_SECURITY                              = src.WindowsUpdateSettings_SECURITY
	WindowsUpdateSettings_SERVICE_PACK                          = src.WindowsUpdateSettings_SERVICE_PACK
	WindowsUpdateSettings_TOOL                                  = src.WindowsUpdateSettings_TOOL
	WindowsUpdateSettings_UPDATE                                = src.WindowsUpdateSettings_UPDATE
	WindowsUpdateSettings_UPDATE_ROLLUP                         = src.WindowsUpdateSettings_UPDATE_ROLLUP
)

// Deprecated: Please use vars in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
var (
	AptRepository_ArchiveType_name                            = src.AptRepository_ArchiveType_name
	AptRepository_ArchiveType_value                           = src.AptRepository_ArchiveType_value
	AptSettings_Type_name                                     = src.AptSettings_Type_name
	AptSettings_Type_value                                    = src.AptSettings_Type_value
	DesiredState_name                                         = src.DesiredState_name
	DesiredState_value                                        = src.DesiredState_value
	ExecStepConfig_Interpreter_name                           = src.ExecStepConfig_Interpreter_name
	ExecStepConfig_Interpreter_value                          = src.ExecStepConfig_Interpreter_value
	File_google_cloud_osconfig_v1beta_guest_policies_proto    = src.File_google_cloud_osconfig_v1beta_guest_policies_proto
	File_google_cloud_osconfig_v1beta_osconfig_common_proto   = src.File_google_cloud_osconfig_v1beta_osconfig_common_proto
	File_google_cloud_osconfig_v1beta_osconfig_service_proto  = src.File_google_cloud_osconfig_v1beta_osconfig_service_proto
	File_google_cloud_osconfig_v1beta_patch_deployments_proto = src.File_google_cloud_osconfig_v1beta_patch_deployments_proto
	File_google_cloud_osconfig_v1beta_patch_jobs_proto        = src.File_google_cloud_osconfig_v1beta_patch_jobs_proto
	Instance_PatchState_name                                  = src.Instance_PatchState_name
	Instance_PatchState_value                                 = src.Instance_PatchState_value
	Package_Manager_name                                      = src.Package_Manager_name
	Package_Manager_value                                     = src.Package_Manager_value
	PatchConfig_RebootConfig_name                             = src.PatchConfig_RebootConfig_name
	PatchConfig_RebootConfig_value                            = src.PatchConfig_RebootConfig_value
	PatchDeployment_State_name                                = src.PatchDeployment_State_name
	PatchDeployment_State_value                               = src.PatchDeployment_State_value
	PatchJob_State_name                                       = src.PatchJob_State_name
	PatchJob_State_value                                      = src.PatchJob_State_value
	PatchRollout_Mode_name                                    = src.PatchRollout_Mode_name
	PatchRollout_Mode_value                                   = src.PatchRollout_Mode_value
	RecurringSchedule_Frequency_name                          = src.RecurringSchedule_Frequency_name
	RecurringSchedule_Frequency_value                         = src.RecurringSchedule_Frequency_value
	SoftwareRecipe_Step_ExtractArchive_ArchiveType_name       = src.SoftwareRecipe_Step_ExtractArchive_ArchiveType_name
	SoftwareRecipe_Step_ExtractArchive_ArchiveType_value      = src.SoftwareRecipe_Step_ExtractArchive_ArchiveType_value
	SoftwareRecipe_Step_RunScript_Interpreter_name            = src.SoftwareRecipe_Step_RunScript_Interpreter_name
	SoftwareRecipe_Step_RunScript_Interpreter_value           = src.SoftwareRecipe_Step_RunScript_Interpreter_value
	WindowsUpdateSettings_Classification_name                 = src.WindowsUpdateSettings_Classification_name
	WindowsUpdateSettings_Classification_value                = src.WindowsUpdateSettings_Classification_value
)

// Represents a single Apt package repository. This repository is added to a
// repo file that is stored at `/etc/apt/sources.list.d/google_osconfig.list`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type AptRepository = src.AptRepository

// Type of archive.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type AptRepository_ArchiveType = src.AptRepository_ArchiveType

// Apt patching is completed by executing `apt-get update && apt-get upgrade`.
// Additional options can be set to control how this is executed.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type AptSettings = src.AptSettings

// Apt patch type.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type AptSettings_Type = src.AptSettings_Type

// An assignment represents the group or groups of VM instances that the
// policy applies to. If an assignment is empty, it applies to all VM
// instances. Otherwise, the targeted VM instances must meet all the criteria
// specified. So if both labels and zones are specified, the policy applies to
// VM instances with those labels and in those zones.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type Assignment = src.Assignment

// Represents a group of VM intances that can be identified as having all
// these labels, for example "env=prod and app=web".
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type Assignment_GroupLabel = src.Assignment_GroupLabel

// Defines the criteria for selecting VM Instances by OS type.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type Assignment_OsType = src.Assignment_OsType

// Message for canceling a patch job.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type CancelPatchJobRequest = src.CancelPatchJobRequest

// A request message for creating a guest policy.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type CreateGuestPolicyRequest = src.CreateGuestPolicyRequest

// A request message for creating a patch deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type CreatePatchDeploymentRequest = src.CreatePatchDeploymentRequest

// A request message for deleting a guest policy.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type DeleteGuestPolicyRequest = src.DeleteGuestPolicyRequest

// A request message for deleting a patch deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type DeletePatchDeploymentRequest = src.DeletePatchDeploymentRequest

// The desired state that the OS Config agent maintains on the VM instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type DesiredState = src.DesiredState

// The effective guest policy that applies to a VM instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type EffectiveGuestPolicy = src.EffectiveGuestPolicy

// A guest policy package including its source.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type EffectiveGuestPolicy_SourcedPackage = src.EffectiveGuestPolicy_SourcedPackage

// A guest policy package repository including its source.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type EffectiveGuestPolicy_SourcedPackageRepository = src.EffectiveGuestPolicy_SourcedPackageRepository

// A guest policy recipe including its source.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type EffectiveGuestPolicy_SourcedSoftwareRecipe = src.EffectiveGuestPolicy_SourcedSoftwareRecipe

// A step that runs an executable for a PatchJob.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ExecStep = src.ExecStep

// Common configurations for an ExecStep.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ExecStepConfig = src.ExecStepConfig
type ExecStepConfig_GcsObject = src.ExecStepConfig_GcsObject

// The interpreter used to execute the a file.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ExecStepConfig_Interpreter = src.ExecStepConfig_Interpreter
type ExecStepConfig_LocalPath = src.ExecStepConfig_LocalPath

// A request message to initiate patching across Compute Engine instances.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ExecutePatchJobRequest = src.ExecutePatchJobRequest

// Message encapsulating a value that can be either absolute ("fixed") or
// relative ("percent") to a value.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type FixedOrPercent = src.FixedOrPercent
type FixedOrPercent_Fixed = src.FixedOrPercent_Fixed
type FixedOrPercent_Percent = src.FixedOrPercent_Percent

// Google Cloud Storage object representation.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type GcsObject = src.GcsObject

// A request message for retrieving a guest policy.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type GetGuestPolicyRequest = src.GetGuestPolicyRequest

// A request message for retrieving a patch deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type GetPatchDeploymentRequest = src.GetPatchDeploymentRequest

// Request to get an active or completed patch job.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type GetPatchJobRequest = src.GetPatchJobRequest

// Represents a Goo package repository. These is added to a repo file that is
// stored at C:/ProgramData/GooGet/repos/google_osconfig.repo.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type GooRepository = src.GooRepository

// Googet patching is performed by running `googet update`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type GooSettings = src.GooSettings

// An OS Config resource representing a guest configuration policy. These
// policies represent the desired state for VM instance guest environments
// including packages to install or remove, package repository configurations,
// and software to install.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type GuestPolicy = src.GuestPolicy

// Namespace for instance state enums.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type Instance = src.Instance

// Patch state of an instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type Instance_PatchState = src.Instance_PatchState

// A request message for listing guest policies.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ListGuestPoliciesRequest = src.ListGuestPoliciesRequest

// A response message for listing guest policies.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ListGuestPoliciesResponse = src.ListGuestPoliciesResponse

// A request message for listing patch deployments.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ListPatchDeploymentsRequest = src.ListPatchDeploymentsRequest

// A response message for listing patch deployments.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ListPatchDeploymentsResponse = src.ListPatchDeploymentsResponse

// Request to list details for all instances that are part of a patch job.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ListPatchJobInstanceDetailsRequest = src.ListPatchJobInstanceDetailsRequest

// A response message for listing the instances details for a patch job.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ListPatchJobInstanceDetailsResponse = src.ListPatchJobInstanceDetailsResponse

// A request message for listing patch jobs.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ListPatchJobsRequest = src.ListPatchJobsRequest

// A response message for listing patch jobs.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ListPatchJobsResponse = src.ListPatchJobsResponse

// A request message for getting the effective guest policy assigned to the
// instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type LookupEffectiveGuestPolicyRequest = src.LookupEffectiveGuestPolicyRequest

// Represents a monthly schedule. An example of a valid monthly schedule is
// "on the third Tuesday of the month" or "on the 15th of the month".
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type MonthlySchedule = src.MonthlySchedule
type MonthlySchedule_MonthDay = src.MonthlySchedule_MonthDay
type MonthlySchedule_WeekDayOfMonth = src.MonthlySchedule_WeekDayOfMonth

// Sets the time for a one time patch deployment. Timestamp is in
// [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type OneTimeSchedule = src.OneTimeSchedule

// OsConfigServiceClient is the client API for OsConfigService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type OsConfigServiceClient = src.OsConfigServiceClient

// OsConfigServiceServer is the server API for OsConfigService service.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type OsConfigServiceServer = src.OsConfigServiceServer

// Package is a reference to the software package to be installed or removed.
// The agent on the VM instance uses the system package manager to apply the
// config. These are the commands that the agent uses to install or remove
// packages. Apt install: `apt-get update && apt-get -y install package1
// package2 package3` remove: `apt-get -y remove package1 package2 package3`
// Yum install: `yum -y install package1 package2 package3` remove: `yum -y
// remove package1 package2 package3` Zypper install: `zypper install package1
// package2 package3` remove: `zypper rm package1 package2` Googet install:
// `googet -noconfirm install package1 package2 package3` remove: `googet
// -noconfirm remove package1 package2 package3`
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type Package = src.Package

// A package repository.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PackageRepository = src.PackageRepository
type PackageRepository_Apt = src.PackageRepository_Apt
type PackageRepository_Goo = src.PackageRepository_Goo
type PackageRepository_Yum = src.PackageRepository_Yum
type PackageRepository_Zypper = src.PackageRepository_Zypper

// Types of package managers that may be used to manage this package.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type Package_Manager = src.Package_Manager

// Patch configuration specifications. Contains details on how to apply the
// patch(es) to a VM instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchConfig = src.PatchConfig

// Post-patch reboot settings.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchConfig_RebootConfig = src.PatchConfig_RebootConfig

// Patch deployments are configurations that individual patch jobs use to
// complete a patch. These configurations include instance filter, package
// repository settings, and a schedule. For more information about creating and
// managing patch deployments, see [Scheduling patch
// jobs](https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchDeployment = src.PatchDeployment
type PatchDeployment_OneTimeSchedule = src.PatchDeployment_OneTimeSchedule
type PatchDeployment_RecurringSchedule = src.PatchDeployment_RecurringSchedule

// Represents state of patch peployment.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchDeployment_State = src.PatchDeployment_State

// A filter to target VM instances for patching. The targeted VMs must meet
// all criteria specified. So if both labels and zones are specified, the patch
// job targets only VMs with those labels and in those zones.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchInstanceFilter = src.PatchInstanceFilter

// Represents a group of VMs that can be identified as having all these
// labels, for example "env=prod and app=web".
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchInstanceFilter_GroupLabel = src.PatchInstanceFilter_GroupLabel

// A high level representation of a patch job that is either in progress or
// has completed. Instance details are not included in the job. To paginate
// through instance details, use `ListPatchJobInstanceDetails`. For more
// information about patch jobs, see [Creating patch
// jobs](https://cloud.google.com/compute/docs/os-patch-management/create-patch-job).
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchJob = src.PatchJob

// Patch details for a VM instance. For more information about reviewing VM
// instance details, see [Listing all VM instance details for a specific patch
// job](https://cloud.google.com/compute/docs/os-patch-management/manage-patch-jobs#list-instance-details).
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchJobInstanceDetails = src.PatchJobInstanceDetails

// A summary of the current patch state across all instances that this patch
// job affects. Contains counts of instances in different states. These states
// map to `InstancePatchState`. List patch job instance details to see the
// specific states of each instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchJob_InstanceDetailsSummary = src.PatchJob_InstanceDetailsSummary

// Enumeration of the various states a patch job passes through as it
// executes.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchJob_State = src.PatchJob_State

// Patch rollout configuration specifications. Contains details on the
// concurrency control when applying patch(es) to all targeted VMs.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchRollout = src.PatchRollout

// Type of the rollout.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PatchRollout_Mode = src.PatchRollout_Mode

// A request message for pausing a patch deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type PausePatchDeploymentRequest = src.PausePatchDeploymentRequest

// Sets the time for recurring patch deployments.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type RecurringSchedule = src.RecurringSchedule

// Specifies the frequency of the recurring patch deployments.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type RecurringSchedule_Frequency = src.RecurringSchedule_Frequency
type RecurringSchedule_Monthly = src.RecurringSchedule_Monthly
type RecurringSchedule_Weekly = src.RecurringSchedule_Weekly

// A request message for resuming a patch deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ResumePatchDeploymentRequest = src.ResumePatchDeploymentRequest

// A software recipe is a set of instructions for installing and configuring a
// piece of software. It consists of a set of artifacts that are downloaded,
// and a set of steps that install, configure, and/or update the software.
// Recipes support installing and updating software from artifacts in the
// following formats: Zip archive, Tar archive, Windows MSI, Debian package,
// and RPM package. Additionally, recipes support executing a script (either
// defined in a file or directly in this api) in bash, sh, cmd, and powershell.
// # Updating a software recipe If a recipe is assigned to an instance and
// there is a recipe with the same name but a lower version already installed
// and the assigned state of the recipe is `UPDATED`, then the recipe is
// updated to the new version. # Script Working Directories Each script or
// execution step is run in its own temporary directory which is deleted after
// completing the step.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe = src.SoftwareRecipe

// Specifies a resource to be used in the recipe.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Artifact = src.SoftwareRecipe_Artifact

// Specifies an artifact available as a Google Cloud Storage object.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Artifact_Gcs = src.SoftwareRecipe_Artifact_Gcs
type SoftwareRecipe_Artifact_Gcs_ = src.SoftwareRecipe_Artifact_Gcs_

// Specifies an artifact available via some URI.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Artifact_Remote = src.SoftwareRecipe_Artifact_Remote
type SoftwareRecipe_Artifact_Remote_ = src.SoftwareRecipe_Artifact_Remote_

// An action that can be taken as part of installing or updating a recipe.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Step = src.SoftwareRecipe_Step
type SoftwareRecipe_Step_ArchiveExtraction = src.SoftwareRecipe_Step_ArchiveExtraction

// Copies the artifact to the specified path on the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Step_CopyFile = src.SoftwareRecipe_Step_CopyFile
type SoftwareRecipe_Step_DpkgInstallation = src.SoftwareRecipe_Step_DpkgInstallation

// Executes an artifact or local file.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Step_ExecFile = src.SoftwareRecipe_Step_ExecFile
type SoftwareRecipe_Step_ExecFile_ArtifactId = src.SoftwareRecipe_Step_ExecFile_ArtifactId
type SoftwareRecipe_Step_ExecFile_LocalPath = src.SoftwareRecipe_Step_ExecFile_LocalPath

// Extracts an archive of the type specified in the specified directory.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Step_ExtractArchive = src.SoftwareRecipe_Step_ExtractArchive

// Specifying the type of archive.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Step_ExtractArchive_ArchiveType = src.SoftwareRecipe_Step_ExtractArchive_ArchiveType
type SoftwareRecipe_Step_FileCopy = src.SoftwareRecipe_Step_FileCopy
type SoftwareRecipe_Step_FileExec = src.SoftwareRecipe_Step_FileExec

// Installs a deb via dpkg.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Step_InstallDpkg = src.SoftwareRecipe_Step_InstallDpkg

// Installs an MSI file.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Step_InstallMsi = src.SoftwareRecipe_Step_InstallMsi

// Installs an rpm file via the rpm utility.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Step_InstallRpm = src.SoftwareRecipe_Step_InstallRpm
type SoftwareRecipe_Step_MsiInstallation = src.SoftwareRecipe_Step_MsiInstallation
type SoftwareRecipe_Step_RpmInstallation = src.SoftwareRecipe_Step_RpmInstallation

// Runs a script through an interpreter.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Step_RunScript = src.SoftwareRecipe_Step_RunScript

// The interpreter used to execute a script.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type SoftwareRecipe_Step_RunScript_Interpreter = src.SoftwareRecipe_Step_RunScript_Interpreter
type SoftwareRecipe_Step_ScriptRun = src.SoftwareRecipe_Step_ScriptRun

// UnimplementedOsConfigServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type UnimplementedOsConfigServiceServer = src.UnimplementedOsConfigServiceServer

// A request message for updating a guest policy.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type UpdateGuestPolicyRequest = src.UpdateGuestPolicyRequest

// A request message for updating a patch deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type UpdatePatchDeploymentRequest = src.UpdatePatchDeploymentRequest

// Represents one week day in a month. An example is "the 4th Sunday".
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type WeekDayOfMonth = src.WeekDayOfMonth

// Represents a weekly schedule.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type WeeklySchedule = src.WeeklySchedule

// Windows patching is performed using the Windows Update Agent.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type WindowsUpdateSettings = src.WindowsUpdateSettings

// Microsoft Windows update classifications as defined in [1]
// https://support.microsoft.com/en-us/help/824684/description-of-the-standard-terminology-that-is-used-to-describe-micro
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type WindowsUpdateSettings_Classification = src.WindowsUpdateSettings_Classification

// Represents a single Yum package repository. This repository is added to a
// repo file that is stored at `/etc/yum.repos.d/google_osconfig.repo`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type YumRepository = src.YumRepository

// Yum patching is performed by executing `yum update`. Additional options can
// be set to control how this is executed. Note that not all settings are
// supported on all platforms.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type YumSettings = src.YumSettings

// Represents a single Zypper package repository. This repository is added to
// a repo file that is stored at `/etc/zypp/repos.d/google_osconfig.repo`.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ZypperRepository = src.ZypperRepository

// Zypper patching is performed by running `zypper patch`. See also
// https://en.opensuse.org/SDB:Zypper_manual.
//
// Deprecated: Please use types in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
type ZypperSettings = src.ZypperSettings

// Deprecated: Please use funcs in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
func NewOsConfigServiceClient(cc grpc.ClientConnInterface) OsConfigServiceClient {
	return src.NewOsConfigServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/osconfig/apiv1beta/osconfigpb
func RegisterOsConfigServiceServer(s *grpc.Server, srv OsConfigServiceServer) {
	src.RegisterOsConfigServiceServer(s, srv)
}
