// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package vision aliases all exported identifiers in package
// "cloud.google.com/go/vision/v2/apiv1/visionpb".
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package vision

import (
	src "cloud.google.com/go/vision/v2/apiv1/visionpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/vision/v2/apiv1/visionpb
const (
	BatchOperationMetadata_CANCELLED                     = src.BatchOperationMetadata_CANCELLED
	BatchOperationMetadata_FAILED                        = src.BatchOperationMetadata_FAILED
	BatchOperationMetadata_PROCESSING                    = src.BatchOperationMetadata_PROCESSING
	BatchOperationMetadata_STATE_UNSPECIFIED             = src.BatchOperationMetadata_STATE_UNSPECIFIED
	BatchOperationMetadata_SUCCESSFUL                    = src.BatchOperationMetadata_SUCCESSFUL
	Block_BARCODE                                        = src.Block_BARCODE
	Block_PICTURE                                        = src.Block_PICTURE
	Block_RULER                                          = src.Block_RULER
	Block_TABLE                                          = src.Block_TABLE
	Block_TEXT                                           = src.Block_TEXT
	Block_UNKNOWN                                        = src.Block_UNKNOWN
	FaceAnnotation_Landmark_CHIN_GNATHION                = src.FaceAnnotation_Landmark_CHIN_GNATHION
	FaceAnnotation_Landmark_CHIN_LEFT_GONION             = src.FaceAnnotation_Landmark_CHIN_LEFT_GONION
	FaceAnnotation_Landmark_CHIN_RIGHT_GONION            = src.FaceAnnotation_Landmark_CHIN_RIGHT_GONION
	FaceAnnotation_Landmark_FOREHEAD_GLABELLA            = src.FaceAnnotation_Landmark_FOREHEAD_GLABELLA
	FaceAnnotation_Landmark_LEFT_CHEEK_CENTER            = src.FaceAnnotation_Landmark_LEFT_CHEEK_CENTER
	FaceAnnotation_Landmark_LEFT_EAR_TRAGION             = src.FaceAnnotation_Landmark_LEFT_EAR_TRAGION
	FaceAnnotation_Landmark_LEFT_EYE                     = src.FaceAnnotation_Landmark_LEFT_EYE
	FaceAnnotation_Landmark_LEFT_EYEBROW_UPPER_MIDPOINT  = src.FaceAnnotation_Landmark_LEFT_EYEBROW_UPPER_MIDPOINT
	FaceAnnotation_Landmark_LEFT_EYE_BOTTOM_BOUNDARY     = src.FaceAnnotation_Landmark_LEFT_EYE_BOTTOM_BOUNDARY
	FaceAnnotation_Landmark_LEFT_EYE_LEFT_CORNER         = src.FaceAnnotation_Landmark_LEFT_EYE_LEFT_CORNER
	FaceAnnotation_Landmark_LEFT_EYE_PUPIL               = src.FaceAnnotation_Landmark_LEFT_EYE_PUPIL
	FaceAnnotation_Landmark_LEFT_EYE_RIGHT_CORNER        = src.FaceAnnotation_Landmark_LEFT_EYE_RIGHT_CORNER
	FaceAnnotation_Landmark_LEFT_EYE_TOP_BOUNDARY        = src.FaceAnnotation_Landmark_LEFT_EYE_TOP_BOUNDARY
	FaceAnnotation_Landmark_LEFT_OF_LEFT_EYEBROW         = src.FaceAnnotation_Landmark_LEFT_OF_LEFT_EYEBROW
	FaceAnnotation_Landmark_LEFT_OF_RIGHT_EYEBROW        = src.FaceAnnotation_Landmark_LEFT_OF_RIGHT_EYEBROW
	FaceAnnotation_Landmark_LOWER_LIP                    = src.FaceAnnotation_Landmark_LOWER_LIP
	FaceAnnotation_Landmark_MIDPOINT_BETWEEN_EYES        = src.FaceAnnotation_Landmark_MIDPOINT_BETWEEN_EYES
	FaceAnnotation_Landmark_MOUTH_CENTER                 = src.FaceAnnotation_Landmark_MOUTH_CENTER
	FaceAnnotation_Landmark_MOUTH_LEFT                   = src.FaceAnnotation_Landmark_MOUTH_LEFT
	FaceAnnotation_Landmark_MOUTH_RIGHT                  = src.FaceAnnotation_Landmark_MOUTH_RIGHT
	FaceAnnotation_Landmark_NOSE_BOTTOM_CENTER           = src.FaceAnnotation_Landmark_NOSE_BOTTOM_CENTER
	FaceAnnotation_Landmark_NOSE_BOTTOM_LEFT             = src.FaceAnnotation_Landmark_NOSE_BOTTOM_LEFT
	FaceAnnotation_Landmark_NOSE_BOTTOM_RIGHT            = src.FaceAnnotation_Landmark_NOSE_BOTTOM_RIGHT
	FaceAnnotation_Landmark_NOSE_TIP                     = src.FaceAnnotation_Landmark_NOSE_TIP
	FaceAnnotation_Landmark_RIGHT_CHEEK_CENTER           = src.FaceAnnotation_Landmark_RIGHT_CHEEK_CENTER
	FaceAnnotation_Landmark_RIGHT_EAR_TRAGION            = src.FaceAnnotation_Landmark_RIGHT_EAR_TRAGION
	FaceAnnotation_Landmark_RIGHT_EYE                    = src.FaceAnnotation_Landmark_RIGHT_EYE
	FaceAnnotation_Landmark_RIGHT_EYEBROW_UPPER_MIDPOINT = src.FaceAnnotation_Landmark_RIGHT_EYEBROW_UPPER_MIDPOINT
	FaceAnnotation_Landmark_RIGHT_EYE_BOTTOM_BOUNDARY    = src.FaceAnnotation_Landmark_RIGHT_EYE_BOTTOM_BOUNDARY
	FaceAnnotation_Landmark_RIGHT_EYE_LEFT_CORNER        = src.FaceAnnotation_Landmark_RIGHT_EYE_LEFT_CORNER
	FaceAnnotation_Landmark_RIGHT_EYE_PUPIL              = src.FaceAnnotation_Landmark_RIGHT_EYE_PUPIL
	FaceAnnotation_Landmark_RIGHT_EYE_RIGHT_CORNER       = src.FaceAnnotation_Landmark_RIGHT_EYE_RIGHT_CORNER
	FaceAnnotation_Landmark_RIGHT_EYE_TOP_BOUNDARY       = src.FaceAnnotation_Landmark_RIGHT_EYE_TOP_BOUNDARY
	FaceAnnotation_Landmark_RIGHT_OF_LEFT_EYEBROW        = src.FaceAnnotation_Landmark_RIGHT_OF_LEFT_EYEBROW
	FaceAnnotation_Landmark_RIGHT_OF_RIGHT_EYEBROW       = src.FaceAnnotation_Landmark_RIGHT_OF_RIGHT_EYEBROW
	FaceAnnotation_Landmark_UNKNOWN_LANDMARK             = src.FaceAnnotation_Landmark_UNKNOWN_LANDMARK
	FaceAnnotation_Landmark_UPPER_LIP                    = src.FaceAnnotation_Landmark_UPPER_LIP
	Feature_CROP_HINTS                                   = src.Feature_CROP_HINTS
	Feature_DOCUMENT_TEXT_DETECTION                      = src.Feature_DOCUMENT_TEXT_DETECTION
	Feature_FACE_DETECTION                               = src.Feature_FACE_DETECTION
	Feature_IMAGE_PROPERTIES                             = src.Feature_IMAGE_PROPERTIES
	Feature_LABEL_DETECTION                              = src.Feature_LABEL_DETECTION
	Feature_LANDMARK_DETECTION                           = src.Feature_LANDMARK_DETECTION
	Feature_LOGO_DETECTION                               = src.Feature_LOGO_DETECTION
	Feature_OBJECT_LOCALIZATION                          = src.Feature_OBJECT_LOCALIZATION
	Feature_PRODUCT_SEARCH                               = src.Feature_PRODUCT_SEARCH
	Feature_SAFE_SEARCH_DETECTION                        = src.Feature_SAFE_SEARCH_DETECTION
	Feature_TEXT_DETECTION                               = src.Feature_TEXT_DETECTION
	Feature_TYPE_UNSPECIFIED                             = src.Feature_TYPE_UNSPECIFIED
	Feature_WEB_DETECTION                                = src.Feature_WEB_DETECTION
	Likelihood_LIKELY                                    = src.Likelihood_LIKELY
	Likelihood_POSSIBLE                                  = src.Likelihood_POSSIBLE
	Likelihood_UNKNOWN                                   = src.Likelihood_UNKNOWN
	Likelihood_UNLIKELY                                  = src.Likelihood_UNLIKELY
	Likelihood_VERY_LIKELY                               = src.Likelihood_VERY_LIKELY
	Likelihood_VERY_UNLIKELY                             = src.Likelihood_VERY_UNLIKELY
	OperationMetadata_CANCELLED                          = src.OperationMetadata_CANCELLED
	OperationMetadata_CREATED                            = src.OperationMetadata_CREATED
	OperationMetadata_DONE                               = src.OperationMetadata_DONE
	OperationMetadata_RUNNING                            = src.OperationMetadata_RUNNING
	OperationMetadata_STATE_UNSPECIFIED                  = src.OperationMetadata_STATE_UNSPECIFIED
	TextAnnotation_DetectedBreak_EOL_SURE_SPACE          = src.TextAnnotation_DetectedBreak_EOL_SURE_SPACE
	TextAnnotation_DetectedBreak_HYPHEN                  = src.TextAnnotation_DetectedBreak_HYPHEN
	TextAnnotation_DetectedBreak_LINE_BREAK              = src.TextAnnotation_DetectedBreak_LINE_BREAK
	TextAnnotation_DetectedBreak_SPACE                   = src.TextAnnotation_DetectedBreak_SPACE
	TextAnnotation_DetectedBreak_SURE_SPACE              = src.TextAnnotation_DetectedBreak_SURE_SPACE
	TextAnnotation_DetectedBreak_UNKNOWN                 = src.TextAnnotation_DetectedBreak_UNKNOWN
)

// Deprecated: Please use vars in: cloud.google.com/go/vision/v2/apiv1/visionpb
var (
	BatchOperationMetadata_State_name                        = src.BatchOperationMetadata_State_name
	BatchOperationMetadata_State_value                       = src.BatchOperationMetadata_State_value
	Block_BlockType_name                                     = src.Block_BlockType_name
	Block_BlockType_value                                    = src.Block_BlockType_value
	FaceAnnotation_Landmark_Type_name                        = src.FaceAnnotation_Landmark_Type_name
	FaceAnnotation_Landmark_Type_value                       = src.FaceAnnotation_Landmark_Type_value
	Feature_Type_name                                        = src.Feature_Type_name
	Feature_Type_value                                       = src.Feature_Type_value
	File_google_cloud_vision_v1_geometry_proto               = src.File_google_cloud_vision_v1_geometry_proto
	File_google_cloud_vision_v1_image_annotator_proto        = src.File_google_cloud_vision_v1_image_annotator_proto
	File_google_cloud_vision_v1_product_search_proto         = src.File_google_cloud_vision_v1_product_search_proto
	File_google_cloud_vision_v1_product_search_service_proto = src.File_google_cloud_vision_v1_product_search_service_proto
	File_google_cloud_vision_v1_text_annotation_proto        = src.File_google_cloud_vision_v1_text_annotation_proto
	File_google_cloud_vision_v1_web_detection_proto          = src.File_google_cloud_vision_v1_web_detection_proto
	Likelihood_name                                          = src.Likelihood_name
	Likelihood_value                                         = src.Likelihood_value
	OperationMetadata_State_name                             = src.OperationMetadata_State_name
	OperationMetadata_State_value                            = src.OperationMetadata_State_value
	TextAnnotation_DetectedBreak_BreakType_name              = src.TextAnnotation_DetectedBreak_BreakType_name
	TextAnnotation_DetectedBreak_BreakType_value             = src.TextAnnotation_DetectedBreak_BreakType_value
)

// Request message for the `AddProductToProductSet` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AddProductToProductSetRequest = src.AddProductToProductSetRequest

// A request to annotate one single file, e.g. a PDF, TIFF or GIF file.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AnnotateFileRequest = src.AnnotateFileRequest

// Response to a single file annotation request. A file may contain one or
// more images, which individually have their own responses.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AnnotateFileResponse = src.AnnotateFileResponse

// Request for performing Google Cloud Vision API tasks over a user-provided
// image, with user-requested features, and with context information.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AnnotateImageRequest = src.AnnotateImageRequest

// Response to an image annotation request.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AnnotateImageResponse = src.AnnotateImageResponse

// An offline file annotation request.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AsyncAnnotateFileRequest = src.AsyncAnnotateFileRequest

// The response for a single offline file annotation request.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AsyncAnnotateFileResponse = src.AsyncAnnotateFileResponse

// Multiple async file annotation requests are batched into a single service
// call.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AsyncBatchAnnotateFilesRequest = src.AsyncBatchAnnotateFilesRequest

// Response to an async batch file annotation request.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AsyncBatchAnnotateFilesResponse = src.AsyncBatchAnnotateFilesResponse

// Request for async image annotation for a list of images.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AsyncBatchAnnotateImagesRequest = src.AsyncBatchAnnotateImagesRequest

// Response to an async batch image annotation request.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type AsyncBatchAnnotateImagesResponse = src.AsyncBatchAnnotateImagesResponse

// A list of requests to annotate files using the BatchAnnotateFiles API.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type BatchAnnotateFilesRequest = src.BatchAnnotateFilesRequest

// A list of file annotation responses.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type BatchAnnotateFilesResponse = src.BatchAnnotateFilesResponse

// Multiple image annotation requests are batched into a single service call.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type BatchAnnotateImagesRequest = src.BatchAnnotateImagesRequest

// Response to a batch image annotation request.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type BatchAnnotateImagesResponse = src.BatchAnnotateImagesResponse

// Metadata for the batch operations such as the current state. This is
// included in the `metadata` field of the `Operation` returned by the
// `GetOperation` call of the `google::longrunning::Operations` service.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type BatchOperationMetadata = src.BatchOperationMetadata

// Enumerates the possible states that the batch request can be in.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type BatchOperationMetadata_State = src.BatchOperationMetadata_State

// Logical element on the page.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Block = src.Block

// Type of a block (text, image etc) as identified by OCR.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Block_BlockType = src.Block_BlockType

// A bounding polygon for the detected image annotation.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type BoundingPoly = src.BoundingPoly

// Color information consists of RGB channels, score, and the fraction of the
// image that the color occupies in the image.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ColorInfo = src.ColorInfo

// Request message for the `CreateProduct` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type CreateProductRequest = src.CreateProductRequest

// Request message for the `CreateProductSet` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type CreateProductSetRequest = src.CreateProductSetRequest

// Request message for the `CreateReferenceImage` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type CreateReferenceImageRequest = src.CreateReferenceImageRequest

// Single crop hint that is used to generate a new crop when serving an image.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type CropHint = src.CropHint

// Set of crop hints that are used to generate new crops when serving images.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type CropHintsAnnotation = src.CropHintsAnnotation

// Parameters for crop hints annotation request.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type CropHintsParams = src.CropHintsParams

// Request message for the `DeleteProduct` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type DeleteProductRequest = src.DeleteProductRequest

// Request message for the `DeleteProductSet` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type DeleteProductSetRequest = src.DeleteProductSetRequest

// Request message for the `DeleteReferenceImage` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type DeleteReferenceImageRequest = src.DeleteReferenceImageRequest

// Set of dominant colors and their corresponding scores.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type DominantColorsAnnotation = src.DominantColorsAnnotation

// Set of detected entity features.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type EntityAnnotation = src.EntityAnnotation

// A face annotation object contains the results of face detection.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type FaceAnnotation = src.FaceAnnotation

// A face-specific landmark (for example, a face feature).
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type FaceAnnotation_Landmark = src.FaceAnnotation_Landmark

// Face landmark (feature) type. Left and right are defined from the vantage
// of the viewer of the image without considering mirror projections typical of
// photos. So, `LEFT_EYE`, typically, is the person's right eye.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type FaceAnnotation_Landmark_Type = src.FaceAnnotation_Landmark_Type

// The type of Google Cloud Vision API detection to perform, and the maximum
// number of results to return for that type. Multiple `Feature` objects can be
// specified in the `features` list.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Feature = src.Feature

// Type of Google Cloud Vision API feature to be extracted.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Feature_Type = src.Feature_Type

// The Google Cloud Storage location where the output will be written to.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type GcsDestination = src.GcsDestination

// The Google Cloud Storage location where the input will be read from.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type GcsSource = src.GcsSource

// Request message for the `GetProduct` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type GetProductRequest = src.GetProductRequest

// Request message for the `GetProductSet` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type GetProductSetRequest = src.GetProductSetRequest

// Request message for the `GetReferenceImage` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type GetReferenceImageRequest = src.GetReferenceImageRequest

// Client image to perform Google Cloud Vision API tasks over.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Image = src.Image

// If an image was produced from a file (e.g. a PDF), this message gives
// information about the source of that image.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ImageAnnotationContext = src.ImageAnnotationContext

// ImageAnnotatorClient is the client API for ImageAnnotator service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ImageAnnotatorClient = src.ImageAnnotatorClient

// ImageAnnotatorServer is the server API for ImageAnnotator service.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ImageAnnotatorServer = src.ImageAnnotatorServer

// Image context and/or feature-specific parameters.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ImageContext = src.ImageContext

// Stores image properties, such as dominant colors.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ImageProperties = src.ImageProperties

// External image source (Google Cloud Storage or web URL image location).
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ImageSource = src.ImageSource

// The Google Cloud Storage location for a csv file which preserves a list of
// ImportProductSetRequests in each line.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ImportProductSetsGcsSource = src.ImportProductSetsGcsSource

// The input content for the `ImportProductSets` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ImportProductSetsInputConfig = src.ImportProductSetsInputConfig
type ImportProductSetsInputConfig_GcsSource = src.ImportProductSetsInputConfig_GcsSource

// Request message for the `ImportProductSets` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ImportProductSetsRequest = src.ImportProductSetsRequest

// Response message for the `ImportProductSets` method. This message is
// returned by the
// [google.longrunning.Operations.GetOperation][google.longrunning.Operations.GetOperation]
// method in the returned
// [google.longrunning.Operation.response][google.longrunning.Operation.response]
// field.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ImportProductSetsResponse = src.ImportProductSetsResponse

// The desired input location and metadata.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type InputConfig = src.InputConfig

// Rectangle determined by min and max `LatLng` pairs.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type LatLongRect = src.LatLongRect

// A bucketized representation of likelihood, which is intended to give
// clients highly stable results across model upgrades.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Likelihood = src.Likelihood

// Request message for the `ListProductSets` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ListProductSetsRequest = src.ListProductSetsRequest

// Response message for the `ListProductSets` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ListProductSetsResponse = src.ListProductSetsResponse

// Request message for the `ListProductsInProductSet` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ListProductsInProductSetRequest = src.ListProductsInProductSetRequest

// Response message for the `ListProductsInProductSet` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ListProductsInProductSetResponse = src.ListProductsInProductSetResponse

// Request message for the `ListProducts` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ListProductsRequest = src.ListProductsRequest

// Response message for the `ListProducts` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ListProductsResponse = src.ListProductsResponse

// Request message for the `ListReferenceImages` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ListReferenceImagesRequest = src.ListReferenceImagesRequest

// Response message for the `ListReferenceImages` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ListReferenceImagesResponse = src.ListReferenceImagesResponse

// Set of detected objects with bounding boxes.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type LocalizedObjectAnnotation = src.LocalizedObjectAnnotation

// Detected entity location information.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type LocationInfo = src.LocationInfo

// A vertex represents a 2D point in the image. NOTE: the normalized vertex
// coordinates are relative to the original image and range from 0 to 1.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type NormalizedVertex = src.NormalizedVertex

// Contains metadata for the BatchAnnotateImages operation.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type OperationMetadata = src.OperationMetadata

// Batch operation states.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type OperationMetadata_State = src.OperationMetadata_State

// The desired output location and metadata.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type OutputConfig = src.OutputConfig

// Detected page from OCR.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Page = src.Page

// Structural unit of text representing a number of words in certain order.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Paragraph = src.Paragraph

// A 3D position in the image, used primarily for Face detection landmarks. A
// valid Position must have both x and y coordinates. The position coordinates
// are in the same scale as the original image.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Position = src.Position

// A Product contains ReferenceImages.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Product = src.Product

// ProductSearchClient is the client API for ProductSearch service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ProductSearchClient = src.ProductSearchClient

// Parameters for a product search request.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ProductSearchParams = src.ProductSearchParams

// Results for a product search request.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ProductSearchResults = src.ProductSearchResults

// Information about the products similar to a single product in a query
// image.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ProductSearchResults_GroupedResult = src.ProductSearchResults_GroupedResult

// Prediction for what the object in the bounding box is.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ProductSearchResults_ObjectAnnotation = src.ProductSearchResults_ObjectAnnotation

// Information about a product.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ProductSearchResults_Result = src.ProductSearchResults_Result

// ProductSearchServer is the server API for ProductSearch service.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ProductSearchServer = src.ProductSearchServer

// A ProductSet contains Products. A ProductSet can contain a maximum of 1
// million reference images. If the limit is exceeded, periodic indexing will
// fail.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ProductSet = src.ProductSet

// Config to control which ProductSet contains the Products to be deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ProductSetPurgeConfig = src.ProductSetPurgeConfig

// A product label represented as a key-value pair.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Product_KeyValue = src.Product_KeyValue

// A `Property` consists of a user-supplied name/value pair.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Property = src.Property

// Request message for the `PurgeProducts` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type PurgeProductsRequest = src.PurgeProductsRequest
type PurgeProductsRequest_DeleteOrphanProducts = src.PurgeProductsRequest_DeleteOrphanProducts
type PurgeProductsRequest_ProductSetPurgeConfig = src.PurgeProductsRequest_ProductSetPurgeConfig

// A `ReferenceImage` represents a product image and its associated metadata,
// such as bounding boxes.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type ReferenceImage = src.ReferenceImage

// Request message for the `RemoveProductFromProductSet` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type RemoveProductFromProductSetRequest = src.RemoveProductFromProductSetRequest

// Set of features pertaining to the image, computed by computer vision
// methods over safe-search verticals (for example, adult, spoof, medical,
// violence).
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type SafeSearchAnnotation = src.SafeSearchAnnotation

// A single symbol representation.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Symbol = src.Symbol

// TextAnnotation contains a structured representation of OCR extracted text.
// The hierarchy of an OCR extracted text structure is like this:
// TextAnnotation -> Page -> Block -> Paragraph -> Word -> Symbol Each
// structural component, starting from Page, may further have their own
// properties. Properties describe detected languages, breaks etc.. Please
// refer to the
// [TextAnnotation.TextProperty][google.cloud.vision.v1.TextAnnotation.TextProperty]
// message definition below for more detail.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type TextAnnotation = src.TextAnnotation

// Detected start or end of a structural component.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type TextAnnotation_DetectedBreak = src.TextAnnotation_DetectedBreak

// Enum to denote the type of break found. New line, space etc.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type TextAnnotation_DetectedBreak_BreakType = src.TextAnnotation_DetectedBreak_BreakType

// Detected language for a structural component.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type TextAnnotation_DetectedLanguage = src.TextAnnotation_DetectedLanguage

// Additional information detected on the structural component.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type TextAnnotation_TextProperty = src.TextAnnotation_TextProperty

// Parameters for text detections. This is used to control TEXT_DETECTION and
// DOCUMENT_TEXT_DETECTION features.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type TextDetectionParams = src.TextDetectionParams

// UnimplementedImageAnnotatorServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type UnimplementedImageAnnotatorServer = src.UnimplementedImageAnnotatorServer

// UnimplementedProductSearchServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type UnimplementedProductSearchServer = src.UnimplementedProductSearchServer

// Request message for the `UpdateProduct` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type UpdateProductRequest = src.UpdateProductRequest

// Request message for the `UpdateProductSet` method.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type UpdateProductSetRequest = src.UpdateProductSetRequest

// A vertex represents a 2D point in the image. NOTE: the vertex coordinates
// are in the same scale as the original image.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Vertex = src.Vertex

// Relevant information for the image from the Internet.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type WebDetection = src.WebDetection

// Parameters for web detection request.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type WebDetectionParams = src.WebDetectionParams

// Entity deduced from similar images on the Internet.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type WebDetection_WebEntity = src.WebDetection_WebEntity

// Metadata for online images.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type WebDetection_WebImage = src.WebDetection_WebImage

// Label to provide extra metadata for the web detection.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type WebDetection_WebLabel = src.WebDetection_WebLabel

// Metadata for web pages.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type WebDetection_WebPage = src.WebDetection_WebPage

// A word representation.
//
// Deprecated: Please use types in: cloud.google.com/go/vision/v2/apiv1/visionpb
type Word = src.Word

// Deprecated: Please use funcs in: cloud.google.com/go/vision/v2/apiv1/visionpb
func NewImageAnnotatorClient(cc grpc.ClientConnInterface) ImageAnnotatorClient {
	return src.NewImageAnnotatorClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/vision/v2/apiv1/visionpb
func NewProductSearchClient(cc grpc.ClientConnInterface) ProductSearchClient {
	return src.NewProductSearchClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/vision/v2/apiv1/visionpb
func RegisterImageAnnotatorServer(s *grpc.Server, srv ImageAnnotatorServer) {
	src.RegisterImageAnnotatorServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/vision/v2/apiv1/visionpb
func RegisterProductSearchServer(s *grpc.Server, srv ProductSearchServer) {
	src.RegisterProductSearchServer(s, srv)
}
