// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package connection aliases all exported identifiers in package
// "cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb".
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package connection

import (
	src "cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
const (
	CloudSqlProperties_DATABASE_TYPE_UNSPECIFIED = src.CloudSqlProperties_DATABASE_TYPE_UNSPECIFIED
	CloudSqlProperties_MYSQL                     = src.CloudSqlProperties_MYSQL
	CloudSqlProperties_POSTGRES                  = src.CloudSqlProperties_POSTGRES
)

// Deprecated: Please use vars in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
var (
	CloudSqlProperties_DatabaseType_name                           = src.CloudSqlProperties_DatabaseType_name
	CloudSqlProperties_DatabaseType_value                          = src.CloudSqlProperties_DatabaseType_value
	File_google_cloud_bigquery_connection_v1beta1_connection_proto = src.File_google_cloud_bigquery_connection_v1beta1_connection_proto
)

// Credential info for the Cloud SQL.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type CloudSqlCredential = src.CloudSqlCredential

// Connection properties specific to the Cloud SQL.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type CloudSqlProperties = src.CloudSqlProperties

// Supported Cloud SQL database types.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type CloudSqlProperties_DatabaseType = src.CloudSqlProperties_DatabaseType

// Configuration parameters to establish connection with an external data
// source, except the credential attributes.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type Connection = src.Connection

// Credential to use with a connection.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type ConnectionCredential = src.ConnectionCredential
type ConnectionCredential_CloudSql = src.ConnectionCredential_CloudSql

// ConnectionServiceClient is the client API for ConnectionService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type ConnectionServiceClient = src.ConnectionServiceClient

// ConnectionServiceServer is the server API for ConnectionService service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type ConnectionServiceServer = src.ConnectionServiceServer
type Connection_CloudSql = src.Connection_CloudSql

// The request for
// [ConnectionService.CreateConnection][google.cloud.bigquery.connection.v1beta1.ConnectionService.CreateConnection].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type CreateConnectionRequest = src.CreateConnectionRequest

// The request for [ConnectionService.DeleteConnectionRequest][].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type DeleteConnectionRequest = src.DeleteConnectionRequest

// The request for
// [ConnectionService.GetConnection][google.cloud.bigquery.connection.v1beta1.ConnectionService.GetConnection].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type GetConnectionRequest = src.GetConnectionRequest

// The request for
// [ConnectionService.ListConnections][google.cloud.bigquery.connection.v1beta1.ConnectionService.ListConnections].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type ListConnectionsRequest = src.ListConnectionsRequest

// The response for
// [ConnectionService.ListConnections][google.cloud.bigquery.connection.v1beta1.ConnectionService.ListConnections].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type ListConnectionsResponse = src.ListConnectionsResponse

// UnimplementedConnectionServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type UnimplementedConnectionServiceServer = src.UnimplementedConnectionServiceServer

// The request for
// [ConnectionService.UpdateConnectionCredential][google.cloud.bigquery.connection.v1beta1.ConnectionService.UpdateConnectionCredential].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type UpdateConnectionCredentialRequest = src.UpdateConnectionCredentialRequest

// The request for
// [ConnectionService.UpdateConnection][google.cloud.bigquery.connection.v1beta1.ConnectionService.UpdateConnection].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
type UpdateConnectionRequest = src.UpdateConnectionRequest

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
func NewConnectionServiceClient(cc grpc.ClientConnInterface) ConnectionServiceClient {
	return src.NewConnectionServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/connection/apiv1beta1/connectionpb
func RegisterConnectionServiceServer(s *grpc.Server, srv ConnectionServiceServer) {
	src.RegisterConnectionServiceServer(s, srv)
}
