// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package reservation aliases all exported identifiers in package
// "cloud.google.com/go/bigquery/reservation/apiv1/reservationpb".
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package reservation

import (
	src "cloud.google.com/go/bigquery/reservation/apiv1/reservationpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
const (
	Assignment_ACTIVE                              = src.Assignment_ACTIVE
	Assignment_JOB_TYPE_UNSPECIFIED                = src.Assignment_JOB_TYPE_UNSPECIFIED
	Assignment_ML_EXTERNAL                         = src.Assignment_ML_EXTERNAL
	Assignment_PENDING                             = src.Assignment_PENDING
	Assignment_PIPELINE                            = src.Assignment_PIPELINE
	Assignment_QUERY                               = src.Assignment_QUERY
	Assignment_STATE_UNSPECIFIED                   = src.Assignment_STATE_UNSPECIFIED
	CapacityCommitment_ACTIVE                      = src.CapacityCommitment_ACTIVE
	CapacityCommitment_ANNUAL                      = src.CapacityCommitment_ANNUAL
	CapacityCommitment_COMMITMENT_PLAN_UNSPECIFIED = src.CapacityCommitment_COMMITMENT_PLAN_UNSPECIFIED
	CapacityCommitment_FAILED                      = src.CapacityCommitment_FAILED
	CapacityCommitment_FLEX                        = src.CapacityCommitment_FLEX
	CapacityCommitment_MONTHLY                     = src.CapacityCommitment_MONTHLY
	CapacityCommitment_PENDING                     = src.CapacityCommitment_PENDING
	CapacityCommitment_STATE_UNSPECIFIED           = src.CapacityCommitment_STATE_UNSPECIFIED
	CapacityCommitment_TRIAL                       = src.CapacityCommitment_TRIAL
)

// Deprecated: Please use vars in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
var (
	Assignment_JobType_name                                     = src.Assignment_JobType_name
	Assignment_JobType_value                                    = src.Assignment_JobType_value
	Assignment_State_name                                       = src.Assignment_State_name
	Assignment_State_value                                      = src.Assignment_State_value
	CapacityCommitment_CommitmentPlan_name                      = src.CapacityCommitment_CommitmentPlan_name
	CapacityCommitment_CommitmentPlan_value                     = src.CapacityCommitment_CommitmentPlan_value
	CapacityCommitment_State_name                               = src.CapacityCommitment_State_name
	CapacityCommitment_State_value                              = src.CapacityCommitment_State_value
	File_google_cloud_bigquery_reservation_v1_reservation_proto = src.File_google_cloud_bigquery_reservation_v1_reservation_proto
)

// An assignment allows a project to submit jobs of a certain type using slots
// from the specified reservation.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type Assignment = src.Assignment

// Types of job, which could be specified when using the reservation.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type Assignment_JobType = src.Assignment_JobType

// Assignment will remain in PENDING state if no active capacity commitment is
// present. It will become ACTIVE when some capacity commitment becomes active.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type Assignment_State = src.Assignment_State

// Represents a BI Reservation.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type BiReservation = src.BiReservation

// Capacity commitment is a way to purchase compute capacity for BigQuery jobs
// (in the form of slots) with some committed period of usage. Annual
// commitments renew by default. Commitments can be removed after their
// commitment end time passes. In order to remove annual commitment, its plan
// needs to be changed to monthly or flex first. A capacity commitment resource
// exists as a child resource of the admin project.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type CapacityCommitment = src.CapacityCommitment

// Commitment plan defines the current committed period. Capacity commitment
// cannot be deleted during it's committed period.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type CapacityCommitment_CommitmentPlan = src.CapacityCommitment_CommitmentPlan

// Capacity commitment can either become ACTIVE right away or transition from
// PENDING to ACTIVE or FAILED.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type CapacityCommitment_State = src.CapacityCommitment_State

// The request for
// [ReservationService.CreateAssignment][google.cloud.bigquery.reservation.v1.ReservationService.CreateAssignment].
// Note: "bigquery.reservationAssignments.create" permission is required on the
// related assignee.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type CreateAssignmentRequest = src.CreateAssignmentRequest

// The request for
// [ReservationService.CreateCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.CreateCapacityCommitment].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type CreateCapacityCommitmentRequest = src.CreateCapacityCommitmentRequest

// The request for
// [ReservationService.CreateReservation][google.cloud.bigquery.reservation.v1.ReservationService.CreateReservation].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type CreateReservationRequest = src.CreateReservationRequest

// The request for
// [ReservationService.DeleteAssignment][google.cloud.bigquery.reservation.v1.ReservationService.DeleteAssignment].
// Note: "bigquery.reservationAssignments.delete" permission is required on the
// related assignee.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type DeleteAssignmentRequest = src.DeleteAssignmentRequest

// The request for
// [ReservationService.DeleteCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.DeleteCapacityCommitment].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type DeleteCapacityCommitmentRequest = src.DeleteCapacityCommitmentRequest

// The request for
// [ReservationService.DeleteReservation][google.cloud.bigquery.reservation.v1.ReservationService.DeleteReservation].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type DeleteReservationRequest = src.DeleteReservationRequest

// A request to get a singleton BI reservation.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type GetBiReservationRequest = src.GetBiReservationRequest

// The request for
// [ReservationService.GetCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.GetCapacityCommitment].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type GetCapacityCommitmentRequest = src.GetCapacityCommitmentRequest

// The request for
// [ReservationService.GetReservation][google.cloud.bigquery.reservation.v1.ReservationService.GetReservation].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type GetReservationRequest = src.GetReservationRequest

// The request for
// [ReservationService.ListAssignments][google.cloud.bigquery.reservation.v1.ReservationService.ListAssignments].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type ListAssignmentsRequest = src.ListAssignmentsRequest

// The response for
// [ReservationService.ListAssignments][google.cloud.bigquery.reservation.v1.ReservationService.ListAssignments].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type ListAssignmentsResponse = src.ListAssignmentsResponse

// The request for
// [ReservationService.ListCapacityCommitments][google.cloud.bigquery.reservation.v1.ReservationService.ListCapacityCommitments].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type ListCapacityCommitmentsRequest = src.ListCapacityCommitmentsRequest

// The response for
// [ReservationService.ListCapacityCommitments][google.cloud.bigquery.reservation.v1.ReservationService.ListCapacityCommitments].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type ListCapacityCommitmentsResponse = src.ListCapacityCommitmentsResponse

// The request for
// [ReservationService.ListReservations][google.cloud.bigquery.reservation.v1.ReservationService.ListReservations].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type ListReservationsRequest = src.ListReservationsRequest

// The response for
// [ReservationService.ListReservations][google.cloud.bigquery.reservation.v1.ReservationService.ListReservations].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type ListReservationsResponse = src.ListReservationsResponse

// The request for
// [ReservationService.MergeCapacityCommitments][google.cloud.bigquery.reservation.v1.ReservationService.MergeCapacityCommitments].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type MergeCapacityCommitmentsRequest = src.MergeCapacityCommitmentsRequest

// The request for
// [ReservationService.MoveAssignment][google.cloud.bigquery.reservation.v1.ReservationService.MoveAssignment].
// **Note**: "bigquery.reservationAssignments.create" permission is required on
// the destination_id. **Note**: "bigquery.reservationAssignments.create" and
// "bigquery.reservationAssignments.delete" permission are required on the
// related assignee.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type MoveAssignmentRequest = src.MoveAssignmentRequest

// A reservation is a mechanism used to guarantee slots to users.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type Reservation = src.Reservation

// ReservationServiceClient is the client API for ReservationService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type ReservationServiceClient = src.ReservationServiceClient

// ReservationServiceServer is the server API for ReservationService service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type ReservationServiceServer = src.ReservationServiceServer

// The request for
// [ReservationService.SearchAllAssignments][google.cloud.bigquery.reservation.v1.ReservationService.SearchAllAssignments].
// Note: "bigquery.reservationAssignments.search" permission is required on the
// related assignee.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type SearchAllAssignmentsRequest = src.SearchAllAssignmentsRequest

// The response for
// [ReservationService.SearchAllAssignments][google.cloud.bigquery.reservation.v1.ReservationService.SearchAllAssignments].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type SearchAllAssignmentsResponse = src.SearchAllAssignmentsResponse

// The request for
// [ReservationService.SearchAssignments][google.cloud.bigquery.reservation.v1.ReservationService.SearchAssignments].
// Note: "bigquery.reservationAssignments.search" permission is required on the
// related assignee.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type SearchAssignmentsRequest = src.SearchAssignmentsRequest

// The response for
// [ReservationService.SearchAssignments][google.cloud.bigquery.reservation.v1.ReservationService.SearchAssignments].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type SearchAssignmentsResponse = src.SearchAssignmentsResponse

// The request for
// [ReservationService.SplitCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.SplitCapacityCommitment].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type SplitCapacityCommitmentRequest = src.SplitCapacityCommitmentRequest

// The response for
// [ReservationService.SplitCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.SplitCapacityCommitment].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type SplitCapacityCommitmentResponse = src.SplitCapacityCommitmentResponse

// Fully qualified reference to BigQuery table. Internally stored as
// google.cloud.bi.v1.BqTableReference.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type TableReference = src.TableReference

// UnimplementedReservationServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type UnimplementedReservationServiceServer = src.UnimplementedReservationServiceServer

// The request for
// [ReservationService.UpdateAssignment][google.cloud.bigquery.reservation.v1.ReservationService.UpdateAssignment].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type UpdateAssignmentRequest = src.UpdateAssignmentRequest

// A request to update a BI reservation.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type UpdateBiReservationRequest = src.UpdateBiReservationRequest

// The request for
// [ReservationService.UpdateCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.UpdateCapacityCommitment].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type UpdateCapacityCommitmentRequest = src.UpdateCapacityCommitmentRequest

// The request for
// [ReservationService.UpdateReservation][google.cloud.bigquery.reservation.v1.ReservationService.UpdateReservation].
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
type UpdateReservationRequest = src.UpdateReservationRequest

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
func NewReservationServiceClient(cc grpc.ClientConnInterface) ReservationServiceClient {
	return src.NewReservationServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/reservation/apiv1/reservationpb
func RegisterReservationServiceServer(s *grpc.Server, srv ReservationServiceServer) {
	src.RegisterReservationServiceServer(s, srv)
}
