// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package firestore aliases all exported identifiers in package
// "cloud.google.com/go/firestore/apiv1/firestorepb".
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package firestore

import (
	src "cloud.google.com/go/firestore/apiv1/firestorepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/firestore/apiv1/firestorepb
const (
	DocumentTransform_FieldTransform_REQUEST_TIME             = src.DocumentTransform_FieldTransform_REQUEST_TIME
	DocumentTransform_FieldTransform_SERVER_VALUE_UNSPECIFIED = src.DocumentTransform_FieldTransform_SERVER_VALUE_UNSPECIFIED
	StructuredQuery_ASCENDING                                 = src.StructuredQuery_ASCENDING
	StructuredQuery_CompositeFilter_AND                       = src.StructuredQuery_CompositeFilter_AND
	StructuredQuery_CompositeFilter_OPERATOR_UNSPECIFIED      = src.StructuredQuery_CompositeFilter_OPERATOR_UNSPECIFIED
	StructuredQuery_DESCENDING                                = src.StructuredQuery_DESCENDING
	StructuredQuery_DIRECTION_UNSPECIFIED                     = src.StructuredQuery_DIRECTION_UNSPECIFIED
	StructuredQuery_FieldFilter_ARRAY_CONTAINS                = src.StructuredQuery_FieldFilter_ARRAY_CONTAINS
	StructuredQuery_FieldFilter_ARRAY_CONTAINS_ANY            = src.StructuredQuery_FieldFilter_ARRAY_CONTAINS_ANY
	StructuredQuery_FieldFilter_EQUAL                         = src.StructuredQuery_FieldFilter_EQUAL
	StructuredQuery_FieldFilter_GREATER_THAN                  = src.StructuredQuery_FieldFilter_GREATER_THAN
	StructuredQuery_FieldFilter_GREATER_THAN_OR_EQUAL         = src.StructuredQuery_FieldFilter_GREATER_THAN_OR_EQUAL
	StructuredQuery_FieldFilter_IN                            = src.StructuredQuery_FieldFilter_IN
	StructuredQuery_FieldFilter_LESS_THAN                     = src.StructuredQuery_FieldFilter_LESS_THAN
	StructuredQuery_FieldFilter_LESS_THAN_OR_EQUAL            = src.StructuredQuery_FieldFilter_LESS_THAN_OR_EQUAL
	StructuredQuery_FieldFilter_NOT_EQUAL                     = src.StructuredQuery_FieldFilter_NOT_EQUAL
	StructuredQuery_FieldFilter_NOT_IN                        = src.StructuredQuery_FieldFilter_NOT_IN
	StructuredQuery_FieldFilter_OPERATOR_UNSPECIFIED          = src.StructuredQuery_FieldFilter_OPERATOR_UNSPECIFIED
	StructuredQuery_UnaryFilter_IS_NAN                        = src.StructuredQuery_UnaryFilter_IS_NAN
	StructuredQuery_UnaryFilter_IS_NOT_NAN                    = src.StructuredQuery_UnaryFilter_IS_NOT_NAN
	StructuredQuery_UnaryFilter_IS_NOT_NULL                   = src.StructuredQuery_UnaryFilter_IS_NOT_NULL
	StructuredQuery_UnaryFilter_IS_NULL                       = src.StructuredQuery_UnaryFilter_IS_NULL
	StructuredQuery_UnaryFilter_OPERATOR_UNSPECIFIED          = src.StructuredQuery_UnaryFilter_OPERATOR_UNSPECIFIED
	TargetChange_ADD                                          = src.TargetChange_ADD
	TargetChange_CURRENT                                      = src.TargetChange_CURRENT
	TargetChange_NO_CHANGE                                    = src.TargetChange_NO_CHANGE
	TargetChange_REMOVE                                       = src.TargetChange_REMOVE
	TargetChange_RESET                                        = src.TargetChange_RESET
)

// Deprecated: Please use vars in: cloud.google.com/go/firestore/apiv1/firestorepb
var (
	DocumentTransform_FieldTransform_ServerValue_name  = src.DocumentTransform_FieldTransform_ServerValue_name
	DocumentTransform_FieldTransform_ServerValue_value = src.DocumentTransform_FieldTransform_ServerValue_value
	File_google_firestore_v1_aggregation_result_proto  = src.File_google_firestore_v1_aggregation_result_proto
	File_google_firestore_v1_common_proto              = src.File_google_firestore_v1_common_proto
	File_google_firestore_v1_document_proto            = src.File_google_firestore_v1_document_proto
	File_google_firestore_v1_firestore_proto           = src.File_google_firestore_v1_firestore_proto
	File_google_firestore_v1_query_proto               = src.File_google_firestore_v1_query_proto
	File_google_firestore_v1_write_proto               = src.File_google_firestore_v1_write_proto
	StructuredQuery_CompositeFilter_Operator_name      = src.StructuredQuery_CompositeFilter_Operator_name
	StructuredQuery_CompositeFilter_Operator_value     = src.StructuredQuery_CompositeFilter_Operator_value
	StructuredQuery_Direction_name                     = src.StructuredQuery_Direction_name
	StructuredQuery_Direction_value                    = src.StructuredQuery_Direction_value
	StructuredQuery_FieldFilter_Operator_name          = src.StructuredQuery_FieldFilter_Operator_name
	StructuredQuery_FieldFilter_Operator_value         = src.StructuredQuery_FieldFilter_Operator_value
	StructuredQuery_UnaryFilter_Operator_name          = src.StructuredQuery_UnaryFilter_Operator_name
	StructuredQuery_UnaryFilter_Operator_value         = src.StructuredQuery_UnaryFilter_Operator_value
	TargetChange_TargetChangeType_name                 = src.TargetChange_TargetChangeType_name
	TargetChange_TargetChangeType_value                = src.TargetChange_TargetChangeType_value
)

// The result of a single bucket from a Firestore aggregation query. The keys
// of `aggregate_fields` are the same for all results in an aggregation query,
// unlike document queries which can have different fields present for each
// result.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type AggregationResult = src.AggregationResult

// An array value.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type ArrayValue = src.ArrayValue

// The request for
// [Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type BatchGetDocumentsRequest = src.BatchGetDocumentsRequest
type BatchGetDocumentsRequest_NewTransaction = src.BatchGetDocumentsRequest_NewTransaction
type BatchGetDocumentsRequest_ReadTime = src.BatchGetDocumentsRequest_ReadTime
type BatchGetDocumentsRequest_Transaction = src.BatchGetDocumentsRequest_Transaction

// The streamed response for
// [Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type BatchGetDocumentsResponse = src.BatchGetDocumentsResponse
type BatchGetDocumentsResponse_Found = src.BatchGetDocumentsResponse_Found
type BatchGetDocumentsResponse_Missing = src.BatchGetDocumentsResponse_Missing

// The request for
// [Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type BatchWriteRequest = src.BatchWriteRequest

// The response from
// [Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type BatchWriteResponse = src.BatchWriteResponse

// The request for
// [Firestore.BeginTransaction][google.firestore.v1.Firestore.BeginTransaction].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type BeginTransactionRequest = src.BeginTransactionRequest

// The response for
// [Firestore.BeginTransaction][google.firestore.v1.Firestore.BeginTransaction].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type BeginTransactionResponse = src.BeginTransactionResponse

// The request for [Firestore.Commit][google.firestore.v1.Firestore.Commit].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type CommitRequest = src.CommitRequest

// The response for [Firestore.Commit][google.firestore.v1.Firestore.Commit].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type CommitResponse = src.CommitResponse

// The request for
// [Firestore.CreateDocument][google.firestore.v1.Firestore.CreateDocument].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type CreateDocumentRequest = src.CreateDocumentRequest

// A position in a query result set.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type Cursor = src.Cursor

// The request for
// [Firestore.DeleteDocument][google.firestore.v1.Firestore.DeleteDocument].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type DeleteDocumentRequest = src.DeleteDocumentRequest

// A Firestore document. Must not exceed 1 MiB - 4 bytes.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type Document = src.Document

// A [Document][google.firestore.v1.Document] has changed. May be the result
// of multiple [writes][google.firestore.v1.Write], including deletes, that
// ultimately resulted in a new value for the
// [Document][google.firestore.v1.Document]. Multiple
// [DocumentChange][google.firestore.v1.DocumentChange] messages may be
// returned for the same logical change, if multiple targets are affected.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type DocumentChange = src.DocumentChange

// A [Document][google.firestore.v1.Document] has been deleted. May be the
// result of multiple [writes][google.firestore.v1.Write], including updates,
// the last of which deleted the [Document][google.firestore.v1.Document].
// Multiple [DocumentDelete][google.firestore.v1.DocumentDelete] messages may
// be returned for the same logical delete, if multiple targets are affected.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type DocumentDelete = src.DocumentDelete

// A set of field paths on a document. Used to restrict a get or update
// operation on a document to a subset of its fields. This is different from
// standard field masks, as this is always scoped to a
// [Document][google.firestore.v1.Document], and takes in account the dynamic
// nature of [Value][google.firestore.v1.Value].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type DocumentMask = src.DocumentMask

// A [Document][google.firestore.v1.Document] has been removed from the view
// of the targets. Sent if the document is no longer relevant to a target and
// is out of view. Can be sent instead of a DocumentDelete or a DocumentChange
// if the server can not send the new value of the document. Multiple
// [DocumentRemove][google.firestore.v1.DocumentRemove] messages may be
// returned for the same logical write or delete, if multiple targets are
// affected.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type DocumentRemove = src.DocumentRemove

// A transformation of a document.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type DocumentTransform = src.DocumentTransform

// A transformation of a field of the document.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type DocumentTransform_FieldTransform = src.DocumentTransform_FieldTransform
type DocumentTransform_FieldTransform_AppendMissingElements = src.DocumentTransform_FieldTransform_AppendMissingElements
type DocumentTransform_FieldTransform_Increment = src.DocumentTransform_FieldTransform_Increment
type DocumentTransform_FieldTransform_Maximum = src.DocumentTransform_FieldTransform_Maximum
type DocumentTransform_FieldTransform_Minimum = src.DocumentTransform_FieldTransform_Minimum
type DocumentTransform_FieldTransform_RemoveAllFromArray = src.DocumentTransform_FieldTransform_RemoveAllFromArray

// A value that is calculated by the server.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type DocumentTransform_FieldTransform_ServerValue = src.DocumentTransform_FieldTransform_ServerValue
type DocumentTransform_FieldTransform_SetToServerValue = src.DocumentTransform_FieldTransform_SetToServerValue

// A digest of all the documents that match a given target.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type ExistenceFilter = src.ExistenceFilter

// FirestoreClient is the client API for Firestore service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type FirestoreClient = src.FirestoreClient

// FirestoreServer is the server API for Firestore service.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type FirestoreServer = src.FirestoreServer
type Firestore_BatchGetDocumentsClient = src.Firestore_BatchGetDocumentsClient
type Firestore_BatchGetDocumentsServer = src.Firestore_BatchGetDocumentsServer
type Firestore_ListenClient = src.Firestore_ListenClient
type Firestore_ListenServer = src.Firestore_ListenServer
type Firestore_RunAggregationQueryClient = src.Firestore_RunAggregationQueryClient
type Firestore_RunAggregationQueryServer = src.Firestore_RunAggregationQueryServer
type Firestore_RunQueryClient = src.Firestore_RunQueryClient
type Firestore_RunQueryServer = src.Firestore_RunQueryServer
type Firestore_WriteClient = src.Firestore_WriteClient
type Firestore_WriteServer = src.Firestore_WriteServer

// The request for
// [Firestore.GetDocument][google.firestore.v1.Firestore.GetDocument].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type GetDocumentRequest = src.GetDocumentRequest
type GetDocumentRequest_ReadTime = src.GetDocumentRequest_ReadTime
type GetDocumentRequest_Transaction = src.GetDocumentRequest_Transaction

// The request for
// [Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type ListCollectionIdsRequest = src.ListCollectionIdsRequest
type ListCollectionIdsRequest_ReadTime = src.ListCollectionIdsRequest_ReadTime

// The response from
// [Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type ListCollectionIdsResponse = src.ListCollectionIdsResponse

// The request for
// [Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type ListDocumentsRequest = src.ListDocumentsRequest
type ListDocumentsRequest_ReadTime = src.ListDocumentsRequest_ReadTime
type ListDocumentsRequest_Transaction = src.ListDocumentsRequest_Transaction

// The response for
// [Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type ListDocumentsResponse = src.ListDocumentsResponse

// A request for [Firestore.Listen][google.firestore.v1.Firestore.Listen]
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type ListenRequest = src.ListenRequest
type ListenRequest_AddTarget = src.ListenRequest_AddTarget
type ListenRequest_RemoveTarget = src.ListenRequest_RemoveTarget

// The response for [Firestore.Listen][google.firestore.v1.Firestore.Listen].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type ListenResponse = src.ListenResponse
type ListenResponse_DocumentChange = src.ListenResponse_DocumentChange
type ListenResponse_DocumentDelete = src.ListenResponse_DocumentDelete
type ListenResponse_DocumentRemove = src.ListenResponse_DocumentRemove
type ListenResponse_Filter = src.ListenResponse_Filter
type ListenResponse_TargetChange = src.ListenResponse_TargetChange

// A map value.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type MapValue = src.MapValue

// The request for
// [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type PartitionQueryRequest = src.PartitionQueryRequest
type PartitionQueryRequest_ReadTime = src.PartitionQueryRequest_ReadTime
type PartitionQueryRequest_StructuredQuery = src.PartitionQueryRequest_StructuredQuery

// The response for
// [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type PartitionQueryResponse = src.PartitionQueryResponse

// A precondition on a document, used for conditional operations.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type Precondition = src.Precondition
type Precondition_Exists = src.Precondition_Exists
type Precondition_UpdateTime = src.Precondition_UpdateTime

// The request for
// [Firestore.Rollback][google.firestore.v1.Firestore.Rollback].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type RollbackRequest = src.RollbackRequest

// The request for
// [Firestore.RunAggregationQuery][google.firestore.v1.Firestore.RunAggregationQuery].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type RunAggregationQueryRequest = src.RunAggregationQueryRequest
type RunAggregationQueryRequest_NewTransaction = src.RunAggregationQueryRequest_NewTransaction
type RunAggregationQueryRequest_ReadTime = src.RunAggregationQueryRequest_ReadTime
type RunAggregationQueryRequest_StructuredAggregationQuery = src.RunAggregationQueryRequest_StructuredAggregationQuery
type RunAggregationQueryRequest_Transaction = src.RunAggregationQueryRequest_Transaction

// The response for
// [Firestore.RunAggregationQuery][google.firestore.v1.Firestore.RunAggregationQuery].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type RunAggregationQueryResponse = src.RunAggregationQueryResponse

// The request for
// [Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type RunQueryRequest = src.RunQueryRequest
type RunQueryRequest_NewTransaction = src.RunQueryRequest_NewTransaction
type RunQueryRequest_ReadTime = src.RunQueryRequest_ReadTime
type RunQueryRequest_StructuredQuery = src.RunQueryRequest_StructuredQuery
type RunQueryRequest_Transaction = src.RunQueryRequest_Transaction

// The response for
// [Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type RunQueryResponse = src.RunQueryResponse
type RunQueryResponse_Done = src.RunQueryResponse_Done

// Firestore query for running an aggregation over a
// [StructuredQuery][google.firestore.v1.StructuredQuery].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredAggregationQuery = src.StructuredAggregationQuery

// Defines a aggregation that produces a single result.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredAggregationQuery_Aggregation = src.StructuredAggregationQuery_Aggregation

// Count of documents that match the query. The `COUNT(*)` aggregation
// function operates on the entire document so it does not require a field
// reference.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredAggregationQuery_Aggregation_Count = src.StructuredAggregationQuery_Aggregation_Count
type StructuredAggregationQuery_Aggregation_Count_ = src.StructuredAggregationQuery_Aggregation_Count_
type StructuredAggregationQuery_StructuredQuery = src.StructuredAggregationQuery_StructuredQuery

// A Firestore query.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery = src.StructuredQuery

// A selection of a collection, such as `messages as m1`.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_CollectionSelector = src.StructuredQuery_CollectionSelector

// A filter that merges multiple other filters using the given operator.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_CompositeFilter = src.StructuredQuery_CompositeFilter

// A composite filter operator.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_CompositeFilter_Operator = src.StructuredQuery_CompositeFilter_Operator

// A sort direction.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_Direction = src.StructuredQuery_Direction

// A filter on a specific field.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_FieldFilter = src.StructuredQuery_FieldFilter

// A field filter operator.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_FieldFilter_Operator = src.StructuredQuery_FieldFilter_Operator

// A reference to a field in a document, ex: `stats.operations`.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_FieldReference = src.StructuredQuery_FieldReference

// A filter.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_Filter = src.StructuredQuery_Filter
type StructuredQuery_Filter_CompositeFilter = src.StructuredQuery_Filter_CompositeFilter
type StructuredQuery_Filter_FieldFilter = src.StructuredQuery_Filter_FieldFilter
type StructuredQuery_Filter_UnaryFilter = src.StructuredQuery_Filter_UnaryFilter

// An order on a field.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_Order = src.StructuredQuery_Order

// The projection of document's fields to return.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_Projection = src.StructuredQuery_Projection

// A filter with a single operand.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_UnaryFilter = src.StructuredQuery_UnaryFilter
type StructuredQuery_UnaryFilter_Field = src.StructuredQuery_UnaryFilter_Field

// A unary operator.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type StructuredQuery_UnaryFilter_Operator = src.StructuredQuery_UnaryFilter_Operator

// A specification of a set of documents to listen to.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type Target = src.Target

// Targets being watched have changed.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type TargetChange = src.TargetChange

// The type of change.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type TargetChange_TargetChangeType = src.TargetChange_TargetChangeType
type Target_Documents = src.Target_Documents

// A target specified by a set of documents names.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type Target_DocumentsTarget = src.Target_DocumentsTarget
type Target_Query = src.Target_Query

// A target specified by a query.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type Target_QueryTarget = src.Target_QueryTarget
type Target_QueryTarget_StructuredQuery = src.Target_QueryTarget_StructuredQuery
type Target_ReadTime = src.Target_ReadTime
type Target_ResumeToken = src.Target_ResumeToken

// Options for creating a new transaction.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type TransactionOptions = src.TransactionOptions

// Options for a transaction that can only be used to read documents.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type TransactionOptions_ReadOnly = src.TransactionOptions_ReadOnly
type TransactionOptions_ReadOnly_ = src.TransactionOptions_ReadOnly_
type TransactionOptions_ReadOnly_ReadTime = src.TransactionOptions_ReadOnly_ReadTime

// Options for a transaction that can be used to read and write documents.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type TransactionOptions_ReadWrite = src.TransactionOptions_ReadWrite
type TransactionOptions_ReadWrite_ = src.TransactionOptions_ReadWrite_

// UnimplementedFirestoreServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type UnimplementedFirestoreServer = src.UnimplementedFirestoreServer

// The request for
// [Firestore.UpdateDocument][google.firestore.v1.Firestore.UpdateDocument].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type UpdateDocumentRequest = src.UpdateDocumentRequest

// A message that can hold any of the supported value types.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type Value = src.Value
type Value_ArrayValue = src.Value_ArrayValue
type Value_BooleanValue = src.Value_BooleanValue
type Value_BytesValue = src.Value_BytesValue
type Value_DoubleValue = src.Value_DoubleValue
type Value_GeoPointValue = src.Value_GeoPointValue
type Value_IntegerValue = src.Value_IntegerValue
type Value_MapValue = src.Value_MapValue
type Value_NullValue = src.Value_NullValue
type Value_ReferenceValue = src.Value_ReferenceValue
type Value_StringValue = src.Value_StringValue
type Value_TimestampValue = src.Value_TimestampValue

// A write on a document.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type Write = src.Write

// The request for [Firestore.Write][google.firestore.v1.Firestore.Write]. The
// first request creates a stream, or resumes an existing one from a token.
// When creating a new stream, the server replies with a response containing
// only an ID and a token, to use in the next request. When resuming a stream,
// the server first streams any responses later than the given token, then a
// response containing only an up-to-date token, to use in the next request.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type WriteRequest = src.WriteRequest

// The response for [Firestore.Write][google.firestore.v1.Firestore.Write].
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type WriteResponse = src.WriteResponse

// The result of applying a write.
//
// Deprecated: Please use types in: cloud.google.com/go/firestore/apiv1/firestorepb
type WriteResult = src.WriteResult
type Write_Delete = src.Write_Delete
type Write_Transform = src.Write_Transform
type Write_Update = src.Write_Update

// Deprecated: Please use funcs in: cloud.google.com/go/firestore/apiv1/firestorepb
func NewFirestoreClient(cc grpc.ClientConnInterface) FirestoreClient {
	return src.NewFirestoreClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/firestore/apiv1/firestorepb
func RegisterFirestoreServer(s *grpc.Server, srv FirestoreServer) {
	src.RegisterFirestoreServer(s, srv)
}
