// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package database aliases all exported identifiers in package
// "cloud.google.com/go/spanner/admin/database/apiv1/databasepb".
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package database

import (
	src "cloud.google.com/go/spanner/admin/database/apiv1/databasepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
const (
	Backup_CREATING                                                         = src.Backup_CREATING
	Backup_READY                                                            = src.Backup_READY
	Backup_STATE_UNSPECIFIED                                                = src.Backup_STATE_UNSPECIFIED
	CopyBackupEncryptionConfig_CUSTOMER_MANAGED_ENCRYPTION                  = src.CopyBackupEncryptionConfig_CUSTOMER_MANAGED_ENCRYPTION
	CopyBackupEncryptionConfig_ENCRYPTION_TYPE_UNSPECIFIED                  = src.CopyBackupEncryptionConfig_ENCRYPTION_TYPE_UNSPECIFIED
	CopyBackupEncryptionConfig_GOOGLE_DEFAULT_ENCRYPTION                    = src.CopyBackupEncryptionConfig_GOOGLE_DEFAULT_ENCRYPTION
	CopyBackupEncryptionConfig_USE_CONFIG_DEFAULT_OR_BACKUP_ENCRYPTION      = src.CopyBackupEncryptionConfig_USE_CONFIG_DEFAULT_OR_BACKUP_ENCRYPTION
	CreateBackupEncryptionConfig_CUSTOMER_MANAGED_ENCRYPTION                = src.CreateBackupEncryptionConfig_CUSTOMER_MANAGED_ENCRYPTION
	CreateBackupEncryptionConfig_ENCRYPTION_TYPE_UNSPECIFIED                = src.CreateBackupEncryptionConfig_ENCRYPTION_TYPE_UNSPECIFIED
	CreateBackupEncryptionConfig_GOOGLE_DEFAULT_ENCRYPTION                  = src.CreateBackupEncryptionConfig_GOOGLE_DEFAULT_ENCRYPTION
	CreateBackupEncryptionConfig_USE_DATABASE_ENCRYPTION                    = src.CreateBackupEncryptionConfig_USE_DATABASE_ENCRYPTION
	DatabaseDialect_DATABASE_DIALECT_UNSPECIFIED                            = src.DatabaseDialect_DATABASE_DIALECT_UNSPECIFIED
	DatabaseDialect_GOOGLE_STANDARD_SQL                                     = src.DatabaseDialect_GOOGLE_STANDARD_SQL
	DatabaseDialect_POSTGRESQL                                              = src.DatabaseDialect_POSTGRESQL
	Database_CREATING                                                       = src.Database_CREATING
	Database_READY                                                          = src.Database_READY
	Database_READY_OPTIMIZING                                               = src.Database_READY_OPTIMIZING
	Database_STATE_UNSPECIFIED                                              = src.Database_STATE_UNSPECIFIED
	EncryptionInfo_CUSTOMER_MANAGED_ENCRYPTION                              = src.EncryptionInfo_CUSTOMER_MANAGED_ENCRYPTION
	EncryptionInfo_GOOGLE_DEFAULT_ENCRYPTION                                = src.EncryptionInfo_GOOGLE_DEFAULT_ENCRYPTION
	EncryptionInfo_TYPE_UNSPECIFIED                                         = src.EncryptionInfo_TYPE_UNSPECIFIED
	RestoreDatabaseEncryptionConfig_CUSTOMER_MANAGED_ENCRYPTION             = src.RestoreDatabaseEncryptionConfig_CUSTOMER_MANAGED_ENCRYPTION
	RestoreDatabaseEncryptionConfig_ENCRYPTION_TYPE_UNSPECIFIED             = src.RestoreDatabaseEncryptionConfig_ENCRYPTION_TYPE_UNSPECIFIED
	RestoreDatabaseEncryptionConfig_GOOGLE_DEFAULT_ENCRYPTION               = src.RestoreDatabaseEncryptionConfig_GOOGLE_DEFAULT_ENCRYPTION
	RestoreDatabaseEncryptionConfig_USE_CONFIG_DEFAULT_OR_BACKUP_ENCRYPTION = src.RestoreDatabaseEncryptionConfig_USE_CONFIG_DEFAULT_OR_BACKUP_ENCRYPTION
	RestoreSourceType_BACKUP                                                = src.RestoreSourceType_BACKUP
	RestoreSourceType_TYPE_UNSPECIFIED                                      = src.RestoreSourceType_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
var (
	Backup_State_name                                                  = src.Backup_State_name
	Backup_State_value                                                 = src.Backup_State_value
	CopyBackupEncryptionConfig_EncryptionType_name                     = src.CopyBackupEncryptionConfig_EncryptionType_name
	CopyBackupEncryptionConfig_EncryptionType_value                    = src.CopyBackupEncryptionConfig_EncryptionType_value
	CreateBackupEncryptionConfig_EncryptionType_name                   = src.CreateBackupEncryptionConfig_EncryptionType_name
	CreateBackupEncryptionConfig_EncryptionType_value                  = src.CreateBackupEncryptionConfig_EncryptionType_value
	DatabaseDialect_name                                               = src.DatabaseDialect_name
	DatabaseDialect_value                                              = src.DatabaseDialect_value
	Database_State_name                                                = src.Database_State_name
	Database_State_value                                               = src.Database_State_value
	EncryptionInfo_Type_name                                           = src.EncryptionInfo_Type_name
	EncryptionInfo_Type_value                                          = src.EncryptionInfo_Type_value
	File_google_spanner_admin_database_v1_backup_proto                 = src.File_google_spanner_admin_database_v1_backup_proto
	File_google_spanner_admin_database_v1_common_proto                 = src.File_google_spanner_admin_database_v1_common_proto
	File_google_spanner_admin_database_v1_spanner_database_admin_proto = src.File_google_spanner_admin_database_v1_spanner_database_admin_proto
	RestoreDatabaseEncryptionConfig_EncryptionType_name                = src.RestoreDatabaseEncryptionConfig_EncryptionType_name
	RestoreDatabaseEncryptionConfig_EncryptionType_value               = src.RestoreDatabaseEncryptionConfig_EncryptionType_value
	RestoreSourceType_name                                             = src.RestoreSourceType_name
	RestoreSourceType_value                                            = src.RestoreSourceType_value
)

// A backup of a Cloud Spanner database.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type Backup = src.Backup

// Information about a backup.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type BackupInfo = src.BackupInfo

// Indicates the current state of the backup.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type Backup_State = src.Backup_State

// Encryption configuration for the copied backup.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type CopyBackupEncryptionConfig = src.CopyBackupEncryptionConfig

// Encryption types for the backup.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type CopyBackupEncryptionConfig_EncryptionType = src.CopyBackupEncryptionConfig_EncryptionType

// Metadata type for the google.longrunning.Operation returned by
// [CopyBackup][google.spanner.admin.database.v1.DatabaseAdmin.CopyBackup].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type CopyBackupMetadata = src.CopyBackupMetadata

// The request for
// [CopyBackup][google.spanner.admin.database.v1.DatabaseAdmin.CopyBackup].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type CopyBackupRequest = src.CopyBackupRequest

// Encryption configuration for the backup to create.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type CreateBackupEncryptionConfig = src.CreateBackupEncryptionConfig

// Encryption types for the backup.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type CreateBackupEncryptionConfig_EncryptionType = src.CreateBackupEncryptionConfig_EncryptionType

// Metadata type for the operation returned by
// [CreateBackup][google.spanner.admin.database.v1.DatabaseAdmin.CreateBackup].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type CreateBackupMetadata = src.CreateBackupMetadata

// The request for
// [CreateBackup][google.spanner.admin.database.v1.DatabaseAdmin.CreateBackup].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type CreateBackupRequest = src.CreateBackupRequest

// Metadata type for the operation returned by
// [CreateDatabase][google.spanner.admin.database.v1.DatabaseAdmin.CreateDatabase].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type CreateDatabaseMetadata = src.CreateDatabaseMetadata

// The request for
// [CreateDatabase][google.spanner.admin.database.v1.DatabaseAdmin.CreateDatabase].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type CreateDatabaseRequest = src.CreateDatabaseRequest

// A Cloud Spanner database.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type Database = src.Database

// DatabaseAdminClient is the client API for DatabaseAdmin service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type DatabaseAdminClient = src.DatabaseAdminClient

// DatabaseAdminServer is the server API for DatabaseAdmin service.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type DatabaseAdminServer = src.DatabaseAdminServer

// Indicates the dialect type of a database.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type DatabaseDialect = src.DatabaseDialect

// A Cloud Spanner database role.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type DatabaseRole = src.DatabaseRole

// Indicates the current state of the database.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type Database_State = src.Database_State

// The request for
// [DeleteBackup][google.spanner.admin.database.v1.DatabaseAdmin.DeleteBackup].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type DeleteBackupRequest = src.DeleteBackupRequest

// The request for
// [DropDatabase][google.spanner.admin.database.v1.DatabaseAdmin.DropDatabase].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type DropDatabaseRequest = src.DropDatabaseRequest

// Encryption configuration for a Cloud Spanner database.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type EncryptionConfig = src.EncryptionConfig

// Encryption information for a Cloud Spanner database or backup.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type EncryptionInfo = src.EncryptionInfo

// Possible encryption types.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type EncryptionInfo_Type = src.EncryptionInfo_Type

// The request for
// [GetBackup][google.spanner.admin.database.v1.DatabaseAdmin.GetBackup].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type GetBackupRequest = src.GetBackupRequest

// The request for
// [GetDatabaseDdl][google.spanner.admin.database.v1.DatabaseAdmin.GetDatabaseDdl].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type GetDatabaseDdlRequest = src.GetDatabaseDdlRequest

// The response for
// [GetDatabaseDdl][google.spanner.admin.database.v1.DatabaseAdmin.GetDatabaseDdl].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type GetDatabaseDdlResponse = src.GetDatabaseDdlResponse

// The request for
// [GetDatabase][google.spanner.admin.database.v1.DatabaseAdmin.GetDatabase].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type GetDatabaseRequest = src.GetDatabaseRequest

// The request for
// [ListBackupOperations][google.spanner.admin.database.v1.DatabaseAdmin.ListBackupOperations].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type ListBackupOperationsRequest = src.ListBackupOperationsRequest

// The response for
// [ListBackupOperations][google.spanner.admin.database.v1.DatabaseAdmin.ListBackupOperations].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type ListBackupOperationsResponse = src.ListBackupOperationsResponse

// The request for
// [ListBackups][google.spanner.admin.database.v1.DatabaseAdmin.ListBackups].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type ListBackupsRequest = src.ListBackupsRequest

// The response for
// [ListBackups][google.spanner.admin.database.v1.DatabaseAdmin.ListBackups].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type ListBackupsResponse = src.ListBackupsResponse

// The request for
// [ListDatabaseOperations][google.spanner.admin.database.v1.DatabaseAdmin.ListDatabaseOperations].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type ListDatabaseOperationsRequest = src.ListDatabaseOperationsRequest

// The response for
// [ListDatabaseOperations][google.spanner.admin.database.v1.DatabaseAdmin.ListDatabaseOperations].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type ListDatabaseOperationsResponse = src.ListDatabaseOperationsResponse

// The request for
// [ListDatabaseRoles][google.spanner.admin.database.v1.DatabaseAdmin.ListDatabaseRoles].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type ListDatabaseRolesRequest = src.ListDatabaseRolesRequest

// The response for
// [ListDatabaseRoles][google.spanner.admin.database.v1.DatabaseAdmin.ListDatabaseRoles].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type ListDatabaseRolesResponse = src.ListDatabaseRolesResponse

// The request for
// [ListDatabases][google.spanner.admin.database.v1.DatabaseAdmin.ListDatabases].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type ListDatabasesRequest = src.ListDatabasesRequest

// The response for
// [ListDatabases][google.spanner.admin.database.v1.DatabaseAdmin.ListDatabases].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type ListDatabasesResponse = src.ListDatabasesResponse

// Encapsulates progress related information for a Cloud Spanner long running
// operation.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type OperationProgress = src.OperationProgress

// Metadata type for the long-running operation used to track the progress of
// optimizations performed on a newly restored database. This long-running
// operation is automatically created by the system after the successful
// completion of a database restore, and cannot be cancelled.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type OptimizeRestoredDatabaseMetadata = src.OptimizeRestoredDatabaseMetadata

// Encryption configuration for the restored database.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type RestoreDatabaseEncryptionConfig = src.RestoreDatabaseEncryptionConfig

// Encryption types for the database to be restored.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type RestoreDatabaseEncryptionConfig_EncryptionType = src.RestoreDatabaseEncryptionConfig_EncryptionType

// Metadata type for the long-running operation returned by
// [RestoreDatabase][google.spanner.admin.database.v1.DatabaseAdmin.RestoreDatabase].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type RestoreDatabaseMetadata = src.RestoreDatabaseMetadata
type RestoreDatabaseMetadata_BackupInfo = src.RestoreDatabaseMetadata_BackupInfo

// The request for
// [RestoreDatabase][google.spanner.admin.database.v1.DatabaseAdmin.RestoreDatabase].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type RestoreDatabaseRequest = src.RestoreDatabaseRequest
type RestoreDatabaseRequest_Backup = src.RestoreDatabaseRequest_Backup

// Information about the database restore.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type RestoreInfo = src.RestoreInfo
type RestoreInfo_BackupInfo = src.RestoreInfo_BackupInfo

// Indicates the type of the restore source.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type RestoreSourceType = src.RestoreSourceType

// UnimplementedDatabaseAdminServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type UnimplementedDatabaseAdminServer = src.UnimplementedDatabaseAdminServer

// The request for
// [UpdateBackup][google.spanner.admin.database.v1.DatabaseAdmin.UpdateBackup].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type UpdateBackupRequest = src.UpdateBackupRequest

// Metadata type for the operation returned by
// [UpdateDatabaseDdl][google.spanner.admin.database.v1.DatabaseAdmin.UpdateDatabaseDdl].
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type UpdateDatabaseDdlMetadata = src.UpdateDatabaseDdlMetadata

// Enqueues the given DDL statements to be applied, in order but not
// necessarily all at once, to the database schema at some point (or points) in
// the future. The server checks that the statements are executable
// (syntactically valid, name tables that exist, etc.) before enqueueing them,
// but they may still fail upon later execution (e.g., if a statement from
// another batch of statements is applied first and it conflicts in some way,
// or if there is some data-related problem like a `NULL` value in a column to
// which `NOT NULL` would be added). If a statement fails, all subsequent
// statements in the batch are automatically cancelled. Each batch of
// statements is assigned a name which can be used with the
// [Operations][google.longrunning.Operations] API to monitor progress. See the
// [operation_id][google.spanner.admin.database.v1.UpdateDatabaseDdlRequest.operation_id]
// field for more details.
//
// Deprecated: Please use types in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
type UpdateDatabaseDdlRequest = src.UpdateDatabaseDdlRequest

// Deprecated: Please use funcs in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
func NewDatabaseAdminClient(cc grpc.ClientConnInterface) DatabaseAdminClient {
	return src.NewDatabaseAdminClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/spanner/admin/database/apiv1/databasepb
func RegisterDatabaseAdminServer(s *grpc.Server, srv DatabaseAdminServer) {
	src.RegisterDatabaseAdminServer(s, srv)
}
