// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package transcoder aliases all exported identifiers in package
// "cloud.google.com/go/video/transcoder/apiv1/transcoderpb".
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package transcoder

import (
	src "cloud.google.com/go/video/transcoder/apiv1/transcoderpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
const (
	Job_FAILED                         = src.Job_FAILED
	Job_PENDING                        = src.Job_PENDING
	Job_PROCESSING_STATE_UNSPECIFIED   = src.Job_PROCESSING_STATE_UNSPECIFIED
	Job_RUNNING                        = src.Job_RUNNING
	Job_SUCCEEDED                      = src.Job_SUCCEEDED
	Manifest_DASH                      = src.Manifest_DASH
	Manifest_HLS                       = src.Manifest_HLS
	Manifest_MANIFEST_TYPE_UNSPECIFIED = src.Manifest_MANIFEST_TYPE_UNSPECIFIED
	Overlay_FADE_IN                    = src.Overlay_FADE_IN
	Overlay_FADE_OUT                   = src.Overlay_FADE_OUT
	Overlay_FADE_TYPE_UNSPECIFIED      = src.Overlay_FADE_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
var (
	File_google_cloud_video_transcoder_v1_resources_proto = src.File_google_cloud_video_transcoder_v1_resources_proto
	File_google_cloud_video_transcoder_v1_services_proto  = src.File_google_cloud_video_transcoder_v1_services_proto
	Job_ProcessingState_name                              = src.Job_ProcessingState_name
	Job_ProcessingState_value                             = src.Job_ProcessingState_value
	Manifest_ManifestType_name                            = src.Manifest_ManifestType_name
	Manifest_ManifestType_value                           = src.Manifest_ManifestType_value
	Overlay_FadeType_name                                 = src.Overlay_FadeType_name
	Overlay_FadeType_value                                = src.Overlay_FadeType_value
)

// Ad break.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type AdBreak = src.AdBreak

// Audio stream resource.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type AudioStream = src.AudioStream

// The mapping for the `Job.edit_list` atoms with audio `EditAtom.inputs`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type AudioStream_AudioMapping = src.AudioStream_AudioMapping

// Request message for `TranscoderService.CreateJob`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type CreateJobRequest = src.CreateJobRequest

// Request message for `TranscoderService.CreateJobTemplate`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type CreateJobTemplateRequest = src.CreateJobTemplateRequest

// Request message for `TranscoderService.DeleteJob`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type DeleteJobRequest = src.DeleteJobRequest

// Request message for `TranscoderService.DeleteJobTemplate`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type DeleteJobTemplateRequest = src.DeleteJobTemplateRequest

// Edit atom.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type EditAtom = src.EditAtom

// Encoding of an input file such as an audio, video, or text track.
// Elementary streams must be packaged before mapping and sharing between
// different output formats.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type ElementaryStream = src.ElementaryStream
type ElementaryStream_AudioStream = src.ElementaryStream_AudioStream
type ElementaryStream_TextStream = src.ElementaryStream_TextStream
type ElementaryStream_VideoStream = src.ElementaryStream_VideoStream

// Request message for `TranscoderService.GetJob`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type GetJobRequest = src.GetJobRequest

// Request message for `TranscoderService.GetJobTemplate`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type GetJobTemplateRequest = src.GetJobTemplateRequest

// Input asset.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Input = src.Input

// Transcoding job resource.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Job = src.Job

// Job configuration
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type JobConfig = src.JobConfig

// Transcoding job template resource.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type JobTemplate = src.JobTemplate
type Job_Config = src.Job_Config

// The current state of the job.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Job_ProcessingState = src.Job_ProcessingState
type Job_TemplateId = src.Job_TemplateId

// Request message for `TranscoderService.ListJobTemplates`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type ListJobTemplatesRequest = src.ListJobTemplatesRequest

// Response message for `TranscoderService.ListJobTemplates`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type ListJobTemplatesResponse = src.ListJobTemplatesResponse

// Request message for `TranscoderService.ListJobs`. The parent location from
// which to retrieve the collection of jobs.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type ListJobsRequest = src.ListJobsRequest

// Response message for `TranscoderService.ListJobs`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type ListJobsResponse = src.ListJobsResponse

// Manifest configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Manifest = src.Manifest

// The manifest type can be either `HLS` or `DASH`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Manifest_ManifestType = src.Manifest_ManifestType

// Multiplexing settings for output stream.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type MuxStream = src.MuxStream

// Location of output file(s) in a Cloud Storage bucket.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Output = src.Output

// Overlay configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Overlay = src.Overlay

// Animation types.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Overlay_Animation = src.Overlay_Animation

// End previous overlay animation from the video. Without AnimationEnd, the
// overlay object will keep the state of previous animation until the end of
// the video.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Overlay_AnimationEnd = src.Overlay_AnimationEnd

// Display overlay object with fade animation.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Overlay_AnimationFade = src.Overlay_AnimationFade

// Display static overlay object.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Overlay_AnimationStatic = src.Overlay_AnimationStatic
type Overlay_Animation_AnimationEnd = src.Overlay_Animation_AnimationEnd
type Overlay_Animation_AnimationFade = src.Overlay_Animation_AnimationFade
type Overlay_Animation_AnimationStatic = src.Overlay_Animation_AnimationStatic

// Fade type for the overlay: `FADE_IN` or `FADE_OUT`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Overlay_FadeType = src.Overlay_FadeType

// Overlaid jpeg image.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Overlay_Image = src.Overlay_Image

// 2D normalized coordinates. Default: `{0.0, 0.0}`
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type Overlay_NormalizedCoordinate = src.Overlay_NormalizedCoordinate

// Preprocessing configurations.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type PreprocessingConfig = src.PreprocessingConfig

// Audio preprocessing configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type PreprocessingConfig_Audio = src.PreprocessingConfig_Audio

// Color preprocessing configuration. **Note:** This configuration is not
// supported.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type PreprocessingConfig_Color = src.PreprocessingConfig_Color

// Video cropping configuration for the input video. The cropped input video
// is scaled to match the output resolution.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type PreprocessingConfig_Crop = src.PreprocessingConfig_Crop

// Deblock preprocessing configuration. **Note:** This configuration is not
// supported.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type PreprocessingConfig_Deblock = src.PreprocessingConfig_Deblock

// Denoise preprocessing configuration. **Note:** This configuration is not
// supported.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type PreprocessingConfig_Denoise = src.PreprocessingConfig_Denoise

// Pad filter configuration for the input video. The padded input video is
// scaled after padding with black to match the output resolution.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type PreprocessingConfig_Pad = src.PreprocessingConfig_Pad

// A Pub/Sub destination.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type PubsubDestination = src.PubsubDestination

// Segment settings for `ts`, `fmp4` and `vtt`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type SegmentSettings = src.SegmentSettings

// Sprite sheet configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type SpriteSheet = src.SpriteSheet
type SpriteSheet_Interval = src.SpriteSheet_Interval
type SpriteSheet_TotalCount = src.SpriteSheet_TotalCount

// Encoding of a text stream. For example, closed captions or subtitles.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type TextStream = src.TextStream

// The mapping for the `Job.edit_list` atoms with text `EditAtom.inputs`.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type TextStream_TextMapping = src.TextStream_TextMapping

// TranscoderServiceClient is the client API for TranscoderService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type TranscoderServiceClient = src.TranscoderServiceClient

// TranscoderServiceServer is the server API for TranscoderService service.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type TranscoderServiceServer = src.TranscoderServiceServer

// UnimplementedTranscoderServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type UnimplementedTranscoderServiceServer = src.UnimplementedTranscoderServiceServer

// Video stream resource.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type VideoStream = src.VideoStream
type VideoStream_H264 = src.VideoStream_H264

// H264 codec settings.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type VideoStream_H264CodecSettings = src.VideoStream_H264CodecSettings
type VideoStream_H264CodecSettings_GopDuration = src.VideoStream_H264CodecSettings_GopDuration
type VideoStream_H264CodecSettings_GopFrameCount = src.VideoStream_H264CodecSettings_GopFrameCount
type VideoStream_H265 = src.VideoStream_H265

// H265 codec settings.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type VideoStream_H265CodecSettings = src.VideoStream_H265CodecSettings
type VideoStream_H265CodecSettings_GopDuration = src.VideoStream_H265CodecSettings_GopDuration
type VideoStream_H265CodecSettings_GopFrameCount = src.VideoStream_H265CodecSettings_GopFrameCount
type VideoStream_Vp9 = src.VideoStream_Vp9

// VP9 codec settings.
//
// Deprecated: Please use types in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
type VideoStream_Vp9CodecSettings = src.VideoStream_Vp9CodecSettings
type VideoStream_Vp9CodecSettings_GopDuration = src.VideoStream_Vp9CodecSettings_GopDuration
type VideoStream_Vp9CodecSettings_GopFrameCount = src.VideoStream_Vp9CodecSettings_GopFrameCount

// Deprecated: Please use funcs in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
func NewTranscoderServiceClient(cc grpc.ClientConnInterface) TranscoderServiceClient {
	return src.NewTranscoderServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/video/transcoder/apiv1/transcoderpb
func RegisterTranscoderServiceServer(s *grpc.Server, srv TranscoderServiceServer) {
	src.RegisterTranscoderServiceServer(s, srv)
}
