// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package ids aliases all exported identifiers in package
// "cloud.google.com/go/ids/apiv1/idspb".
//
// Deprecated: Please use types in: cloud.google.com/go/ids/apiv1/idspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package ids

import (
	src "cloud.google.com/go/ids/apiv1/idspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/ids/apiv1/idspb
const (
	Endpoint_CREATING             = src.Endpoint_CREATING
	Endpoint_CRITICAL             = src.Endpoint_CRITICAL
	Endpoint_DELETING             = src.Endpoint_DELETING
	Endpoint_HIGH                 = src.Endpoint_HIGH
	Endpoint_INFORMATIONAL        = src.Endpoint_INFORMATIONAL
	Endpoint_LOW                  = src.Endpoint_LOW
	Endpoint_MEDIUM               = src.Endpoint_MEDIUM
	Endpoint_READY                = src.Endpoint_READY
	Endpoint_SEVERITY_UNSPECIFIED = src.Endpoint_SEVERITY_UNSPECIFIED
	Endpoint_STATE_UNSPECIFIED    = src.Endpoint_STATE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/ids/apiv1/idspb
var (
	Endpoint_Severity_name             = src.Endpoint_Severity_name
	Endpoint_Severity_value            = src.Endpoint_Severity_value
	Endpoint_State_name                = src.Endpoint_State_name
	Endpoint_State_value               = src.Endpoint_State_value
	File_google_cloud_ids_v1_ids_proto = src.File_google_cloud_ids_v1_ids_proto
)

type CreateEndpointRequest = src.CreateEndpointRequest
type DeleteEndpointRequest = src.DeleteEndpointRequest

// Endpoint describes a single IDS endpoint. It defines a forwarding rule to
// which packets can be sent for IDS inspection.
//
// Deprecated: Please use types in: cloud.google.com/go/ids/apiv1/idspb
type Endpoint = src.Endpoint

// Threat severity levels.
//
// Deprecated: Please use types in: cloud.google.com/go/ids/apiv1/idspb
type Endpoint_Severity = src.Endpoint_Severity

// Endpoint state
//
// Deprecated: Please use types in: cloud.google.com/go/ids/apiv1/idspb
type Endpoint_State = src.Endpoint_State
type GetEndpointRequest = src.GetEndpointRequest

// IDSClient is the client API for IDS service. For semantics around ctx use
// and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/ids/apiv1/idspb
type IDSClient = src.IDSClient

// IDSServer is the server API for IDS service.
//
// Deprecated: Please use types in: cloud.google.com/go/ids/apiv1/idspb
type IDSServer = src.IDSServer
type ListEndpointsRequest = src.ListEndpointsRequest
type ListEndpointsResponse = src.ListEndpointsResponse

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/ids/apiv1/idspb
type OperationMetadata = src.OperationMetadata

// UnimplementedIDSServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/ids/apiv1/idspb
type UnimplementedIDSServer = src.UnimplementedIDSServer

// Deprecated: Please use funcs in: cloud.google.com/go/ids/apiv1/idspb
func NewIDSClient(cc grpc.ClientConnInterface) IDSClient { return src.NewIDSClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/ids/apiv1/idspb
func RegisterIDSServer(s *grpc.Server, srv IDSServer) { src.RegisterIDSServer(s, srv) }
