// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package domains aliases all exported identifiers in package
// "cloud.google.com/go/domains/apiv1beta1/domainspb".
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package domains

import (
	src "cloud.google.com/go/domains/apiv1beta1/domainspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/domains/apiv1beta1/domainspb
const (
	ContactNotice_CONTACT_NOTICE_UNSPECIFIED          = src.ContactNotice_CONTACT_NOTICE_UNSPECIFIED
	ContactNotice_PUBLIC_CONTACT_DATA_ACKNOWLEDGEMENT = src.ContactNotice_PUBLIC_CONTACT_DATA_ACKNOWLEDGEMENT
	ContactPrivacy_CONTACT_PRIVACY_UNSPECIFIED        = src.ContactPrivacy_CONTACT_PRIVACY_UNSPECIFIED
	ContactPrivacy_PRIVATE_CONTACT_DATA               = src.ContactPrivacy_PRIVATE_CONTACT_DATA
	ContactPrivacy_PUBLIC_CONTACT_DATA                = src.ContactPrivacy_PUBLIC_CONTACT_DATA
	ContactPrivacy_REDACTED_CONTACT_DATA              = src.ContactPrivacy_REDACTED_CONTACT_DATA
	DnsSettings_DS_RECORDS_PUBLISHED                  = src.DnsSettings_DS_RECORDS_PUBLISHED
	DnsSettings_DS_RECORDS_UNPUBLISHED                = src.DnsSettings_DS_RECORDS_UNPUBLISHED
	DnsSettings_DS_STATE_UNSPECIFIED                  = src.DnsSettings_DS_STATE_UNSPECIFIED
	DnsSettings_DsRecord_ALGORITHM_UNSPECIFIED        = src.DnsSettings_DsRecord_ALGORITHM_UNSPECIFIED
	DnsSettings_DsRecord_DH                           = src.DnsSettings_DsRecord_DH
	DnsSettings_DsRecord_DIGEST_TYPE_UNSPECIFIED      = src.DnsSettings_DsRecord_DIGEST_TYPE_UNSPECIFIED
	DnsSettings_DsRecord_DSA                          = src.DnsSettings_DsRecord_DSA
	DnsSettings_DsRecord_DSANSEC3SHA1                 = src.DnsSettings_DsRecord_DSANSEC3SHA1
	DnsSettings_DsRecord_ECC                          = src.DnsSettings_DsRecord_ECC
	DnsSettings_DsRecord_ECCGOST                      = src.DnsSettings_DsRecord_ECCGOST
	DnsSettings_DsRecord_ECDSAP256SHA256              = src.DnsSettings_DsRecord_ECDSAP256SHA256
	DnsSettings_DsRecord_ECDSAP384SHA384              = src.DnsSettings_DsRecord_ECDSAP384SHA384
	DnsSettings_DsRecord_ED25519                      = src.DnsSettings_DsRecord_ED25519
	DnsSettings_DsRecord_ED448                        = src.DnsSettings_DsRecord_ED448
	DnsSettings_DsRecord_GOST3411                     = src.DnsSettings_DsRecord_GOST3411
	DnsSettings_DsRecord_INDIRECT                     = src.DnsSettings_DsRecord_INDIRECT
	DnsSettings_DsRecord_PRIVATEDNS                   = src.DnsSettings_DsRecord_PRIVATEDNS
	DnsSettings_DsRecord_PRIVATEOID                   = src.DnsSettings_DsRecord_PRIVATEOID
	DnsSettings_DsRecord_RSAMD5                       = src.DnsSettings_DsRecord_RSAMD5
	DnsSettings_DsRecord_RSASHA1                      = src.DnsSettings_DsRecord_RSASHA1
	DnsSettings_DsRecord_RSASHA1NSEC3SHA1             = src.DnsSettings_DsRecord_RSASHA1NSEC3SHA1
	DnsSettings_DsRecord_RSASHA256                    = src.DnsSettings_DsRecord_RSASHA256
	DnsSettings_DsRecord_RSASHA512                    = src.DnsSettings_DsRecord_RSASHA512
	DnsSettings_DsRecord_SHA1                         = src.DnsSettings_DsRecord_SHA1
	DnsSettings_DsRecord_SHA256                       = src.DnsSettings_DsRecord_SHA256
	DnsSettings_DsRecord_SHA384                       = src.DnsSettings_DsRecord_SHA384
	DomainNotice_DOMAIN_NOTICE_UNSPECIFIED            = src.DomainNotice_DOMAIN_NOTICE_UNSPECIFIED
	DomainNotice_HSTS_PRELOADED                       = src.DomainNotice_HSTS_PRELOADED
	ManagementSettings_AUTOMATIC_RENEWAL              = src.ManagementSettings_AUTOMATIC_RENEWAL
	ManagementSettings_MANUAL_RENEWAL                 = src.ManagementSettings_MANUAL_RENEWAL
	ManagementSettings_RENEWAL_METHOD_UNSPECIFIED     = src.ManagementSettings_RENEWAL_METHOD_UNSPECIFIED
	RegisterParameters_AVAILABILITY_UNSPECIFIED       = src.RegisterParameters_AVAILABILITY_UNSPECIFIED
	RegisterParameters_AVAILABLE                      = src.RegisterParameters_AVAILABLE
	RegisterParameters_UNAVAILABLE                    = src.RegisterParameters_UNAVAILABLE
	RegisterParameters_UNKNOWN                        = src.RegisterParameters_UNKNOWN
	RegisterParameters_UNSUPPORTED                    = src.RegisterParameters_UNSUPPORTED
	Registration_ACTIVE                               = src.Registration_ACTIVE
	Registration_CONTACT_SUPPORT                      = src.Registration_CONTACT_SUPPORT
	Registration_EXPORTED                             = src.Registration_EXPORTED
	Registration_ISSUE_UNSPECIFIED                    = src.Registration_ISSUE_UNSPECIFIED
	Registration_REGISTRATION_FAILED                  = src.Registration_REGISTRATION_FAILED
	Registration_REGISTRATION_PENDING                 = src.Registration_REGISTRATION_PENDING
	Registration_STATE_UNSPECIFIED                    = src.Registration_STATE_UNSPECIFIED
	Registration_SUSPENDED                            = src.Registration_SUSPENDED
	Registration_TRANSFER_FAILED                      = src.Registration_TRANSFER_FAILED
	Registration_TRANSFER_PENDING                     = src.Registration_TRANSFER_PENDING
	Registration_UNVERIFIED_EMAIL                     = src.Registration_UNVERIFIED_EMAIL
	TransferLockState_LOCKED                          = src.TransferLockState_LOCKED
	TransferLockState_TRANSFER_LOCK_STATE_UNSPECIFIED = src.TransferLockState_TRANSFER_LOCK_STATE_UNSPECIFIED
	TransferLockState_UNLOCKED                        = src.TransferLockState_UNLOCKED
)

// Deprecated: Please use vars in: cloud.google.com/go/domains/apiv1beta1/domainspb
var (
	ContactNotice_name                              = src.ContactNotice_name
	ContactNotice_value                             = src.ContactNotice_value
	ContactPrivacy_name                             = src.ContactPrivacy_name
	ContactPrivacy_value                            = src.ContactPrivacy_value
	DnsSettings_DsRecord_Algorithm_name             = src.DnsSettings_DsRecord_Algorithm_name
	DnsSettings_DsRecord_Algorithm_value            = src.DnsSettings_DsRecord_Algorithm_value
	DnsSettings_DsRecord_DigestType_name            = src.DnsSettings_DsRecord_DigestType_name
	DnsSettings_DsRecord_DigestType_value           = src.DnsSettings_DsRecord_DigestType_value
	DnsSettings_DsState_name                        = src.DnsSettings_DsState_name
	DnsSettings_DsState_value                       = src.DnsSettings_DsState_value
	DomainNotice_name                               = src.DomainNotice_name
	DomainNotice_value                              = src.DomainNotice_value
	File_google_cloud_domains_v1beta1_domains_proto = src.File_google_cloud_domains_v1beta1_domains_proto
	ManagementSettings_RenewalMethod_name           = src.ManagementSettings_RenewalMethod_name
	ManagementSettings_RenewalMethod_value          = src.ManagementSettings_RenewalMethod_value
	RegisterParameters_Availability_name            = src.RegisterParameters_Availability_name
	RegisterParameters_Availability_value           = src.RegisterParameters_Availability_value
	Registration_Issue_name                         = src.Registration_Issue_name
	Registration_Issue_value                        = src.Registration_Issue_value
	Registration_State_name                         = src.Registration_State_name
	Registration_State_value                        = src.Registration_State_value
	TransferLockState_name                          = src.TransferLockState_name
	TransferLockState_value                         = src.TransferLockState_value
)

// Defines an authorization code.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type AuthorizationCode = src.AuthorizationCode

// Request for the `ConfigureContactSettings` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ConfigureContactSettingsRequest = src.ConfigureContactSettingsRequest

// Request for the `ConfigureDnsSettings` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ConfigureDnsSettingsRequest = src.ConfigureDnsSettingsRequest

// Request for the `ConfigureManagementSettings` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ConfigureManagementSettingsRequest = src.ConfigureManagementSettingsRequest

// Notices related to contact information.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ContactNotice = src.ContactNotice

// Defines a set of possible contact privacy settings for a `Registration`.
// [ICANN](https://icann.org/) maintains the WHOIS database, a publicly
// accessible mapping from domain name to contact information, and requires
// that each domain name have an entry. Choose from these options to control
// how much information in your `ContactSettings` is published.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ContactPrivacy = src.ContactPrivacy

// Defines the contact information associated with a `Registration`.
// [ICANN](https://icann.org/) requires all domain names to have associated
// contact information. The `registrant_contact` is considered the domain's
// legal owner, and often the other contacts are identical.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ContactSettings = src.ContactSettings

// Details required for a contact associated with a `Registration`.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ContactSettings_Contact = src.ContactSettings_Contact

// Request for the `DeleteRegistration` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DeleteRegistrationRequest = src.DeleteRegistrationRequest

// Defines the DNS configuration of a `Registration`, including name servers,
// DNSSEC, and glue records.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DnsSettings = src.DnsSettings

// Configuration for an arbitrary DNS provider.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DnsSettings_CustomDns = src.DnsSettings_CustomDns
type DnsSettings_CustomDns_ = src.DnsSettings_CustomDns_

// Defines a Delegation Signer (DS) record, which is needed to enable DNSSEC
// for a domain. It contains a digest (hash) of a DNSKEY record that must be
// present in the domain's DNS zone.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DnsSettings_DsRecord = src.DnsSettings_DsRecord

// List of algorithms used to create a DNSKEY. Certain algorithms are not
// supported for particular domains.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DnsSettings_DsRecord_Algorithm = src.DnsSettings_DsRecord_Algorithm

// List of hash functions that may have been used to generate a digest of a
// DNSKEY.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DnsSettings_DsRecord_DigestType = src.DnsSettings_DsRecord_DigestType

// The publication state of DS records for a `Registration`.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DnsSettings_DsState = src.DnsSettings_DsState

// Defines a host on your domain that is a DNS name server for your domain
// and/or other domains. Glue records are a way of making the IP address of a
// name server known, even when it serves DNS queries for its parent domain.
// For example, when `ns.example.com` is a name server for `example.com`, the
// host `ns.example.com` must have a glue record to break the circular DNS
// reference.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DnsSettings_GlueRecord = src.DnsSettings_GlueRecord

// Configuration for using the free DNS zone provided by Google Domains as a
// `Registration`'s `dns_provider`. You cannot configure the DNS zone itself
// using the API. To configure the DNS zone, go to [Google
// Domains](https://domains.google/).
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DnsSettings_GoogleDomainsDns = src.DnsSettings_GoogleDomainsDns
type DnsSettings_GoogleDomainsDns_ = src.DnsSettings_GoogleDomainsDns_

// Notices about special properties of certain domains.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DomainNotice = src.DomainNotice

// DomainsClient is the client API for Domains service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DomainsClient = src.DomainsClient

// DomainsServer is the server API for Domains service.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type DomainsServer = src.DomainsServer

// Request for the `ExportRegistration` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ExportRegistrationRequest = src.ExportRegistrationRequest

// Request for the `GetRegistration` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type GetRegistrationRequest = src.GetRegistrationRequest

// Request for the `ListRegistrations` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ListRegistrationsRequest = src.ListRegistrationsRequest

// Response for the `ListRegistrations` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ListRegistrationsResponse = src.ListRegistrationsResponse

// Defines renewal, billing, and transfer settings for a `Registration`.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ManagementSettings = src.ManagementSettings

// Defines how the `Registration` is renewed.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ManagementSettings_RenewalMethod = src.ManagementSettings_RenewalMethod

// Represents the metadata of the long-running operation. Output only.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type OperationMetadata = src.OperationMetadata

// Request for the `RegisterDomain` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type RegisterDomainRequest = src.RegisterDomainRequest

// Parameters required to register a new domain.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type RegisterParameters = src.RegisterParameters

// Possible availability states of a domain name.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type RegisterParameters_Availability = src.RegisterParameters_Availability

// The `Registration` resource facilitates managing and configuring domain
// name registrations. There are several ways to create a new `Registration`
// resource: To create a new `Registration` resource, find a suitable domain
// name by calling the `SearchDomains` method with a query to see available
// domain name options. After choosing a name, call
// `RetrieveRegisterParameters` to ensure availability and obtain information
// like pricing, which is needed to build a call to `RegisterDomain`. Another
// way to create a new `Registration` is to transfer an existing domain from
// another registrar. First, go to the current registrar to unlock the domain
// for transfer and retrieve the domain's transfer authorization code. Then
// call `RetrieveTransferParameters` to confirm that the domain is unlocked and
// to get values needed to build a call to `TransferDomain`.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type Registration = src.Registration

// Possible issues with a `Registration` that require attention.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type Registration_Issue = src.Registration_Issue

// Possible states of a `Registration`.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type Registration_State = src.Registration_State

// Request for the `ResetAuthorizationCode` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type ResetAuthorizationCodeRequest = src.ResetAuthorizationCodeRequest

// Request for the `RetrieveAuthorizationCode` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type RetrieveAuthorizationCodeRequest = src.RetrieveAuthorizationCodeRequest

// Request for the `RetrieveRegisterParameters` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type RetrieveRegisterParametersRequest = src.RetrieveRegisterParametersRequest

// Response for the `RetrieveRegisterParameters` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type RetrieveRegisterParametersResponse = src.RetrieveRegisterParametersResponse

// Request for the `RetrieveTransferParameters` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type RetrieveTransferParametersRequest = src.RetrieveTransferParametersRequest

// Response for the `RetrieveTransferParameters` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type RetrieveTransferParametersResponse = src.RetrieveTransferParametersResponse

// Request for the `SearchDomains` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type SearchDomainsRequest = src.SearchDomainsRequest

// Response for the `SearchDomains` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type SearchDomainsResponse = src.SearchDomainsResponse

// Request for the `TransferDomain` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type TransferDomainRequest = src.TransferDomainRequest

// Possible states of a `Registration`'s transfer lock.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type TransferLockState = src.TransferLockState

// Parameters required to transfer a domain from another registrar.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type TransferParameters = src.TransferParameters

// UnimplementedDomainsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type UnimplementedDomainsServer = src.UnimplementedDomainsServer

// Request for the `UpdateRegistration` method.
//
// Deprecated: Please use types in: cloud.google.com/go/domains/apiv1beta1/domainspb
type UpdateRegistrationRequest = src.UpdateRegistrationRequest

// Deprecated: Please use funcs in: cloud.google.com/go/domains/apiv1beta1/domainspb
func NewDomainsClient(cc grpc.ClientConnInterface) DomainsClient { return src.NewDomainsClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/domains/apiv1beta1/domainspb
func RegisterDomainsServer(s *grpc.Server, srv DomainsServer) { src.RegisterDomainsServer(s, srv) }
