// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package credentials aliases all exported identifiers in package
// "cloud.google.com/go/iam/credentials/apiv1/credentialspb".
//
// Deprecated: Please use types in: cloud.google.com/go/iam/credentials/apiv1/credentialspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package credentials

import (
	src "cloud.google.com/go/iam/credentials/apiv1/credentialspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use vars in: cloud.google.com/go/iam/credentials/apiv1/credentialspb
var (
	File_google_iam_credentials_v1_common_proto         = src.File_google_iam_credentials_v1_common_proto
	File_google_iam_credentials_v1_iamcredentials_proto = src.File_google_iam_credentials_v1_iamcredentials_proto
)

type GenerateAccessTokenRequest = src.GenerateAccessTokenRequest
type GenerateAccessTokenResponse = src.GenerateAccessTokenResponse
type GenerateIdTokenRequest = src.GenerateIdTokenRequest
type GenerateIdTokenResponse = src.GenerateIdTokenResponse

// IAMCredentialsClient is the client API for IAMCredentials service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/credentials/apiv1/credentialspb
type IAMCredentialsClient = src.IAMCredentialsClient

// IAMCredentialsServer is the server API for IAMCredentials service.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/credentials/apiv1/credentialspb
type IAMCredentialsServer = src.IAMCredentialsServer
type SignBlobRequest = src.SignBlobRequest
type SignBlobResponse = src.SignBlobResponse
type SignJwtRequest = src.SignJwtRequest
type SignJwtResponse = src.SignJwtResponse

// UnimplementedIAMCredentialsServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/credentials/apiv1/credentialspb
type UnimplementedIAMCredentialsServer = src.UnimplementedIAMCredentialsServer

// Deprecated: Please use funcs in: cloud.google.com/go/iam/credentials/apiv1/credentialspb
func NewIAMCredentialsClient(cc grpc.ClientConnInterface) IAMCredentialsClient {
	return src.NewIAMCredentialsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/iam/credentials/apiv1/credentialspb
func RegisterIAMCredentialsServer(s *grpc.Server, srv IAMCredentialsServer) {
	src.RegisterIAMCredentialsServer(s, srv)
}
