// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package secretmanager aliases all exported identifiers in package
// "cloud.google.com/go/secretmanager/apiv1/secretmanagerpb".
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package secretmanager

import (
	src "cloud.google.com/go/secretmanager/apiv1/secretmanagerpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
const (
	SecretVersion_DESTROYED         = src.SecretVersion_DESTROYED
	SecretVersion_DISABLED          = src.SecretVersion_DISABLED
	SecretVersion_ENABLED           = src.SecretVersion_ENABLED
	SecretVersion_STATE_UNSPECIFIED = src.SecretVersion_STATE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
var (
	File_google_cloud_secretmanager_v1_resources_proto = src.File_google_cloud_secretmanager_v1_resources_proto
	File_google_cloud_secretmanager_v1_service_proto   = src.File_google_cloud_secretmanager_v1_service_proto
	SecretVersion_State_name                           = src.SecretVersion_State_name
	SecretVersion_State_value                          = src.SecretVersion_State_value
)

// Request message for
// [SecretManagerService.AccessSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.AccessSecretVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type AccessSecretVersionRequest = src.AccessSecretVersionRequest

// Response message for
// [SecretManagerService.AccessSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.AccessSecretVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type AccessSecretVersionResponse = src.AccessSecretVersionResponse

// Request message for
// [SecretManagerService.AddSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.AddSecretVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type AddSecretVersionRequest = src.AddSecretVersionRequest

// Request message for
// [SecretManagerService.CreateSecret][google.cloud.secretmanager.v1.SecretManagerService.CreateSecret].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type CreateSecretRequest = src.CreateSecretRequest

// Configuration for encrypting secret payloads using customer-managed
// encryption keys (CMEK).
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type CustomerManagedEncryption = src.CustomerManagedEncryption

// Describes the status of customer-managed encryption.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type CustomerManagedEncryptionStatus = src.CustomerManagedEncryptionStatus

// Request message for
// [SecretManagerService.DeleteSecret][google.cloud.secretmanager.v1.SecretManagerService.DeleteSecret].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type DeleteSecretRequest = src.DeleteSecretRequest

// Request message for
// [SecretManagerService.DestroySecretVersion][google.cloud.secretmanager.v1.SecretManagerService.DestroySecretVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type DestroySecretVersionRequest = src.DestroySecretVersionRequest

// Request message for
// [SecretManagerService.DisableSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.DisableSecretVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type DisableSecretVersionRequest = src.DisableSecretVersionRequest

// Request message for
// [SecretManagerService.EnableSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.EnableSecretVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type EnableSecretVersionRequest = src.EnableSecretVersionRequest

// Request message for
// [SecretManagerService.GetSecret][google.cloud.secretmanager.v1.SecretManagerService.GetSecret].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type GetSecretRequest = src.GetSecretRequest

// Request message for
// [SecretManagerService.GetSecretVersion][google.cloud.secretmanager.v1.SecretManagerService.GetSecretVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type GetSecretVersionRequest = src.GetSecretVersionRequest

// Request message for
// [SecretManagerService.ListSecretVersions][google.cloud.secretmanager.v1.SecretManagerService.ListSecretVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type ListSecretVersionsRequest = src.ListSecretVersionsRequest

// Response message for
// [SecretManagerService.ListSecretVersions][google.cloud.secretmanager.v1.SecretManagerService.ListSecretVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type ListSecretVersionsResponse = src.ListSecretVersionsResponse

// Request message for
// [SecretManagerService.ListSecrets][google.cloud.secretmanager.v1.SecretManagerService.ListSecrets].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type ListSecretsRequest = src.ListSecretsRequest

// Response message for
// [SecretManagerService.ListSecrets][google.cloud.secretmanager.v1.SecretManagerService.ListSecrets].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type ListSecretsResponse = src.ListSecretsResponse

// A policy that defines the replication and encryption configuration of data.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type Replication = src.Replication

// The replication status of a
// [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type ReplicationStatus = src.ReplicationStatus
type ReplicationStatus_Automatic = src.ReplicationStatus_Automatic

// The replication status of a
// [SecretVersion][google.cloud.secretmanager.v1.SecretVersion] using automatic
// replication. Only populated if the parent
// [Secret][google.cloud.secretmanager.v1.Secret] has an automatic replication
// policy.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type ReplicationStatus_AutomaticStatus = src.ReplicationStatus_AutomaticStatus
type ReplicationStatus_UserManaged = src.ReplicationStatus_UserManaged

// The replication status of a
// [SecretVersion][google.cloud.secretmanager.v1.SecretVersion] using
// user-managed replication. Only populated if the parent
// [Secret][google.cloud.secretmanager.v1.Secret] has a user-managed
// replication policy.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type ReplicationStatus_UserManagedStatus = src.ReplicationStatus_UserManagedStatus

// Describes the status of a user-managed replica for the
// [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type ReplicationStatus_UserManagedStatus_ReplicaStatus = src.ReplicationStatus_UserManagedStatus_ReplicaStatus

// A replication policy that replicates the
// [Secret][google.cloud.secretmanager.v1.Secret] payload without any
// restrictions.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type Replication_Automatic = src.Replication_Automatic
type Replication_Automatic_ = src.Replication_Automatic_

// A replication policy that replicates the
// [Secret][google.cloud.secretmanager.v1.Secret] payload into the locations
// specified in [Secret.replication.user_managed.replicas][]
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type Replication_UserManaged = src.Replication_UserManaged
type Replication_UserManaged_ = src.Replication_UserManaged_

// Represents a Replica for this
// [Secret][google.cloud.secretmanager.v1.Secret].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type Replication_UserManaged_Replica = src.Replication_UserManaged_Replica

// The rotation time and period for a
// [Secret][google.cloud.secretmanager.v1.Secret]. At next_rotation_time,
// Secret Manager will send a Pub/Sub notification to the topics configured on
// the Secret. [Secret.topics][google.cloud.secretmanager.v1.Secret.topics]
// must be set to configure rotation.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type Rotation = src.Rotation

// A [Secret][google.cloud.secretmanager.v1.Secret] is a logical secret whose
// value and versions can be accessed. A
// [Secret][google.cloud.secretmanager.v1.Secret] is made up of zero or more
// [SecretVersions][google.cloud.secretmanager.v1.SecretVersion] that represent
// the secret data.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type Secret = src.Secret

// SecretManagerServiceClient is the client API for SecretManagerService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type SecretManagerServiceClient = src.SecretManagerServiceClient

// SecretManagerServiceServer is the server API for SecretManagerService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type SecretManagerServiceServer = src.SecretManagerServiceServer

// A secret payload resource in the Secret Manager API. This contains the
// sensitive secret payload that is associated with a
// [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type SecretPayload = src.SecretPayload

// A secret version resource in the Secret Manager API.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type SecretVersion = src.SecretVersion

// The state of a
// [SecretVersion][google.cloud.secretmanager.v1.SecretVersion], indicating if
// it can be accessed.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type SecretVersion_State = src.SecretVersion_State
type Secret_ExpireTime = src.Secret_ExpireTime
type Secret_Ttl = src.Secret_Ttl

// A Pub/Sub topic which Secret Manager will publish to when control plane
// events occur on this secret.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type Topic = src.Topic

// UnimplementedSecretManagerServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type UnimplementedSecretManagerServiceServer = src.UnimplementedSecretManagerServiceServer

// Request message for
// [SecretManagerService.UpdateSecret][google.cloud.secretmanager.v1.SecretManagerService.UpdateSecret].
//
// Deprecated: Please use types in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
type UpdateSecretRequest = src.UpdateSecretRequest

// Deprecated: Please use funcs in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
func NewSecretManagerServiceClient(cc grpc.ClientConnInterface) SecretManagerServiceClient {
	return src.NewSecretManagerServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/secretmanager/apiv1/secretmanagerpb
func RegisterSecretManagerServiceServer(s *grpc.Server, srv SecretManagerServiceServer) {
	src.RegisterSecretManagerServiceServer(s, srv)
}
