// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package tpu aliases all exported identifiers in package
// "cloud.google.com/go/tpu/apiv1/tpupb".
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package tpu

import (
	src "cloud.google.com/go/tpu/apiv1/tpupb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/tpu/apiv1/tpupb
const (
	Node_API_VERSION_UNSPECIFIED     = src.Node_API_VERSION_UNSPECIFIED
	Node_CREATING                    = src.Node_CREATING
	Node_DELETING                    = src.Node_DELETING
	Node_DEPRECATED_UNHEALTHY        = src.Node_DEPRECATED_UNHEALTHY
	Node_HEALTHY                     = src.Node_HEALTHY
	Node_HEALTH_UNSPECIFIED          = src.Node_HEALTH_UNSPECIFIED
	Node_HIDDEN                      = src.Node_HIDDEN
	Node_HIDING                      = src.Node_HIDING
	Node_PREEMPTED                   = src.Node_PREEMPTED
	Node_READY                       = src.Node_READY
	Node_REIMAGING                   = src.Node_REIMAGING
	Node_REPAIRING                   = src.Node_REPAIRING
	Node_RESTARTING                  = src.Node_RESTARTING
	Node_STARTING                    = src.Node_STARTING
	Node_STATE_UNSPECIFIED           = src.Node_STATE_UNSPECIFIED
	Node_STOPPED                     = src.Node_STOPPED
	Node_STOPPING                    = src.Node_STOPPING
	Node_TERMINATED                  = src.Node_TERMINATED
	Node_TIMEOUT                     = src.Node_TIMEOUT
	Node_UNHEALTHY_MAINTENANCE       = src.Node_UNHEALTHY_MAINTENANCE
	Node_UNHEALTHY_TENSORFLOW        = src.Node_UNHEALTHY_TENSORFLOW
	Node_UNHIDING                    = src.Node_UNHIDING
	Node_V1                          = src.Node_V1
	Node_V1_ALPHA1                   = src.Node_V1_ALPHA1
	Node_V2_ALPHA1                   = src.Node_V2_ALPHA1
	Symptom_EXECUTE_TIMED_OUT        = src.Symptom_EXECUTE_TIMED_OUT
	Symptom_HBM_OUT_OF_MEMORY        = src.Symptom_HBM_OUT_OF_MEMORY
	Symptom_LOW_MEMORY               = src.Symptom_LOW_MEMORY
	Symptom_MESH_BUILD_FAIL          = src.Symptom_MESH_BUILD_FAIL
	Symptom_OUT_OF_MEMORY            = src.Symptom_OUT_OF_MEMORY
	Symptom_PROJECT_ABUSE            = src.Symptom_PROJECT_ABUSE
	Symptom_SYMPTOM_TYPE_UNSPECIFIED = src.Symptom_SYMPTOM_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/tpu/apiv1/tpupb
var (
	File_google_cloud_tpu_v1_cloud_tpu_proto = src.File_google_cloud_tpu_v1_cloud_tpu_proto
	Node_ApiVersion_name                     = src.Node_ApiVersion_name
	Node_ApiVersion_value                    = src.Node_ApiVersion_value
	Node_Health_name                         = src.Node_Health_name
	Node_Health_value                        = src.Node_Health_value
	Node_State_name                          = src.Node_State_name
	Node_State_value                         = src.Node_State_value
	Symptom_SymptomType_name                 = src.Symptom_SymptomType_name
	Symptom_SymptomType_value                = src.Symptom_SymptomType_value
)

// A accelerator type that a Node can be configured with.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type AcceleratorType = src.AcceleratorType

// Request for [CreateNode][google.cloud.tpu.v1.Tpu.CreateNode].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type CreateNodeRequest = src.CreateNodeRequest

// Request for [DeleteNode][google.cloud.tpu.v1.Tpu.DeleteNode].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type DeleteNodeRequest = src.DeleteNodeRequest

// Request for
// [GetAcceleratorType][google.cloud.tpu.v1.Tpu.GetAcceleratorType].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type GetAcceleratorTypeRequest = src.GetAcceleratorTypeRequest

// Request for [GetNode][google.cloud.tpu.v1.Tpu.GetNode].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type GetNodeRequest = src.GetNodeRequest

// Request for
// [GetTensorFlowVersion][google.cloud.tpu.v1.Tpu.GetTensorFlowVersion].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type GetTensorFlowVersionRequest = src.GetTensorFlowVersionRequest

// Request for
// [ListAcceleratorTypes][google.cloud.tpu.v1.Tpu.ListAcceleratorTypes].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type ListAcceleratorTypesRequest = src.ListAcceleratorTypesRequest

// Response for
// [ListAcceleratorTypes][google.cloud.tpu.v1.Tpu.ListAcceleratorTypes].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type ListAcceleratorTypesResponse = src.ListAcceleratorTypesResponse

// Request for [ListNodes][google.cloud.tpu.v1.Tpu.ListNodes].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type ListNodesRequest = src.ListNodesRequest

// Response for [ListNodes][google.cloud.tpu.v1.Tpu.ListNodes].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type ListNodesResponse = src.ListNodesResponse

// Request for
// [ListTensorFlowVersions][google.cloud.tpu.v1.Tpu.ListTensorFlowVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type ListTensorFlowVersionsRequest = src.ListTensorFlowVersionsRequest

// Response for
// [ListTensorFlowVersions][google.cloud.tpu.v1.Tpu.ListTensorFlowVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type ListTensorFlowVersionsResponse = src.ListTensorFlowVersionsResponse

// A network endpoint over which a TPU worker can be reached.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type NetworkEndpoint = src.NetworkEndpoint

// A TPU instance.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type Node = src.Node

// TPU API Version.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type Node_ApiVersion = src.Node_ApiVersion

// Health defines the status of a TPU node as reported by Health Monitor.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type Node_Health = src.Node_Health

// Represents the different states of a TPU node during its lifecycle.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type Node_State = src.Node_State

// Metadata describing an [Operation][google.longrunning.Operation]
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type OperationMetadata = src.OperationMetadata

// Request for [ReimageNode][google.cloud.tpu.v1.Tpu.ReimageNode].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type ReimageNodeRequest = src.ReimageNodeRequest

// Sets the scheduling options for this node.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type SchedulingConfig = src.SchedulingConfig

// Request for [StartNode][google.cloud.tpu.v1.Tpu.StartNode].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type StartNodeRequest = src.StartNodeRequest

// Request for [StopNode][google.cloud.tpu.v1.Tpu.StopNode].
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type StopNodeRequest = src.StopNodeRequest

// A Symptom instance.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type Symptom = src.Symptom

// SymptomType represents the different types of Symptoms that a TPU can be
// at.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type Symptom_SymptomType = src.Symptom_SymptomType

// A tensorflow version that a Node can be configured with.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type TensorFlowVersion = src.TensorFlowVersion

// TpuClient is the client API for Tpu service. For semantics around ctx use
// and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type TpuClient = src.TpuClient

// TpuServer is the server API for Tpu service.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type TpuServer = src.TpuServer

// UnimplementedTpuServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/tpu/apiv1/tpupb
type UnimplementedTpuServer = src.UnimplementedTpuServer

// Deprecated: Please use funcs in: cloud.google.com/go/tpu/apiv1/tpupb
func NewTpuClient(cc grpc.ClientConnInterface) TpuClient { return src.NewTpuClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/tpu/apiv1/tpupb
func RegisterTpuServer(s *grpc.Server, srv TpuServer) { src.RegisterTpuServer(s, srv) }
