// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package publishing aliases all exported identifiers in package
// "cloud.google.com/go/eventarc/publishing/apiv1/publishingpb".
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package publishing

import (
	src "cloud.google.com/go/eventarc/publishing/apiv1/publishingpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use vars in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb
var (
	File_google_cloud_eventarc_publishing_v1_publisher_proto = src.File_google_cloud_eventarc_publishing_v1_publisher_proto
)

// The request message for the PublishChannelConnectionEvents method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb
type PublishChannelConnectionEventsRequest = src.PublishChannelConnectionEventsRequest

// The response message for the PublishChannelConnectionEvents method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb
type PublishChannelConnectionEventsResponse = src.PublishChannelConnectionEventsResponse

// The request message for the PublishEvents method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb
type PublishEventsRequest = src.PublishEventsRequest

// The response message for the PublishEvents method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb
type PublishEventsResponse = src.PublishEventsResponse

// PublisherClient is the client API for Publisher service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb
type PublisherClient = src.PublisherClient

// PublisherServer is the server API for Publisher service.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb
type PublisherServer = src.PublisherServer

// UnimplementedPublisherServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb
type UnimplementedPublisherServer = src.UnimplementedPublisherServer

// Deprecated: Please use funcs in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb
func NewPublisherClient(cc grpc.ClientConnInterface) PublisherClient {
	return src.NewPublisherClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/eventarc/publishing/apiv1/publishingpb
func RegisterPublisherServer(s *grpc.Server, srv PublisherServer) {
	src.RegisterPublisherServer(s, srv)
}
