// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package oslogin aliases all exported identifiers in package
// "cloud.google.com/go/oslogin/apiv1/osloginpb".
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package oslogin

import (
	src "cloud.google.com/go/oslogin/apiv1/osloginpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use vars in: cloud.google.com/go/oslogin/apiv1/osloginpb
var (
	File_google_cloud_oslogin_v1_oslogin_proto = src.File_google_cloud_oslogin_v1_oslogin_proto
)

// A request message for deleting a POSIX account entry.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type DeletePosixAccountRequest = src.DeletePosixAccountRequest

// A request message for deleting an SSH public key.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type DeleteSshPublicKeyRequest = src.DeleteSshPublicKeyRequest

// A request message for retrieving the login profile information for a user.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type GetLoginProfileRequest = src.GetLoginProfileRequest

// A request message for retrieving an SSH public key.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type GetSshPublicKeyRequest = src.GetSshPublicKeyRequest

// A request message for importing an SSH public key.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type ImportSshPublicKeyRequest = src.ImportSshPublicKeyRequest

// A response message for importing an SSH public key.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type ImportSshPublicKeyResponse = src.ImportSshPublicKeyResponse

// The user profile information used for logging in to a virtual machine on
// Google Compute Engine.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type LoginProfile = src.LoginProfile

// OsLoginServiceClient is the client API for OsLoginService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type OsLoginServiceClient = src.OsLoginServiceClient

// OsLoginServiceServer is the server API for OsLoginService service.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type OsLoginServiceServer = src.OsLoginServiceServer

// UnimplementedOsLoginServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type UnimplementedOsLoginServiceServer = src.UnimplementedOsLoginServiceServer

// A request message for updating an SSH public key.
//
// Deprecated: Please use types in: cloud.google.com/go/oslogin/apiv1/osloginpb
type UpdateSshPublicKeyRequest = src.UpdateSshPublicKeyRequest

// Deprecated: Please use funcs in: cloud.google.com/go/oslogin/apiv1/osloginpb
func NewOsLoginServiceClient(cc grpc.ClientConnInterface) OsLoginServiceClient {
	return src.NewOsLoginServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/oslogin/apiv1/osloginpb
func RegisterOsLoginServiceServer(s *grpc.Server, srv OsLoginServiceServer) {
	src.RegisterOsLoginServiceServer(s, srv)
}
