// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package admin aliases all exported identifiers in package
// "cloud.google.com/go/iam/admin/apiv1/adminpb".
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package admin

import (
	src "cloud.google.com/go/iam/admin/apiv1/adminpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/iam/admin/apiv1/adminpb
const (
	LintResult_CONDITION                                      = src.LintResult_CONDITION
	LintResult_DEPRECATED                                     = src.LintResult_DEPRECATED
	LintResult_ERROR                                          = src.LintResult_ERROR
	LintResult_INFO                                           = src.LintResult_INFO
	LintResult_LEVEL_UNSPECIFIED                              = src.LintResult_LEVEL_UNSPECIFIED
	LintResult_NOTICE                                         = src.LintResult_NOTICE
	LintResult_SEVERITY_UNSPECIFIED                           = src.LintResult_SEVERITY_UNSPECIFIED
	LintResult_WARNING                                        = src.LintResult_WARNING
	ListServiceAccountKeysRequest_KEY_TYPE_UNSPECIFIED        = src.ListServiceAccountKeysRequest_KEY_TYPE_UNSPECIFIED
	ListServiceAccountKeysRequest_SYSTEM_MANAGED              = src.ListServiceAccountKeysRequest_SYSTEM_MANAGED
	ListServiceAccountKeysRequest_USER_MANAGED                = src.ListServiceAccountKeysRequest_USER_MANAGED
	Permission_ALPHA                                          = src.Permission_ALPHA
	Permission_BETA                                           = src.Permission_BETA
	Permission_DEPRECATED                                     = src.Permission_DEPRECATED
	Permission_GA                                             = src.Permission_GA
	Permission_NOT_SUPPORTED                                  = src.Permission_NOT_SUPPORTED
	Permission_SUPPORTED                                      = src.Permission_SUPPORTED
	Permission_TESTING                                        = src.Permission_TESTING
	RoleView_BASIC                                            = src.RoleView_BASIC
	RoleView_FULL                                             = src.RoleView_FULL
	Role_ALPHA                                                = src.Role_ALPHA
	Role_BETA                                                 = src.Role_BETA
	Role_DEPRECATED                                           = src.Role_DEPRECATED
	Role_DISABLED                                             = src.Role_DISABLED
	Role_EAP                                                  = src.Role_EAP
	Role_GA                                                   = src.Role_GA
	ServiceAccountKeyAlgorithm_KEY_ALG_RSA_1024               = src.ServiceAccountKeyAlgorithm_KEY_ALG_RSA_1024
	ServiceAccountKeyAlgorithm_KEY_ALG_RSA_2048               = src.ServiceAccountKeyAlgorithm_KEY_ALG_RSA_2048
	ServiceAccountKeyAlgorithm_KEY_ALG_UNSPECIFIED            = src.ServiceAccountKeyAlgorithm_KEY_ALG_UNSPECIFIED
	ServiceAccountKeyOrigin_GOOGLE_PROVIDED                   = src.ServiceAccountKeyOrigin_GOOGLE_PROVIDED
	ServiceAccountKeyOrigin_ORIGIN_UNSPECIFIED                = src.ServiceAccountKeyOrigin_ORIGIN_UNSPECIFIED
	ServiceAccountKeyOrigin_USER_PROVIDED                     = src.ServiceAccountKeyOrigin_USER_PROVIDED
	ServiceAccountPrivateKeyType_TYPE_GOOGLE_CREDENTIALS_FILE = src.ServiceAccountPrivateKeyType_TYPE_GOOGLE_CREDENTIALS_FILE
	ServiceAccountPrivateKeyType_TYPE_PKCS12_FILE             = src.ServiceAccountPrivateKeyType_TYPE_PKCS12_FILE
	ServiceAccountPrivateKeyType_TYPE_UNSPECIFIED             = src.ServiceAccountPrivateKeyType_TYPE_UNSPECIFIED
	ServiceAccountPublicKeyType_TYPE_NONE                     = src.ServiceAccountPublicKeyType_TYPE_NONE
	ServiceAccountPublicKeyType_TYPE_RAW_PUBLIC_KEY           = src.ServiceAccountPublicKeyType_TYPE_RAW_PUBLIC_KEY
	ServiceAccountPublicKeyType_TYPE_X509_PEM_FILE            = src.ServiceAccountPublicKeyType_TYPE_X509_PEM_FILE
)

// Deprecated: Please use vars in: cloud.google.com/go/iam/admin/apiv1/adminpb
var (
	File_google_iam_admin_v1_audit_data_proto   = src.File_google_iam_admin_v1_audit_data_proto
	File_google_iam_admin_v1_iam_proto          = src.File_google_iam_admin_v1_iam_proto
	LintResult_Level_name                       = src.LintResult_Level_name
	LintResult_Level_value                      = src.LintResult_Level_value
	LintResult_Severity_name                    = src.LintResult_Severity_name
	LintResult_Severity_value                   = src.LintResult_Severity_value
	ListServiceAccountKeysRequest_KeyType_name  = src.ListServiceAccountKeysRequest_KeyType_name
	ListServiceAccountKeysRequest_KeyType_value = src.ListServiceAccountKeysRequest_KeyType_value
	Permission_CustomRolesSupportLevel_name     = src.Permission_CustomRolesSupportLevel_name
	Permission_CustomRolesSupportLevel_value    = src.Permission_CustomRolesSupportLevel_value
	Permission_PermissionLaunchStage_name       = src.Permission_PermissionLaunchStage_name
	Permission_PermissionLaunchStage_value      = src.Permission_PermissionLaunchStage_value
	RoleView_name                               = src.RoleView_name
	RoleView_value                              = src.RoleView_value
	Role_RoleLaunchStage_name                   = src.Role_RoleLaunchStage_name
	Role_RoleLaunchStage_value                  = src.Role_RoleLaunchStage_value
	ServiceAccountKeyAlgorithm_name             = src.ServiceAccountKeyAlgorithm_name
	ServiceAccountKeyAlgorithm_value            = src.ServiceAccountKeyAlgorithm_value
	ServiceAccountKeyOrigin_name                = src.ServiceAccountKeyOrigin_name
	ServiceAccountKeyOrigin_value               = src.ServiceAccountKeyOrigin_value
	ServiceAccountPrivateKeyType_name           = src.ServiceAccountPrivateKeyType_name
	ServiceAccountPrivateKeyType_value          = src.ServiceAccountPrivateKeyType_value
	ServiceAccountPublicKeyType_name            = src.ServiceAccountPublicKeyType_name
	ServiceAccountPublicKeyType_value           = src.ServiceAccountPublicKeyType_value
)

// Audit log information specific to Cloud IAM admin APIs. This message is
// serialized as an `Any` type in the `ServiceData` message of an `AuditLog`
// message.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type AuditData = src.AuditData

// A PermissionDelta message to record the added_permissions and
// removed_permissions inside a role.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type AuditData_PermissionDelta = src.AuditData_PermissionDelta

// The request to create a new role.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type CreateRoleRequest = src.CreateRoleRequest

// The service account key create request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type CreateServiceAccountKeyRequest = src.CreateServiceAccountKeyRequest

// The service account create request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type CreateServiceAccountRequest = src.CreateServiceAccountRequest

// The request to delete an existing role.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type DeleteRoleRequest = src.DeleteRoleRequest

// The service account key delete request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type DeleteServiceAccountKeyRequest = src.DeleteServiceAccountKeyRequest

// The service account delete request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type DeleteServiceAccountRequest = src.DeleteServiceAccountRequest

// The service account key disable request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type DisableServiceAccountKeyRequest = src.DisableServiceAccountKeyRequest

// The service account disable request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type DisableServiceAccountRequest = src.DisableServiceAccountRequest

// The service account key enable request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type EnableServiceAccountKeyRequest = src.EnableServiceAccountKeyRequest

// The service account enable request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type EnableServiceAccountRequest = src.EnableServiceAccountRequest

// The request to get the definition of an existing role.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type GetRoleRequest = src.GetRoleRequest

// The service account key get by id request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type GetServiceAccountKeyRequest = src.GetServiceAccountKeyRequest

// The service account get request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type GetServiceAccountRequest = src.GetServiceAccountRequest

// IAMClient is the client API for IAM service. For semantics around ctx use
// and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type IAMClient = src.IAMClient

// IAMServer is the server API for IAM service.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type IAMServer = src.IAMServer

// The request to lint a Cloud IAM policy object.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type LintPolicyRequest = src.LintPolicyRequest
type LintPolicyRequest_Condition = src.LintPolicyRequest_Condition

// The response of a lint operation. An empty response indicates the operation
// was able to fully execute and no lint issue was found.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type LintPolicyResponse = src.LintPolicyResponse

// Structured response of a single validation unit.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type LintResult = src.LintResult

// Possible Level values of a validation unit corresponding to its domain of
// discourse.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type LintResult_Level = src.LintResult_Level

// Possible Severity values of an issued result.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type LintResult_Severity = src.LintResult_Severity

// The request to get all roles defined under a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ListRolesRequest = src.ListRolesRequest

// The response containing the roles defined under a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ListRolesResponse = src.ListRolesResponse

// The service account keys list request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ListServiceAccountKeysRequest = src.ListServiceAccountKeysRequest

// `KeyType` filters to selectively retrieve certain varieties of keys.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ListServiceAccountKeysRequest_KeyType = src.ListServiceAccountKeysRequest_KeyType

// The service account keys list response.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ListServiceAccountKeysResponse = src.ListServiceAccountKeysResponse

// The service account list request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ListServiceAccountsRequest = src.ListServiceAccountsRequest

// The service account list response.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ListServiceAccountsResponse = src.ListServiceAccountsResponse

// The service account patch request. You can patch only the `display_name`
// and `description` fields. You must use the `update_mask` field to specify
// which of these fields you want to patch. Only the fields specified in the
// request are guaranteed to be returned in the response. Other fields may be
// empty in the response.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type PatchServiceAccountRequest = src.PatchServiceAccountRequest

// A permission which can be included by a role.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type Permission = src.Permission

// The state of the permission with regards to custom roles.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type Permission_CustomRolesSupportLevel = src.Permission_CustomRolesSupportLevel

// A stage representing a permission's lifecycle phase.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type Permission_PermissionLaunchStage = src.Permission_PermissionLaunchStage

// A request to get the list of auditable services for a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type QueryAuditableServicesRequest = src.QueryAuditableServicesRequest

// A response containing a list of auditable services for a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type QueryAuditableServicesResponse = src.QueryAuditableServicesResponse

// Contains information about an auditable service.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type QueryAuditableServicesResponse_AuditableService = src.QueryAuditableServicesResponse_AuditableService

// The grantable role query request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type QueryGrantableRolesRequest = src.QueryGrantableRolesRequest

// The grantable role query response.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type QueryGrantableRolesResponse = src.QueryGrantableRolesResponse

// A request to get permissions which can be tested on a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type QueryTestablePermissionsRequest = src.QueryTestablePermissionsRequest

// The response containing permissions which can be tested on a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type QueryTestablePermissionsResponse = src.QueryTestablePermissionsResponse

// A role in the Identity and Access Management API.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type Role = src.Role

// A view for Role objects.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type RoleView = src.RoleView

// A stage representing a role's lifecycle phase.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type Role_RoleLaunchStage = src.Role_RoleLaunchStage

// An IAM service account. A service account is an account for an application
// or a virtual machine (VM) instance, not a person. You can use a service
// account to call Google APIs. To learn more, read the [overview of service
// accounts](https://cloud.google.com/iam/help/service-accounts/overview). When
// you create a service account, you specify the project ID that owns the
// service account, as well as a name that must be unique within the project.
// IAM uses these values to create an email address that identifies the service
// account.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ServiceAccount = src.ServiceAccount

// Represents a service account key. A service account has two sets of
// key-pairs: user-managed, and system-managed. User-managed key-pairs can be
// created and deleted by users. Users are responsible for rotating these keys
// periodically to ensure security of their service accounts. Users retain the
// private key of these key-pairs, and Google retains ONLY the public key.
// System-managed keys are automatically rotated by Google, and are used for
// signing for a maximum of two weeks. The rotation process is probabilistic,
// and usage of the new key will gradually ramp up and down over the key's
// lifetime. If you cache the public key set for a service account, we
// recommend that you update the cache every 15 minutes. User-managed keys can
// be added and removed at any time, so it is important to update the cache
// frequently. For Google-managed keys, Google will publish a key at least 6
// hours before it is first used for signing and will keep publishing it for at
// least 6 hours after it was last used for signing. Public keys for all
// service accounts are also published at the OAuth2 Service Account API.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ServiceAccountKey = src.ServiceAccountKey

// Supported key algorithms.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ServiceAccountKeyAlgorithm = src.ServiceAccountKeyAlgorithm

// Service Account Key Origin.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ServiceAccountKeyOrigin = src.ServiceAccountKeyOrigin

// Supported private key output formats.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ServiceAccountPrivateKeyType = src.ServiceAccountPrivateKeyType

// Supported public key output formats.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type ServiceAccountPublicKeyType = src.ServiceAccountPublicKeyType

// Deprecated. [Migrate to Service Account Credentials
// API](https://cloud.google.com/iam/help/credentials/migrate-api). The service
// account sign blob request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type SignBlobRequest = src.SignBlobRequest

// Deprecated. [Migrate to Service Account Credentials
// API](https://cloud.google.com/iam/help/credentials/migrate-api). The service
// account sign blob response.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type SignBlobResponse = src.SignBlobResponse

// Deprecated. [Migrate to Service Account Credentials
// API](https://cloud.google.com/iam/help/credentials/migrate-api). The service
// account sign JWT request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type SignJwtRequest = src.SignJwtRequest

// Deprecated. [Migrate to Service Account Credentials
// API](https://cloud.google.com/iam/help/credentials/migrate-api). The service
// account sign JWT response.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type SignJwtResponse = src.SignJwtResponse

// The request to undelete an existing role.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type UndeleteRoleRequest = src.UndeleteRoleRequest

// The service account undelete request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type UndeleteServiceAccountRequest = src.UndeleteServiceAccountRequest
type UndeleteServiceAccountResponse = src.UndeleteServiceAccountResponse

// UnimplementedIAMServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type UnimplementedIAMServer = src.UnimplementedIAMServer

// The request to update a role.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type UpdateRoleRequest = src.UpdateRoleRequest

// The service account key upload request.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/admin/apiv1/adminpb
type UploadServiceAccountKeyRequest = src.UploadServiceAccountKeyRequest

// Deprecated: Please use funcs in: cloud.google.com/go/iam/admin/apiv1/adminpb
func NewIAMClient(cc grpc.ClientConnInterface) IAMClient { return src.NewIAMClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/iam/admin/apiv1/adminpb
func RegisterIAMServer(s *grpc.Server, srv IAMServer) { src.RegisterIAMServer(s, srv) }
