// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package notebooks aliases all exported identifiers in package
// "cloud.google.com/go/notebooks/apiv1beta1/notebookspb".
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package notebooks

import (
	src "cloud.google.com/go/notebooks/apiv1beta1/notebookspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
const (
	Instance_ACCELERATOR_TYPE_UNSPECIFIED = src.Instance_ACCELERATOR_TYPE_UNSPECIFIED
	Instance_ACTIVE                       = src.Instance_ACTIVE
	Instance_CMEK                         = src.Instance_CMEK
	Instance_DELETED                      = src.Instance_DELETED
	Instance_DISK_ENCRYPTION_UNSPECIFIED  = src.Instance_DISK_ENCRYPTION_UNSPECIFIED
	Instance_DISK_TYPE_UNSPECIFIED        = src.Instance_DISK_TYPE_UNSPECIFIED
	Instance_GMEK                         = src.Instance_GMEK
	Instance_INITIALIZING                 = src.Instance_INITIALIZING
	Instance_NVIDIA_TESLA_K80             = src.Instance_NVIDIA_TESLA_K80
	Instance_NVIDIA_TESLA_P100            = src.Instance_NVIDIA_TESLA_P100
	Instance_NVIDIA_TESLA_P100_VWS        = src.Instance_NVIDIA_TESLA_P100_VWS
	Instance_NVIDIA_TESLA_P4              = src.Instance_NVIDIA_TESLA_P4
	Instance_NVIDIA_TESLA_P4_VWS          = src.Instance_NVIDIA_TESLA_P4_VWS
	Instance_NVIDIA_TESLA_T4              = src.Instance_NVIDIA_TESLA_T4
	Instance_NVIDIA_TESLA_T4_VWS          = src.Instance_NVIDIA_TESLA_T4_VWS
	Instance_NVIDIA_TESLA_V100            = src.Instance_NVIDIA_TESLA_V100
	Instance_PD_BALANCED                  = src.Instance_PD_BALANCED
	Instance_PD_SSD                       = src.Instance_PD_SSD
	Instance_PD_STANDARD                  = src.Instance_PD_STANDARD
	Instance_PROVISIONING                 = src.Instance_PROVISIONING
	Instance_REGISTERING                  = src.Instance_REGISTERING
	Instance_STARTING                     = src.Instance_STARTING
	Instance_STATE_UNSPECIFIED            = src.Instance_STATE_UNSPECIFIED
	Instance_STOPPED                      = src.Instance_STOPPED
	Instance_STOPPING                     = src.Instance_STOPPING
	Instance_TPU_V2                       = src.Instance_TPU_V2
	Instance_TPU_V3                       = src.Instance_TPU_V3
	Instance_UPGRADING                    = src.Instance_UPGRADING
)

// Deprecated: Please use vars in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
var (
	File_google_cloud_notebooks_v1beta1_environment_proto = src.File_google_cloud_notebooks_v1beta1_environment_proto
	File_google_cloud_notebooks_v1beta1_instance_proto    = src.File_google_cloud_notebooks_v1beta1_instance_proto
	File_google_cloud_notebooks_v1beta1_service_proto     = src.File_google_cloud_notebooks_v1beta1_service_proto
	Instance_AcceleratorType_name                         = src.Instance_AcceleratorType_name
	Instance_AcceleratorType_value                        = src.Instance_AcceleratorType_value
	Instance_DiskEncryption_name                          = src.Instance_DiskEncryption_name
	Instance_DiskEncryption_value                         = src.Instance_DiskEncryption_value
	Instance_DiskType_name                                = src.Instance_DiskType_name
	Instance_DiskType_value                               = src.Instance_DiskType_value
	Instance_State_name                                   = src.Instance_State_name
	Instance_State_value                                  = src.Instance_State_value
)

// Definition of a container image for starting a notebook instance with the
// environment installed in a container.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type ContainerImage = src.ContainerImage

// Request for creating a notebook environment.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type CreateEnvironmentRequest = src.CreateEnvironmentRequest

// Request for creating a notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type CreateInstanceRequest = src.CreateInstanceRequest

// Request for deleting a notebook environment.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type DeleteEnvironmentRequest = src.DeleteEnvironmentRequest

// Request for deleting a notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type DeleteInstanceRequest = src.DeleteInstanceRequest

// Definition of a software environment that is used to start a notebook
// instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type Environment = src.Environment
type Environment_ContainerImage = src.Environment_ContainerImage
type Environment_VmImage = src.Environment_VmImage

// Request for getting a notebook environment.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type GetEnvironmentRequest = src.GetEnvironmentRequest

// Request for getting a notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type GetInstanceRequest = src.GetInstanceRequest

// The definition of a notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type Instance = src.Instance

// Definition of a hardware accelerator. Note that not all combinations of
// `type` and `core_count` are valid. Check [GPUs on Compute
// Engine](/compute/docs/gpus/#gpus-list) to find a valid combination. TPUs are
// not supported.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type Instance_AcceleratorConfig = src.Instance_AcceleratorConfig

// Definition of the types of hardware accelerators that can be used on this
// instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type Instance_AcceleratorType = src.Instance_AcceleratorType
type Instance_ContainerImage = src.Instance_ContainerImage

// Definition of the disk encryption options.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type Instance_DiskEncryption = src.Instance_DiskEncryption

// Possible disk types for notebook instances.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type Instance_DiskType = src.Instance_DiskType

// The definition of the states of this instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type Instance_State = src.Instance_State
type Instance_VmImage = src.Instance_VmImage

// Request for checking if a notebook instance is upgradeable.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type IsInstanceUpgradeableRequest = src.IsInstanceUpgradeableRequest

// Response for checking if a notebook instance is upgradeable.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type IsInstanceUpgradeableResponse = src.IsInstanceUpgradeableResponse

// Request for listing environments.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type ListEnvironmentsRequest = src.ListEnvironmentsRequest

// Response for listing environments.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type ListEnvironmentsResponse = src.ListEnvironmentsResponse

// Request for listing notebook instances.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type ListInstancesRequest = src.ListInstancesRequest

// Response for listing notebook instances.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type ListInstancesResponse = src.ListInstancesResponse

// NotebookServiceClient is the client API for NotebookService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type NotebookServiceClient = src.NotebookServiceClient

// NotebookServiceServer is the server API for NotebookService service.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type NotebookServiceServer = src.NotebookServiceServer

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type OperationMetadata = src.OperationMetadata

// Request for registering a notebook instance.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type RegisterInstanceRequest = src.RegisterInstanceRequest

// Request for notebook instances to report information to Notebooks API.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type ReportInstanceInfoRequest = src.ReportInstanceInfoRequest

// Request for reseting a notebook instance
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type ResetInstanceRequest = src.ResetInstanceRequest

// Request for setting instance accelerator.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type SetInstanceAcceleratorRequest = src.SetInstanceAcceleratorRequest

// Request for setting instance labels.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type SetInstanceLabelsRequest = src.SetInstanceLabelsRequest

// Request for setting instance machine type.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type SetInstanceMachineTypeRequest = src.SetInstanceMachineTypeRequest

// Request for starting a notebook instance
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type StartInstanceRequest = src.StartInstanceRequest

// Request for stopping a notebook instance
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type StopInstanceRequest = src.StopInstanceRequest

// UnimplementedNotebookServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type UnimplementedNotebookServiceServer = src.UnimplementedNotebookServiceServer

// Request for upgrading a notebook instance from within the VM
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type UpgradeInstanceInternalRequest = src.UpgradeInstanceInternalRequest

// Request for upgrading a notebook instance
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type UpgradeInstanceRequest = src.UpgradeInstanceRequest

// Definition of a custom Compute Engine virtual machine image for starting a
// notebook instance with the environment installed directly on the VM.
//
// Deprecated: Please use types in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
type VmImage = src.VmImage
type VmImage_ImageFamily = src.VmImage_ImageFamily
type VmImage_ImageName = src.VmImage_ImageName

// Deprecated: Please use funcs in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
func NewNotebookServiceClient(cc grpc.ClientConnInterface) NotebookServiceClient {
	return src.NewNotebookServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/notebooks/apiv1beta1/notebookspb
func RegisterNotebookServiceServer(s *grpc.Server, srv NotebookServiceServer) {
	src.RegisterNotebookServiceServer(s, srv)
}
