// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package trace aliases all exported identifiers in package
// "cloud.google.com/go/trace/apiv1/tracepb".
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package trace

import (
	src "cloud.google.com/go/trace/apiv1/tracepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/trace/apiv1/tracepb
const (
	ListTracesRequest_COMPLETE              = src.ListTracesRequest_COMPLETE
	ListTracesRequest_MINIMAL               = src.ListTracesRequest_MINIMAL
	ListTracesRequest_ROOTSPAN              = src.ListTracesRequest_ROOTSPAN
	ListTracesRequest_VIEW_TYPE_UNSPECIFIED = src.ListTracesRequest_VIEW_TYPE_UNSPECIFIED
	TraceSpan_RPC_CLIENT                    = src.TraceSpan_RPC_CLIENT
	TraceSpan_RPC_SERVER                    = src.TraceSpan_RPC_SERVER
	TraceSpan_SPAN_KIND_UNSPECIFIED         = src.TraceSpan_SPAN_KIND_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/trace/apiv1/tracepb
var (
	File_google_devtools_cloudtrace_v1_trace_proto = src.File_google_devtools_cloudtrace_v1_trace_proto
	ListTracesRequest_ViewType_name                = src.ListTracesRequest_ViewType_name
	ListTracesRequest_ViewType_value               = src.ListTracesRequest_ViewType_value
	TraceSpan_SpanKind_name                        = src.TraceSpan_SpanKind_name
	TraceSpan_SpanKind_value                       = src.TraceSpan_SpanKind_value
)

// The request message for the `GetTrace` method.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type GetTraceRequest = src.GetTraceRequest

// The request message for the `ListTraces` method. All fields are required
// unless specified.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type ListTracesRequest = src.ListTracesRequest

// Type of data returned for traces in the list.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type ListTracesRequest_ViewType = src.ListTracesRequest_ViewType

// The response message for the `ListTraces` method.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type ListTracesResponse = src.ListTracesResponse

// The request message for the `PatchTraces` method.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type PatchTracesRequest = src.PatchTracesRequest

// A trace describes how long it takes for an application to perform an
// operation. It consists of a set of spans, each of which represent a single
// timed event within the operation.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type Trace = src.Trace

// TraceServiceClient is the client API for TraceService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type TraceServiceClient = src.TraceServiceClient

// TraceServiceServer is the server API for TraceService service.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type TraceServiceServer = src.TraceServiceServer

// A span represents a single timed event within a trace. Spans can be nested
// and form a trace tree. Often, a trace contains a root span that describes
// the end-to-end latency of an operation and, optionally, one or more subspans
// for its suboperations. Spans do not need to be contiguous. There may be gaps
// between spans in a trace.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type TraceSpan = src.TraceSpan

// Type of span. Can be used to specify additional relationships between spans
// in addition to a parent/child relationship.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type TraceSpan_SpanKind = src.TraceSpan_SpanKind

// List of new or updated traces.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type Traces = src.Traces

// UnimplementedTraceServiceServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/trace/apiv1/tracepb
type UnimplementedTraceServiceServer = src.UnimplementedTraceServiceServer

// Deprecated: Please use funcs in: cloud.google.com/go/trace/apiv1/tracepb
func NewTraceServiceClient(cc grpc.ClientConnInterface) TraceServiceClient {
	return src.NewTraceServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/trace/apiv1/tracepb
func RegisterTraceServiceServer(s *grpc.Server, srv TraceServiceServer) {
	src.RegisterTraceServiceServer(s, srv)
}
