// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package iot aliases all exported identifiers in package
// "cloud.google.com/go/iot/apiv1/iotpb".
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package iot

import (
	src "cloud.google.com/go/iot/apiv1/iotpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/iot/apiv1/iotpb
const (
	GatewayAuthMethod_ASSOCIATION_AND_DEVICE_AUTH_TOKEN                  = src.GatewayAuthMethod_ASSOCIATION_AND_DEVICE_AUTH_TOKEN
	GatewayAuthMethod_ASSOCIATION_ONLY                                   = src.GatewayAuthMethod_ASSOCIATION_ONLY
	GatewayAuthMethod_DEVICE_AUTH_TOKEN_ONLY                             = src.GatewayAuthMethod_DEVICE_AUTH_TOKEN_ONLY
	GatewayAuthMethod_GATEWAY_AUTH_METHOD_UNSPECIFIED                    = src.GatewayAuthMethod_GATEWAY_AUTH_METHOD_UNSPECIFIED
	GatewayType_GATEWAY                                                  = src.GatewayType_GATEWAY
	GatewayType_GATEWAY_TYPE_UNSPECIFIED                                 = src.GatewayType_GATEWAY_TYPE_UNSPECIFIED
	GatewayType_NON_GATEWAY                                              = src.GatewayType_NON_GATEWAY
	HttpState_HTTP_DISABLED                                              = src.HttpState_HTTP_DISABLED
	HttpState_HTTP_ENABLED                                               = src.HttpState_HTTP_ENABLED
	HttpState_HTTP_STATE_UNSPECIFIED                                     = src.HttpState_HTTP_STATE_UNSPECIFIED
	LogLevel_DEBUG                                                       = src.LogLevel_DEBUG
	LogLevel_ERROR                                                       = src.LogLevel_ERROR
	LogLevel_INFO                                                        = src.LogLevel_INFO
	LogLevel_LOG_LEVEL_UNSPECIFIED                                       = src.LogLevel_LOG_LEVEL_UNSPECIFIED
	LogLevel_NONE                                                        = src.LogLevel_NONE
	MqttState_MQTT_DISABLED                                              = src.MqttState_MQTT_DISABLED
	MqttState_MQTT_ENABLED                                               = src.MqttState_MQTT_ENABLED
	MqttState_MQTT_STATE_UNSPECIFIED                                     = src.MqttState_MQTT_STATE_UNSPECIFIED
	PublicKeyCertificateFormat_UNSPECIFIED_PUBLIC_KEY_CERTIFICATE_FORMAT = src.PublicKeyCertificateFormat_UNSPECIFIED_PUBLIC_KEY_CERTIFICATE_FORMAT
	PublicKeyCertificateFormat_X509_CERTIFICATE_PEM                      = src.PublicKeyCertificateFormat_X509_CERTIFICATE_PEM
	PublicKeyFormat_ES256_PEM                                            = src.PublicKeyFormat_ES256_PEM
	PublicKeyFormat_ES256_X509_PEM                                       = src.PublicKeyFormat_ES256_X509_PEM
	PublicKeyFormat_RSA_PEM                                              = src.PublicKeyFormat_RSA_PEM
	PublicKeyFormat_RSA_X509_PEM                                         = src.PublicKeyFormat_RSA_X509_PEM
	PublicKeyFormat_UNSPECIFIED_PUBLIC_KEY_FORMAT                        = src.PublicKeyFormat_UNSPECIFIED_PUBLIC_KEY_FORMAT
)

// Deprecated: Please use vars in: cloud.google.com/go/iot/apiv1/iotpb
var (
	File_google_cloud_iot_v1_device_manager_proto = src.File_google_cloud_iot_v1_device_manager_proto
	File_google_cloud_iot_v1_resources_proto      = src.File_google_cloud_iot_v1_resources_proto
	GatewayAuthMethod_name                        = src.GatewayAuthMethod_name
	GatewayAuthMethod_value                       = src.GatewayAuthMethod_value
	GatewayType_name                              = src.GatewayType_name
	GatewayType_value                             = src.GatewayType_value
	HttpState_name                                = src.HttpState_name
	HttpState_value                               = src.HttpState_value
	LogLevel_name                                 = src.LogLevel_name
	LogLevel_value                                = src.LogLevel_value
	MqttState_name                                = src.MqttState_name
	MqttState_value                               = src.MqttState_value
	PublicKeyCertificateFormat_name               = src.PublicKeyCertificateFormat_name
	PublicKeyCertificateFormat_value              = src.PublicKeyCertificateFormat_value
	PublicKeyFormat_name                          = src.PublicKeyFormat_name
	PublicKeyFormat_value                         = src.PublicKeyFormat_value
)

// Request for `BindDeviceToGateway`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type BindDeviceToGatewayRequest = src.BindDeviceToGatewayRequest

// Response for `BindDeviceToGateway`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type BindDeviceToGatewayResponse = src.BindDeviceToGatewayResponse

// Request for `CreateDeviceRegistry`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type CreateDeviceRegistryRequest = src.CreateDeviceRegistryRequest

// Request for `CreateDevice`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type CreateDeviceRequest = src.CreateDeviceRequest

// Request for `DeleteDeviceRegistry`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type DeleteDeviceRegistryRequest = src.DeleteDeviceRegistryRequest

// Request for `DeleteDevice`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type DeleteDeviceRequest = src.DeleteDeviceRequest

// The device resource.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type Device = src.Device

// The device configuration. Eventually delivered to devices.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type DeviceConfig = src.DeviceConfig

// A server-stored device credential used for authentication.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type DeviceCredential = src.DeviceCredential
type DeviceCredential_PublicKey = src.DeviceCredential_PublicKey

// DeviceManagerClient is the client API for DeviceManager service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type DeviceManagerClient = src.DeviceManagerClient

// DeviceManagerServer is the server API for DeviceManager service.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type DeviceManagerServer = src.DeviceManagerServer

// A container for a group of devices.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type DeviceRegistry = src.DeviceRegistry

// The device state, as reported by the device.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type DeviceState = src.DeviceState

// The configuration for forwarding telemetry events.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type EventNotificationConfig = src.EventNotificationConfig

// The gateway authorization/authentication method. This setting determines
// how Cloud IoT Core authorizes/authenticate devices to access the gateway.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type GatewayAuthMethod = src.GatewayAuthMethod

// Gateway-related configuration and state.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type GatewayConfig = src.GatewayConfig

// Options for limiting the list based on gateway type and associations.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type GatewayListOptions = src.GatewayListOptions
type GatewayListOptions_AssociationsDeviceId = src.GatewayListOptions_AssociationsDeviceId
type GatewayListOptions_AssociationsGatewayId = src.GatewayListOptions_AssociationsGatewayId
type GatewayListOptions_GatewayType = src.GatewayListOptions_GatewayType

// Gateway type.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type GatewayType = src.GatewayType

// Request for `GetDeviceRegistry`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type GetDeviceRegistryRequest = src.GetDeviceRegistryRequest

// Request for `GetDevice`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type GetDeviceRequest = src.GetDeviceRequest

// The configuration of the HTTP bridge for a device registry.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type HttpConfig = src.HttpConfig

// Indicates whether DeviceService (HTTP) is enabled or disabled for the
// registry. See the field description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type HttpState = src.HttpState

// Request for `ListDeviceConfigVersions`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type ListDeviceConfigVersionsRequest = src.ListDeviceConfigVersionsRequest

// Response for `ListDeviceConfigVersions`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type ListDeviceConfigVersionsResponse = src.ListDeviceConfigVersionsResponse

// Request for `ListDeviceRegistries`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type ListDeviceRegistriesRequest = src.ListDeviceRegistriesRequest

// Response for `ListDeviceRegistries`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type ListDeviceRegistriesResponse = src.ListDeviceRegistriesResponse

// Request for `ListDeviceStates`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type ListDeviceStatesRequest = src.ListDeviceStatesRequest

// Response for `ListDeviceStates`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type ListDeviceStatesResponse = src.ListDeviceStatesResponse

// Request for `ListDevices`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type ListDevicesRequest = src.ListDevicesRequest

// Response for `ListDevices`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type ListDevicesResponse = src.ListDevicesResponse

// **Beta Feature** The logging verbosity for device activity. Specifies which
// events should be written to logs. For example, if the LogLevel is ERROR,
// only events that terminate in errors will be logged. LogLevel is inclusive;
// enabling INFO logging will also enable ERROR logging.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type LogLevel = src.LogLevel

// Request for `ModifyCloudToDeviceConfig`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type ModifyCloudToDeviceConfigRequest = src.ModifyCloudToDeviceConfigRequest

// The configuration of MQTT for a device registry.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type MqttConfig = src.MqttConfig

// Indicates whether an MQTT connection is enabled or disabled. See the field
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type MqttState = src.MqttState

// A public key certificate format and data.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type PublicKeyCertificate = src.PublicKeyCertificate

// The supported formats for the public key.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type PublicKeyCertificateFormat = src.PublicKeyCertificateFormat

// A public key format and data.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type PublicKeyCredential = src.PublicKeyCredential

// The supported formats for the public key.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type PublicKeyFormat = src.PublicKeyFormat

// A server-stored registry credential used to validate device credentials.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type RegistryCredential = src.RegistryCredential
type RegistryCredential_PublicKeyCertificate = src.RegistryCredential_PublicKeyCertificate

// Request for `SendCommandToDevice`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type SendCommandToDeviceRequest = src.SendCommandToDeviceRequest

// Response for `SendCommandToDevice`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type SendCommandToDeviceResponse = src.SendCommandToDeviceResponse

// The configuration for notification of new states received from the device.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type StateNotificationConfig = src.StateNotificationConfig

// Request for `UnbindDeviceFromGateway`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type UnbindDeviceFromGatewayRequest = src.UnbindDeviceFromGatewayRequest

// Response for `UnbindDeviceFromGateway`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type UnbindDeviceFromGatewayResponse = src.UnbindDeviceFromGatewayResponse

// UnimplementedDeviceManagerServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type UnimplementedDeviceManagerServer = src.UnimplementedDeviceManagerServer

// Request for `UpdateDeviceRegistry`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type UpdateDeviceRegistryRequest = src.UpdateDeviceRegistryRequest

// Request for `UpdateDevice`.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type UpdateDeviceRequest = src.UpdateDeviceRequest

// Details of an X.509 certificate. For informational purposes only.
//
// Deprecated: Please use types in: cloud.google.com/go/iot/apiv1/iotpb
type X509CertificateDetails = src.X509CertificateDetails

// Deprecated: Please use funcs in: cloud.google.com/go/iot/apiv1/iotpb
func NewDeviceManagerClient(cc grpc.ClientConnInterface) DeviceManagerClient {
	return src.NewDeviceManagerClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/iot/apiv1/iotpb
func RegisterDeviceManagerServer(s *grpc.Server, srv DeviceManagerServer) {
	src.RegisterDeviceManagerServer(s, srv)
}
