// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package recommender aliases all exported identifiers in package
// "cloud.google.com/go/recommender/apiv1/recommenderpb".
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package recommender

import (
	src "cloud.google.com/go/recommender/apiv1/recommenderpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/recommender/apiv1/recommenderpb
const (
	Impact_CATEGORY_UNSPECIFIED               = src.Impact_CATEGORY_UNSPECIFIED
	Impact_COST                               = src.Impact_COST
	Impact_MANAGEABILITY                      = src.Impact_MANAGEABILITY
	Impact_PERFORMANCE                        = src.Impact_PERFORMANCE
	Impact_SECURITY                           = src.Impact_SECURITY
	InsightStateInfo_ACCEPTED                 = src.InsightStateInfo_ACCEPTED
	InsightStateInfo_ACTIVE                   = src.InsightStateInfo_ACTIVE
	InsightStateInfo_DISMISSED                = src.InsightStateInfo_DISMISSED
	InsightStateInfo_STATE_UNSPECIFIED        = src.InsightStateInfo_STATE_UNSPECIFIED
	Insight_CATEGORY_UNSPECIFIED              = src.Insight_CATEGORY_UNSPECIFIED
	Insight_COST                              = src.Insight_COST
	Insight_CRITICAL                          = src.Insight_CRITICAL
	Insight_HIGH                              = src.Insight_HIGH
	Insight_LOW                               = src.Insight_LOW
	Insight_MANAGEABILITY                     = src.Insight_MANAGEABILITY
	Insight_MEDIUM                            = src.Insight_MEDIUM
	Insight_PERFORMANCE                       = src.Insight_PERFORMANCE
	Insight_SECURITY                          = src.Insight_SECURITY
	Insight_SEVERITY_UNSPECIFIED              = src.Insight_SEVERITY_UNSPECIFIED
	RecommendationStateInfo_ACTIVE            = src.RecommendationStateInfo_ACTIVE
	RecommendationStateInfo_CLAIMED           = src.RecommendationStateInfo_CLAIMED
	RecommendationStateInfo_DISMISSED         = src.RecommendationStateInfo_DISMISSED
	RecommendationStateInfo_FAILED            = src.RecommendationStateInfo_FAILED
	RecommendationStateInfo_STATE_UNSPECIFIED = src.RecommendationStateInfo_STATE_UNSPECIFIED
	RecommendationStateInfo_SUCCEEDED         = src.RecommendationStateInfo_SUCCEEDED
	Recommendation_P1                         = src.Recommendation_P1
	Recommendation_P2                         = src.Recommendation_P2
	Recommendation_P3                         = src.Recommendation_P3
	Recommendation_P4                         = src.Recommendation_P4
	Recommendation_PRIORITY_UNSPECIFIED       = src.Recommendation_PRIORITY_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/recommender/apiv1/recommenderpb
var (
	File_google_cloud_recommender_v1_insight_proto             = src.File_google_cloud_recommender_v1_insight_proto
	File_google_cloud_recommender_v1_insight_type_config_proto = src.File_google_cloud_recommender_v1_insight_type_config_proto
	File_google_cloud_recommender_v1_recommendation_proto      = src.File_google_cloud_recommender_v1_recommendation_proto
	File_google_cloud_recommender_v1_recommender_config_proto  = src.File_google_cloud_recommender_v1_recommender_config_proto
	File_google_cloud_recommender_v1_recommender_service_proto = src.File_google_cloud_recommender_v1_recommender_service_proto
	Impact_Category_name                                       = src.Impact_Category_name
	Impact_Category_value                                      = src.Impact_Category_value
	InsightStateInfo_State_name                                = src.InsightStateInfo_State_name
	InsightStateInfo_State_value                               = src.InsightStateInfo_State_value
	Insight_Category_name                                      = src.Insight_Category_name
	Insight_Category_value                                     = src.Insight_Category_value
	Insight_Severity_name                                      = src.Insight_Severity_name
	Insight_Severity_value                                     = src.Insight_Severity_value
	RecommendationStateInfo_State_name                         = src.RecommendationStateInfo_State_name
	RecommendationStateInfo_State_value                        = src.RecommendationStateInfo_State_value
	Recommendation_Priority_name                               = src.Recommendation_Priority_name
	Recommendation_Priority_value                              = src.Recommendation_Priority_value
)

// Contains metadata about how much money a recommendation can save or incur.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type CostProjection = src.CostProjection

// Request to the `GetInsight` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type GetInsightRequest = src.GetInsightRequest

// Request for the GetInsightTypeConfig` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type GetInsightTypeConfigRequest = src.GetInsightTypeConfigRequest

// Request to the `GetRecommendation` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type GetRecommendationRequest = src.GetRecommendationRequest

// Request for the GetRecommenderConfig` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type GetRecommenderConfigRequest = src.GetRecommenderConfigRequest

// Contains the impact a recommendation can have for a given category.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type Impact = src.Impact

// The category of the impact.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type Impact_Category = src.Impact_Category
type Impact_CostProjection = src.Impact_CostProjection
type Impact_SecurityProjection = src.Impact_SecurityProjection

// An insight along with the information used to derive the insight. The
// insight may have associated recomendations as well.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type Insight = src.Insight

// Information related to insight state.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type InsightStateInfo = src.InsightStateInfo

// Represents insight state.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type InsightStateInfo_State = src.InsightStateInfo_State

// Configuration for an InsightType.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type InsightTypeConfig = src.InsightTypeConfig

// A configuration to customize the generation of insights. Eg, customizing
// the lookback period considered when generating a insight.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type InsightTypeGenerationConfig = src.InsightTypeGenerationConfig

// Insight category.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type Insight_Category = src.Insight_Category

// Reference to an associated recommendation.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type Insight_RecommendationReference = src.Insight_RecommendationReference

// Insight severity levels.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type Insight_Severity = src.Insight_Severity

// Request for the `ListInsights` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type ListInsightsRequest = src.ListInsightsRequest

// Response to the `ListInsights` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type ListInsightsResponse = src.ListInsightsResponse

// Request for the `ListRecommendations` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type ListRecommendationsRequest = src.ListRecommendationsRequest

// Response to the `ListRecommendations` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type ListRecommendationsResponse = src.ListRecommendationsResponse

// Request for the `MarkInsightAccepted` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type MarkInsightAcceptedRequest = src.MarkInsightAcceptedRequest

// Request for the `MarkRecommendationClaimed` Method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type MarkRecommendationClaimedRequest = src.MarkRecommendationClaimedRequest

// Request for the `MarkRecommendationFailed` Method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type MarkRecommendationFailedRequest = src.MarkRecommendationFailedRequest

// Request for the `MarkRecommendationSucceeded` Method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type MarkRecommendationSucceededRequest = src.MarkRecommendationSucceededRequest

// Contains an operation for a resource loosely based on the JSON-PATCH format
// with support for: - Custom filters for describing partial array patch. -
// Extended path values for describing nested arrays. - Custom fields for
// describing the resource for which the operation is being described. - Allows
// extension to custom operations not natively supported by RFC6902. See
// https://tools.ietf.org/html/rfc6902 for details on the original RFC.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type Operation = src.Operation

// Group of operations that need to be performed atomically.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type OperationGroup = src.OperationGroup
type Operation_Value = src.Operation_Value
type Operation_ValueMatcher = src.Operation_ValueMatcher

// A recommendation along with a suggested action. E.g., a rightsizing
// recommendation for an underutilized VM, IAM role recommendations, etc
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type Recommendation = src.Recommendation

// Contains what resources are changing and how they are changing.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type RecommendationContent = src.RecommendationContent

// Information for state. Contains state and metadata.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type RecommendationStateInfo = src.RecommendationStateInfo

// Represents Recommendation State.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type RecommendationStateInfo_State = src.RecommendationStateInfo_State

// Reference to an associated insight.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type Recommendation_InsightReference = src.Recommendation_InsightReference

// Recommendation priority levels.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type Recommendation_Priority = src.Recommendation_Priority

// RecommenderClient is the client API for Recommender service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type RecommenderClient = src.RecommenderClient

// Configuration for a Recommender.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type RecommenderConfig = src.RecommenderConfig

// A Configuration to customize the generation of recommendations. Eg,
// customizing the lookback period considered when generating a recommendation.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type RecommenderGenerationConfig = src.RecommenderGenerationConfig

// RecommenderServer is the server API for Recommender service.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type RecommenderServer = src.RecommenderServer

// Contains various ways of describing the impact on Security.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type SecurityProjection = src.SecurityProjection

// UnimplementedRecommenderServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type UnimplementedRecommenderServer = src.UnimplementedRecommenderServer

// Request for the `UpdateInsightTypeConfig` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type UpdateInsightTypeConfigRequest = src.UpdateInsightTypeConfigRequest

// Request for the `UpdateRecommenderConfig` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type UpdateRecommenderConfigRequest = src.UpdateRecommenderConfigRequest

// Contains various matching options for values for a GCP resource field.
//
// Deprecated: Please use types in: cloud.google.com/go/recommender/apiv1/recommenderpb
type ValueMatcher = src.ValueMatcher
type ValueMatcher_MatchesPattern = src.ValueMatcher_MatchesPattern

// Deprecated: Please use funcs in: cloud.google.com/go/recommender/apiv1/recommenderpb
func NewRecommenderClient(cc grpc.ClientConnInterface) RecommenderClient {
	return src.NewRecommenderClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/recommender/apiv1/recommenderpb
func RegisterRecommenderServer(s *grpc.Server, srv RecommenderServer) {
	src.RegisterRecommenderServer(s, srv)
}
