// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package dataplex aliases all exported identifiers in package
// "cloud.google.com/go/dataplex/apiv1/dataplexpb".
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package dataplex

import (
	src "cloud.google.com/go/dataplex/apiv1/dataplexpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/dataplex/apiv1/dataplexpb
const (
	Action_CATEGORY_UNSPECIFIED                                 = src.Action_CATEGORY_UNSPECIFIED
	Action_DATA_DISCOVERY                                       = src.Action_DATA_DISCOVERY
	Action_IncompatibleDataSchema_INCOMPATIBLE                  = src.Action_IncompatibleDataSchema_INCOMPATIBLE
	Action_IncompatibleDataSchema_MODIFIED                      = src.Action_IncompatibleDataSchema_MODIFIED
	Action_IncompatibleDataSchema_SCHEMA_CHANGE_UNSPECIFIED     = src.Action_IncompatibleDataSchema_SCHEMA_CHANGE_UNSPECIFIED
	Action_InvalidDataPartition_CONSISTENT_KEYS                 = src.Action_InvalidDataPartition_CONSISTENT_KEYS
	Action_InvalidDataPartition_HIVE_STYLE_KEYS                 = src.Action_InvalidDataPartition_HIVE_STYLE_KEYS
	Action_InvalidDataPartition_PARTITION_STRUCTURE_UNSPECIFIED = src.Action_InvalidDataPartition_PARTITION_STRUCTURE_UNSPECIFIED
	Action_RESOURCE_MANAGEMENT                                  = src.Action_RESOURCE_MANAGEMENT
	Action_SECURITY_POLICY                                      = src.Action_SECURITY_POLICY
	Asset_DiscoveryStatus_DISABLED                              = src.Asset_DiscoveryStatus_DISABLED
	Asset_DiscoveryStatus_IN_PROGRESS                           = src.Asset_DiscoveryStatus_IN_PROGRESS
	Asset_DiscoveryStatus_PAUSED                                = src.Asset_DiscoveryStatus_PAUSED
	Asset_DiscoveryStatus_SCHEDULED                             = src.Asset_DiscoveryStatus_SCHEDULED
	Asset_DiscoveryStatus_STATE_UNSPECIFIED                     = src.Asset_DiscoveryStatus_STATE_UNSPECIFIED
	Asset_ResourceSpec_BIGQUERY_DATASET                         = src.Asset_ResourceSpec_BIGQUERY_DATASET
	Asset_ResourceSpec_STORAGE_BUCKET                           = src.Asset_ResourceSpec_STORAGE_BUCKET
	Asset_ResourceSpec_TYPE_UNSPECIFIED                         = src.Asset_ResourceSpec_TYPE_UNSPECIFIED
	Asset_ResourceStatus_ERROR                                  = src.Asset_ResourceStatus_ERROR
	Asset_ResourceStatus_READY                                  = src.Asset_ResourceStatus_READY
	Asset_ResourceStatus_STATE_UNSPECIFIED                      = src.Asset_ResourceStatus_STATE_UNSPECIFIED
	Asset_SecurityStatus_APPLYING                               = src.Asset_SecurityStatus_APPLYING
	Asset_SecurityStatus_ERROR                                  = src.Asset_SecurityStatus_ERROR
	Asset_SecurityStatus_READY                                  = src.Asset_SecurityStatus_READY
	Asset_SecurityStatus_STATE_UNSPECIFIED                      = src.Asset_SecurityStatus_STATE_UNSPECIFIED
	Content_Notebook_KERNEL_TYPE_UNSPECIFIED                    = src.Content_Notebook_KERNEL_TYPE_UNSPECIFIED
	Content_Notebook_PYTHON3                                    = src.Content_Notebook_PYTHON3
	Content_SqlScript_QUERY_ENGINE_UNSPECIFIED                  = src.Content_SqlScript_QUERY_ENGINE_UNSPECIFIED
	Content_SqlScript_SPARK                                     = src.Content_SqlScript_SPARK
	DiscoveryEvent_CONFIG                                       = src.DiscoveryEvent_CONFIG
	DiscoveryEvent_ENTITY_CREATED                               = src.DiscoveryEvent_ENTITY_CREATED
	DiscoveryEvent_ENTITY_DELETED                               = src.DiscoveryEvent_ENTITY_DELETED
	DiscoveryEvent_ENTITY_TYPE_UNSPECIFIED                      = src.DiscoveryEvent_ENTITY_TYPE_UNSPECIFIED
	DiscoveryEvent_ENTITY_UPDATED                               = src.DiscoveryEvent_ENTITY_UPDATED
	DiscoveryEvent_EVENT_TYPE_UNSPECIFIED                       = src.DiscoveryEvent_EVENT_TYPE_UNSPECIFIED
	DiscoveryEvent_FILESET                                      = src.DiscoveryEvent_FILESET
	DiscoveryEvent_PARTITION_CREATED                            = src.DiscoveryEvent_PARTITION_CREATED
	DiscoveryEvent_PARTITION_DELETED                            = src.DiscoveryEvent_PARTITION_DELETED
	DiscoveryEvent_PARTITION_UPDATED                            = src.DiscoveryEvent_PARTITION_UPDATED
	DiscoveryEvent_TABLE                                        = src.DiscoveryEvent_TABLE
	Entity_FILESET                                              = src.Entity_FILESET
	Entity_TABLE                                                = src.Entity_TABLE
	Entity_TYPE_UNSPECIFIED                                     = src.Entity_TYPE_UNSPECIFIED
	GetEntityRequest_BASIC                                      = src.GetEntityRequest_BASIC
	GetEntityRequest_ENTITY_VIEW_UNSPECIFIED                    = src.GetEntityRequest_ENTITY_VIEW_UNSPECIFIED
	GetEntityRequest_FULL                                       = src.GetEntityRequest_FULL
	GetEntityRequest_SCHEMA                                     = src.GetEntityRequest_SCHEMA
	JobEvent_ABORTED                                            = src.JobEvent_ABORTED
	JobEvent_CANCELLED                                          = src.JobEvent_CANCELLED
	JobEvent_DATAPROC                                           = src.JobEvent_DATAPROC
	JobEvent_FAILED                                             = src.JobEvent_FAILED
	JobEvent_NOTEBOOK                                           = src.JobEvent_NOTEBOOK
	JobEvent_SERVICE_UNSPECIFIED                                = src.JobEvent_SERVICE_UNSPECIFIED
	JobEvent_SPARK                                              = src.JobEvent_SPARK
	JobEvent_STATE_UNSPECIFIED                                  = src.JobEvent_STATE_UNSPECIFIED
	JobEvent_SUCCEEDED                                          = src.JobEvent_SUCCEEDED
	JobEvent_TYPE_UNSPECIFIED                                   = src.JobEvent_TYPE_UNSPECIFIED
	Job_ABORTED                                                 = src.Job_ABORTED
	Job_CANCELLED                                               = src.Job_CANCELLED
	Job_CANCELLING                                              = src.Job_CANCELLING
	Job_DATAPROC                                                = src.Job_DATAPROC
	Job_FAILED                                                  = src.Job_FAILED
	Job_RUNNING                                                 = src.Job_RUNNING
	Job_SERVICE_UNSPECIFIED                                     = src.Job_SERVICE_UNSPECIFIED
	Job_STATE_UNSPECIFIED                                       = src.Job_STATE_UNSPECIFIED
	Job_SUCCEEDED                                               = src.Job_SUCCEEDED
	Lake_MetastoreStatus_ERROR                                  = src.Lake_MetastoreStatus_ERROR
	Lake_MetastoreStatus_NONE                                   = src.Lake_MetastoreStatus_NONE
	Lake_MetastoreStatus_READY                                  = src.Lake_MetastoreStatus_READY
	Lake_MetastoreStatus_STATE_UNSPECIFIED                      = src.Lake_MetastoreStatus_STATE_UNSPECIFIED
	Lake_MetastoreStatus_UPDATING                               = src.Lake_MetastoreStatus_UPDATING
	ListEntitiesRequest_ENTITY_VIEW_UNSPECIFIED                 = src.ListEntitiesRequest_ENTITY_VIEW_UNSPECIFIED
	ListEntitiesRequest_FILESETS                                = src.ListEntitiesRequest_FILESETS
	ListEntitiesRequest_TABLES                                  = src.ListEntitiesRequest_TABLES
	Schema_BINARY                                               = src.Schema_BINARY
	Schema_BOOLEAN                                              = src.Schema_BOOLEAN
	Schema_BYTE                                                 = src.Schema_BYTE
	Schema_DATE                                                 = src.Schema_DATE
	Schema_DECIMAL                                              = src.Schema_DECIMAL
	Schema_DOUBLE                                               = src.Schema_DOUBLE
	Schema_FLOAT                                                = src.Schema_FLOAT
	Schema_HIVE_COMPATIBLE                                      = src.Schema_HIVE_COMPATIBLE
	Schema_INT16                                                = src.Schema_INT16
	Schema_INT32                                                = src.Schema_INT32
	Schema_INT64                                                = src.Schema_INT64
	Schema_MODE_UNSPECIFIED                                     = src.Schema_MODE_UNSPECIFIED
	Schema_NULL                                                 = src.Schema_NULL
	Schema_NULLABLE                                             = src.Schema_NULLABLE
	Schema_PARTITION_STYLE_UNSPECIFIED                          = src.Schema_PARTITION_STYLE_UNSPECIFIED
	Schema_RECORD                                               = src.Schema_RECORD
	Schema_REPEATED                                             = src.Schema_REPEATED
	Schema_REQUIRED                                             = src.Schema_REQUIRED
	Schema_STRING                                               = src.Schema_STRING
	Schema_TIME                                                 = src.Schema_TIME
	Schema_TIMESTAMP                                            = src.Schema_TIMESTAMP
	Schema_TYPE_UNSPECIFIED                                     = src.Schema_TYPE_UNSPECIFIED
	SessionEvent_CREATE                                         = src.SessionEvent_CREATE
	SessionEvent_EVENT_TYPE_UNSPECIFIED                         = src.SessionEvent_EVENT_TYPE_UNSPECIFIED
	SessionEvent_QUERY                                          = src.SessionEvent_QUERY
	SessionEvent_QueryDetail_BIGQUERY                           = src.SessionEvent_QueryDetail_BIGQUERY
	SessionEvent_QueryDetail_ENGINE_UNSPECIFIED                 = src.SessionEvent_QueryDetail_ENGINE_UNSPECIFIED
	SessionEvent_QueryDetail_SPARK_SQL                          = src.SessionEvent_QueryDetail_SPARK_SQL
	SessionEvent_START                                          = src.SessionEvent_START
	SessionEvent_STOP                                           = src.SessionEvent_STOP
	State_ACTION_REQUIRED                                       = src.State_ACTION_REQUIRED
	State_ACTIVE                                                = src.State_ACTIVE
	State_CREATING                                              = src.State_CREATING
	State_DELETING                                              = src.State_DELETING
	State_STATE_UNSPECIFIED                                     = src.State_STATE_UNSPECIFIED
	StorageFormat_AUDIO                                         = src.StorageFormat_AUDIO
	StorageFormat_AVRO                                          = src.StorageFormat_AVRO
	StorageFormat_BZIP2                                         = src.StorageFormat_BZIP2
	StorageFormat_COMPRESSION_FORMAT_UNSPECIFIED                = src.StorageFormat_COMPRESSION_FORMAT_UNSPECIFIED
	StorageFormat_CSV                                           = src.StorageFormat_CSV
	StorageFormat_FORMAT_UNSPECIFIED                            = src.StorageFormat_FORMAT_UNSPECIFIED
	StorageFormat_GZIP                                          = src.StorageFormat_GZIP
	StorageFormat_IMAGE                                         = src.StorageFormat_IMAGE
	StorageFormat_JSON                                          = src.StorageFormat_JSON
	StorageFormat_ORC                                           = src.StorageFormat_ORC
	StorageFormat_OTHER                                         = src.StorageFormat_OTHER
	StorageFormat_PARQUET                                       = src.StorageFormat_PARQUET
	StorageFormat_TEXT                                          = src.StorageFormat_TEXT
	StorageFormat_TFRECORD                                      = src.StorageFormat_TFRECORD
	StorageFormat_UNKNOWN                                       = src.StorageFormat_UNKNOWN
	StorageFormat_VIDEO                                         = src.StorageFormat_VIDEO
	StorageSystem_BIGQUERY                                      = src.StorageSystem_BIGQUERY
	StorageSystem_CLOUD_STORAGE                                 = src.StorageSystem_CLOUD_STORAGE
	StorageSystem_STORAGE_SYSTEM_UNSPECIFIED                    = src.StorageSystem_STORAGE_SYSTEM_UNSPECIFIED
	Task_TriggerSpec_ON_DEMAND                                  = src.Task_TriggerSpec_ON_DEMAND
	Task_TriggerSpec_RECURRING                                  = src.Task_TriggerSpec_RECURRING
	Task_TriggerSpec_TYPE_UNSPECIFIED                           = src.Task_TriggerSpec_TYPE_UNSPECIFIED
	Zone_CURATED                                                = src.Zone_CURATED
	Zone_RAW                                                    = src.Zone_RAW
	Zone_ResourceSpec_LOCATION_TYPE_UNSPECIFIED                 = src.Zone_ResourceSpec_LOCATION_TYPE_UNSPECIFIED
	Zone_ResourceSpec_MULTI_REGION                              = src.Zone_ResourceSpec_MULTI_REGION
	Zone_ResourceSpec_SINGLE_REGION                             = src.Zone_ResourceSpec_SINGLE_REGION
	Zone_TYPE_UNSPECIFIED                                       = src.Zone_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/dataplex/apiv1/dataplexpb
var (
	Action_Category_name                                 = src.Action_Category_name
	Action_Category_value                                = src.Action_Category_value
	Action_IncompatibleDataSchema_SchemaChange_name      = src.Action_IncompatibleDataSchema_SchemaChange_name
	Action_IncompatibleDataSchema_SchemaChange_value     = src.Action_IncompatibleDataSchema_SchemaChange_value
	Action_InvalidDataPartition_PartitionStructure_name  = src.Action_InvalidDataPartition_PartitionStructure_name
	Action_InvalidDataPartition_PartitionStructure_value = src.Action_InvalidDataPartition_PartitionStructure_value
	Asset_DiscoveryStatus_State_name                     = src.Asset_DiscoveryStatus_State_name
	Asset_DiscoveryStatus_State_value                    = src.Asset_DiscoveryStatus_State_value
	Asset_ResourceSpec_Type_name                         = src.Asset_ResourceSpec_Type_name
	Asset_ResourceSpec_Type_value                        = src.Asset_ResourceSpec_Type_value
	Asset_ResourceStatus_State_name                      = src.Asset_ResourceStatus_State_name
	Asset_ResourceStatus_State_value                     = src.Asset_ResourceStatus_State_value
	Asset_SecurityStatus_State_name                      = src.Asset_SecurityStatus_State_name
	Asset_SecurityStatus_State_value                     = src.Asset_SecurityStatus_State_value
	Content_Notebook_KernelType_name                     = src.Content_Notebook_KernelType_name
	Content_Notebook_KernelType_value                    = src.Content_Notebook_KernelType_value
	Content_SqlScript_QueryEngine_name                   = src.Content_SqlScript_QueryEngine_name
	Content_SqlScript_QueryEngine_value                  = src.Content_SqlScript_QueryEngine_value
	DiscoveryEvent_EntityType_name                       = src.DiscoveryEvent_EntityType_name
	DiscoveryEvent_EntityType_value                      = src.DiscoveryEvent_EntityType_value
	DiscoveryEvent_EventType_name                        = src.DiscoveryEvent_EventType_name
	DiscoveryEvent_EventType_value                       = src.DiscoveryEvent_EventType_value
	Entity_Type_name                                     = src.Entity_Type_name
	Entity_Type_value                                    = src.Entity_Type_value
	File_google_cloud_dataplex_v1_analyze_proto          = src.File_google_cloud_dataplex_v1_analyze_proto
	File_google_cloud_dataplex_v1_content_proto          = src.File_google_cloud_dataplex_v1_content_proto
	File_google_cloud_dataplex_v1_logs_proto             = src.File_google_cloud_dataplex_v1_logs_proto
	File_google_cloud_dataplex_v1_metadata_proto         = src.File_google_cloud_dataplex_v1_metadata_proto
	File_google_cloud_dataplex_v1_resources_proto        = src.File_google_cloud_dataplex_v1_resources_proto
	File_google_cloud_dataplex_v1_service_proto          = src.File_google_cloud_dataplex_v1_service_proto
	File_google_cloud_dataplex_v1_tasks_proto            = src.File_google_cloud_dataplex_v1_tasks_proto
	GetEntityRequest_EntityView_name                     = src.GetEntityRequest_EntityView_name
	GetEntityRequest_EntityView_value                    = src.GetEntityRequest_EntityView_value
	JobEvent_Service_name                                = src.JobEvent_Service_name
	JobEvent_Service_value                               = src.JobEvent_Service_value
	JobEvent_State_name                                  = src.JobEvent_State_name
	JobEvent_State_value                                 = src.JobEvent_State_value
	JobEvent_Type_name                                   = src.JobEvent_Type_name
	JobEvent_Type_value                                  = src.JobEvent_Type_value
	Job_Service_name                                     = src.Job_Service_name
	Job_Service_value                                    = src.Job_Service_value
	Job_State_name                                       = src.Job_State_name
	Job_State_value                                      = src.Job_State_value
	Lake_MetastoreStatus_State_name                      = src.Lake_MetastoreStatus_State_name
	Lake_MetastoreStatus_State_value                     = src.Lake_MetastoreStatus_State_value
	ListEntitiesRequest_EntityView_name                  = src.ListEntitiesRequest_EntityView_name
	ListEntitiesRequest_EntityView_value                 = src.ListEntitiesRequest_EntityView_value
	Schema_Mode_name                                     = src.Schema_Mode_name
	Schema_Mode_value                                    = src.Schema_Mode_value
	Schema_PartitionStyle_name                           = src.Schema_PartitionStyle_name
	Schema_PartitionStyle_value                          = src.Schema_PartitionStyle_value
	Schema_Type_name                                     = src.Schema_Type_name
	Schema_Type_value                                    = src.Schema_Type_value
	SessionEvent_EventType_name                          = src.SessionEvent_EventType_name
	SessionEvent_EventType_value                         = src.SessionEvent_EventType_value
	SessionEvent_QueryDetail_Engine_name                 = src.SessionEvent_QueryDetail_Engine_name
	SessionEvent_QueryDetail_Engine_value                = src.SessionEvent_QueryDetail_Engine_value
	State_name                                           = src.State_name
	State_value                                          = src.State_value
	StorageFormat_CompressionFormat_name                 = src.StorageFormat_CompressionFormat_name
	StorageFormat_CompressionFormat_value                = src.StorageFormat_CompressionFormat_value
	StorageFormat_Format_name                            = src.StorageFormat_Format_name
	StorageFormat_Format_value                           = src.StorageFormat_Format_value
	StorageSystem_name                                   = src.StorageSystem_name
	StorageSystem_value                                  = src.StorageSystem_value
	Task_TriggerSpec_Type_name                           = src.Task_TriggerSpec_Type_name
	Task_TriggerSpec_Type_value                          = src.Task_TriggerSpec_Type_value
	Zone_ResourceSpec_LocationType_name                  = src.Zone_ResourceSpec_LocationType_name
	Zone_ResourceSpec_LocationType_value                 = src.Zone_ResourceSpec_LocationType_value
	Zone_Type_name                                       = src.Zone_Type_name
	Zone_Type_value                                      = src.Zone_Type_value
)

// Action represents an issue requiring administrator action for resolution.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action = src.Action

// The category of issues.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_Category = src.Action_Category

// Failed to apply security policy to the managed resource(s) under a lake,
// zone or an asset. For a lake or zone resource, one or more underlying assets
// has a failure applying security policy to the associated managed resource.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_FailedSecurityPolicyApply = src.Action_FailedSecurityPolicyApply
type Action_FailedSecurityPolicyApply_ = src.Action_FailedSecurityPolicyApply_

// Action details for incompatible schemas detected by discovery.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_IncompatibleDataSchema = src.Action_IncompatibleDataSchema
type Action_IncompatibleDataSchema_ = src.Action_IncompatibleDataSchema_

// Whether the action relates to a schema that is incompatible or modified.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_IncompatibleDataSchema_SchemaChange = src.Action_IncompatibleDataSchema_SchemaChange

// Action details for invalid or unsupported data files detected by discovery.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_InvalidDataFormat = src.Action_InvalidDataFormat
type Action_InvalidDataFormat_ = src.Action_InvalidDataFormat_

// Action details for invalid data arrangement.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_InvalidDataOrganization = src.Action_InvalidDataOrganization
type Action_InvalidDataOrganization_ = src.Action_InvalidDataOrganization_

// Action details for invalid or unsupported partitions detected by discovery.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_InvalidDataPartition = src.Action_InvalidDataPartition
type Action_InvalidDataPartition_ = src.Action_InvalidDataPartition_

// The expected partition structure.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_InvalidDataPartition_PartitionStructure = src.Action_InvalidDataPartition_PartitionStructure

// Action details for absence of data detected by discovery.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_MissingData = src.Action_MissingData
type Action_MissingData_ = src.Action_MissingData_

// Action details for resource references in assets that cannot be located.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_MissingResource = src.Action_MissingResource
type Action_MissingResource_ = src.Action_MissingResource_

// Action details for unauthorized resource issues raised to indicate that the
// service account associated with the lake instance is not authorized to
// access or manage the resource associated with an asset.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Action_UnauthorizedResource = src.Action_UnauthorizedResource
type Action_UnauthorizedResource_ = src.Action_UnauthorizedResource_

// An asset represents a cloud resource that is being managed within a lake as
// a member of a zone.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset = src.Asset

// Aggregated status of the underlying assets of a lake or zone.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type AssetStatus = src.AssetStatus

// Settings to manage the metadata discovery and publishing for an asset.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_DiscoverySpec = src.Asset_DiscoverySpec

// Describe CSV and similar semi-structured data formats.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_DiscoverySpec_CsvOptions = src.Asset_DiscoverySpec_CsvOptions

// Describe JSON data format.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_DiscoverySpec_JsonOptions = src.Asset_DiscoverySpec_JsonOptions
type Asset_DiscoverySpec_Schedule = src.Asset_DiscoverySpec_Schedule

// Status of discovery for an asset.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_DiscoveryStatus = src.Asset_DiscoveryStatus

// Current state of discovery.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_DiscoveryStatus_State = src.Asset_DiscoveryStatus_State

// The aggregated data statistics for the asset reported by discovery.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_DiscoveryStatus_Stats = src.Asset_DiscoveryStatus_Stats

// Identifies the cloud resource that is referenced by this asset.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_ResourceSpec = src.Asset_ResourceSpec

// Type of resource.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_ResourceSpec_Type = src.Asset_ResourceSpec_Type

// Status of the resource referenced by an asset.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_ResourceStatus = src.Asset_ResourceStatus

// The state of a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_ResourceStatus_State = src.Asset_ResourceStatus_State

// Security policy status of the asset. Data security policy, i.e., readers,
// writers & owners, should be specified in the lake/zone/asset IAM policy.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_SecurityStatus = src.Asset_SecurityStatus

// The state of the security policy.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Asset_SecurityStatus_State = src.Asset_SecurityStatus_State

// Cancel task jobs.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type CancelJobRequest = src.CancelJobRequest

// Content represents a user-visible notebook or a sql script
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Content = src.Content

// ContentServiceClient is the client API for ContentService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ContentServiceClient = src.ContentServiceClient

// ContentServiceServer is the server API for ContentService service.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ContentServiceServer = src.ContentServiceServer
type Content_DataText = src.Content_DataText

// Configuration for Notebook content.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Content_Notebook = src.Content_Notebook
type Content_Notebook_ = src.Content_Notebook_

// Kernel Type of the Jupyter notebook.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Content_Notebook_KernelType = src.Content_Notebook_KernelType

// Configuration for the Sql Script content.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Content_SqlScript = src.Content_SqlScript
type Content_SqlScript_ = src.Content_SqlScript_

// Query Engine Type of the SQL Script.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Content_SqlScript_QueryEngine = src.Content_SqlScript_QueryEngine

// Create asset request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type CreateAssetRequest = src.CreateAssetRequest

// Create a metadata entity request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type CreateEntityRequest = src.CreateEntityRequest

// Create lake request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type CreateLakeRequest = src.CreateLakeRequest

// Create metadata partition request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type CreatePartitionRequest = src.CreatePartitionRequest

// Create task request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type CreateTaskRequest = src.CreateTaskRequest

// Create zone request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type CreateZoneRequest = src.CreateZoneRequest

// DataplexServiceClient is the client API for DataplexService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DataplexServiceClient = src.DataplexServiceClient

// DataplexServiceServer is the server API for DataplexService service.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DataplexServiceServer = src.DataplexServiceServer

// Delete asset request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DeleteAssetRequest = src.DeleteAssetRequest

// Delete a metadata entity request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DeleteEntityRequest = src.DeleteEntityRequest

// Delete lake request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DeleteLakeRequest = src.DeleteLakeRequest

// Delete metadata partition request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DeletePartitionRequest = src.DeletePartitionRequest

// Delete task request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DeleteTaskRequest = src.DeleteTaskRequest

// Delete zone request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DeleteZoneRequest = src.DeleteZoneRequest

// The payload associated with Discovery data processing.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DiscoveryEvent = src.DiscoveryEvent
type DiscoveryEvent_Action = src.DiscoveryEvent_Action

// Details about the action.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DiscoveryEvent_ActionDetails = src.DiscoveryEvent_ActionDetails
type DiscoveryEvent_Config = src.DiscoveryEvent_Config

// Details about configuration events.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DiscoveryEvent_ConfigDetails = src.DiscoveryEvent_ConfigDetails
type DiscoveryEvent_Entity = src.DiscoveryEvent_Entity

// Details about the entity.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DiscoveryEvent_EntityDetails = src.DiscoveryEvent_EntityDetails

// The type of the entity.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DiscoveryEvent_EntityType = src.DiscoveryEvent_EntityType

// The type of the event.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DiscoveryEvent_EventType = src.DiscoveryEvent_EventType
type DiscoveryEvent_Partition = src.DiscoveryEvent_Partition

// Details about the partition.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type DiscoveryEvent_PartitionDetails = src.DiscoveryEvent_PartitionDetails

// Represents tables and fileset metadata contained within a zone.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Entity = src.Entity

// Provides compatibility information for various metadata stores.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Entity_CompatibilityStatus = src.Entity_CompatibilityStatus

// Provides compatibility information for a specific metadata store.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Entity_CompatibilityStatus_Compatibility = src.Entity_CompatibilityStatus_Compatibility

// The type of entity.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Entity_Type = src.Entity_Type

// Environment represents a user-visible compute infrastructure for analytics
// within a lake.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Environment = src.Environment
type Environment_Endpoints = src.Environment_Endpoints

// Configuration for the underlying infrastructure used to run workloads.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Environment_InfrastructureSpec = src.Environment_InfrastructureSpec
type Environment_InfrastructureSpec_Compute = src.Environment_InfrastructureSpec_Compute

// Compute resources associated with the analyze interactive workloads.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Environment_InfrastructureSpec_ComputeResources = src.Environment_InfrastructureSpec_ComputeResources
type Environment_InfrastructureSpec_OsImage = src.Environment_InfrastructureSpec_OsImage

// Software Runtime Configuration to run Analyze.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Environment_InfrastructureSpec_OsImageRuntime = src.Environment_InfrastructureSpec_OsImageRuntime
type Environment_SessionSpec = src.Environment_SessionSpec
type Environment_SessionStatus = src.Environment_SessionStatus

// Get asset request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type GetAssetRequest = src.GetAssetRequest

// Get metadata entity request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type GetEntityRequest = src.GetEntityRequest

// Entity views for get entity partial result.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type GetEntityRequest_EntityView = src.GetEntityRequest_EntityView

// Get job request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type GetJobRequest = src.GetJobRequest

// Get lake request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type GetLakeRequest = src.GetLakeRequest

// Get metadata partition request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type GetPartitionRequest = src.GetPartitionRequest

// Get task request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type GetTaskRequest = src.GetTaskRequest

// Get zone request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type GetZoneRequest = src.GetZoneRequest

// A job represents an instance of a task.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Job = src.Job

// The payload associated with Job logs that contains events describing jobs
// that have run within a Lake.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type JobEvent = src.JobEvent

// The service used to execute the job.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type JobEvent_Service = src.JobEvent_Service

// The completion status of the job.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type JobEvent_State = src.JobEvent_State

// The type of the job.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type JobEvent_Type = src.JobEvent_Type
type Job_Service = src.Job_Service
type Job_State = src.Job_State

// A lake is a centralized repository for managing enterprise data across the
// organization distributed across many cloud projects, and stored in a variety
// of storage services such as Google Cloud Storage and BigQuery. The resources
// attached to a lake are referred to as managed resources. Data within these
// managed resources can be structured or unstructured. A lake provides data
// admins with tools to organize, secure and manage their data at scale, and
// provides data scientists and data engineers an integrated experience to
// easily search, discover, analyze and transform data and associated metadata.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Lake = src.Lake

// Settings to manage association of Dataproc Metastore with a lake.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Lake_Metastore = src.Lake_Metastore

// Status of Lake and Dataproc Metastore service instance association.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Lake_MetastoreStatus = src.Lake_MetastoreStatus

// Current state of association.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Lake_MetastoreStatus_State = src.Lake_MetastoreStatus_State

// List actions response.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListActionsResponse = src.ListActionsResponse

// List asset actions request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListAssetActionsRequest = src.ListAssetActionsRequest

// List assets request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListAssetsRequest = src.ListAssetsRequest

// List assets response.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListAssetsResponse = src.ListAssetsResponse

// List metadata entities request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListEntitiesRequest = src.ListEntitiesRequest

// Entity views.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListEntitiesRequest_EntityView = src.ListEntitiesRequest_EntityView

// List metadata entities response.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListEntitiesResponse = src.ListEntitiesResponse

// List jobs request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListJobsRequest = src.ListJobsRequest

// List jobs response.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListJobsResponse = src.ListJobsResponse

// List lake actions request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListLakeActionsRequest = src.ListLakeActionsRequest

// List lakes request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListLakesRequest = src.ListLakesRequest

// List lakes response.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListLakesResponse = src.ListLakesResponse

// List metadata partitions request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListPartitionsRequest = src.ListPartitionsRequest

// List metadata partitions response.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListPartitionsResponse = src.ListPartitionsResponse

// List tasks request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListTasksRequest = src.ListTasksRequest

// List tasks response.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListTasksResponse = src.ListTasksResponse

// List zone actions request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListZoneActionsRequest = src.ListZoneActionsRequest

// List zones request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListZonesRequest = src.ListZonesRequest

// List zones response.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type ListZonesResponse = src.ListZonesResponse

// MetadataServiceClient is the client API for MetadataService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type MetadataServiceClient = src.MetadataServiceClient

// MetadataServiceServer is the server API for MetadataService service.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type MetadataServiceServer = src.MetadataServiceServer

// Represents the metadata of a long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type OperationMetadata = src.OperationMetadata

// Represents partition metadata contained within entity instances.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Partition = src.Partition

// Schema information describing the structure and layout of the data.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Schema = src.Schema

// Additional qualifiers to define field semantics.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Schema_Mode = src.Schema_Mode

// Represents a key field within the entity's partition structure. You could
// have up to 20 partition fields, but only the first 10 partitions have the
// filtering ability due to performance consideration. **Note:** Partition
// fields are immutable.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Schema_PartitionField = src.Schema_PartitionField

// The structure of paths within the entity, which represent partitions.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Schema_PartitionStyle = src.Schema_PartitionStyle

// Represents a column field within a table schema.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Schema_SchemaField = src.Schema_SchemaField

// Type information for fields in schemas and partition schemas.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Schema_Type = src.Schema_Type

// Represents an active analyze session running for a user.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Session = src.Session

// These messages contain information about sessions within an environment.
// The monitored resource is 'Environment'.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type SessionEvent = src.SessionEvent

// The type of the event.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type SessionEvent_EventType = src.SessionEvent_EventType
type SessionEvent_Query = src.SessionEvent_Query

// Execution details of the query.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type SessionEvent_QueryDetail = src.SessionEvent_QueryDetail

// Query Execution engine.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type SessionEvent_QueryDetail_Engine = src.SessionEvent_QueryDetail_Engine

// State of a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type State = src.State

// Describes the format of the data within its storage location.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type StorageFormat = src.StorageFormat

// The specific compressed file format of the data.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type StorageFormat_CompressionFormat = src.StorageFormat_CompressionFormat
type StorageFormat_Csv = src.StorageFormat_Csv

// Describes CSV and similar semi-structured data formats.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type StorageFormat_CsvOptions = src.StorageFormat_CsvOptions

// The specific file format of the data.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type StorageFormat_Format = src.StorageFormat_Format
type StorageFormat_Json = src.StorageFormat_Json

// Describes JSON data format.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type StorageFormat_JsonOptions = src.StorageFormat_JsonOptions

// Identifies the cloud system that manages the data storage.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type StorageSystem = src.StorageSystem

// A task represents a user-visible job.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task = src.Task

// Execution related settings, like retry and service_account.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task_ExecutionSpec = src.Task_ExecutionSpec

// Status of the task execution (e.g. Jobs).
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task_ExecutionStatus = src.Task_ExecutionStatus

// Configuration for the underlying infrastructure used to run workloads.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task_InfrastructureSpec = src.Task_InfrastructureSpec
type Task_InfrastructureSpec_Batch = src.Task_InfrastructureSpec_Batch

// Batch compute resources associated with the task.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task_InfrastructureSpec_BatchComputeResources = src.Task_InfrastructureSpec_BatchComputeResources
type Task_InfrastructureSpec_ContainerImage = src.Task_InfrastructureSpec_ContainerImage

// Container Image Runtime Configuration used with Batch execution.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task_InfrastructureSpec_ContainerImageRuntime = src.Task_InfrastructureSpec_ContainerImageRuntime

// Cloud VPC Network used to run the infrastructure.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task_InfrastructureSpec_VpcNetwork = src.Task_InfrastructureSpec_VpcNetwork
type Task_InfrastructureSpec_VpcNetwork_ = src.Task_InfrastructureSpec_VpcNetwork_
type Task_InfrastructureSpec_VpcNetwork_Network = src.Task_InfrastructureSpec_VpcNetwork_Network
type Task_InfrastructureSpec_VpcNetwork_SubNetwork = src.Task_InfrastructureSpec_VpcNetwork_SubNetwork
type Task_Notebook = src.Task_Notebook

// Config for running scheduled notebooks.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task_NotebookTaskConfig = src.Task_NotebookTaskConfig
type Task_Spark = src.Task_Spark

// User-specified config for running a Spark task.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task_SparkTaskConfig = src.Task_SparkTaskConfig
type Task_SparkTaskConfig_MainClass = src.Task_SparkTaskConfig_MainClass
type Task_SparkTaskConfig_MainJarFileUri = src.Task_SparkTaskConfig_MainJarFileUri
type Task_SparkTaskConfig_PythonScriptFile = src.Task_SparkTaskConfig_PythonScriptFile
type Task_SparkTaskConfig_SqlScript = src.Task_SparkTaskConfig_SqlScript
type Task_SparkTaskConfig_SqlScriptFile = src.Task_SparkTaskConfig_SqlScriptFile

// Task scheduling and trigger settings.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task_TriggerSpec = src.Task_TriggerSpec
type Task_TriggerSpec_Schedule = src.Task_TriggerSpec_Schedule

// Determines how often and when the job will run.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Task_TriggerSpec_Type = src.Task_TriggerSpec_Type

// UnimplementedContentServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type UnimplementedContentServiceServer = src.UnimplementedContentServiceServer

// UnimplementedDataplexServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type UnimplementedDataplexServiceServer = src.UnimplementedDataplexServiceServer

// UnimplementedMetadataServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type UnimplementedMetadataServiceServer = src.UnimplementedMetadataServiceServer

// Update asset request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type UpdateAssetRequest = src.UpdateAssetRequest

// Update a metadata entity request. The exiting entity will be fully replaced
// by the entity in the request. The entity ID is mutable. To modify the ID,
// use the current entity ID in the request URL and specify the new ID in the
// request body.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type UpdateEntityRequest = src.UpdateEntityRequest

// Update lake request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type UpdateLakeRequest = src.UpdateLakeRequest

// Update task request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type UpdateTaskRequest = src.UpdateTaskRequest

// Update zone request.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type UpdateZoneRequest = src.UpdateZoneRequest

// A zone represents a logical group of related assets within a lake. A zone
// can be used to map to organizational structure or represent stages of data
// readiness from raw to curated. It provides managing behavior that is shared
// or inherited by all contained assets.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Zone = src.Zone

// Settings to manage the metadata discovery and publishing in a zone.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Zone_DiscoverySpec = src.Zone_DiscoverySpec

// Describe CSV and similar semi-structured data formats.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Zone_DiscoverySpec_CsvOptions = src.Zone_DiscoverySpec_CsvOptions

// Describe JSON data format.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Zone_DiscoverySpec_JsonOptions = src.Zone_DiscoverySpec_JsonOptions
type Zone_DiscoverySpec_Schedule = src.Zone_DiscoverySpec_Schedule

// Settings for resources attached as assets within a zone.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Zone_ResourceSpec = src.Zone_ResourceSpec

// Location type of the resources attached to a zone.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Zone_ResourceSpec_LocationType = src.Zone_ResourceSpec_LocationType

// Type of zone.
//
// Deprecated: Please use types in: cloud.google.com/go/dataplex/apiv1/dataplexpb
type Zone_Type = src.Zone_Type

// Deprecated: Please use funcs in: cloud.google.com/go/dataplex/apiv1/dataplexpb
func NewContentServiceClient(cc grpc.ClientConnInterface) ContentServiceClient {
	return src.NewContentServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dataplex/apiv1/dataplexpb
func NewDataplexServiceClient(cc grpc.ClientConnInterface) DataplexServiceClient {
	return src.NewDataplexServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dataplex/apiv1/dataplexpb
func NewMetadataServiceClient(cc grpc.ClientConnInterface) MetadataServiceClient {
	return src.NewMetadataServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dataplex/apiv1/dataplexpb
func RegisterContentServiceServer(s *grpc.Server, srv ContentServiceServer) {
	src.RegisterContentServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dataplex/apiv1/dataplexpb
func RegisterDataplexServiceServer(s *grpc.Server, srv DataplexServiceServer) {
	src.RegisterDataplexServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dataplex/apiv1/dataplexpb
func RegisterMetadataServiceServer(s *grpc.Server, srv MetadataServiceServer) {
	src.RegisterMetadataServiceServer(s, srv)
}
