// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package gkemulticloud aliases all exported identifiers in package
// "cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb".
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package gkemulticloud

import (
	src "cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
const (
	AwsCluster_DEGRADED                          = src.AwsCluster_DEGRADED
	AwsCluster_ERROR                             = src.AwsCluster_ERROR
	AwsCluster_PROVISIONING                      = src.AwsCluster_PROVISIONING
	AwsCluster_RECONCILING                       = src.AwsCluster_RECONCILING
	AwsCluster_RUNNING                           = src.AwsCluster_RUNNING
	AwsCluster_STATE_UNSPECIFIED                 = src.AwsCluster_STATE_UNSPECIFIED
	AwsCluster_STOPPING                          = src.AwsCluster_STOPPING
	AwsInstancePlacement_DEDICATED               = src.AwsInstancePlacement_DEDICATED
	AwsInstancePlacement_DEFAULT                 = src.AwsInstancePlacement_DEFAULT
	AwsInstancePlacement_HOST                    = src.AwsInstancePlacement_HOST
	AwsInstancePlacement_TENANCY_UNSPECIFIED     = src.AwsInstancePlacement_TENANCY_UNSPECIFIED
	AwsNodePool_DEGRADED                         = src.AwsNodePool_DEGRADED
	AwsNodePool_ERROR                            = src.AwsNodePool_ERROR
	AwsNodePool_PROVISIONING                     = src.AwsNodePool_PROVISIONING
	AwsNodePool_RECONCILING                      = src.AwsNodePool_RECONCILING
	AwsNodePool_RUNNING                          = src.AwsNodePool_RUNNING
	AwsNodePool_STATE_UNSPECIFIED                = src.AwsNodePool_STATE_UNSPECIFIED
	AwsNodePool_STOPPING                         = src.AwsNodePool_STOPPING
	AwsVolumeTemplate_GP2                        = src.AwsVolumeTemplate_GP2
	AwsVolumeTemplate_GP3                        = src.AwsVolumeTemplate_GP3
	AwsVolumeTemplate_VOLUME_TYPE_UNSPECIFIED    = src.AwsVolumeTemplate_VOLUME_TYPE_UNSPECIFIED
	AzureCluster_DEGRADED                        = src.AzureCluster_DEGRADED
	AzureCluster_ERROR                           = src.AzureCluster_ERROR
	AzureCluster_PROVISIONING                    = src.AzureCluster_PROVISIONING
	AzureCluster_RECONCILING                     = src.AzureCluster_RECONCILING
	AzureCluster_RUNNING                         = src.AzureCluster_RUNNING
	AzureCluster_STATE_UNSPECIFIED               = src.AzureCluster_STATE_UNSPECIFIED
	AzureCluster_STOPPING                        = src.AzureCluster_STOPPING
	AzureNodePool_DEGRADED                       = src.AzureNodePool_DEGRADED
	AzureNodePool_ERROR                          = src.AzureNodePool_ERROR
	AzureNodePool_PROVISIONING                   = src.AzureNodePool_PROVISIONING
	AzureNodePool_RECONCILING                    = src.AzureNodePool_RECONCILING
	AzureNodePool_RUNNING                        = src.AzureNodePool_RUNNING
	AzureNodePool_STATE_UNSPECIFIED              = src.AzureNodePool_STATE_UNSPECIFIED
	AzureNodePool_STOPPING                       = src.AzureNodePool_STOPPING
	LoggingComponentConfig_COMPONENT_UNSPECIFIED = src.LoggingComponentConfig_COMPONENT_UNSPECIFIED
	LoggingComponentConfig_SYSTEM_COMPONENTS     = src.LoggingComponentConfig_SYSTEM_COMPONENTS
	LoggingComponentConfig_WORKLOADS             = src.LoggingComponentConfig_WORKLOADS
	NodeTaint_EFFECT_UNSPECIFIED                 = src.NodeTaint_EFFECT_UNSPECIFIED
	NodeTaint_NO_EXECUTE                         = src.NodeTaint_NO_EXECUTE
	NodeTaint_NO_SCHEDULE                        = src.NodeTaint_NO_SCHEDULE
	NodeTaint_PREFER_NO_SCHEDULE                 = src.NodeTaint_PREFER_NO_SCHEDULE
)

// Deprecated: Please use vars in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
var (
	AwsCluster_State_name                                     = src.AwsCluster_State_name
	AwsCluster_State_value                                    = src.AwsCluster_State_value
	AwsInstancePlacement_Tenancy_name                         = src.AwsInstancePlacement_Tenancy_name
	AwsInstancePlacement_Tenancy_value                        = src.AwsInstancePlacement_Tenancy_value
	AwsNodePool_State_name                                    = src.AwsNodePool_State_name
	AwsNodePool_State_value                                   = src.AwsNodePool_State_value
	AwsVolumeTemplate_VolumeType_name                         = src.AwsVolumeTemplate_VolumeType_name
	AwsVolumeTemplate_VolumeType_value                        = src.AwsVolumeTemplate_VolumeType_value
	AzureCluster_State_name                                   = src.AzureCluster_State_name
	AzureCluster_State_value                                  = src.AzureCluster_State_value
	AzureNodePool_State_name                                  = src.AzureNodePool_State_name
	AzureNodePool_State_value                                 = src.AzureNodePool_State_value
	File_google_cloud_gkemulticloud_v1_aws_resources_proto    = src.File_google_cloud_gkemulticloud_v1_aws_resources_proto
	File_google_cloud_gkemulticloud_v1_aws_service_proto      = src.File_google_cloud_gkemulticloud_v1_aws_service_proto
	File_google_cloud_gkemulticloud_v1_azure_resources_proto  = src.File_google_cloud_gkemulticloud_v1_azure_resources_proto
	File_google_cloud_gkemulticloud_v1_azure_service_proto    = src.File_google_cloud_gkemulticloud_v1_azure_service_proto
	File_google_cloud_gkemulticloud_v1_common_resources_proto = src.File_google_cloud_gkemulticloud_v1_common_resources_proto
	LoggingComponentConfig_Component_name                     = src.LoggingComponentConfig_Component_name
	LoggingComponentConfig_Component_value                    = src.LoggingComponentConfig_Component_value
	NodeTaint_Effect_name                                     = src.NodeTaint_Effect_name
	NodeTaint_Effect_value                                    = src.NodeTaint_Effect_value
)

// Configuration related to the cluster RBAC settings.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsAuthorization = src.AwsAuthorization

// An Anthos cluster running on AWS.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsCluster = src.AwsCluster

// ClusterNetworking defines cluster-wide networking configuration. Anthos
// clusters on AWS run on a single VPC. This includes control plane replicas
// and node pool nodes.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsClusterNetworking = src.AwsClusterNetworking

// Identities of a user-type subject for AWS clusters.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsClusterUser = src.AwsClusterUser

// The lifecycle state of the cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsCluster_State = src.AwsCluster_State

// AwsClustersClient is the client API for AwsClusters service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsClustersClient = src.AwsClustersClient

// AwsClustersServer is the server API for AwsClusters service.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsClustersServer = src.AwsClustersServer

// Config encryption for user data.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsConfigEncryption = src.AwsConfigEncryption

// ControlPlane defines common parameters between control plane nodes.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsControlPlane = src.AwsControlPlane

// Configuration related to application-layer secrets encryption.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsDatabaseEncryption = src.AwsDatabaseEncryption

// Details of placement information for an instance. Limitations for using the
// `host` tenancy: - T3 instances that use the unlimited CPU credit option
// don't support host tenancy.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsInstancePlacement = src.AwsInstancePlacement

// Tenancy defines how EC2 instances are distributed across physical hardware.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsInstancePlacement_Tenancy = src.AwsInstancePlacement_Tenancy

// Kubernetes version information of GKE cluster on AWS.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsK8SVersionInfo = src.AwsK8SVersionInfo

// Parameters that describe the nodes in a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsNodeConfig = src.AwsNodeConfig

// An Anthos node pool running on AWS.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsNodePool = src.AwsNodePool

// AwsNodePoolAutoscaling contains information required by cluster autoscaler
// to adjust the size of the node pool to the current cluster usage.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsNodePoolAutoscaling = src.AwsNodePoolAutoscaling

// The lifecycle state of the node pool.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsNodePool_State = src.AwsNodePool_State

// Details of a proxy config stored in AWS Secret Manager.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsProxyConfig = src.AwsProxyConfig

// AwsServerConfig is the configuration of GKE cluster on AWS.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsServerConfig = src.AwsServerConfig

// Authentication configuration for the management of AWS resources.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsServicesAuthentication = src.AwsServicesAuthentication

// SSH configuration for AWS resources.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsSshConfig = src.AwsSshConfig

// Configuration template for AWS EBS volumes.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsVolumeTemplate = src.AwsVolumeTemplate

// Types of supported EBS volumes. We currently only support GP2 or GP3
// volumes. See
// https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html for
// more information.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AwsVolumeTemplate_VolumeType = src.AwsVolumeTemplate_VolumeType

// Configuration related to the cluster RBAC settings.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureAuthorization = src.AzureAuthorization

// `AzureClient` resources hold client authentication information needed by
// the Anthos Multi-Cloud API to manage Azure resources on your Azure
// subscription. When an
// [AzureCluster][google.cloud.gkemulticloud.v1.AzureCluster] is created, an
// `AzureClient` resource needs to be provided and all operations on Azure
// resources associated to that cluster will authenticate to Azure services
// using the given client. `AzureClient` resources are immutable and cannot be
// modified upon creation. Each `AzureClient` resource is bound to a single
// Azure Active Directory Application and tenant.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureClient = src.AzureClient

// An Anthos cluster running on Azure.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureCluster = src.AzureCluster

// ClusterNetworking contains cluster-wide networking configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureClusterNetworking = src.AzureClusterNetworking

// Managed Azure resources for the cluster. The values could change and be
// empty, depending on the state of the cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureClusterResources = src.AzureClusterResources

// Identities of a user-type subject for Azure clusters.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureClusterUser = src.AzureClusterUser

// The lifecycle state of the cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureCluster_State = src.AzureCluster_State

// AzureClustersClient is the client API for AzureClusters service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureClustersClient = src.AzureClustersClient

// AzureClustersServer is the server API for AzureClusters service.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureClustersServer = src.AzureClustersServer

// Configuration related to config data encryption. Azure VM bootstrap secret
// is envelope encrypted with the provided key vault key.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureConfigEncryption = src.AzureConfigEncryption

// AzureControlPlane represents the control plane configurations.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureControlPlane = src.AzureControlPlane

// Configuration related to application-layer secrets encryption. Anthos
// clusters on Azure encrypts your Kubernetes data at rest in etcd using Azure
// Key Vault.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureDatabaseEncryption = src.AzureDatabaseEncryption

// Configuration for Azure Disks.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureDiskTemplate = src.AzureDiskTemplate

// Information about a supported Kubernetes version.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureK8SVersionInfo = src.AzureK8SVersionInfo

// Parameters that describe the configuration of all node machines on a given
// node pool.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureNodeConfig = src.AzureNodeConfig

// An Anthos node pool running on Azure.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureNodePool = src.AzureNodePool

// Configuration related to Kubernetes cluster autoscaler. The Kubernetes
// cluster autoscaler will automatically adjust the size of the node pool based
// on the cluster load.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureNodePoolAutoscaling = src.AzureNodePoolAutoscaling

// The lifecycle state of the node pool.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureNodePool_State = src.AzureNodePool_State

// Details of a proxy config stored in Azure Key Vault.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureProxyConfig = src.AzureProxyConfig

// AzureServerConfig contains information about a Google Cloud location, such
// as supported Azure regions and Kubernetes versions.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureServerConfig = src.AzureServerConfig

// SSH configuration for Azure resources.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type AzureSshConfig = src.AzureSshConfig

// Request message for `AwsClusters.CreateAwsCluster` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type CreateAwsClusterRequest = src.CreateAwsClusterRequest

// Response message for `AwsClusters.CreateAwsNodePool` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type CreateAwsNodePoolRequest = src.CreateAwsNodePoolRequest

// Request message for `AzureClusters.CreateAzureClient` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type CreateAzureClientRequest = src.CreateAzureClientRequest

// Request message for `AzureClusters.CreateAzureCluster` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type CreateAzureClusterRequest = src.CreateAzureClusterRequest

// Response message for `AzureClusters.CreateAzureNodePool` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type CreateAzureNodePoolRequest = src.CreateAzureNodePoolRequest

// Request message for `AwsClusters.DeleteAwsCluster` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type DeleteAwsClusterRequest = src.DeleteAwsClusterRequest

// Request message for `AwsClusters.DeleteNodePool` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type DeleteAwsNodePoolRequest = src.DeleteAwsNodePoolRequest

// Request message for `AzureClusters.DeleteAzureClient` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type DeleteAzureClientRequest = src.DeleteAzureClientRequest

// Request message for `Clusters.DeleteAzureCluster` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type DeleteAzureClusterRequest = src.DeleteAzureClusterRequest

// Delete message for `AzureClusters.DeleteNodePool` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type DeleteAzureNodePoolRequest = src.DeleteAzureNodePoolRequest

// Fleet related configuration. Fleets are a Google Cloud concept for
// logically organizing clusters, letting you use and manage multi-cluster
// capabilities and apply consistent policies across your systems. See [Anthos
// Fleets](https://cloud.google.com/anthos/multicluster-management/fleets) for
// more details on Anthos multi-cluster capabilities using Fleets.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type Fleet = src.Fleet

// Request message for `AwsClusters.GenerateAwsAccessToken` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GenerateAwsAccessTokenRequest = src.GenerateAwsAccessTokenRequest

// Response message for `AwsClusters.GenerateAwsAccessToken` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GenerateAwsAccessTokenResponse = src.GenerateAwsAccessTokenResponse

// Request message for `AzureClusters.GenerateAzureAccessToken` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GenerateAzureAccessTokenRequest = src.GenerateAzureAccessTokenRequest

// Response message for `AzureClusters.GenerateAzureAccessToken` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GenerateAzureAccessTokenResponse = src.GenerateAzureAccessTokenResponse

// Request message for `AwsClusters.GetAwsCluster` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GetAwsClusterRequest = src.GetAwsClusterRequest

// Request message for `AwsClusters.GetAwsNodePool` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GetAwsNodePoolRequest = src.GetAwsNodePoolRequest

// GetAwsServerConfigRequest gets the server config of GKE cluster on AWS.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GetAwsServerConfigRequest = src.GetAwsServerConfigRequest

// Request message for `AzureClusters.GetAzureClient` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GetAzureClientRequest = src.GetAzureClientRequest

// Request message for `AzureClusters.GetAzureCluster` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GetAzureClusterRequest = src.GetAzureClusterRequest

// Request message for `AzureClusters.GetAzureNodePool` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GetAzureNodePoolRequest = src.GetAzureNodePoolRequest

// GetAzureServerConfigRequest gets the server config of GKE cluster on Azure.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type GetAzureServerConfigRequest = src.GetAzureServerConfigRequest

// Request message for `AwsClusters.ListAwsClusters` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ListAwsClustersRequest = src.ListAwsClustersRequest

// Response message for `AwsClusters.ListAwsClusters` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ListAwsClustersResponse = src.ListAwsClustersResponse

// Request message for `AwsClusters.ListAwsNodePools` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ListAwsNodePoolsRequest = src.ListAwsNodePoolsRequest

// Response message for `AwsClusters.ListAwsNodePools` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ListAwsNodePoolsResponse = src.ListAwsNodePoolsResponse

// Request message for `AzureClusters.ListAzureClients` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ListAzureClientsRequest = src.ListAzureClientsRequest

// Response message for `AzureClusters.ListAzureClients` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ListAzureClientsResponse = src.ListAzureClientsResponse

// Request message for `AzureClusters.ListAzureClusters` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ListAzureClustersRequest = src.ListAzureClustersRequest

// Response message for `AzureClusters.ListAzureClusters` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ListAzureClustersResponse = src.ListAzureClustersResponse

// Request message for `AzureClusters.ListAzureNodePools` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ListAzureNodePoolsRequest = src.ListAzureNodePoolsRequest

// Response message for `AzureClusters.ListAzureNodePools` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ListAzureNodePoolsResponse = src.ListAzureNodePoolsResponse

// Parameters that describe the Logging component configuration in a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type LoggingComponentConfig = src.LoggingComponentConfig

// The components of the logging configuration;
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type LoggingComponentConfig_Component = src.LoggingComponentConfig_Component

// Parameters that describe the Logging configuration in a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type LoggingConfig = src.LoggingConfig

// Constraints applied to pods.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type MaxPodsConstraint = src.MaxPodsConstraint

// The taint content for the node taint.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type NodeTaint = src.NodeTaint

// The taint effect.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type NodeTaint_Effect = src.NodeTaint_Effect

// Metadata about a long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type OperationMetadata = src.OperationMetadata

// Configuration for the placement of a control plane replica.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type ReplicaPlacement = src.ReplicaPlacement

// UnimplementedAwsClustersServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type UnimplementedAwsClustersServer = src.UnimplementedAwsClustersServer

// UnimplementedAzureClustersServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type UnimplementedAzureClustersServer = src.UnimplementedAzureClustersServer

// Request message for `AwsClusters.UpdateAwsCluster` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type UpdateAwsClusterRequest = src.UpdateAwsClusterRequest

// Request message for `AwsClusters.UpdateAwsNodePool` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type UpdateAwsNodePoolRequest = src.UpdateAwsNodePoolRequest

// Request message for `AzureClusters.UpdateAzureCluster` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type UpdateAzureClusterRequest = src.UpdateAzureClusterRequest

// Request message for `AzureClusters.UpdateAzureNodePool` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type UpdateAzureNodePoolRequest = src.UpdateAzureNodePoolRequest

// Workload Identity settings.
//
// Deprecated: Please use types in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
type WorkloadIdentityConfig = src.WorkloadIdentityConfig

// Deprecated: Please use funcs in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
func NewAwsClustersClient(cc grpc.ClientConnInterface) AwsClustersClient {
	return src.NewAwsClustersClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
func NewAzureClustersClient(cc grpc.ClientConnInterface) AzureClustersClient {
	return src.NewAzureClustersClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
func RegisterAwsClustersServer(s *grpc.Server, srv AwsClustersServer) {
	src.RegisterAwsClustersServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/gkemulticloud/apiv1/gkemulticloudpb
func RegisterAzureClustersServer(s *grpc.Server, srv AzureClustersServer) {
	src.RegisterAzureClustersServer(s, srv)
}
