// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package appgateways aliases all exported identifiers in package
// "cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb".
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package appgateways

import (
	src "cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
const (
	AppGateway_CREATED               = src.AppGateway_CREATED
	AppGateway_CREATING              = src.AppGateway_CREATING
	AppGateway_DELETING              = src.AppGateway_DELETING
	AppGateway_DOWN                  = src.AppGateway_DOWN
	AppGateway_GCP_REGIONAL_MIG      = src.AppGateway_GCP_REGIONAL_MIG
	AppGateway_HOST_TYPE_UNSPECIFIED = src.AppGateway_HOST_TYPE_UNSPECIFIED
	AppGateway_STATE_UNSPECIFIED     = src.AppGateway_STATE_UNSPECIFIED
	AppGateway_TCP_PROXY             = src.AppGateway_TCP_PROXY
	AppGateway_TYPE_UNSPECIFIED      = src.AppGateway_TYPE_UNSPECIFIED
	AppGateway_UPDATING              = src.AppGateway_UPDATING
)

// Deprecated: Please use vars in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
var (
	AppGateway_HostType_name                                               = src.AppGateway_HostType_name
	AppGateway_HostType_value                                              = src.AppGateway_HostType_value
	AppGateway_State_name                                                  = src.AppGateway_State_name
	AppGateway_State_value                                                 = src.AppGateway_State_value
	AppGateway_Type_name                                                   = src.AppGateway_Type_name
	AppGateway_Type_value                                                  = src.AppGateway_Type_value
	File_google_cloud_beyondcorp_appgateways_v1_app_gateways_service_proto = src.File_google_cloud_beyondcorp_appgateways_v1_app_gateways_service_proto
)

// A BeyondCorp AppGateway resource represents a BeyondCorp protected
// AppGateway to a remote application. It creates all the necessary GCP
// components needed for creating a BeyondCorp protected AppGateway. Multiple
// connectors can be authorised for a single AppGateway.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type AppGateway = src.AppGateway

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type AppGatewayOperationMetadata = src.AppGatewayOperationMetadata

// Allocated connection of the AppGateway.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type AppGateway_AllocatedConnection = src.AppGateway_AllocatedConnection

// Enum containing list of all possible host types supported by BeyondCorp
// Connection.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type AppGateway_HostType = src.AppGateway_HostType

// Represents the different states of an AppGateway.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type AppGateway_State = src.AppGateway_State

// Enum containing list of all possible network connectivity options supported
// by BeyondCorp AppGateway.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type AppGateway_Type = src.AppGateway_Type

// AppGatewaysServiceClient is the client API for AppGatewaysService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type AppGatewaysServiceClient = src.AppGatewaysServiceClient

// AppGatewaysServiceServer is the server API for AppGatewaysService service.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type AppGatewaysServiceServer = src.AppGatewaysServiceServer

// Request message for BeyondCorp.CreateAppGateway.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type CreateAppGatewayRequest = src.CreateAppGatewayRequest

// Request message for BeyondCorp.DeleteAppGateway.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type DeleteAppGatewayRequest = src.DeleteAppGatewayRequest

// Request message for BeyondCorp.GetAppGateway.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type GetAppGatewayRequest = src.GetAppGatewayRequest

// Request message for BeyondCorp.ListAppGateways.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type ListAppGatewaysRequest = src.ListAppGatewaysRequest

// Response message for BeyondCorp.ListAppGateways.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type ListAppGatewaysResponse = src.ListAppGatewaysResponse

// UnimplementedAppGatewaysServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
type UnimplementedAppGatewaysServiceServer = src.UnimplementedAppGatewaysServiceServer

// Deprecated: Please use funcs in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
func NewAppGatewaysServiceClient(cc grpc.ClientConnInterface) AppGatewaysServiceClient {
	return src.NewAppGatewaysServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/beyondcorp/appgateways/apiv1/appgatewayspb
func RegisterAppGatewaysServiceServer(s *grpc.Server, srv AppGatewaysServiceServer) {
	src.RegisterAppGatewaysServiceServer(s, srv)
}
