// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package iam aliases all exported identifiers in package
// "cloud.google.com/go/iam/apiv2/iampb".
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package iam

import (
	src "cloud.google.com/go/iam/apiv2/iampb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use vars in: cloud.google.com/go/iam/apiv2/iampb
var (
	File_google_iam_v2_deny_proto   = src.File_google_iam_v2_deny_proto
	File_google_iam_v2_policy_proto = src.File_google_iam_v2_policy_proto
)

// Request message for `CreatePolicy`.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type CreatePolicyRequest = src.CreatePolicyRequest

// Request message for `DeletePolicy`.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type DeletePolicyRequest = src.DeletePolicyRequest

// A deny rule in an IAM deny policy.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type DenyRule = src.DenyRule

// Request message for `GetPolicy`.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type GetPolicyRequest = src.GetPolicyRequest

// Request message for `ListPolicies`.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type ListPoliciesRequest = src.ListPoliciesRequest

// Response message for `ListPolicies`.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type ListPoliciesResponse = src.ListPoliciesResponse

// PoliciesClient is the client API for Policies service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type PoliciesClient = src.PoliciesClient

// PoliciesServer is the server API for Policies service.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type PoliciesServer = src.PoliciesServer

// Data for an IAM policy.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type Policy = src.Policy

// Metadata for long-running `Policy` operations.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type PolicyOperationMetadata = src.PolicyOperationMetadata

// A single rule in a `Policy`.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type PolicyRule = src.PolicyRule
type PolicyRule_DenyRule = src.PolicyRule_DenyRule

// UnimplementedPoliciesServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type UnimplementedPoliciesServer = src.UnimplementedPoliciesServer

// Request message for `UpdatePolicy`.
//
// Deprecated: Please use types in: cloud.google.com/go/iam/apiv2/iampb
type UpdatePolicyRequest = src.UpdatePolicyRequest

// Deprecated: Please use funcs in: cloud.google.com/go/iam/apiv2/iampb
func NewPoliciesClient(cc grpc.ClientConnInterface) PoliciesClient { return src.NewPoliciesClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/iam/apiv2/iampb
func RegisterPoliciesServer(s *grpc.Server, srv PoliciesServer) { src.RegisterPoliciesServer(s, srv) }
