// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package metastore aliases all exported identifiers in package
// "cloud.google.com/go/metastore/apiv1beta/metastorepb".
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package metastore

import (
	src "cloud.google.com/go/metastore/apiv1beta/metastorepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/metastore/apiv1beta/metastorepb
const (
	Backup_ACTIVE                                         = src.Backup_ACTIVE
	Backup_CREATING                                       = src.Backup_CREATING
	Backup_DELETING                                       = src.Backup_DELETING
	Backup_FAILED                                         = src.Backup_FAILED
	Backup_STATE_UNSPECIFIED                              = src.Backup_STATE_UNSPECIFIED
	DatabaseDumpSpec_MYSQL                                = src.DatabaseDumpSpec_MYSQL
	DatabaseDumpSpec_TYPE_UNSPECIFIED                     = src.DatabaseDumpSpec_TYPE_UNSPECIFIED
	MetadataExport_CANCELLED                              = src.MetadataExport_CANCELLED
	MetadataExport_FAILED                                 = src.MetadataExport_FAILED
	MetadataExport_RUNNING                                = src.MetadataExport_RUNNING
	MetadataExport_STATE_UNSPECIFIED                      = src.MetadataExport_STATE_UNSPECIFIED
	MetadataExport_SUCCEEDED                              = src.MetadataExport_SUCCEEDED
	MetadataImport_DatabaseDump_DATABASE_TYPE_UNSPECIFIED = src.MetadataImport_DatabaseDump_DATABASE_TYPE_UNSPECIFIED
	MetadataImport_DatabaseDump_MYSQL                     = src.MetadataImport_DatabaseDump_MYSQL
	MetadataImport_FAILED                                 = src.MetadataImport_FAILED
	MetadataImport_RUNNING                                = src.MetadataImport_RUNNING
	MetadataImport_STATE_UNSPECIFIED                      = src.MetadataImport_STATE_UNSPECIFIED
	MetadataImport_SUCCEEDED                              = src.MetadataImport_SUCCEEDED
	MetadataImport_UPDATING                               = src.MetadataImport_UPDATING
	Restore_CANCELLED                                     = src.Restore_CANCELLED
	Restore_FAILED                                        = src.Restore_FAILED
	Restore_FULL                                          = src.Restore_FULL
	Restore_METADATA_ONLY                                 = src.Restore_METADATA_ONLY
	Restore_RESTORE_TYPE_UNSPECIFIED                      = src.Restore_RESTORE_TYPE_UNSPECIFIED
	Restore_RUNNING                                       = src.Restore_RUNNING
	Restore_STATE_UNSPECIFIED                             = src.Restore_STATE_UNSPECIFIED
	Restore_SUCCEEDED                                     = src.Restore_SUCCEEDED
	Service_ACTIVE                                        = src.Service_ACTIVE
	Service_CANARY                                        = src.Service_CANARY
	Service_CREATING                                      = src.Service_CREATING
	Service_DELETING                                      = src.Service_DELETING
	Service_DEVELOPER                                     = src.Service_DEVELOPER
	Service_ENTERPRISE                                    = src.Service_ENTERPRISE
	Service_ERROR                                         = src.Service_ERROR
	Service_RELEASE_CHANNEL_UNSPECIFIED                   = src.Service_RELEASE_CHANNEL_UNSPECIFIED
	Service_STABLE                                        = src.Service_STABLE
	Service_STATE_UNSPECIFIED                             = src.Service_STATE_UNSPECIFIED
	Service_SUSPENDED                                     = src.Service_SUSPENDED
	Service_SUSPENDING                                    = src.Service_SUSPENDING
	Service_TIER_UNSPECIFIED                              = src.Service_TIER_UNSPECIFIED
	Service_UPDATING                                      = src.Service_UPDATING
)

// Deprecated: Please use vars in: cloud.google.com/go/metastore/apiv1beta/metastorepb
var (
	Backup_State_name                                  = src.Backup_State_name
	Backup_State_value                                 = src.Backup_State_value
	DatabaseDumpSpec_Type_name                         = src.DatabaseDumpSpec_Type_name
	DatabaseDumpSpec_Type_value                        = src.DatabaseDumpSpec_Type_value
	File_google_cloud_metastore_v1beta_metastore_proto = src.File_google_cloud_metastore_v1beta_metastore_proto
	MetadataExport_State_name                          = src.MetadataExport_State_name
	MetadataExport_State_value                         = src.MetadataExport_State_value
	MetadataImport_DatabaseDump_DatabaseType_name      = src.MetadataImport_DatabaseDump_DatabaseType_name
	MetadataImport_DatabaseDump_DatabaseType_value     = src.MetadataImport_DatabaseDump_DatabaseType_value
	MetadataImport_State_name                          = src.MetadataImport_State_name
	MetadataImport_State_value                         = src.MetadataImport_State_value
	Restore_RestoreType_name                           = src.Restore_RestoreType_name
	Restore_RestoreType_value                          = src.Restore_RestoreType_value
	Restore_State_name                                 = src.Restore_State_name
	Restore_State_value                                = src.Restore_State_value
	Service_ReleaseChannel_name                        = src.Service_ReleaseChannel_name
	Service_ReleaseChannel_value                       = src.Service_ReleaseChannel_value
	Service_State_name                                 = src.Service_State_name
	Service_State_value                                = src.Service_State_value
	Service_Tier_name                                  = src.Service_Tier_name
	Service_Tier_value                                 = src.Service_Tier_value
)

// The details of a backup resource.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type Backup = src.Backup

// The current state of the backup.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type Backup_State = src.Backup_State

// Request message for
// [DataprocMetastore.CreateBackup][google.cloud.metastore.v1beta.DataprocMetastore.CreateBackup].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type CreateBackupRequest = src.CreateBackupRequest

// Request message for
// [DataprocMetastore.CreateMetadataImport][google.cloud.metastore.v1beta.DataprocMetastore.CreateMetadataImport].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type CreateMetadataImportRequest = src.CreateMetadataImportRequest

// Request message for
// [DataprocMetastore.CreateService][google.cloud.metastore.v1beta.DataprocMetastore.CreateService].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type CreateServiceRequest = src.CreateServiceRequest

// Specifies how metastore metadata should be integrated with the Data Catalog
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type DataCatalogConfig = src.DataCatalogConfig

// The specification of database dump to import from or export to.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type DatabaseDumpSpec = src.DatabaseDumpSpec

// The type of the database dump.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type DatabaseDumpSpec_Type = src.DatabaseDumpSpec_Type

// DataprocMetastoreClient is the client API for DataprocMetastore service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type DataprocMetastoreClient = src.DataprocMetastoreClient

// DataprocMetastoreServer is the server API for DataprocMetastore service.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type DataprocMetastoreServer = src.DataprocMetastoreServer

// Request message for
// [DataprocMetastore.DeleteBackup][google.cloud.metastore.v1beta.DataprocMetastore.DeleteBackup].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type DeleteBackupRequest = src.DeleteBackupRequest

// Request message for
// [DataprocMetastore.DeleteService][google.cloud.metastore.v1beta.DataprocMetastore.DeleteService].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type DeleteServiceRequest = src.DeleteServiceRequest

// Request message for
// [DataprocMetastore.ExportMetadata][google.cloud.metastore.v1beta.DataprocMetastore.ExportMetadata].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type ExportMetadataRequest = src.ExportMetadataRequest
type ExportMetadataRequest_DestinationGcsFolder = src.ExportMetadataRequest_DestinationGcsFolder

// Request message for
// [DataprocMetastore.GetBackup][google.cloud.metastore.v1beta.DataprocMetastore.GetBackup].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type GetBackupRequest = src.GetBackupRequest

// Request message for
// [DataprocMetastore.GetMetadataImport][google.cloud.metastore.v1beta.DataprocMetastore.GetMetadataImport].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type GetMetadataImportRequest = src.GetMetadataImportRequest

// Request message for
// [DataprocMetastore.GetService][google.cloud.metastore.v1beta.DataprocMetastore.GetService].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type GetServiceRequest = src.GetServiceRequest

// Specifies configuration information specific to running Hive metastore
// software as the metastore service.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type HiveMetastoreConfig = src.HiveMetastoreConfig

// Configuration information for a Kerberos principal.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type KerberosConfig = src.KerberosConfig

// Request message for
// [DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type ListBackupsRequest = src.ListBackupsRequest

// Response message for
// [DataprocMetastore.ListBackups][google.cloud.metastore.v1beta.DataprocMetastore.ListBackups].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type ListBackupsResponse = src.ListBackupsResponse

// Request message for
// [DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1beta.DataprocMetastore.ListMetadataImports].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type ListMetadataImportsRequest = src.ListMetadataImportsRequest

// Response message for
// [DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1beta.DataprocMetastore.ListMetadataImports].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type ListMetadataImportsResponse = src.ListMetadataImportsResponse

// Request message for
// [DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type ListServicesRequest = src.ListServicesRequest

// Response message for
// [DataprocMetastore.ListServices][google.cloud.metastore.v1beta.DataprocMetastore.ListServices].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type ListServicesResponse = src.ListServicesResponse

// Metadata about the service in a location.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type LocationMetadata = src.LocationMetadata

// A specification of a supported version of the Hive Metastore software.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type LocationMetadata_HiveMetastoreVersion = src.LocationMetadata_HiveMetastoreVersion

// Maintenance window. This specifies when Dataproc Metastore may perform
// system maintenance operation to the service.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type MaintenanceWindow = src.MaintenanceWindow

// The details of a metadata export operation.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type MetadataExport = src.MetadataExport
type MetadataExport_DestinationGcsUri = src.MetadataExport_DestinationGcsUri

// The current state of the metadata export.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type MetadataExport_State = src.MetadataExport_State

// A metastore resource that imports metadata.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type MetadataImport = src.MetadataImport

// A specification of the location of and metadata about a database dump from
// a relational database management system.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type MetadataImport_DatabaseDump = src.MetadataImport_DatabaseDump
type MetadataImport_DatabaseDump_ = src.MetadataImport_DatabaseDump_

// The type of the database.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type MetadataImport_DatabaseDump_DatabaseType = src.MetadataImport_DatabaseDump_DatabaseType

// The current state of the metadata import.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type MetadataImport_State = src.MetadataImport_State

// Specifies how metastore metadata should be integrated with external
// services.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type MetadataIntegration = src.MetadataIntegration

// The metadata management activities of the metastore service.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type MetadataManagementActivity = src.MetadataManagementActivity

// Represents the metadata of a long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type OperationMetadata = src.OperationMetadata

// The details of a metadata restore operation.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type Restore = src.Restore

// Request message for [DataprocMetastore.Restore][].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type RestoreServiceRequest = src.RestoreServiceRequest

// The type of restore.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type Restore_RestoreType = src.Restore_RestoreType

// The current state of the restore.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type Restore_State = src.Restore_State

// A securely stored value.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type Secret = src.Secret
type Secret_CloudSecret = src.Secret_CloudSecret

// A managed metastore service that serves metadata queries.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type Service = src.Service
type Service_HiveMetastoreConfig = src.Service_HiveMetastoreConfig

// Release channels bundle features of varying levels of stability. Newer
// features may be introduced initially into less stable release channels and
// can be automatically promoted into more stable release channels.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type Service_ReleaseChannel = src.Service_ReleaseChannel

// The current state of the metastore service.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type Service_State = src.Service_State

// Available service tiers.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type Service_Tier = src.Service_Tier

// UnimplementedDataprocMetastoreServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type UnimplementedDataprocMetastoreServer = src.UnimplementedDataprocMetastoreServer

// Request message for
// [DataprocMetastore.UpdateMetadataImport][google.cloud.metastore.v1beta.DataprocMetastore.UpdateMetadataImport].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type UpdateMetadataImportRequest = src.UpdateMetadataImportRequest

// Request message for
// [DataprocMetastore.UpdateService][google.cloud.metastore.v1beta.DataprocMetastore.UpdateService].
//
// Deprecated: Please use types in: cloud.google.com/go/metastore/apiv1beta/metastorepb
type UpdateServiceRequest = src.UpdateServiceRequest

// Deprecated: Please use funcs in: cloud.google.com/go/metastore/apiv1beta/metastorepb
func NewDataprocMetastoreClient(cc grpc.ClientConnInterface) DataprocMetastoreClient {
	return src.NewDataprocMetastoreClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/metastore/apiv1beta/metastorepb
func RegisterDataprocMetastoreServer(s *grpc.Server, srv DataprocMetastoreServer) {
	src.RegisterDataprocMetastoreServer(s, srv)
}
