// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package recommendationengine aliases all exported identifiers in package
// "cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb".
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package recommendationengine

import (
	src "cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
const (
	ProductCatalogItem_BACKORDER               = src.ProductCatalogItem_BACKORDER
	ProductCatalogItem_IN_STOCK                = src.ProductCatalogItem_IN_STOCK
	ProductCatalogItem_OUT_OF_STOCK            = src.ProductCatalogItem_OUT_OF_STOCK
	ProductCatalogItem_PREORDER                = src.ProductCatalogItem_PREORDER
	ProductCatalogItem_STOCK_STATE_UNSPECIFIED = src.ProductCatalogItem_STOCK_STATE_UNSPECIFIED
	UserEvent_AUTOML                           = src.UserEvent_AUTOML
	UserEvent_BATCH_UPLOAD                     = src.UserEvent_BATCH_UPLOAD
	UserEvent_ECOMMERCE                        = src.UserEvent_ECOMMERCE
	UserEvent_EVENT_SOURCE_UNSPECIFIED         = src.UserEvent_EVENT_SOURCE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
var (
	File_google_cloud_recommendationengine_v1beta1_catalog_proto                            = src.File_google_cloud_recommendationengine_v1beta1_catalog_proto
	File_google_cloud_recommendationengine_v1beta1_catalog_service_proto                    = src.File_google_cloud_recommendationengine_v1beta1_catalog_service_proto
	File_google_cloud_recommendationengine_v1beta1_common_proto                             = src.File_google_cloud_recommendationengine_v1beta1_common_proto
	File_google_cloud_recommendationengine_v1beta1_import_proto                             = src.File_google_cloud_recommendationengine_v1beta1_import_proto
	File_google_cloud_recommendationengine_v1beta1_prediction_apikey_registry_service_proto = src.File_google_cloud_recommendationengine_v1beta1_prediction_apikey_registry_service_proto
	File_google_cloud_recommendationengine_v1beta1_prediction_service_proto                 = src.File_google_cloud_recommendationengine_v1beta1_prediction_service_proto
	File_google_cloud_recommendationengine_v1beta1_recommendationengine_resources_proto     = src.File_google_cloud_recommendationengine_v1beta1_recommendationengine_resources_proto
	File_google_cloud_recommendationengine_v1beta1_user_event_proto                         = src.File_google_cloud_recommendationengine_v1beta1_user_event_proto
	File_google_cloud_recommendationengine_v1beta1_user_event_service_proto                 = src.File_google_cloud_recommendationengine_v1beta1_user_event_service_proto
	ProductCatalogItem_StockState_name                                                      = src.ProductCatalogItem_StockState_name
	ProductCatalogItem_StockState_value                                                     = src.ProductCatalogItem_StockState_value
	UserEvent_EventSource_name                                                              = src.UserEvent_EventSource_name
	UserEvent_EventSource_value                                                             = src.UserEvent_EventSource_value
)

// The inline source for the input config for ImportCatalogItems method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type CatalogInlineSource = src.CatalogInlineSource

// CatalogItem captures all metadata information of items to be recommended.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type CatalogItem = src.CatalogItem

// Category represents catalog item category hierarchy.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type CatalogItem_CategoryHierarchy = src.CatalogItem_CategoryHierarchy
type CatalogItem_ProductMetadata = src.CatalogItem_ProductMetadata

// CatalogServiceClient is the client API for CatalogService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type CatalogServiceClient = src.CatalogServiceClient

// CatalogServiceServer is the server API for CatalogService service.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type CatalogServiceServer = src.CatalogServiceServer

// Request message for CollectUserEvent method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type CollectUserEventRequest = src.CollectUserEventRequest

// Request message for CreateCatalogItem method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type CreateCatalogItemRequest = src.CreateCatalogItemRequest

// Request message for the `CreatePredictionApiKeyRegistration` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type CreatePredictionApiKeyRegistrationRequest = src.CreatePredictionApiKeyRegistrationRequest

// Request message for DeleteCatalogItem method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type DeleteCatalogItemRequest = src.DeleteCatalogItemRequest

// Request message for `DeletePredictionApiKeyRegistration` method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type DeletePredictionApiKeyRegistrationRequest = src.DeletePredictionApiKeyRegistrationRequest

// User event details shared by all recommendation types.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type EventDetail = src.EventDetail

// FeatureMap represents extra features that customers want to include in the
// recommendation model for catalogs/user events as categorical/numerical
// features.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type FeatureMap = src.FeatureMap

// A list of float features.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type FeatureMap_FloatList = src.FeatureMap_FloatList

// A list of string features.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type FeatureMap_StringList = src.FeatureMap_StringList

// Google Cloud Storage location for input content. format.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type GcsSource = src.GcsSource

// Request message for GetCatalogItem method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type GetCatalogItemRequest = src.GetCatalogItemRequest

// Catalog item thumbnail/detail image.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type Image = src.Image

// Request message for Import methods.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ImportCatalogItemsRequest = src.ImportCatalogItemsRequest

// Response of the ImportCatalogItemsRequest. If the long running operation is
// done, then this message is returned by the
// google.longrunning.Operations.response field if the operation was
// successful.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ImportCatalogItemsResponse = src.ImportCatalogItemsResponse

// Configuration of destination for Import related errors.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ImportErrorsConfig = src.ImportErrorsConfig
type ImportErrorsConfig_GcsPrefix = src.ImportErrorsConfig_GcsPrefix

// Metadata related to the progress of the Import operation. This will be
// returned by the google.longrunning.Operation.metadata field.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ImportMetadata = src.ImportMetadata

// Request message for the ImportUserEvents request.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ImportUserEventsRequest = src.ImportUserEventsRequest

// Response of the ImportUserEventsRequest. If the long running operation was
// successful, then this message is returned by the
// google.longrunning.Operations.response field if the operation was
// successful.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ImportUserEventsResponse = src.ImportUserEventsResponse

// The input config source.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type InputConfig = src.InputConfig
type InputConfig_CatalogInlineSource = src.InputConfig_CatalogInlineSource
type InputConfig_GcsSource = src.InputConfig_GcsSource
type InputConfig_UserEventInlineSource = src.InputConfig_UserEventInlineSource

// Request message for ListCatalogItems method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ListCatalogItemsRequest = src.ListCatalogItemsRequest

// Response message for ListCatalogItems method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ListCatalogItemsResponse = src.ListCatalogItemsResponse

// Request message for the `ListPredictionApiKeyRegistrations`.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ListPredictionApiKeyRegistrationsRequest = src.ListPredictionApiKeyRegistrationsRequest

// Response message for the `ListPredictionApiKeyRegistrations`.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ListPredictionApiKeyRegistrationsResponse = src.ListPredictionApiKeyRegistrationsResponse

// Request message for ListUserEvents method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ListUserEventsRequest = src.ListUserEventsRequest

// Response message for ListUserEvents method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ListUserEventsResponse = src.ListUserEventsResponse

// Request message for Predict method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PredictRequest = src.PredictRequest

// Response message for predict method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PredictResponse = src.PredictResponse

// PredictionResult represents the recommendation prediction results.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PredictResponse_PredictionResult = src.PredictResponse_PredictionResult

// Registered Api Key.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PredictionApiKeyRegistration = src.PredictionApiKeyRegistration

// PredictionApiKeyRegistryClient is the client API for
// PredictionApiKeyRegistry service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PredictionApiKeyRegistryClient = src.PredictionApiKeyRegistryClient

// PredictionApiKeyRegistryServer is the server API for
// PredictionApiKeyRegistry service.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PredictionApiKeyRegistryServer = src.PredictionApiKeyRegistryServer

// PredictionServiceClient is the client API for PredictionService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PredictionServiceClient = src.PredictionServiceClient

// PredictionServiceServer is the server API for PredictionService service.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PredictionServiceServer = src.PredictionServiceServer

// ProductCatalogItem captures item metadata specific to retail products.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ProductCatalogItem = src.ProductCatalogItem

// Exact product price.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ProductCatalogItem_ExactPrice = src.ProductCatalogItem_ExactPrice
type ProductCatalogItem_ExactPrice_ = src.ProductCatalogItem_ExactPrice_

// Product price range when there are a range of prices for different
// variations of the same product.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ProductCatalogItem_PriceRange = src.ProductCatalogItem_PriceRange
type ProductCatalogItem_PriceRange_ = src.ProductCatalogItem_PriceRange_

// Item stock state. If this field is unspecified, the item is assumed to be
// in stock.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ProductCatalogItem_StockState = src.ProductCatalogItem_StockState

// Detailed product information associated with a user event.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ProductDetail = src.ProductDetail

// ProductEventDetail captures user event information specific to retail
// products.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type ProductEventDetail = src.ProductEventDetail

// A transaction represents the entire purchase transaction.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PurchaseTransaction = src.PurchaseTransaction

// Metadata related to the progress of the PurgeUserEvents operation. This
// will be returned by the google.longrunning.Operation.metadata field.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PurgeUserEventsMetadata = src.PurgeUserEventsMetadata

// Request message for PurgeUserEvents method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PurgeUserEventsRequest = src.PurgeUserEventsRequest

// Response of the PurgeUserEventsRequest. If the long running operation is
// successfully done, then this message is returned by the
// google.longrunning.Operations.response field.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type PurgeUserEventsResponse = src.PurgeUserEventsResponse

// UnimplementedCatalogServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UnimplementedCatalogServiceServer = src.UnimplementedCatalogServiceServer

// UnimplementedPredictionApiKeyRegistryServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UnimplementedPredictionApiKeyRegistryServer = src.UnimplementedPredictionApiKeyRegistryServer

// UnimplementedPredictionServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UnimplementedPredictionServiceServer = src.UnimplementedPredictionServiceServer

// UnimplementedUserEventServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UnimplementedUserEventServiceServer = src.UnimplementedUserEventServiceServer

// Request message for UpdateCatalogItem method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UpdateCatalogItemRequest = src.UpdateCatalogItemRequest

// UserEvent captures all metadata information recommendation engine needs to
// know about how end users interact with customers' website.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UserEvent = src.UserEvent

// A summary of import result. The UserEventImportSummary summarizes the
// import status for user events.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UserEventImportSummary = src.UserEventImportSummary

// The inline source for the input config for ImportUserEvents method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UserEventInlineSource = src.UserEventInlineSource

// UserEventServiceClient is the client API for UserEventService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UserEventServiceClient = src.UserEventServiceClient

// UserEventServiceServer is the server API for UserEventService service.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UserEventServiceServer = src.UserEventServiceServer

// User event source.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UserEvent_EventSource = src.UserEvent_EventSource

// Information of end users.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type UserInfo = src.UserInfo

// Request message for WriteUserEvent method.
//
// Deprecated: Please use types in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
type WriteUserEventRequest = src.WriteUserEventRequest

// Deprecated: Please use funcs in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
func NewCatalogServiceClient(cc grpc.ClientConnInterface) CatalogServiceClient {
	return src.NewCatalogServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
func NewPredictionApiKeyRegistryClient(cc grpc.ClientConnInterface) PredictionApiKeyRegistryClient {
	return src.NewPredictionApiKeyRegistryClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
func NewPredictionServiceClient(cc grpc.ClientConnInterface) PredictionServiceClient {
	return src.NewPredictionServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
func NewUserEventServiceClient(cc grpc.ClientConnInterface) UserEventServiceClient {
	return src.NewUserEventServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
func RegisterCatalogServiceServer(s *grpc.Server, srv CatalogServiceServer) {
	src.RegisterCatalogServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
func RegisterPredictionApiKeyRegistryServer(s *grpc.Server, srv PredictionApiKeyRegistryServer) {
	src.RegisterPredictionApiKeyRegistryServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
func RegisterPredictionServiceServer(s *grpc.Server, srv PredictionServiceServer) {
	src.RegisterPredictionServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/recommendationengine/apiv1beta1/recommendationenginepb
func RegisterUserEventServiceServer(s *grpc.Server, srv UserEventServiceServer) {
	src.RegisterUserEventServiceServer(s, srv)
}
