// Copyright 2023 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package apigeeregistry aliases all exported identifiers in package
// "cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb".
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package apigeeregistry

import (
	src "cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
const (
	Instance_ACTIVE            = src.Instance_ACTIVE
	Instance_CREATING          = src.Instance_CREATING
	Instance_DELETING          = src.Instance_DELETING
	Instance_FAILED            = src.Instance_FAILED
	Instance_INACTIVE          = src.Instance_INACTIVE
	Instance_STATE_UNSPECIFIED = src.Instance_STATE_UNSPECIFIED
	Instance_UPDATING          = src.Instance_UPDATING
)

// Deprecated: Please use vars in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
var (
	File_google_cloud_apigeeregistry_v1_provisioning_service_proto = src.File_google_cloud_apigeeregistry_v1_provisioning_service_proto
	File_google_cloud_apigeeregistry_v1_registry_models_proto      = src.File_google_cloud_apigeeregistry_v1_registry_models_proto
	File_google_cloud_apigeeregistry_v1_registry_service_proto     = src.File_google_cloud_apigeeregistry_v1_registry_service_proto
	Instance_State_name                                            = src.Instance_State_name
	Instance_State_value                                           = src.Instance_State_value
)

// A top-level description of an API. Produced by producers and are
// commitments to provide services.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type Api = src.Api

// Describes a service running at particular address that provides a
// particular version of an API. ApiDeployments have revisions which correspond
// to different configurations of a single deployment in time. Revision
// identifiers should be updated whenever the served API spec or endpoint
// address changes.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ApiDeployment = src.ApiDeployment

// Describes a version of an API in a structured way. ApiSpecs provide formal
// descriptions that consumers can use to use a version. ApiSpec resources are
// intended to be fully-resolved descriptions of an ApiVersion. When specs
// consist of multiple files, these should be bundled together (e.g., in a zip
// archive) and stored as a unit. Multiple specs can exist to provide
// representations in different API description formats. Synchronization of
// these representations would be provided by tooling and background services.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ApiSpec = src.ApiSpec

// Describes a particular version of an API. ApiVersions are what consumers
// actually use.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ApiVersion = src.ApiVersion

// Artifacts of resources. Artifacts are unique (single-value) per resource
// and are used to store metadata that is too large or numerous to be stored
// directly on the resource. Since artifacts are stored separately from parent
// resources, they should generally be used for metadata that is needed
// infrequently, i.e., not for display in primary views of the resource but
// perhaps displayed or downloaded upon request. The `ListArtifacts` method
// allows artifacts to be quickly enumerated and checked for presence without
// downloading their (potentially-large) contents.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type Artifact = src.Artifact

// Request message for CreateApiDeployment.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type CreateApiDeploymentRequest = src.CreateApiDeploymentRequest

// Request message for CreateApi.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type CreateApiRequest = src.CreateApiRequest

// Request message for CreateApiSpec.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type CreateApiSpecRequest = src.CreateApiSpecRequest

// Request message for CreateApiVersion.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type CreateApiVersionRequest = src.CreateApiVersionRequest

// Request message for CreateArtifact.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type CreateArtifactRequest = src.CreateArtifactRequest

// Request message for CreateInstance.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type CreateInstanceRequest = src.CreateInstanceRequest

// Request message for DeleteApiDeployment.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type DeleteApiDeploymentRequest = src.DeleteApiDeploymentRequest

// Request message for DeleteApiDeploymentRevision.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type DeleteApiDeploymentRevisionRequest = src.DeleteApiDeploymentRevisionRequest

// Request message for DeleteApi.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type DeleteApiRequest = src.DeleteApiRequest

// Request message for DeleteApiSpec.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type DeleteApiSpecRequest = src.DeleteApiSpecRequest

// Request message for DeleteApiSpecRevision.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type DeleteApiSpecRevisionRequest = src.DeleteApiSpecRevisionRequest

// Request message for DeleteApiVersion.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type DeleteApiVersionRequest = src.DeleteApiVersionRequest

// Request message for DeleteArtifact.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type DeleteArtifactRequest = src.DeleteArtifactRequest

// Request message for DeleteInstance.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type DeleteInstanceRequest = src.DeleteInstanceRequest

// Request message for GetApiDeployment.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type GetApiDeploymentRequest = src.GetApiDeploymentRequest

// Request message for GetApi.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type GetApiRequest = src.GetApiRequest

// Request message for GetApiSpecContents.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type GetApiSpecContentsRequest = src.GetApiSpecContentsRequest

// Request message for GetApiSpec.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type GetApiSpecRequest = src.GetApiSpecRequest

// Request message for GetApiVersion.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type GetApiVersionRequest = src.GetApiVersionRequest

// Request message for GetArtifactContents.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type GetArtifactContentsRequest = src.GetArtifactContentsRequest

// Request message for GetArtifact.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type GetArtifactRequest = src.GetArtifactRequest

// Request message for GetInstance.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type GetInstanceRequest = src.GetInstanceRequest

// An Instance represents the instance resources of the Registry. Currently,
// only one instance is allowed for each project.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type Instance = src.Instance

// Available configurations to provision an Instance.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type Instance_Config = src.Instance_Config

// State of the Instance.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type Instance_State = src.Instance_State

// Request message for ListApiDeploymentRevisions.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApiDeploymentRevisionsRequest = src.ListApiDeploymentRevisionsRequest

// Response message for ListApiDeploymentRevisionsResponse.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApiDeploymentRevisionsResponse = src.ListApiDeploymentRevisionsResponse

// Request message for ListApiDeployments.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApiDeploymentsRequest = src.ListApiDeploymentsRequest

// Response message for ListApiDeployments.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApiDeploymentsResponse = src.ListApiDeploymentsResponse

// Request message for ListApiSpecRevisions.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApiSpecRevisionsRequest = src.ListApiSpecRevisionsRequest

// Response message for ListApiSpecRevisionsResponse.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApiSpecRevisionsResponse = src.ListApiSpecRevisionsResponse

// Request message for ListApiSpecs.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApiSpecsRequest = src.ListApiSpecsRequest

// Response message for ListApiSpecs.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApiSpecsResponse = src.ListApiSpecsResponse

// Request message for ListApiVersions.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApiVersionsRequest = src.ListApiVersionsRequest

// Response message for ListApiVersions.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApiVersionsResponse = src.ListApiVersionsResponse

// Request message for ListApis.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApisRequest = src.ListApisRequest

// Response message for ListApis.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListApisResponse = src.ListApisResponse

// Request message for ListArtifacts.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListArtifactsRequest = src.ListArtifactsRequest

// Response message for ListArtifacts.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ListArtifactsResponse = src.ListArtifactsResponse

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type OperationMetadata = src.OperationMetadata

// ProvisioningClient is the client API for Provisioning service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ProvisioningClient = src.ProvisioningClient

// ProvisioningServer is the server API for Provisioning service.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ProvisioningServer = src.ProvisioningServer

// RegistryClient is the client API for Registry service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type RegistryClient = src.RegistryClient

// RegistryServer is the server API for Registry service.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type RegistryServer = src.RegistryServer

// Request message for ReplaceArtifact.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type ReplaceArtifactRequest = src.ReplaceArtifactRequest

// Request message for RollbackApiDeployment.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type RollbackApiDeploymentRequest = src.RollbackApiDeploymentRequest

// Request message for RollbackApiSpec.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type RollbackApiSpecRequest = src.RollbackApiSpecRequest

// Request message for TagApiDeploymentRevision.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type TagApiDeploymentRevisionRequest = src.TagApiDeploymentRevisionRequest

// Request message for TagApiSpecRevision.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type TagApiSpecRevisionRequest = src.TagApiSpecRevisionRequest

// UnimplementedProvisioningServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type UnimplementedProvisioningServer = src.UnimplementedProvisioningServer

// UnimplementedRegistryServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type UnimplementedRegistryServer = src.UnimplementedRegistryServer

// Request message for UpdateApiDeployment.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type UpdateApiDeploymentRequest = src.UpdateApiDeploymentRequest

// Request message for UpdateApi.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type UpdateApiRequest = src.UpdateApiRequest

// Request message for UpdateApiSpec.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type UpdateApiSpecRequest = src.UpdateApiSpecRequest

// Request message for UpdateApiVersion.
//
// Deprecated: Please use types in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
type UpdateApiVersionRequest = src.UpdateApiVersionRequest

// Deprecated: Please use funcs in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
func NewProvisioningClient(cc grpc.ClientConnInterface) ProvisioningClient {
	return src.NewProvisioningClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
func NewRegistryClient(cc grpc.ClientConnInterface) RegistryClient { return src.NewRegistryClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
func RegisterProvisioningServer(s *grpc.Server, srv ProvisioningServer) {
	src.RegisterProvisioningServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/apigeeregistry/apiv1/apigeeregistrypb
func RegisterRegistryServer(s *grpc.Server, srv RegistryServer) { src.RegisterRegistryServer(s, srv) }
