// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package migration aliases all exported identifiers in package
// "cloud.google.com/go/bigquery/migration/apiv2/migrationpb".
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package migration

import (
	src "cloud.google.com/go/bigquery/migration/apiv2/migrationpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
const (
	MigrationSubtask_ACTIVE             = src.MigrationSubtask_ACTIVE
	MigrationSubtask_FAILED             = src.MigrationSubtask_FAILED
	MigrationSubtask_PAUSED             = src.MigrationSubtask_PAUSED
	MigrationSubtask_RUNNING            = src.MigrationSubtask_RUNNING
	MigrationSubtask_STATE_UNSPECIFIED  = src.MigrationSubtask_STATE_UNSPECIFIED
	MigrationSubtask_SUCCEEDED          = src.MigrationSubtask_SUCCEEDED
	MigrationTask_FAILED                = src.MigrationTask_FAILED
	MigrationTask_ORCHESTRATING         = src.MigrationTask_ORCHESTRATING
	MigrationTask_PAUSED                = src.MigrationTask_PAUSED
	MigrationTask_PENDING               = src.MigrationTask_PENDING
	MigrationTask_RUNNING               = src.MigrationTask_RUNNING
	MigrationTask_STATE_UNSPECIFIED     = src.MigrationTask_STATE_UNSPECIFIED
	MigrationTask_SUCCEEDED             = src.MigrationTask_SUCCEEDED
	MigrationWorkflow_COMPLETED         = src.MigrationWorkflow_COMPLETED
	MigrationWorkflow_DRAFT             = src.MigrationWorkflow_DRAFT
	MigrationWorkflow_PAUSED            = src.MigrationWorkflow_PAUSED
	MigrationWorkflow_RUNNING           = src.MigrationWorkflow_RUNNING
	MigrationWorkflow_STATE_UNSPECIFIED = src.MigrationWorkflow_STATE_UNSPECIFIED
	NameMappingKey_ATTRIBUTE            = src.NameMappingKey_ATTRIBUTE
	NameMappingKey_ATTRIBUTE_ALIAS      = src.NameMappingKey_ATTRIBUTE_ALIAS
	NameMappingKey_DATABASE             = src.NameMappingKey_DATABASE
	NameMappingKey_FUNCTION             = src.NameMappingKey_FUNCTION
	NameMappingKey_RELATION             = src.NameMappingKey_RELATION
	NameMappingKey_RELATION_ALIAS       = src.NameMappingKey_RELATION_ALIAS
	NameMappingKey_SCHEMA               = src.NameMappingKey_SCHEMA
	NameMappingKey_TYPE_UNSPECIFIED     = src.NameMappingKey_TYPE_UNSPECIFIED
	TeradataDialect_BTEQ                = src.TeradataDialect_BTEQ
	TeradataDialect_MODE_UNSPECIFIED    = src.TeradataDialect_MODE_UNSPECIFIED
	TeradataDialect_SQL                 = src.TeradataDialect_SQL
)

// Deprecated: Please use vars in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
var (
	File_google_cloud_bigquery_migration_v2_migration_entities_proto      = src.File_google_cloud_bigquery_migration_v2_migration_entities_proto
	File_google_cloud_bigquery_migration_v2_migration_error_details_proto = src.File_google_cloud_bigquery_migration_v2_migration_error_details_proto
	File_google_cloud_bigquery_migration_v2_migration_metrics_proto       = src.File_google_cloud_bigquery_migration_v2_migration_metrics_proto
	File_google_cloud_bigquery_migration_v2_migration_service_proto       = src.File_google_cloud_bigquery_migration_v2_migration_service_proto
	File_google_cloud_bigquery_migration_v2_translation_config_proto      = src.File_google_cloud_bigquery_migration_v2_translation_config_proto
	MigrationSubtask_State_name                                           = src.MigrationSubtask_State_name
	MigrationSubtask_State_value                                          = src.MigrationSubtask_State_value
	MigrationTask_State_name                                              = src.MigrationTask_State_name
	MigrationTask_State_value                                             = src.MigrationTask_State_value
	MigrationWorkflow_State_name                                          = src.MigrationWorkflow_State_name
	MigrationWorkflow_State_value                                         = src.MigrationWorkflow_State_value
	NameMappingKey_Type_name                                              = src.NameMappingKey_Type_name
	NameMappingKey_Type_value                                             = src.NameMappingKey_Type_value
	TeradataDialect_Mode_name                                             = src.TeradataDialect_Mode_name
	TeradataDialect_Mode_value                                            = src.TeradataDialect_Mode_value
)

// The dialect definition for Azure Synapse.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type AzureSynapseDialect = src.AzureSynapseDialect

// The dialect definition for BigQuery.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type BigQueryDialect = src.BigQueryDialect

// Request to create a migration workflow resource.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type CreateMigrationWorkflowRequest = src.CreateMigrationWorkflowRequest

// A request to delete a previously created migration workflow.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type DeleteMigrationWorkflowRequest = src.DeleteMigrationWorkflowRequest

// The possible dialect options for translation.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type Dialect = src.Dialect
type Dialect_AzureSynapseDialect = src.Dialect_AzureSynapseDialect
type Dialect_BigqueryDialect = src.Dialect_BigqueryDialect
type Dialect_HiveqlDialect = src.Dialect_HiveqlDialect
type Dialect_MysqlDialect = src.Dialect_MysqlDialect
type Dialect_NetezzaDialect = src.Dialect_NetezzaDialect
type Dialect_OracleDialect = src.Dialect_OracleDialect
type Dialect_PostgresqlDialect = src.Dialect_PostgresqlDialect
type Dialect_PrestoDialect = src.Dialect_PrestoDialect
type Dialect_RedshiftDialect = src.Dialect_RedshiftDialect
type Dialect_SnowflakeDialect = src.Dialect_SnowflakeDialect
type Dialect_SparksqlDialect = src.Dialect_SparksqlDialect
type Dialect_SqlServerDialect = src.Dialect_SqlServerDialect
type Dialect_TeradataDialect = src.Dialect_TeradataDialect
type Dialect_VerticaDialect = src.Dialect_VerticaDialect

// Provides details for errors, e.g. issues that where encountered when
// processing a subtask.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type ErrorDetail = src.ErrorDetail

// Holds information about where the error is located.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type ErrorLocation = src.ErrorLocation

// A request to get a previously created migration subtasks.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type GetMigrationSubtaskRequest = src.GetMigrationSubtaskRequest

// A request to get a previously created migration workflow.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type GetMigrationWorkflowRequest = src.GetMigrationWorkflowRequest

// The dialect definition for HiveQL.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type HiveQLDialect = src.HiveQLDialect

// A request to list previously created migration subtasks.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type ListMigrationSubtasksRequest = src.ListMigrationSubtasksRequest

// Response object for a `ListMigrationSubtasks` call.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type ListMigrationSubtasksResponse = src.ListMigrationSubtasksResponse

// A request to list previously created migration workflows.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type ListMigrationWorkflowsRequest = src.ListMigrationWorkflowsRequest

// Response object for a `ListMigrationWorkflows` call.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type ListMigrationWorkflowsResponse = src.ListMigrationWorkflowsResponse

// MigrationServiceClient is the client API for MigrationService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type MigrationServiceClient = src.MigrationServiceClient

// MigrationServiceServer is the server API for MigrationService service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type MigrationServiceServer = src.MigrationServiceServer

// A subtask for a migration which carries details about the configuration of
// the subtask. The content of the details should not matter to the end user,
// but is a contract between the subtask creator and subtask worker.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type MigrationSubtask = src.MigrationSubtask

// Possible states of a migration subtask.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type MigrationSubtask_State = src.MigrationSubtask_State

// A single task for a migration which has details about the configuration of
// the task.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type MigrationTask = src.MigrationTask

// Possible states of a migration task.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type MigrationTask_State = src.MigrationTask_State
type MigrationTask_TranslationConfigDetails = src.MigrationTask_TranslationConfigDetails

// A migration workflow which specifies what needs to be done for an EDW
// migration.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type MigrationWorkflow = src.MigrationWorkflow

// Possible migration workflow states.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type MigrationWorkflow_State = src.MigrationWorkflow_State

// The dialect definition for MySQL.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type MySQLDialect = src.MySQLDialect

// The potential components of a full name mapping that will be mapped during
// translation in the source data warehouse.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type NameMappingKey = src.NameMappingKey

// The type of the object that is being mapped.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type NameMappingKey_Type = src.NameMappingKey_Type

// The potential components of a full name mapping that will be mapped during
// translation in the target data warehouse.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type NameMappingValue = src.NameMappingValue

// The dialect definition for Netezza.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type NetezzaDialect = src.NetezzaDialect

// Represents a key-value pair of NameMappingKey to NameMappingValue to
// represent the mapping of SQL names from the input value to desired output.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type ObjectNameMapping = src.ObjectNameMapping

// Represents a map of name mappings using a list of key:value proto messages
// of existing name to desired output name.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type ObjectNameMappingList = src.ObjectNameMappingList

// The dialect definition for Oracle.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type OracleDialect = src.OracleDialect

// A single data point in a time series.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type Point = src.Point

// The dialect definition for Postgresql.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type PostgresqlDialect = src.PostgresqlDialect

// The dialect definition for Presto.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type PrestoDialect = src.PrestoDialect

// The dialect definition for Redshift.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type RedshiftDialect = src.RedshiftDialect

// Provides details for errors and the corresponding resources.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type ResourceErrorDetail = src.ResourceErrorDetail

// The dialect definition for SQL Server.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type SQLServerDialect = src.SQLServerDialect

// The dialect definition for Snowflake.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type SnowflakeDialect = src.SnowflakeDialect

// Represents the default source environment values for the translation.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type SourceEnv = src.SourceEnv

// The dialect definition for SparkSQL.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type SparkSQLDialect = src.SparkSQLDialect

// A request to start a previously created migration workflow.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type StartMigrationWorkflowRequest = src.StartMigrationWorkflowRequest

// The dialect definition for Teradata.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type TeradataDialect = src.TeradataDialect

// The sub-dialect options for Teradata.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type TeradataDialect_Mode = src.TeradataDialect_Mode

// A time interval extending just after a start time through an end time. If
// the start time is the same as the end time, then the interval represents a
// single point in time.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type TimeInterval = src.TimeInterval

// The metrics object for a SubTask.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type TimeSeries = src.TimeSeries

// The translation config to capture necessary settings for a translation task
// and subtask.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type TranslationConfigDetails = src.TranslationConfigDetails
type TranslationConfigDetails_GcsSourcePath = src.TranslationConfigDetails_GcsSourcePath
type TranslationConfigDetails_GcsTargetPath = src.TranslationConfigDetails_GcsTargetPath
type TranslationConfigDetails_NameMappingList = src.TranslationConfigDetails_NameMappingList

// A single strongly-typed value.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type TypedValue = src.TypedValue
type TypedValue_BoolValue = src.TypedValue_BoolValue
type TypedValue_DistributionValue = src.TypedValue_DistributionValue
type TypedValue_DoubleValue = src.TypedValue_DoubleValue
type TypedValue_Int64Value = src.TypedValue_Int64Value
type TypedValue_StringValue = src.TypedValue_StringValue

// UnimplementedMigrationServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type UnimplementedMigrationServiceServer = src.UnimplementedMigrationServiceServer

// The dialect definition for Vertica.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
type VerticaDialect = src.VerticaDialect

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
func NewMigrationServiceClient(cc grpc.ClientConnInterface) MigrationServiceClient {
	return src.NewMigrationServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/migration/apiv2/migrationpb
func RegisterMigrationServiceServer(s *grpc.Server, srv MigrationServiceServer) {
	src.RegisterMigrationServiceServer(s, srv)
}
