// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package dataqna aliases all exported identifiers in package
// "cloud.google.com/go/dataqna/apiv1alpha/dataqnapb".
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package dataqna

import (
	src "cloud.google.com/go/dataqna/apiv1alpha/dataqnapb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
const (
	AnnotatedString_BLOCKED                                = src.AnnotatedString_BLOCKED
	AnnotatedString_DIMENSION                              = src.AnnotatedString_DIMENSION
	AnnotatedString_FILTER                                 = src.AnnotatedString_FILTER
	AnnotatedString_MARKUP_TYPE_UNSPECIFIED                = src.AnnotatedString_MARKUP_TYPE_UNSPECIFIED
	AnnotatedString_METRIC                                 = src.AnnotatedString_METRIC
	AnnotatedString_ROW                                    = src.AnnotatedString_ROW
	AnnotatedString_UNUSED                                 = src.AnnotatedString_UNUSED
	ExecutionInfo_FAILED                                   = src.ExecutionInfo_FAILED
	ExecutionInfo_JOB_EXECUTION_STATE_UNSPECIFIED          = src.ExecutionInfo_JOB_EXECUTION_STATE_UNSPECIFIED
	ExecutionInfo_NOT_EXECUTED                             = src.ExecutionInfo_NOT_EXECUTED
	ExecutionInfo_RUNNING                                  = src.ExecutionInfo_RUNNING
	ExecutionInfo_SUCCEEDED                                = src.ExecutionInfo_SUCCEEDED
	InterpretEntity_DIMENSION                              = src.InterpretEntity_DIMENSION
	InterpretEntity_INTERPRET_ENTITY_UNSPECIFIED           = src.InterpretEntity_INTERPRET_ENTITY_UNSPECIFIED
	InterpretEntity_METRIC                                 = src.InterpretEntity_METRIC
	InterpretError_FAILED_TO_ANSWER                        = src.InterpretError_FAILED_TO_ANSWER
	InterpretError_FAILED_TO_UNDERSTAND                    = src.InterpretError_FAILED_TO_UNDERSTAND
	InterpretError_INTERPRET_ERROR_CODE_UNSPECIFIED        = src.InterpretError_INTERPRET_ERROR_CODE_UNSPECIFIED
	InterpretError_INVALID_QUERY                           = src.InterpretError_INVALID_QUERY
	InterpretationStructure_AREA_CHART                     = src.InterpretationStructure_AREA_CHART
	InterpretationStructure_BAR_CHART                      = src.InterpretationStructure_BAR_CHART
	InterpretationStructure_CHART_NOT_UNDERSTOOD           = src.InterpretationStructure_CHART_NOT_UNDERSTOOD
	InterpretationStructure_COLUMN_CHART                   = src.InterpretationStructure_COLUMN_CHART
	InterpretationStructure_COMBO_CHART                    = src.InterpretationStructure_COMBO_CHART
	InterpretationStructure_GENERIC_CHART                  = src.InterpretationStructure_GENERIC_CHART
	InterpretationStructure_HISTOGRAM                      = src.InterpretationStructure_HISTOGRAM
	InterpretationStructure_LINE_CHART                     = src.InterpretationStructure_LINE_CHART
	InterpretationStructure_PIE_CHART                      = src.InterpretationStructure_PIE_CHART
	InterpretationStructure_SCATTER_PLOT                   = src.InterpretationStructure_SCATTER_PLOT
	InterpretationStructure_TABLE                          = src.InterpretationStructure_TABLE
	InterpretationStructure_TIMELINE                       = src.InterpretationStructure_TIMELINE
	InterpretationStructure_VISUALIZATION_TYPE_UNSPECIFIED = src.InterpretationStructure_VISUALIZATION_TYPE_UNSPECIFIED
	SuggestionType_ENTITY                                  = src.SuggestionType_ENTITY
	SuggestionType_SUGGESTION_TYPE_UNSPECIFIED             = src.SuggestionType_SUGGESTION_TYPE_UNSPECIFIED
	SuggestionType_TEMPLATE                                = src.SuggestionType_TEMPLATE
	UserFeedback_NEGATIVE                                  = src.UserFeedback_NEGATIVE
	UserFeedback_POSITIVE                                  = src.UserFeedback_POSITIVE
	UserFeedback_USER_FEEDBACK_RATING_UNSPECIFIED          = src.UserFeedback_USER_FEEDBACK_RATING_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
var (
	AnnotatedString_SemanticMarkupType_name                         = src.AnnotatedString_SemanticMarkupType_name
	AnnotatedString_SemanticMarkupType_value                        = src.AnnotatedString_SemanticMarkupType_value
	ExecutionInfo_JobExecutionState_name                            = src.ExecutionInfo_JobExecutionState_name
	ExecutionInfo_JobExecutionState_value                           = src.ExecutionInfo_JobExecutionState_value
	File_google_cloud_dataqna_v1alpha_annotated_string_proto        = src.File_google_cloud_dataqna_v1alpha_annotated_string_proto
	File_google_cloud_dataqna_v1alpha_auto_suggestion_service_proto = src.File_google_cloud_dataqna_v1alpha_auto_suggestion_service_proto
	File_google_cloud_dataqna_v1alpha_question_proto                = src.File_google_cloud_dataqna_v1alpha_question_proto
	File_google_cloud_dataqna_v1alpha_question_service_proto        = src.File_google_cloud_dataqna_v1alpha_question_service_proto
	File_google_cloud_dataqna_v1alpha_user_feedback_proto           = src.File_google_cloud_dataqna_v1alpha_user_feedback_proto
	InterpretEntity_name                                            = src.InterpretEntity_name
	InterpretEntity_value                                           = src.InterpretEntity_value
	InterpretError_InterpretErrorCode_name                          = src.InterpretError_InterpretErrorCode_name
	InterpretError_InterpretErrorCode_value                         = src.InterpretError_InterpretErrorCode_value
	InterpretationStructure_VisualizationType_name                  = src.InterpretationStructure_VisualizationType_name
	InterpretationStructure_VisualizationType_value                 = src.InterpretationStructure_VisualizationType_value
	SuggestionType_name                                             = src.SuggestionType_name
	SuggestionType_value                                            = src.SuggestionType_value
	UserFeedback_UserFeedbackRating_name                            = src.UserFeedback_UserFeedbackRating_name
	UserFeedback_UserFeedbackRating_value                           = src.UserFeedback_UserFeedbackRating_value
)

// Describes string annotation from both semantic and formatting perspectives.
// Example: User Query: top countries by population in Africa 0 4 14 17 28 31
// 37 Table Data: + "country" - dimension + "population" - metric + "Africa" -
// value in the "continent" column text_formatted = `"top countries by
// population in Africa"` html_formatted = `"top <b>countries</b> by
// <b>population</b> in <i>Africa</i>"` ``` markups = [ {DIMENSION, 4, 12}, //
// 'countries' {METRIC, 17, 26}, // 'population' {FILTER, 31, 36} // 'Africa' ]
// ``` Note that html formattings for 'DIMENSION' and 'METRIC' are the same,
// while semantic markups are different.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type AnnotatedString = src.AnnotatedString

// Semantic markup denotes a substring (by index and length) with markup
// information.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type AnnotatedString_SemanticMarkup = src.AnnotatedString_SemanticMarkup

// Semantic markup types.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type AnnotatedString_SemanticMarkupType = src.AnnotatedString_SemanticMarkupType

// AutoSuggestionServiceClient is the client API for AutoSuggestionService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type AutoSuggestionServiceClient = src.AutoSuggestionServiceClient

// AutoSuggestionServiceServer is the server API for AutoSuggestionService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type AutoSuggestionServiceServer = src.AutoSuggestionServiceServer

// BigQuery job information. This can be used to query the BigQuery API and
// retrieve the current job's status (using
// [jobs.get](https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/get)).
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type BigQueryJob = src.BigQueryJob

// Request to create a question resource.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type CreateQuestionRequest = src.CreateQuestionRequest

// Representation of the data query for the backend. This is provided for
// informational purposes only. Clients should not use it to send it to the
// backend directly, but rather use the `execute` RPC to trigger the execution.
// Using the `execute` RPC is needed in order to track the state of a question
// and report on it correctly to the data administrators.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type DataQuery = src.DataQuery

// Configuriation of debug flags.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type DebugFlags = src.DebugFlags

// Request to execute an interpretation.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type ExecuteQuestionRequest = src.ExecuteQuestionRequest

// Information about the backend status (such as BigQuery) of the execution.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type ExecutionInfo = src.ExecutionInfo

// Enum of possible job execution statuses.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type ExecutionInfo_JobExecutionState = src.ExecutionInfo_JobExecutionState

// A request to get a previously created question.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type GetQuestionRequest = src.GetQuestionRequest

// Request to get user feedback.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type GetUserFeedbackRequest = src.GetUserFeedbackRequest

// Human readable interpretation.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type HumanReadable = src.HumanReadable

// Query entities of an interpretation.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type InterpretEntity = src.InterpretEntity

// Details on the failure to interpret the question.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type InterpretError = src.InterpretError

// Details about a query that was too ambiguous. Currently, the message has no
// fields and its presence signals that there was ambiguity.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type InterpretError_InterpretAmbiguityDetails = src.InterpretError_InterpretAmbiguityDetails

// The interpret error code provides an error category why the interpretation
// failed.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type InterpretError_InterpretErrorCode = src.InterpretError_InterpretErrorCode

// Details on interpretation failure.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type InterpretError_InterpretErrorDetails = src.InterpretError_InterpretErrorDetails

// Details about an incomplete query.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type InterpretError_InterpretIncompleteQueryDetails = src.InterpretError_InterpretIncompleteQueryDetails

// Details about unsupported parts in a query.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type InterpretError_InterpretUnsupportedDetails = src.InterpretError_InterpretUnsupportedDetails

// An interpretation of a natural language query.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type Interpretation = src.Interpretation

// Information about the interpretation structure that helps to understand and
// visualize the response.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type InterpretationStructure = src.InterpretationStructure

// Information about a column.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type InterpretationStructure_ColumnInfo = src.InterpretationStructure_ColumnInfo

// Enumeration of visualzation types to use for query response data.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type InterpretationStructure_VisualizationType = src.InterpretationStructure_VisualizationType

// The question resource represents a natural language query, its settings,
// understanding generated by the system, and answer retrieval status. A
// question cannot be modified.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type Question = src.Question

// QuestionServiceClient is the client API for QuestionService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type QuestionServiceClient = src.QuestionServiceClient

// QuestionServiceServer is the server API for QuestionService service.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type QuestionServiceServer = src.QuestionServiceServer

// Request for query suggestions.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type SuggestQueriesRequest = src.SuggestQueriesRequest

// Response to SuggestQueries.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type SuggestQueriesResponse = src.SuggestQueriesResponse

// A suggestion for a query with a ranking score.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type Suggestion = src.Suggestion

// Detailed information about the suggestion.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type SuggestionInfo = src.SuggestionInfo

// MatchInfo describes which part of suggestion matched with data in user
// typed query. This can be used to highlight matching parts in the UI. This is
// different from the annotations provided in annotated_suggestion. The
// annotated_suggestion provides information about the semantic meaning, while
// this provides information about how it relates to the input. Example: user
// query: `top products` ``` annotated_suggestion { text_formatted = "top
// product_group" html_formatted = "top <b>product_group</b>" markups { {type:
// TEXT, start_char_index: 0, length: 3} {type: DIMENSION, start_char_index: 4,
// length: 13} } } query_matches { { start_char_index: 0, length: 3 } {
// start_char_index: 4, length: 7} } ```
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type SuggestionInfo_MatchInfo = src.SuggestionInfo_MatchInfo

// The type of suggestion.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type SuggestionType = src.SuggestionType

// UnimplementedAutoSuggestionServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type UnimplementedAutoSuggestionServiceServer = src.UnimplementedAutoSuggestionServiceServer

// UnimplementedQuestionServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type UnimplementedQuestionServiceServer = src.UnimplementedQuestionServiceServer

// Request to updates user feedback.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type UpdateUserFeedbackRequest = src.UpdateUserFeedbackRequest

// Feedback provided by a user.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type UserFeedback = src.UserFeedback

// Enumeration of feedback ratings.
//
// Deprecated: Please use types in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
type UserFeedback_UserFeedbackRating = src.UserFeedback_UserFeedbackRating

// Deprecated: Please use funcs in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
func NewAutoSuggestionServiceClient(cc grpc.ClientConnInterface) AutoSuggestionServiceClient {
	return src.NewAutoSuggestionServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
func NewQuestionServiceClient(cc grpc.ClientConnInterface) QuestionServiceClient {
	return src.NewQuestionServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
func RegisterAutoSuggestionServiceServer(s *grpc.Server, srv AutoSuggestionServiceServer) {
	src.RegisterAutoSuggestionServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/dataqna/apiv1alpha/dataqnapb
func RegisterQuestionServiceServer(s *grpc.Server, srv QuestionServiceServer) {
	src.RegisterQuestionServiceServer(s, srv)
}
