// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package publicca aliases all exported identifiers in package
// "cloud.google.com/go/security/publicca/apiv1beta1/publiccapb".
//
// Deprecated: Please use types in: cloud.google.com/go/security/publicca/apiv1beta1/publiccapb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package publicca

import (
	src "cloud.google.com/go/security/publicca/apiv1beta1/publiccapb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use vars in: cloud.google.com/go/security/publicca/apiv1beta1/publiccapb
var (
	File_google_cloud_security_publicca_v1beta1_resources_proto = src.File_google_cloud_security_publicca_v1beta1_resources_proto
	File_google_cloud_security_publicca_v1beta1_service_proto   = src.File_google_cloud_security_publicca_v1beta1_service_proto
)

// Creates a new
// [ExternalAccountKey][google.cloud.security.publicca.v1beta1.ExternalAccountKey]
// in a given project.
//
// Deprecated: Please use types in: cloud.google.com/go/security/publicca/apiv1beta1/publiccapb
type CreateExternalAccountKeyRequest = src.CreateExternalAccountKeyRequest

// A representation of an ExternalAccountKey used for [external account
// binding](https://tools.ietf.org/html/rfc8555#section-7.3.4) within ACME.
//
// Deprecated: Please use types in: cloud.google.com/go/security/publicca/apiv1beta1/publiccapb
type ExternalAccountKey = src.ExternalAccountKey

// PublicCertificateAuthorityServiceClient is the client API for
// PublicCertificateAuthorityService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/security/publicca/apiv1beta1/publiccapb
type PublicCertificateAuthorityServiceClient = src.PublicCertificateAuthorityServiceClient

// PublicCertificateAuthorityServiceServer is the server API for
// PublicCertificateAuthorityService service.
//
// Deprecated: Please use types in: cloud.google.com/go/security/publicca/apiv1beta1/publiccapb
type PublicCertificateAuthorityServiceServer = src.PublicCertificateAuthorityServiceServer

// UnimplementedPublicCertificateAuthorityServiceServer can be embedded to
// have forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/security/publicca/apiv1beta1/publiccapb
type UnimplementedPublicCertificateAuthorityServiceServer = src.UnimplementedPublicCertificateAuthorityServiceServer

// Deprecated: Please use funcs in: cloud.google.com/go/security/publicca/apiv1beta1/publiccapb
func NewPublicCertificateAuthorityServiceClient(cc grpc.ClientConnInterface) PublicCertificateAuthorityServiceClient {
	return src.NewPublicCertificateAuthorityServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/security/publicca/apiv1beta1/publiccapb
func RegisterPublicCertificateAuthorityServiceServer(s *grpc.Server, srv PublicCertificateAuthorityServiceServer) {
	src.RegisterPublicCertificateAuthorityServiceServer(s, srv)
}
