// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package lifesciences aliases all exported identifiers in package
// "cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb".
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package lifesciences

import (
	src "cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use vars in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
var (
	File_google_cloud_lifesciences_v2beta_workflows_proto = src.File_google_cloud_lifesciences_v2beta_workflows_proto
)

// Carries information about an accelerator that can be attached to a VM.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Accelerator = src.Accelerator

// Specifies a single action that runs a Docker container.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Action = src.Action

// An event generated when a container is forcibly terminated by the worker.
// Currently, this only occurs when the container outlives the timeout
// specified by the user.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type ContainerKilledEvent = src.ContainerKilledEvent

// An event generated when a container starts.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type ContainerStartedEvent = src.ContainerStartedEvent

// An event generated when a container exits.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type ContainerStoppedEvent = src.ContainerStoppedEvent

// An event generated whenever a resource limitation or transient error delays
// execution of a pipeline that was otherwise ready to run.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type DelayedEvent = src.DelayedEvent

// Carries information about a disk that can be attached to a VM. See
// https://cloud.google.com/compute/docs/disks/performance for more information
// about disk type, size, and performance considerations. Specify either
// [`Volume`][google.cloud.lifesciences.v2beta.Volume] or
// [`Disk`][google.cloud.lifesciences.v2beta.Disk], but not both.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Disk = src.Disk

// Carries information about events that occur during pipeline execution.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Event = src.Event
type Event_ContainerKilled = src.Event_ContainerKilled
type Event_ContainerStarted = src.Event_ContainerStarted
type Event_ContainerStopped = src.Event_ContainerStopped
type Event_Delayed = src.Event_Delayed
type Event_Failed = src.Event_Failed
type Event_PullStarted = src.Event_PullStarted
type Event_PullStopped = src.Event_PullStopped
type Event_UnexpectedExitStatus = src.Event_UnexpectedExitStatus
type Event_WorkerAssigned = src.Event_WorkerAssigned
type Event_WorkerReleased = src.Event_WorkerReleased

// Configuration for an existing disk to be attached to the VM.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type ExistingDisk = src.ExistingDisk

// An event generated when the execution of a pipeline has failed. Note that
// other events can continue to occur after this event.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type FailedEvent = src.FailedEvent

// Carries information about the pipeline execution that is returned in the
// long running operation's metadata field.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Metadata = src.Metadata

// Carries information about a particular disk mount inside a container.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Mount = src.Mount

// Configuration for an `NFSMount` to be attached to the VM.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type NFSMount = src.NFSMount

// VM networking options.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Network = src.Network

// Configuration for a persistent disk to be attached to the VM. See
// https://cloud.google.com/compute/docs/disks/performance for more information
// about disk type, size, and performance considerations.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type PersistentDisk = src.PersistentDisk

// Specifies a series of actions to execute, expressed as Docker containers.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Pipeline = src.Pipeline

// An event generated when the worker starts pulling an image.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type PullStartedEvent = src.PullStartedEvent

// An event generated when the worker stops pulling an image.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type PullStoppedEvent = src.PullStoppedEvent

// The system resources for the pipeline run. At least one zone or region must
// be specified or the pipeline run will fail.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Resources = src.Resources

// The arguments to the `RunPipeline` method. The requesting user must have
// the `iam.serviceAccounts.actAs` permission for the Cloud Life Sciences
// service account or the request will fail.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type RunPipelineRequest = src.RunPipelineRequest

// The response to the RunPipeline method, returned in the operation's result
// field on success.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type RunPipelineResponse = src.RunPipelineResponse

// Holds encrypted information that is only decrypted and stored in RAM by the
// worker VM when running the pipeline.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Secret = src.Secret

// Carries information about a Google Cloud service account.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type ServiceAccount = src.ServiceAccount

// An event generated when the execution of a container results in a non-zero
// exit status that was not otherwise ignored. Execution will continue, but
// only actions that are flagged as `ALWAYS_RUN` will be executed. Other
// actions will be skipped.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type UnexpectedExitStatusEvent = src.UnexpectedExitStatusEvent

// UnimplementedWorkflowsServiceV2BetaServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type UnimplementedWorkflowsServiceV2BetaServer = src.UnimplementedWorkflowsServiceV2BetaServer

// Carries information about a Compute Engine VM resource.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type VirtualMachine = src.VirtualMachine

// Carries information about storage that can be attached to a VM. Specify
// either [`Volume`][google.cloud.lifesciences.v2beta.Volume] or
// [`Disk`][google.cloud.lifesciences.v2beta.Disk], but not both.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type Volume = src.Volume
type Volume_ExistingDisk = src.Volume_ExistingDisk
type Volume_NfsMount = src.Volume_NfsMount
type Volume_PersistentDisk = src.Volume_PersistentDisk

// An event generated after a worker VM has been assigned to run the pipeline.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type WorkerAssignedEvent = src.WorkerAssignedEvent

// An event generated when the worker VM that was assigned to the pipeline has
// been released (deleted).
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type WorkerReleasedEvent = src.WorkerReleasedEvent

// WorkflowsServiceV2BetaClient is the client API for WorkflowsServiceV2Beta
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type WorkflowsServiceV2BetaClient = src.WorkflowsServiceV2BetaClient

// WorkflowsServiceV2BetaServer is the server API for WorkflowsServiceV2Beta
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
type WorkflowsServiceV2BetaServer = src.WorkflowsServiceV2BetaServer

// Deprecated: Please use funcs in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
func NewWorkflowsServiceV2BetaClient(cc grpc.ClientConnInterface) WorkflowsServiceV2BetaClient {
	return src.NewWorkflowsServiceV2BetaClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/lifesciences/apiv2beta/lifesciencespb
func RegisterWorkflowsServiceV2BetaServer(s *grpc.Server, srv WorkflowsServiceV2BetaServer) {
	src.RegisterWorkflowsServiceV2BetaServer(s, srv)
}
