// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package appengine aliases all exported identifiers in package
// "cloud.google.com/go/appengine/apiv1/appenginepb".
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package appengine

import (
	src "cloud.google.com/go/appengine/apiv1/appenginepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/appengine/apiv1/appenginepb
const (
	Application_CLOUD_DATASTORE                                 = src.Application_CLOUD_DATASTORE
	Application_CLOUD_DATASTORE_COMPATIBILITY                   = src.Application_CLOUD_DATASTORE_COMPATIBILITY
	Application_CLOUD_FIRESTORE                                 = src.Application_CLOUD_FIRESTORE
	Application_DATABASE_TYPE_UNSPECIFIED                       = src.Application_DATABASE_TYPE_UNSPECIFIED
	Application_SERVING                                         = src.Application_SERVING
	Application_SYSTEM_DISABLED                                 = src.Application_SYSTEM_DISABLED
	Application_UNSPECIFIED                                     = src.Application_UNSPECIFIED
	Application_USER_DISABLED                                   = src.Application_USER_DISABLED
	AuthFailAction_AUTH_FAIL_ACTION_REDIRECT                    = src.AuthFailAction_AUTH_FAIL_ACTION_REDIRECT
	AuthFailAction_AUTH_FAIL_ACTION_UNAUTHORIZED                = src.AuthFailAction_AUTH_FAIL_ACTION_UNAUTHORIZED
	AuthFailAction_AUTH_FAIL_ACTION_UNSPECIFIED                 = src.AuthFailAction_AUTH_FAIL_ACTION_UNSPECIFIED
	AuthorizedCertificateView_BASIC_CERTIFICATE                 = src.AuthorizedCertificateView_BASIC_CERTIFICATE
	AuthorizedCertificateView_FULL_CERTIFICATE                  = src.AuthorizedCertificateView_FULL_CERTIFICATE
	DomainOverrideStrategy_OVERRIDE                             = src.DomainOverrideStrategy_OVERRIDE
	DomainOverrideStrategy_STRICT                               = src.DomainOverrideStrategy_STRICT
	DomainOverrideStrategy_UNSPECIFIED_DOMAIN_OVERRIDE_STRATEGY = src.DomainOverrideStrategy_UNSPECIFIED_DOMAIN_OVERRIDE_STRATEGY
	EndpointsApiService_FIXED                                   = src.EndpointsApiService_FIXED
	EndpointsApiService_MANAGED                                 = src.EndpointsApiService_MANAGED
	EndpointsApiService_UNSPECIFIED_ROLLOUT_STRATEGY            = src.EndpointsApiService_UNSPECIFIED_ROLLOUT_STRATEGY
	ErrorHandler_ERROR_CODE_DEFAULT                             = src.ErrorHandler_ERROR_CODE_DEFAULT
	ErrorHandler_ERROR_CODE_DOS_API_DENIAL                      = src.ErrorHandler_ERROR_CODE_DOS_API_DENIAL
	ErrorHandler_ERROR_CODE_OVER_QUOTA                          = src.ErrorHandler_ERROR_CODE_OVER_QUOTA
	ErrorHandler_ERROR_CODE_TIMEOUT                             = src.ErrorHandler_ERROR_CODE_TIMEOUT
	ErrorHandler_ERROR_CODE_UNSPECIFIED                         = src.ErrorHandler_ERROR_CODE_UNSPECIFIED
	FirewallRule_ALLOW                                          = src.FirewallRule_ALLOW
	FirewallRule_DENY                                           = src.FirewallRule_DENY
	FirewallRule_UNSPECIFIED_ACTION                             = src.FirewallRule_UNSPECIFIED_ACTION
	InboundServiceType_INBOUND_SERVICE_CHANNEL_PRESENCE         = src.InboundServiceType_INBOUND_SERVICE_CHANNEL_PRESENCE
	InboundServiceType_INBOUND_SERVICE_MAIL                     = src.InboundServiceType_INBOUND_SERVICE_MAIL
	InboundServiceType_INBOUND_SERVICE_MAIL_BOUNCE              = src.InboundServiceType_INBOUND_SERVICE_MAIL_BOUNCE
	InboundServiceType_INBOUND_SERVICE_UNSPECIFIED              = src.InboundServiceType_INBOUND_SERVICE_UNSPECIFIED
	InboundServiceType_INBOUND_SERVICE_WARMUP                   = src.InboundServiceType_INBOUND_SERVICE_WARMUP
	InboundServiceType_INBOUND_SERVICE_XMPP_ERROR               = src.InboundServiceType_INBOUND_SERVICE_XMPP_ERROR
	InboundServiceType_INBOUND_SERVICE_XMPP_MESSAGE             = src.InboundServiceType_INBOUND_SERVICE_XMPP_MESSAGE
	InboundServiceType_INBOUND_SERVICE_XMPP_PRESENCE            = src.InboundServiceType_INBOUND_SERVICE_XMPP_PRESENCE
	InboundServiceType_INBOUND_SERVICE_XMPP_SUBSCRIBE           = src.InboundServiceType_INBOUND_SERVICE_XMPP_SUBSCRIBE
	Instance_DYNAMIC                                            = src.Instance_DYNAMIC
	Instance_Liveness_DRAINING                                  = src.Instance_Liveness_DRAINING
	Instance_Liveness_HEALTHY                                   = src.Instance_Liveness_HEALTHY
	Instance_Liveness_LIVENESS_STATE_UNSPECIFIED                = src.Instance_Liveness_LIVENESS_STATE_UNSPECIFIED
	Instance_Liveness_TIMEOUT                                   = src.Instance_Liveness_TIMEOUT
	Instance_Liveness_UNHEALTHY                                 = src.Instance_Liveness_UNHEALTHY
	Instance_Liveness_UNKNOWN                                   = src.Instance_Liveness_UNKNOWN
	Instance_RESIDENT                                           = src.Instance_RESIDENT
	Instance_UNSPECIFIED                                        = src.Instance_UNSPECIFIED
	LoginRequirement_LOGIN_ADMIN                                = src.LoginRequirement_LOGIN_ADMIN
	LoginRequirement_LOGIN_OPTIONAL                             = src.LoginRequirement_LOGIN_OPTIONAL
	LoginRequirement_LOGIN_REQUIRED                             = src.LoginRequirement_LOGIN_REQUIRED
	LoginRequirement_LOGIN_UNSPECIFIED                          = src.LoginRequirement_LOGIN_UNSPECIFIED
	ManagementStatus_FAILED_PERMANENT                           = src.ManagementStatus_FAILED_PERMANENT
	ManagementStatus_FAILED_RETRYING_CAA_CHECKING               = src.ManagementStatus_FAILED_RETRYING_CAA_CHECKING
	ManagementStatus_FAILED_RETRYING_CAA_FORBIDDEN              = src.ManagementStatus_FAILED_RETRYING_CAA_FORBIDDEN
	ManagementStatus_FAILED_RETRYING_NOT_VISIBLE                = src.ManagementStatus_FAILED_RETRYING_NOT_VISIBLE
	ManagementStatus_MANAGEMENT_STATUS_UNSPECIFIED              = src.ManagementStatus_MANAGEMENT_STATUS_UNSPECIFIED
	ManagementStatus_OK                                         = src.ManagementStatus_OK
	ManagementStatus_PENDING                                    = src.ManagementStatus_PENDING
	NetworkSettings_INGRESS_TRAFFIC_ALLOWED_ALL                 = src.NetworkSettings_INGRESS_TRAFFIC_ALLOWED_ALL
	NetworkSettings_INGRESS_TRAFFIC_ALLOWED_INTERNAL_AND_LB     = src.NetworkSettings_INGRESS_TRAFFIC_ALLOWED_INTERNAL_AND_LB
	NetworkSettings_INGRESS_TRAFFIC_ALLOWED_INTERNAL_ONLY       = src.NetworkSettings_INGRESS_TRAFFIC_ALLOWED_INTERNAL_ONLY
	NetworkSettings_INGRESS_TRAFFIC_ALLOWED_UNSPECIFIED         = src.NetworkSettings_INGRESS_TRAFFIC_ALLOWED_UNSPECIFIED
	ResourceRecord_A                                            = src.ResourceRecord_A
	ResourceRecord_AAAA                                         = src.ResourceRecord_AAAA
	ResourceRecord_CNAME                                        = src.ResourceRecord_CNAME
	ResourceRecord_RECORD_TYPE_UNSPECIFIED                      = src.ResourceRecord_RECORD_TYPE_UNSPECIFIED
	SecurityLevel_SECURE_ALWAYS                                 = src.SecurityLevel_SECURE_ALWAYS
	SecurityLevel_SECURE_DEFAULT                                = src.SecurityLevel_SECURE_DEFAULT
	SecurityLevel_SECURE_NEVER                                  = src.SecurityLevel_SECURE_NEVER
	SecurityLevel_SECURE_OPTIONAL                               = src.SecurityLevel_SECURE_OPTIONAL
	SecurityLevel_SECURE_UNSPECIFIED                            = src.SecurityLevel_SECURE_UNSPECIFIED
	ServingStatus_SERVING                                       = src.ServingStatus_SERVING
	ServingStatus_SERVING_STATUS_UNSPECIFIED                    = src.ServingStatus_SERVING_STATUS_UNSPECIFIED
	ServingStatus_STOPPED                                       = src.ServingStatus_STOPPED
	SslSettings_AUTOMATIC                                       = src.SslSettings_AUTOMATIC
	SslSettings_MANUAL                                          = src.SslSettings_MANUAL
	SslSettings_SSL_MANAGEMENT_TYPE_UNSPECIFIED                 = src.SslSettings_SSL_MANAGEMENT_TYPE_UNSPECIFIED
	TrafficSplit_COOKIE                                         = src.TrafficSplit_COOKIE
	TrafficSplit_IP                                             = src.TrafficSplit_IP
	TrafficSplit_RANDOM                                         = src.TrafficSplit_RANDOM
	TrafficSplit_UNSPECIFIED                                    = src.TrafficSplit_UNSPECIFIED
	UrlMap_REDIRECT_HTTP_RESPONSE_CODE_301                      = src.UrlMap_REDIRECT_HTTP_RESPONSE_CODE_301
	UrlMap_REDIRECT_HTTP_RESPONSE_CODE_302                      = src.UrlMap_REDIRECT_HTTP_RESPONSE_CODE_302
	UrlMap_REDIRECT_HTTP_RESPONSE_CODE_303                      = src.UrlMap_REDIRECT_HTTP_RESPONSE_CODE_303
	UrlMap_REDIRECT_HTTP_RESPONSE_CODE_307                      = src.UrlMap_REDIRECT_HTTP_RESPONSE_CODE_307
	UrlMap_REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED              = src.UrlMap_REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED
	VersionView_BASIC                                           = src.VersionView_BASIC
	VersionView_FULL                                            = src.VersionView_FULL
	VpcAccessConnector_ALL_TRAFFIC                              = src.VpcAccessConnector_ALL_TRAFFIC
	VpcAccessConnector_EGRESS_SETTING_UNSPECIFIED               = src.VpcAccessConnector_EGRESS_SETTING_UNSPECIFIED
	VpcAccessConnector_PRIVATE_IP_RANGES                        = src.VpcAccessConnector_PRIVATE_IP_RANGES
)

// Deprecated: Please use vars in: cloud.google.com/go/appengine/apiv1/appenginepb
var (
	Application_DatabaseType_name                   = src.Application_DatabaseType_name
	Application_DatabaseType_value                  = src.Application_DatabaseType_value
	Application_ServingStatus_name                  = src.Application_ServingStatus_name
	Application_ServingStatus_value                 = src.Application_ServingStatus_value
	AuthFailAction_name                             = src.AuthFailAction_name
	AuthFailAction_value                            = src.AuthFailAction_value
	AuthorizedCertificateView_name                  = src.AuthorizedCertificateView_name
	AuthorizedCertificateView_value                 = src.AuthorizedCertificateView_value
	DomainOverrideStrategy_name                     = src.DomainOverrideStrategy_name
	DomainOverrideStrategy_value                    = src.DomainOverrideStrategy_value
	EndpointsApiService_RolloutStrategy_name        = src.EndpointsApiService_RolloutStrategy_name
	EndpointsApiService_RolloutStrategy_value       = src.EndpointsApiService_RolloutStrategy_value
	ErrorHandler_ErrorCode_name                     = src.ErrorHandler_ErrorCode_name
	ErrorHandler_ErrorCode_value                    = src.ErrorHandler_ErrorCode_value
	File_google_appengine_v1_app_yaml_proto         = src.File_google_appengine_v1_app_yaml_proto
	File_google_appengine_v1_appengine_proto        = src.File_google_appengine_v1_appengine_proto
	File_google_appengine_v1_application_proto      = src.File_google_appengine_v1_application_proto
	File_google_appengine_v1_audit_data_proto       = src.File_google_appengine_v1_audit_data_proto
	File_google_appengine_v1_certificate_proto      = src.File_google_appengine_v1_certificate_proto
	File_google_appengine_v1_deploy_proto           = src.File_google_appengine_v1_deploy_proto
	File_google_appengine_v1_deployed_files_proto   = src.File_google_appengine_v1_deployed_files_proto
	File_google_appengine_v1_domain_mapping_proto   = src.File_google_appengine_v1_domain_mapping_proto
	File_google_appengine_v1_domain_proto           = src.File_google_appengine_v1_domain_proto
	File_google_appengine_v1_firewall_proto         = src.File_google_appengine_v1_firewall_proto
	File_google_appengine_v1_instance_proto         = src.File_google_appengine_v1_instance_proto
	File_google_appengine_v1_location_proto         = src.File_google_appengine_v1_location_proto
	File_google_appengine_v1_network_settings_proto = src.File_google_appengine_v1_network_settings_proto
	File_google_appengine_v1_operation_proto        = src.File_google_appengine_v1_operation_proto
	File_google_appengine_v1_service_proto          = src.File_google_appengine_v1_service_proto
	File_google_appengine_v1_version_proto          = src.File_google_appengine_v1_version_proto
	FirewallRule_Action_name                        = src.FirewallRule_Action_name
	FirewallRule_Action_value                       = src.FirewallRule_Action_value
	InboundServiceType_name                         = src.InboundServiceType_name
	InboundServiceType_value                        = src.InboundServiceType_value
	Instance_Availability_name                      = src.Instance_Availability_name
	Instance_Availability_value                     = src.Instance_Availability_value
	Instance_Liveness_LivenessState_name            = src.Instance_Liveness_LivenessState_name
	Instance_Liveness_LivenessState_value           = src.Instance_Liveness_LivenessState_value
	LoginRequirement_name                           = src.LoginRequirement_name
	LoginRequirement_value                          = src.LoginRequirement_value
	ManagementStatus_name                           = src.ManagementStatus_name
	ManagementStatus_value                          = src.ManagementStatus_value
	NetworkSettings_IngressTrafficAllowed_name      = src.NetworkSettings_IngressTrafficAllowed_name
	NetworkSettings_IngressTrafficAllowed_value     = src.NetworkSettings_IngressTrafficAllowed_value
	ResourceRecord_RecordType_name                  = src.ResourceRecord_RecordType_name
	ResourceRecord_RecordType_value                 = src.ResourceRecord_RecordType_value
	SecurityLevel_name                              = src.SecurityLevel_name
	SecurityLevel_value                             = src.SecurityLevel_value
	ServingStatus_name                              = src.ServingStatus_name
	ServingStatus_value                             = src.ServingStatus_value
	SslSettings_SslManagementType_name              = src.SslSettings_SslManagementType_name
	SslSettings_SslManagementType_value             = src.SslSettings_SslManagementType_value
	TrafficSplit_ShardBy_name                       = src.TrafficSplit_ShardBy_name
	TrafficSplit_ShardBy_value                      = src.TrafficSplit_ShardBy_value
	UrlMap_RedirectHttpResponseCode_name            = src.UrlMap_RedirectHttpResponseCode_name
	UrlMap_RedirectHttpResponseCode_value           = src.UrlMap_RedirectHttpResponseCode_value
	VersionView_name                                = src.VersionView_name
	VersionView_value                               = src.VersionView_value
	VpcAccessConnector_EgressSetting_name           = src.VpcAccessConnector_EgressSetting_name
	VpcAccessConnector_EgressSetting_value          = src.VpcAccessConnector_EgressSetting_value
)

// [Google Cloud
// Endpoints](https://cloud.google.com/appengine/docs/python/endpoints/)
// configuration for API handlers.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ApiConfigHandler = src.ApiConfigHandler

// Uses Google Cloud Endpoints to handle requests.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ApiEndpointHandler = src.ApiEndpointHandler

// An Application resource contains the top-level configuration of an App
// Engine application.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Application = src.Application
type Application_DatabaseType = src.Application_DatabaseType

// The feature specific settings to be used in the application. These define
// behaviors that are user configurable.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Application_FeatureSettings = src.Application_FeatureSettings

// Identity-Aware Proxy
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Application_IdentityAwareProxy = src.Application_IdentityAwareProxy
type Application_ServingStatus = src.Application_ServingStatus

// ApplicationsClient is the client API for Applications service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ApplicationsClient = src.ApplicationsClient

// ApplicationsServer is the server API for Applications service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ApplicationsServer = src.ApplicationsServer

// App Engine admin service audit log.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type AuditData = src.AuditData
type AuditData_CreateVersion = src.AuditData_CreateVersion
type AuditData_UpdateService = src.AuditData_UpdateService

// Actions to take when the user is not logged in.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type AuthFailAction = src.AuthFailAction

// An SSL certificate that a user has been authorized to administer. A user is
// authorized to administer any certificate that applies to one of their
// authorized domains.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type AuthorizedCertificate = src.AuthorizedCertificate

// Fields that should be returned when an AuthorizedCertificate resource is
// retrieved.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type AuthorizedCertificateView = src.AuthorizedCertificateView

// AuthorizedCertificatesClient is the client API for AuthorizedCertificates
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type AuthorizedCertificatesClient = src.AuthorizedCertificatesClient

// AuthorizedCertificatesServer is the server API for AuthorizedCertificates
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type AuthorizedCertificatesServer = src.AuthorizedCertificatesServer

// A domain that a user has been authorized to administer. To authorize use of
// a domain, verify ownership via [Webmaster
// Central](https://www.google.com/webmasters/verification/home).
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type AuthorizedDomain = src.AuthorizedDomain

// AuthorizedDomainsClient is the client API for AuthorizedDomains service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type AuthorizedDomainsClient = src.AuthorizedDomainsClient

// AuthorizedDomainsServer is the server API for AuthorizedDomains service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type AuthorizedDomainsServer = src.AuthorizedDomainsServer

// Automatic scaling is based on request rate, response latencies, and other
// application metrics.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type AutomaticScaling = src.AutomaticScaling

// A service with basic scaling will create an instance when the application
// receives a request. The instance will be turned down when the app becomes
// idle. Basic scaling is ideal for work that is intermittent or driven by user
// activity.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type BasicScaling = src.BasicScaling

// Request message for `Firewall.BatchUpdateIngressRules`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type BatchUpdateIngressRulesRequest = src.BatchUpdateIngressRulesRequest

// Response message for `Firewall.UpdateAllIngressRules`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type BatchUpdateIngressRulesResponse = src.BatchUpdateIngressRulesResponse

// An SSL certificate obtained from a certificate authority.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type CertificateRawData = src.CertificateRawData

// Options for the build operations performed as a part of the version
// deployment. Only applicable for App Engine flexible environment when
// creating a version using source code directly.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type CloudBuildOptions = src.CloudBuildOptions

// Docker image that is used to create a container and start a VM instance for
// the version that you deploy. Only applicable for instances running in the
// App Engine flexible environment.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ContainerInfo = src.ContainerInfo

// Target scaling by CPU usage.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type CpuUtilization = src.CpuUtilization

// Request message for `Applications.CreateApplication`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type CreateApplicationRequest = src.CreateApplicationRequest

// Request message for `AuthorizedCertificates.CreateAuthorizedCertificate`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type CreateAuthorizedCertificateRequest = src.CreateAuthorizedCertificateRequest

// Request message for `DomainMappings.CreateDomainMapping`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type CreateDomainMappingRequest = src.CreateDomainMappingRequest

// Request message for `Firewall.CreateIngressRule`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type CreateIngressRuleRequest = src.CreateIngressRuleRequest

// Metadata for the given
// [google.longrunning.Operation][google.longrunning.Operation] during a
// [google.appengine.v1.CreateVersionRequest][google.appengine.v1.CreateVersionRequest].
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type CreateVersionMetadataV1 = src.CreateVersionMetadataV1

// Detailed information about CreateVersion call.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type CreateVersionMethod = src.CreateVersionMethod

// Request message for `Versions.CreateVersion`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type CreateVersionRequest = src.CreateVersionRequest

// Request message for `Instances.DebugInstance`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DebugInstanceRequest = src.DebugInstanceRequest

// Request message for `AuthorizedCertificates.DeleteAuthorizedCertificate`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DeleteAuthorizedCertificateRequest = src.DeleteAuthorizedCertificateRequest

// Request message for `DomainMappings.DeleteDomainMapping`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DeleteDomainMappingRequest = src.DeleteDomainMappingRequest

// Request message for `Firewall.DeleteIngressRule`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DeleteIngressRuleRequest = src.DeleteIngressRuleRequest

// Request message for `Instances.DeleteInstance`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DeleteInstanceRequest = src.DeleteInstanceRequest

// Request message for `Services.DeleteService`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DeleteServiceRequest = src.DeleteServiceRequest

// Request message for `Versions.DeleteVersion`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DeleteVersionRequest = src.DeleteVersionRequest

// Code and application artifacts used to deploy a version to App Engine.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Deployment = src.Deployment

// Target scaling by disk usage. Only applicable in the App Engine flexible
// environment.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DiskUtilization = src.DiskUtilization

// A domain serving an App Engine application.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DomainMapping = src.DomainMapping

// DomainMappingsClient is the client API for DomainMappings service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DomainMappingsClient = src.DomainMappingsClient

// DomainMappingsServer is the server API for DomainMappings service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DomainMappingsServer = src.DomainMappingsServer

// Override strategy for mutating an existing mapping.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type DomainOverrideStrategy = src.DomainOverrideStrategy

// [Cloud Endpoints](https://cloud.google.com/endpoints) configuration. The
// Endpoints API Service provides tooling for serving Open API and gRPC
// endpoints via an NGINX proxy. Only valid for App Engine Flexible environment
// deployments. The fields here refer to the name and configuration ID of a
// "service" resource in the [Service Management
// API](https://cloud.google.com/service-management/overview).
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type EndpointsApiService = src.EndpointsApiService

// Available rollout strategies.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type EndpointsApiService_RolloutStrategy = src.EndpointsApiService_RolloutStrategy

// The entrypoint for the application.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Entrypoint = src.Entrypoint
type Entrypoint_Shell = src.Entrypoint_Shell

// Custom static error page to be served when an error occurs.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ErrorHandler = src.ErrorHandler

// Error codes.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ErrorHandler_ErrorCode = src.ErrorHandler_ErrorCode

// Single source file that is part of the version to be deployed. Each source
// file that is deployed must be specified separately.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type FileInfo = src.FileInfo

// FirewallClient is the client API for Firewall service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type FirewallClient = src.FirewallClient

// A single firewall rule that is evaluated against incoming traffic and
// provides an action to take on matched requests.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type FirewallRule = src.FirewallRule

// Available actions to take on matching requests.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type FirewallRule_Action = src.FirewallRule_Action

// FirewallServer is the server API for Firewall service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type FirewallServer = src.FirewallServer

// Request message for `Applications.GetApplication`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type GetApplicationRequest = src.GetApplicationRequest

// Request message for `AuthorizedCertificates.GetAuthorizedCertificate`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type GetAuthorizedCertificateRequest = src.GetAuthorizedCertificateRequest

// Request message for `DomainMappings.GetDomainMapping`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type GetDomainMappingRequest = src.GetDomainMappingRequest

// Request message for `Firewall.GetIngressRule`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type GetIngressRuleRequest = src.GetIngressRuleRequest

// Request message for `Instances.GetInstance`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type GetInstanceRequest = src.GetInstanceRequest

// Request message for `Services.GetService`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type GetServiceRequest = src.GetServiceRequest

// Request message for `Versions.GetVersion`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type GetVersionRequest = src.GetVersionRequest

// Health checking configuration for VM instances. Unhealthy instances are
// killed and replaced with new instances. Only applicable for instances in App
// Engine flexible environment.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type HealthCheck = src.HealthCheck

// Available inbound services.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type InboundServiceType = src.InboundServiceType

// An Instance resource is the computing unit that App Engine uses to
// automatically scale an application.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Instance = src.Instance

// Availability of the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Instance_Availability = src.Instance_Availability

// Wrapper for LivenessState enum.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Instance_Liveness = src.Instance_Liveness

// Liveness health check status for Flex instances.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Instance_Liveness_LivenessState = src.Instance_Liveness_LivenessState

// InstancesClient is the client API for Instances service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type InstancesClient = src.InstancesClient

// InstancesServer is the server API for Instances service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type InstancesServer = src.InstancesServer

// Third-party Python runtime library that is required by the application.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Library = src.Library

// Request message for `AuthorizedCertificates.ListAuthorizedCertificates`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListAuthorizedCertificatesRequest = src.ListAuthorizedCertificatesRequest

// Response message for `AuthorizedCertificates.ListAuthorizedCertificates`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListAuthorizedCertificatesResponse = src.ListAuthorizedCertificatesResponse

// Request message for `AuthorizedDomains.ListAuthorizedDomains`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListAuthorizedDomainsRequest = src.ListAuthorizedDomainsRequest

// Response message for `AuthorizedDomains.ListAuthorizedDomains`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListAuthorizedDomainsResponse = src.ListAuthorizedDomainsResponse

// Request message for `DomainMappings.ListDomainMappings`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListDomainMappingsRequest = src.ListDomainMappingsRequest

// Response message for `DomainMappings.ListDomainMappings`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListDomainMappingsResponse = src.ListDomainMappingsResponse

// Request message for `Firewall.ListIngressRules`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListIngressRulesRequest = src.ListIngressRulesRequest

// Response message for `Firewall.ListIngressRules`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListIngressRulesResponse = src.ListIngressRulesResponse

// Request message for `Instances.ListInstances`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListInstancesRequest = src.ListInstancesRequest

// Response message for `Instances.ListInstances`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListInstancesResponse = src.ListInstancesResponse

// Request message for `Services.ListServices`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListServicesRequest = src.ListServicesRequest

// Response message for `Services.ListServices`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListServicesResponse = src.ListServicesResponse

// Request message for `Versions.ListVersions`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListVersionsRequest = src.ListVersionsRequest

// Response message for `Versions.ListVersions`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ListVersionsResponse = src.ListVersionsResponse

// Health checking configuration for VM instances. Unhealthy instances are
// killed and replaced with new instances.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type LivenessCheck = src.LivenessCheck

// Metadata for the given
// [google.cloud.location.Location][google.cloud.location.Location].
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type LocationMetadata = src.LocationMetadata

// Methods to restrict access to a URL based on login status.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type LoginRequirement = src.LoginRequirement

// A certificate managed by App Engine.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ManagedCertificate = src.ManagedCertificate

// State of certificate management. Refers to the most recent certificate
// acquisition or renewal attempt.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ManagementStatus = src.ManagementStatus

// A service with manual scaling runs continuously, allowing you to perform
// complex initialization and rely on the state of its memory over time.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ManualScaling = src.ManualScaling

// Extra network settings. Only applicable in the App Engine flexible
// environment.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Network = src.Network

// A NetworkSettings resource is a container for ingress settings for a
// version or service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type NetworkSettings = src.NetworkSettings

// If unspecified, INGRESS_TRAFFIC_ALLOWED_ALL will be used.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type NetworkSettings_IngressTrafficAllowed = src.NetworkSettings_IngressTrafficAllowed

// Target scaling by network usage. Only applicable in the App Engine flexible
// environment.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type NetworkUtilization = src.NetworkUtilization

// Metadata for the given
// [google.longrunning.Operation][google.longrunning.Operation].
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type OperationMetadataV1 = src.OperationMetadataV1
type OperationMetadataV1_CreateVersionMetadata = src.OperationMetadataV1_CreateVersionMetadata

// Readiness checking configuration for VM instances. Unhealthy instances are
// removed from traffic rotation.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ReadinessCheck = src.ReadinessCheck

// Request message for 'Applications.RepairApplication'.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type RepairApplicationRequest = src.RepairApplicationRequest

// Target scaling by request utilization. Only applicable in the App Engine
// flexible environment.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type RequestUtilization = src.RequestUtilization

// A DNS resource record.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ResourceRecord = src.ResourceRecord

// A resource record type.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ResourceRecord_RecordType = src.ResourceRecord_RecordType

// Machine resources for a version.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Resources = src.Resources

// Executes a script to handle the request that matches the URL pattern.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ScriptHandler = src.ScriptHandler

// Methods to enforce security (HTTPS) on a URL.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type SecurityLevel = src.SecurityLevel

// A Service resource is a logical component of an application that can share
// state and communicate in a secure fashion with other services. For example,
// an application that handles customer requests might include separate
// services to handle tasks such as backend data analysis or API requests from
// mobile devices. Each service has a collection of versions that define a
// specific set of code used to implement the functionality of that service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Service = src.Service

// ServicesClient is the client API for Services service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ServicesClient = src.ServicesClient

// ServicesServer is the server API for Services service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ServicesServer = src.ServicesServer

// Run states of a version.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ServingStatus = src.ServingStatus

// SSL configuration for a `DomainMapping` resource.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type SslSettings = src.SslSettings

// The SSL management type for this domain.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type SslSettings_SslManagementType = src.SslSettings_SslManagementType

// Scheduler settings for standard environment.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type StandardSchedulerSettings = src.StandardSchedulerSettings

// Files served directly to the user for a given URL, such as images, CSS
// stylesheets, or JavaScript source files. Static file handlers describe which
// files in the application directory are static files, and which URLs serve
// them.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type StaticFilesHandler = src.StaticFilesHandler

// Traffic routing configuration for versions within a single service. Traffic
// splits define how traffic directed to the service is assigned to versions.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type TrafficSplit = src.TrafficSplit

// Available sharding mechanisms.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type TrafficSplit_ShardBy = src.TrafficSplit_ShardBy

// UnimplementedApplicationsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UnimplementedApplicationsServer = src.UnimplementedApplicationsServer

// UnimplementedAuthorizedCertificatesServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UnimplementedAuthorizedCertificatesServer = src.UnimplementedAuthorizedCertificatesServer

// UnimplementedAuthorizedDomainsServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UnimplementedAuthorizedDomainsServer = src.UnimplementedAuthorizedDomainsServer

// UnimplementedDomainMappingsServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UnimplementedDomainMappingsServer = src.UnimplementedDomainMappingsServer

// UnimplementedFirewallServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UnimplementedFirewallServer = src.UnimplementedFirewallServer

// UnimplementedInstancesServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UnimplementedInstancesServer = src.UnimplementedInstancesServer

// UnimplementedServicesServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UnimplementedServicesServer = src.UnimplementedServicesServer

// UnimplementedVersionsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UnimplementedVersionsServer = src.UnimplementedVersionsServer

// Request message for `Applications.UpdateApplication`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UpdateApplicationRequest = src.UpdateApplicationRequest

// Request message for `AuthorizedCertificates.UpdateAuthorizedCertificate`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UpdateAuthorizedCertificateRequest = src.UpdateAuthorizedCertificateRequest

// Request message for `DomainMappings.UpdateDomainMapping`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UpdateDomainMappingRequest = src.UpdateDomainMappingRequest

// Request message for `Firewall.UpdateIngressRule`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UpdateIngressRuleRequest = src.UpdateIngressRuleRequest

// Detailed information about UpdateService call.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UpdateServiceMethod = src.UpdateServiceMethod

// Request message for `Services.UpdateService`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UpdateServiceRequest = src.UpdateServiceRequest

// Request message for `Versions.UpdateVersion`.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UpdateVersionRequest = src.UpdateVersionRequest

// Rules to match an HTTP request and dispatch that request to a service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UrlDispatchRule = src.UrlDispatchRule

// URL pattern and description of how the URL should be handled. App Engine
// can handle URLs by executing application code or by serving static files
// uploaded with the version, such as images, CSS, or JavaScript.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UrlMap = src.UrlMap
type UrlMap_ApiEndpoint = src.UrlMap_ApiEndpoint

// Redirect codes.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type UrlMap_RedirectHttpResponseCode = src.UrlMap_RedirectHttpResponseCode
type UrlMap_Script = src.UrlMap_Script
type UrlMap_StaticFiles = src.UrlMap_StaticFiles

// A Version resource is a specific set of source code and configuration files
// that are deployed into a service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Version = src.Version

// Fields that should be returned when [Version][google.appengine.v1.Version]
// resources are retrieved.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type VersionView = src.VersionView
type Version_AutomaticScaling = src.Version_AutomaticScaling
type Version_BasicScaling = src.Version_BasicScaling
type Version_ManualScaling = src.Version_ManualScaling

// VersionsClient is the client API for Versions service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type VersionsClient = src.VersionsClient

// VersionsServer is the server API for Versions service.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type VersionsServer = src.VersionsServer

// Volumes mounted within the app container. Only applicable in the App Engine
// flexible environment.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type Volume = src.Volume

// VPC access connector specification.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type VpcAccessConnector = src.VpcAccessConnector

// Available egress settings. This controls what traffic is diverted through
// the VPC Access Connector resource. By default PRIVATE_IP_RANGES will be
// used.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type VpcAccessConnector_EgressSetting = src.VpcAccessConnector_EgressSetting

// The zip file information for a zip deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/appengine/apiv1/appenginepb
type ZipInfo = src.ZipInfo

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func NewApplicationsClient(cc grpc.ClientConnInterface) ApplicationsClient {
	return src.NewApplicationsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func NewAuthorizedCertificatesClient(cc grpc.ClientConnInterface) AuthorizedCertificatesClient {
	return src.NewAuthorizedCertificatesClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func NewAuthorizedDomainsClient(cc grpc.ClientConnInterface) AuthorizedDomainsClient {
	return src.NewAuthorizedDomainsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func NewDomainMappingsClient(cc grpc.ClientConnInterface) DomainMappingsClient {
	return src.NewDomainMappingsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func NewFirewallClient(cc grpc.ClientConnInterface) FirewallClient { return src.NewFirewallClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func NewInstancesClient(cc grpc.ClientConnInterface) InstancesClient {
	return src.NewInstancesClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func NewServicesClient(cc grpc.ClientConnInterface) ServicesClient { return src.NewServicesClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func NewVersionsClient(cc grpc.ClientConnInterface) VersionsClient { return src.NewVersionsClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func RegisterApplicationsServer(s *grpc.Server, srv ApplicationsServer) {
	src.RegisterApplicationsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func RegisterAuthorizedCertificatesServer(s *grpc.Server, srv AuthorizedCertificatesServer) {
	src.RegisterAuthorizedCertificatesServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func RegisterAuthorizedDomainsServer(s *grpc.Server, srv AuthorizedDomainsServer) {
	src.RegisterAuthorizedDomainsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func RegisterDomainMappingsServer(s *grpc.Server, srv DomainMappingsServer) {
	src.RegisterDomainMappingsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func RegisterFirewallServer(s *grpc.Server, srv FirewallServer) { src.RegisterFirewallServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func RegisterInstancesServer(s *grpc.Server, srv InstancesServer) {
	src.RegisterInstancesServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func RegisterServicesServer(s *grpc.Server, srv ServicesServer) { src.RegisterServicesServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/appengine/apiv1/appenginepb
func RegisterVersionsServer(s *grpc.Server, srv VersionsServer) { src.RegisterVersionsServer(s, srv) }
