// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package servicecontrol aliases all exported identifiers in package
// "cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb".
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package servicecontrol

import (
	src "cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
const (
	CheckError_API_KEY_EXPIRED                            = src.CheckError_API_KEY_EXPIRED
	CheckError_API_KEY_INVALID                            = src.CheckError_API_KEY_INVALID
	CheckError_API_KEY_NOT_FOUND                          = src.CheckError_API_KEY_NOT_FOUND
	CheckError_API_TARGET_BLOCKED                         = src.CheckError_API_TARGET_BLOCKED
	CheckError_BILLING_DISABLED                           = src.CheckError_BILLING_DISABLED
	CheckError_BILLING_STATUS_UNAVAILABLE                 = src.CheckError_BILLING_STATUS_UNAVAILABLE
	CheckError_CLIENT_APP_BLOCKED                         = src.CheckError_CLIENT_APP_BLOCKED
	CheckError_CLOUD_RESOURCE_MANAGER_BACKEND_UNAVAILABLE = src.CheckError_CLOUD_RESOURCE_MANAGER_BACKEND_UNAVAILABLE
	CheckError_CONSUMER_INVALID                           = src.CheckError_CONSUMER_INVALID
	CheckError_ERROR_CODE_UNSPECIFIED                     = src.CheckError_ERROR_CODE_UNSPECIFIED
	CheckError_INVALID_CREDENTIAL                         = src.CheckError_INVALID_CREDENTIAL
	CheckError_IP_ADDRESS_BLOCKED                         = src.CheckError_IP_ADDRESS_BLOCKED
	CheckError_NAMESPACE_LOOKUP_UNAVAILABLE               = src.CheckError_NAMESPACE_LOOKUP_UNAVAILABLE
	CheckError_NOT_FOUND                                  = src.CheckError_NOT_FOUND
	CheckError_PERMISSION_DENIED                          = src.CheckError_PERMISSION_DENIED
	CheckError_PROJECT_DELETED                            = src.CheckError_PROJECT_DELETED
	CheckError_PROJECT_INVALID                            = src.CheckError_PROJECT_INVALID
	CheckError_REFERER_BLOCKED                            = src.CheckError_REFERER_BLOCKED
	CheckError_RESOURCE_EXHAUSTED                         = src.CheckError_RESOURCE_EXHAUSTED
	CheckError_SERVICE_NOT_ACTIVATED                      = src.CheckError_SERVICE_NOT_ACTIVATED
	CheckError_SERVICE_STATUS_UNAVAILABLE                 = src.CheckError_SERVICE_STATUS_UNAVAILABLE
	CheckResponse_ConsumerInfo_CONSUMER_TYPE_UNSPECIFIED  = src.CheckResponse_ConsumerInfo_CONSUMER_TYPE_UNSPECIFIED
	CheckResponse_ConsumerInfo_FOLDER                     = src.CheckResponse_ConsumerInfo_FOLDER
	CheckResponse_ConsumerInfo_ORGANIZATION               = src.CheckResponse_ConsumerInfo_ORGANIZATION
	CheckResponse_ConsumerInfo_PROJECT                    = src.CheckResponse_ConsumerInfo_PROJECT
	CheckResponse_ConsumerInfo_SERVICE_SPECIFIC           = src.CheckResponse_ConsumerInfo_SERVICE_SPECIFIC
	Operation_HIGH                                        = src.Operation_HIGH
	Operation_LOW                                         = src.Operation_LOW
	QuotaError_API_KEY_EXPIRED                            = src.QuotaError_API_KEY_EXPIRED
	QuotaError_API_KEY_INVALID                            = src.QuotaError_API_KEY_INVALID
	QuotaError_BILLING_NOT_ACTIVE                         = src.QuotaError_BILLING_NOT_ACTIVE
	QuotaError_PROJECT_DELETED                            = src.QuotaError_PROJECT_DELETED
	QuotaError_RESOURCE_EXHAUSTED                         = src.QuotaError_RESOURCE_EXHAUSTED
	QuotaError_UNSPECIFIED                                = src.QuotaError_UNSPECIFIED
	QuotaOperation_ADJUST_ONLY                            = src.QuotaOperation_ADJUST_ONLY
	QuotaOperation_BEST_EFFORT                            = src.QuotaOperation_BEST_EFFORT
	QuotaOperation_CHECK_ONLY                             = src.QuotaOperation_CHECK_ONLY
	QuotaOperation_NORMAL                                 = src.QuotaOperation_NORMAL
	QuotaOperation_QUERY_ONLY                             = src.QuotaOperation_QUERY_ONLY
	QuotaOperation_UNSPECIFIED                            = src.QuotaOperation_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
var (
	CheckError_Code_name                                       = src.CheckError_Code_name
	CheckError_Code_value                                      = src.CheckError_Code_value
	CheckResponse_ConsumerInfo_ConsumerType_name               = src.CheckResponse_ConsumerInfo_ConsumerType_name
	CheckResponse_ConsumerInfo_ConsumerType_value              = src.CheckResponse_ConsumerInfo_ConsumerType_value
	File_google_api_servicecontrol_v1_check_error_proto        = src.File_google_api_servicecontrol_v1_check_error_proto
	File_google_api_servicecontrol_v1_distribution_proto       = src.File_google_api_servicecontrol_v1_distribution_proto
	File_google_api_servicecontrol_v1_http_request_proto       = src.File_google_api_servicecontrol_v1_http_request_proto
	File_google_api_servicecontrol_v1_log_entry_proto          = src.File_google_api_servicecontrol_v1_log_entry_proto
	File_google_api_servicecontrol_v1_metric_value_proto       = src.File_google_api_servicecontrol_v1_metric_value_proto
	File_google_api_servicecontrol_v1_operation_proto          = src.File_google_api_servicecontrol_v1_operation_proto
	File_google_api_servicecontrol_v1_quota_controller_proto   = src.File_google_api_servicecontrol_v1_quota_controller_proto
	File_google_api_servicecontrol_v1_service_controller_proto = src.File_google_api_servicecontrol_v1_service_controller_proto
	Operation_Importance_name                                  = src.Operation_Importance_name
	Operation_Importance_value                                 = src.Operation_Importance_value
	QuotaError_Code_name                                       = src.QuotaError_Code_name
	QuotaError_Code_value                                      = src.QuotaError_Code_value
	QuotaOperation_QuotaMode_name                              = src.QuotaOperation_QuotaMode_name
	QuotaOperation_QuotaMode_value                             = src.QuotaOperation_QuotaMode_value
)

// Request message for the AllocateQuota method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type AllocateQuotaRequest = src.AllocateQuotaRequest

// Response message for the AllocateQuota method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type AllocateQuotaResponse = src.AllocateQuotaResponse

// Defines the errors to be returned in
// [google.api.servicecontrol.v1.CheckResponse.check_errors][google.api.servicecontrol.v1.CheckResponse.check_errors].
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type CheckError = src.CheckError

// Error codes for Check responses.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type CheckError_Code = src.CheckError_Code

// Request message for the Check method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type CheckRequest = src.CheckRequest

// Response message for the Check method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type CheckResponse = src.CheckResponse

// Contains additional information about the check operation.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type CheckResponse_CheckInfo = src.CheckResponse_CheckInfo

// `ConsumerInfo` provides information about the consumer.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type CheckResponse_ConsumerInfo = src.CheckResponse_ConsumerInfo

// The type of the consumer as defined in [Google Resource
// Manager](https://cloud.google.com/resource-manager/).
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type CheckResponse_ConsumerInfo_ConsumerType = src.CheckResponse_ConsumerInfo_ConsumerType

// Distribution represents a frequency distribution of double-valued sample
// points. It contains the size of the population of sample points plus
// additional optional information: * the arithmetic mean of the samples * the
// minimum and maximum of the samples * the sum-squared-deviation of the
// samples, used to compute variance * a histogram of the values of the sample
// points
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type Distribution = src.Distribution

// Describing buckets with arbitrary user-provided width.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type Distribution_ExplicitBuckets = src.Distribution_ExplicitBuckets
type Distribution_ExplicitBuckets_ = src.Distribution_ExplicitBuckets_

// Describing buckets with exponentially growing width.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type Distribution_ExponentialBuckets = src.Distribution_ExponentialBuckets
type Distribution_ExponentialBuckets_ = src.Distribution_ExponentialBuckets_

// Describing buckets with constant width.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type Distribution_LinearBuckets = src.Distribution_LinearBuckets
type Distribution_LinearBuckets_ = src.Distribution_LinearBuckets_

// A common proto for logging HTTP requests. Only contains semantics defined
// by the HTTP specification. Product-specific logging information MUST be
// defined in a separate message.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type HttpRequest = src.HttpRequest

// An individual log entry.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type LogEntry = src.LogEntry

// Additional information about a potentially long-running operation with
// which a log entry is associated.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type LogEntryOperation = src.LogEntryOperation

// Additional information about the source code location that produced the log
// entry.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type LogEntrySourceLocation = src.LogEntrySourceLocation
type LogEntry_ProtoPayload = src.LogEntry_ProtoPayload
type LogEntry_StructPayload = src.LogEntry_StructPayload
type LogEntry_TextPayload = src.LogEntry_TextPayload

// Represents a single metric value.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type MetricValue = src.MetricValue

// Represents a set of metric values in the same metric. Each metric value in
// the set should have a unique combination of start time, end time, and label
// values.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type MetricValueSet = src.MetricValueSet
type MetricValue_BoolValue = src.MetricValue_BoolValue
type MetricValue_DistributionValue = src.MetricValue_DistributionValue
type MetricValue_DoubleValue = src.MetricValue_DoubleValue
type MetricValue_Int64Value = src.MetricValue_Int64Value
type MetricValue_StringValue = src.MetricValue_StringValue

// Represents information regarding an operation.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type Operation = src.Operation

// Defines the importance of the data contained in the operation.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type Operation_Importance = src.Operation_Importance

// QuotaControllerClient is the client API for QuotaController service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type QuotaControllerClient = src.QuotaControllerClient

// QuotaControllerServer is the server API for QuotaController service.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type QuotaControllerServer = src.QuotaControllerServer

// Represents error information for
// [QuotaOperation][google.api.servicecontrol.v1.QuotaOperation].
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type QuotaError = src.QuotaError

// Error codes related to project config validations are deprecated since the
// quota controller methods do not perform these validations. Instead services
// have to call the Check method, without quota_properties field, to perform
// these validations before calling the quota controller methods. These methods
// check only for project deletion to be wipe out compliant.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type QuotaError_Code = src.QuotaError_Code

// Represents information regarding a quota operation.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type QuotaOperation = src.QuotaOperation

// Supported quota modes.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type QuotaOperation_QuotaMode = src.QuotaOperation_QuotaMode

// Request message for the Report method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type ReportRequest = src.ReportRequest

// Response message for the Report method.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type ReportResponse = src.ReportResponse

// Represents the processing error of one
// [Operation][google.api.servicecontrol.v1.Operation] in the request.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type ReportResponse_ReportError = src.ReportResponse_ReportError

// ServiceControllerClient is the client API for ServiceController service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type ServiceControllerClient = src.ServiceControllerClient

// ServiceControllerServer is the server API for ServiceController service.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type ServiceControllerServer = src.ServiceControllerServer

// UnimplementedQuotaControllerServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type UnimplementedQuotaControllerServer = src.UnimplementedQuotaControllerServer

// UnimplementedServiceControllerServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
type UnimplementedServiceControllerServer = src.UnimplementedServiceControllerServer

// Deprecated: Please use funcs in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
func NewQuotaControllerClient(cc grpc.ClientConnInterface) QuotaControllerClient {
	return src.NewQuotaControllerClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
func NewServiceControllerClient(cc grpc.ClientConnInterface) ServiceControllerClient {
	return src.NewServiceControllerClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
func RegisterQuotaControllerServer(s *grpc.Server, srv QuotaControllerServer) {
	src.RegisterQuotaControllerServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/servicecontrol/apiv1/servicecontrolpb
func RegisterServiceControllerServer(s *grpc.Server, srv ServiceControllerServer) {
	src.RegisterServiceControllerServer(s, srv)
}
