// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package functions aliases all exported identifiers in package
// "cloud.google.com/go/functions/apiv2/functionspb".
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package functions

import (
	src "cloud.google.com/go/functions/apiv2/functionspb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/functions/apiv2/functionspb
const (
	Environment_ENVIRONMENT_UNSPECIFIED                     = src.Environment_ENVIRONMENT_UNSPECIFIED
	Environment_GEN_1                                       = src.Environment_GEN_1
	Environment_GEN_2                                       = src.Environment_GEN_2
	EventTrigger_RETRY_POLICY_DO_NOT_RETRY                  = src.EventTrigger_RETRY_POLICY_DO_NOT_RETRY
	EventTrigger_RETRY_POLICY_RETRY                         = src.EventTrigger_RETRY_POLICY_RETRY
	EventTrigger_RETRY_POLICY_UNSPECIFIED                   = src.EventTrigger_RETRY_POLICY_UNSPECIFIED
	Function_ACTIVE                                         = src.Function_ACTIVE
	Function_DELETING                                       = src.Function_DELETING
	Function_DEPLOYING                                      = src.Function_DEPLOYING
	Function_FAILED                                         = src.Function_FAILED
	Function_STATE_UNSPECIFIED                              = src.Function_STATE_UNSPECIFIED
	Function_UNKNOWN                                        = src.Function_UNKNOWN
	ListRuntimesResponse_ALPHA                              = src.ListRuntimesResponse_ALPHA
	ListRuntimesResponse_BETA                               = src.ListRuntimesResponse_BETA
	ListRuntimesResponse_DECOMMISSIONED                     = src.ListRuntimesResponse_DECOMMISSIONED
	ListRuntimesResponse_DEPRECATED                         = src.ListRuntimesResponse_DEPRECATED
	ListRuntimesResponse_DEVELOPMENT                        = src.ListRuntimesResponse_DEVELOPMENT
	ListRuntimesResponse_GA                                 = src.ListRuntimesResponse_GA
	ListRuntimesResponse_RUNTIME_STAGE_UNSPECIFIED          = src.ListRuntimesResponse_RUNTIME_STAGE_UNSPECIFIED
	ServiceConfig_ALLOW_ALL                                 = src.ServiceConfig_ALLOW_ALL
	ServiceConfig_ALLOW_INTERNAL_AND_GCLB                   = src.ServiceConfig_ALLOW_INTERNAL_AND_GCLB
	ServiceConfig_ALLOW_INTERNAL_ONLY                       = src.ServiceConfig_ALLOW_INTERNAL_ONLY
	ServiceConfig_ALL_TRAFFIC                               = src.ServiceConfig_ALL_TRAFFIC
	ServiceConfig_INGRESS_SETTINGS_UNSPECIFIED              = src.ServiceConfig_INGRESS_SETTINGS_UNSPECIFIED
	ServiceConfig_PRIVATE_RANGES_ONLY                       = src.ServiceConfig_PRIVATE_RANGES_ONLY
	ServiceConfig_VPC_CONNECTOR_EGRESS_SETTINGS_UNSPECIFIED = src.ServiceConfig_VPC_CONNECTOR_EGRESS_SETTINGS_UNSPECIFIED
	Stage_ARTIFACT_REGISTRY                                 = src.Stage_ARTIFACT_REGISTRY
	Stage_BUILD                                             = src.Stage_BUILD
	Stage_COMPLETE                                          = src.Stage_COMPLETE
	Stage_IN_PROGRESS                                       = src.Stage_IN_PROGRESS
	Stage_NAME_UNSPECIFIED                                  = src.Stage_NAME_UNSPECIFIED
	Stage_NOT_STARTED                                       = src.Stage_NOT_STARTED
	Stage_SERVICE                                           = src.Stage_SERVICE
	Stage_SERVICE_ROLLBACK                                  = src.Stage_SERVICE_ROLLBACK
	Stage_STATE_UNSPECIFIED                                 = src.Stage_STATE_UNSPECIFIED
	Stage_TRIGGER                                           = src.Stage_TRIGGER
	Stage_TRIGGER_ROLLBACK                                  = src.Stage_TRIGGER_ROLLBACK
	StateMessage_ERROR                                      = src.StateMessage_ERROR
	StateMessage_INFO                                       = src.StateMessage_INFO
	StateMessage_SEVERITY_UNSPECIFIED                       = src.StateMessage_SEVERITY_UNSPECIFIED
	StateMessage_WARNING                                    = src.StateMessage_WARNING
)

// Deprecated: Please use vars in: cloud.google.com/go/functions/apiv2/functionspb
var (
	Environment_name                               = src.Environment_name
	Environment_value                              = src.Environment_value
	EventTrigger_RetryPolicy_name                  = src.EventTrigger_RetryPolicy_name
	EventTrigger_RetryPolicy_value                 = src.EventTrigger_RetryPolicy_value
	File_google_cloud_functions_v2_functions_proto = src.File_google_cloud_functions_v2_functions_proto
	Function_State_name                            = src.Function_State_name
	Function_State_value                           = src.Function_State_value
	ListRuntimesResponse_RuntimeStage_name         = src.ListRuntimesResponse_RuntimeStage_name
	ListRuntimesResponse_RuntimeStage_value        = src.ListRuntimesResponse_RuntimeStage_value
	ServiceConfig_IngressSettings_name             = src.ServiceConfig_IngressSettings_name
	ServiceConfig_IngressSettings_value            = src.ServiceConfig_IngressSettings_value
	ServiceConfig_VpcConnectorEgressSettings_name  = src.ServiceConfig_VpcConnectorEgressSettings_name
	ServiceConfig_VpcConnectorEgressSettings_value = src.ServiceConfig_VpcConnectorEgressSettings_value
	Stage_Name_name                                = src.Stage_Name_name
	Stage_Name_value                               = src.Stage_Name_value
	Stage_State_name                               = src.Stage_State_name
	Stage_State_value                              = src.Stage_State_value
	StateMessage_Severity_name                     = src.StateMessage_Severity_name
	StateMessage_Severity_value                    = src.StateMessage_Severity_value
)

// Describes the Build step of the function that builds a container from the
// given source.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type BuildConfig = src.BuildConfig

// Request for the `CreateFunction` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type CreateFunctionRequest = src.CreateFunctionRequest

// Request for the `DeleteFunction` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type DeleteFunctionRequest = src.DeleteFunctionRequest

// The environment the function is hosted on.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type Environment = src.Environment

// Filters events based on exact matches on the CloudEvents attributes.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type EventFilter = src.EventFilter

// Describes EventTrigger, used to request events to be sent from another
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type EventTrigger = src.EventTrigger

// Describes the retry policy in case of function's execution failure. Retried
// execution is charged as any other execution.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type EventTrigger_RetryPolicy = src.EventTrigger_RetryPolicy

// Describes a Cloud Function that contains user computation executed in
// response to an event. It encapsulates function and trigger configurations.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type Function = src.Function

// FunctionServiceClient is the client API for FunctionService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type FunctionServiceClient = src.FunctionServiceClient

// FunctionServiceServer is the server API for FunctionService service.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type FunctionServiceServer = src.FunctionServiceServer

// Describes the current state of the function.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type Function_State = src.Function_State

// Request of `GenerateDownloadUrl` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type GenerateDownloadUrlRequest = src.GenerateDownloadUrlRequest

// Response of `GenerateDownloadUrl` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type GenerateDownloadUrlResponse = src.GenerateDownloadUrlResponse

// Request of `GenerateSourceUploadUrl` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type GenerateUploadUrlRequest = src.GenerateUploadUrlRequest

// Response of `GenerateSourceUploadUrl` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type GenerateUploadUrlResponse = src.GenerateUploadUrlResponse

// Request for the `GetFunction` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type GetFunctionRequest = src.GetFunctionRequest

// Request for the `ListFunctions` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type ListFunctionsRequest = src.ListFunctionsRequest

// Response for the `ListFunctions` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type ListFunctionsResponse = src.ListFunctionsResponse

// Request for the `ListRuntimes` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type ListRuntimesRequest = src.ListRuntimesRequest

// Response for the `ListRuntimes` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type ListRuntimesResponse = src.ListRuntimesResponse

// Describes a runtime and any special information (e.g., deprecation status)
// related to it.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type ListRuntimesResponse_Runtime = src.ListRuntimesResponse_Runtime

// The various stages that a runtime can be in.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type ListRuntimesResponse_RuntimeStage = src.ListRuntimesResponse_RuntimeStage

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type OperationMetadata = src.OperationMetadata

// Location of the source in a Google Cloud Source Repository.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type RepoSource = src.RepoSource
type RepoSource_BranchName = src.RepoSource_BranchName
type RepoSource_CommitSha = src.RepoSource_CommitSha
type RepoSource_TagName = src.RepoSource_TagName

// Configuration for a secret environment variable. It has the information
// necessary to fetch the secret value from secret manager and expose it as an
// environment variable.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type SecretEnvVar = src.SecretEnvVar

// Configuration for a secret volume. It has the information necessary to
// fetch the secret value from secret manager and make it available as files
// mounted at the requested paths within the application container.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type SecretVolume = src.SecretVolume

// Configuration for a single version.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type SecretVolume_SecretVersion = src.SecretVolume_SecretVersion

// Describes the Service being deployed. Currently Supported : Cloud Run
// (fully managed).
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type ServiceConfig = src.ServiceConfig

// Available ingress settings. This controls what traffic can reach the
// function. If unspecified, ALLOW_ALL will be used.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type ServiceConfig_IngressSettings = src.ServiceConfig_IngressSettings

// Available egress settings. This controls what traffic is diverted through
// the VPC Access Connector resource. By default PRIVATE_RANGES_ONLY will be
// used.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type ServiceConfig_VpcConnectorEgressSettings = src.ServiceConfig_VpcConnectorEgressSettings

// The location of the function source code.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type Source = src.Source

// Provenance of the source. Ways to find the original source, or verify that
// some source was used for this build.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type SourceProvenance = src.SourceProvenance
type Source_RepoSource = src.Source_RepoSource
type Source_StorageSource = src.Source_StorageSource

// Each Stage of the deployment process
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type Stage = src.Stage

// Possible names for a Stage
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type Stage_Name = src.Stage_Name

// Possible states for a Stage
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type Stage_State = src.Stage_State

// Informational messages about the state of the Cloud Function or Operation.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type StateMessage = src.StateMessage

// Severity of the state message.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type StateMessage_Severity = src.StateMessage_Severity

// Location of the source in an archive file in Google Cloud Storage.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type StorageSource = src.StorageSource

// UnimplementedFunctionServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type UnimplementedFunctionServiceServer = src.UnimplementedFunctionServiceServer

// Request for the `UpdateFunction` method.
//
// Deprecated: Please use types in: cloud.google.com/go/functions/apiv2/functionspb
type UpdateFunctionRequest = src.UpdateFunctionRequest

// Deprecated: Please use funcs in: cloud.google.com/go/functions/apiv2/functionspb
func NewFunctionServiceClient(cc grpc.ClientConnInterface) FunctionServiceClient {
	return src.NewFunctionServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/functions/apiv2/functionspb
func RegisterFunctionServiceServer(s *grpc.Server, srv FunctionServiceServer) {
	src.RegisterFunctionServiceServer(s, srv)
}
