// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package containeranalysis aliases all exported identifiers in package
// "cloud.google.com/go/containeranalysis/apiv1beta1/containeranalysispb".
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/containeranalysispb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package containeranalysis

import (
	src "cloud.google.com/go/containeranalysis/apiv1beta1/containeranalysispb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use vars in: cloud.google.com/go/containeranalysis/apiv1beta1/containeranalysispb
var (
	File_google_devtools_containeranalysis_v1beta1_containeranalysis_proto = src.File_google_devtools_containeranalysis_v1beta1_containeranalysis_proto
)

// ContainerAnalysisV1Beta1Client is the client API for
// ContainerAnalysisV1Beta1 service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/containeranalysispb
type ContainerAnalysisV1Beta1Client = src.ContainerAnalysisV1Beta1Client

// ContainerAnalysisV1Beta1Server is the server API for
// ContainerAnalysisV1Beta1 service.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/containeranalysispb
type ContainerAnalysisV1Beta1Server = src.ContainerAnalysisV1Beta1Server

// UnimplementedContainerAnalysisV1Beta1Server can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/containeranalysis/apiv1beta1/containeranalysispb
type UnimplementedContainerAnalysisV1Beta1Server = src.UnimplementedContainerAnalysisV1Beta1Server

// Deprecated: Please use funcs in: cloud.google.com/go/containeranalysis/apiv1beta1/containeranalysispb
func NewContainerAnalysisV1Beta1Client(cc grpc.ClientConnInterface) ContainerAnalysisV1Beta1Client {
	return src.NewContainerAnalysisV1Beta1Client(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/containeranalysis/apiv1beta1/containeranalysispb
func RegisterContainerAnalysisV1Beta1Server(s *grpc.Server, srv ContainerAnalysisV1Beta1Server) {
	src.RegisterContainerAnalysisV1Beta1Server(s, srv)
}
