// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package filestore aliases all exported identifiers in package
// "cloud.google.com/go/filestore/apiv1/filestorepb".
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package filestore

import (
	src "cloud.google.com/go/filestore/apiv1/filestorepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/filestore/apiv1/filestorepb
const (
	Backup_CREATING                          = src.Backup_CREATING
	Backup_DELETING                          = src.Backup_DELETING
	Backup_FINALIZING                        = src.Backup_FINALIZING
	Backup_READY                             = src.Backup_READY
	Backup_STATE_UNSPECIFIED                 = src.Backup_STATE_UNSPECIFIED
	Instance_BASIC_HDD                       = src.Instance_BASIC_HDD
	Instance_BASIC_SSD                       = src.Instance_BASIC_SSD
	Instance_CREATING                        = src.Instance_CREATING
	Instance_DELETING                        = src.Instance_DELETING
	Instance_ERROR                           = src.Instance_ERROR
	Instance_HIGH_SCALE_SSD                  = src.Instance_HIGH_SCALE_SSD
	Instance_PREMIUM                         = src.Instance_PREMIUM
	Instance_READY                           = src.Instance_READY
	Instance_REPAIRING                       = src.Instance_REPAIRING
	Instance_RESTORING                       = src.Instance_RESTORING
	Instance_STANDARD                        = src.Instance_STANDARD
	Instance_STATE_UNSPECIFIED               = src.Instance_STATE_UNSPECIFIED
	Instance_TIER_UNSPECIFIED                = src.Instance_TIER_UNSPECIFIED
	NetworkConfig_ADDRESS_MODE_UNSPECIFIED   = src.NetworkConfig_ADDRESS_MODE_UNSPECIFIED
	NetworkConfig_MODE_IPV4                  = src.NetworkConfig_MODE_IPV4
	NfsExportOptions_ACCESS_MODE_UNSPECIFIED = src.NfsExportOptions_ACCESS_MODE_UNSPECIFIED
	NfsExportOptions_NO_ROOT_SQUASH          = src.NfsExportOptions_NO_ROOT_SQUASH
	NfsExportOptions_READ_ONLY               = src.NfsExportOptions_READ_ONLY
	NfsExportOptions_READ_WRITE              = src.NfsExportOptions_READ_WRITE
	NfsExportOptions_ROOT_SQUASH             = src.NfsExportOptions_ROOT_SQUASH
	NfsExportOptions_SQUASH_MODE_UNSPECIFIED = src.NfsExportOptions_SQUASH_MODE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/filestore/apiv1/filestorepb
var (
	Backup_State_name                                            = src.Backup_State_name
	Backup_State_value                                           = src.Backup_State_value
	File_google_cloud_filestore_v1_cloud_filestore_service_proto = src.File_google_cloud_filestore_v1_cloud_filestore_service_proto
	Instance_State_name                                          = src.Instance_State_name
	Instance_State_value                                         = src.Instance_State_value
	Instance_Tier_name                                           = src.Instance_Tier_name
	Instance_Tier_value                                          = src.Instance_Tier_value
	NetworkConfig_AddressMode_name                               = src.NetworkConfig_AddressMode_name
	NetworkConfig_AddressMode_value                              = src.NetworkConfig_AddressMode_value
	NfsExportOptions_AccessMode_name                             = src.NfsExportOptions_AccessMode_name
	NfsExportOptions_AccessMode_value                            = src.NfsExportOptions_AccessMode_value
	NfsExportOptions_SquashMode_name                             = src.NfsExportOptions_SquashMode_name
	NfsExportOptions_SquashMode_value                            = src.NfsExportOptions_SquashMode_value
)

// A Cloud Filestore backup.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type Backup = src.Backup

// The backup state.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type Backup_State = src.Backup_State

// CloudFilestoreManagerClient is the client API for CloudFilestoreManager
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type CloudFilestoreManagerClient = src.CloudFilestoreManagerClient

// CloudFilestoreManagerServer is the server API for CloudFilestoreManager
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type CloudFilestoreManagerServer = src.CloudFilestoreManagerServer

// CreateBackupRequest creates a backup.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type CreateBackupRequest = src.CreateBackupRequest

// CreateInstanceRequest creates an instance.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type CreateInstanceRequest = src.CreateInstanceRequest

// DeleteBackupRequest deletes a backup.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type DeleteBackupRequest = src.DeleteBackupRequest

// DeleteInstanceRequest deletes an instance.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type DeleteInstanceRequest = src.DeleteInstanceRequest

// File share configuration for the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type FileShareConfig = src.FileShareConfig
type FileShareConfig_SourceBackup = src.FileShareConfig_SourceBackup

// GetBackupRequest gets the state of a backup.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type GetBackupRequest = src.GetBackupRequest

// GetInstanceRequest gets the state of an instance.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type GetInstanceRequest = src.GetInstanceRequest

// A Cloud Filestore instance.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type Instance = src.Instance

// The instance state.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type Instance_State = src.Instance_State

// Available service tiers.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type Instance_Tier = src.Instance_Tier

// ListBackupsRequest lists backups.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type ListBackupsRequest = src.ListBackupsRequest

// ListBackupsResponse is the result of ListBackupsRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type ListBackupsResponse = src.ListBackupsResponse

// ListInstancesRequest lists instances.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type ListInstancesRequest = src.ListInstancesRequest

// ListInstancesResponse is the result of ListInstancesRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type ListInstancesResponse = src.ListInstancesResponse

// Network configuration for the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type NetworkConfig = src.NetworkConfig

// Internet protocol versions supported by Cloud Filestore.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type NetworkConfig_AddressMode = src.NetworkConfig_AddressMode

// NFS export options specifications.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type NfsExportOptions = src.NfsExportOptions

// The access mode.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type NfsExportOptions_AccessMode = src.NfsExportOptions_AccessMode

// The squash mode.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type NfsExportOptions_SquashMode = src.NfsExportOptions_SquashMode

// RestoreInstanceRequest restores an existing instances's file share from a
// backup.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type RestoreInstanceRequest = src.RestoreInstanceRequest
type RestoreInstanceRequest_SourceBackup = src.RestoreInstanceRequest_SourceBackup

// UnimplementedCloudFilestoreManagerServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type UnimplementedCloudFilestoreManagerServer = src.UnimplementedCloudFilestoreManagerServer

// UpdateBackupRequest updates description and/or labels for a backup.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type UpdateBackupRequest = src.UpdateBackupRequest

// UpdateInstanceRequest updates the settings of an instance.
//
// Deprecated: Please use types in: cloud.google.com/go/filestore/apiv1/filestorepb
type UpdateInstanceRequest = src.UpdateInstanceRequest

// Deprecated: Please use funcs in: cloud.google.com/go/filestore/apiv1/filestorepb
func NewCloudFilestoreManagerClient(cc grpc.ClientConnInterface) CloudFilestoreManagerClient {
	return src.NewCloudFilestoreManagerClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/filestore/apiv1/filestorepb
func RegisterCloudFilestoreManagerServer(s *grpc.Server, srv CloudFilestoreManagerServer) {
	src.RegisterCloudFilestoreManagerServer(s, srv)
}
