// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package pubsublite aliases all exported identifiers in package
// "cloud.google.com/go/pubsublite/apiv1/pubsublitepb".
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package pubsublite

import (
	src "cloud.google.com/go/pubsublite/apiv1/pubsublitepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
const (
	ExportConfig_ACTIVE                                          = src.ExportConfig_ACTIVE
	ExportConfig_NOT_FOUND                                       = src.ExportConfig_NOT_FOUND
	ExportConfig_PAUSED                                          = src.ExportConfig_PAUSED
	ExportConfig_PERMISSION_DENIED                               = src.ExportConfig_PERMISSION_DENIED
	ExportConfig_STATE_UNSPECIFIED                               = src.ExportConfig_STATE_UNSPECIFIED
	SeekRequest_COMMITTED_CURSOR                                 = src.SeekRequest_COMMITTED_CURSOR
	SeekRequest_HEAD                                             = src.SeekRequest_HEAD
	SeekRequest_NAMED_TARGET_UNSPECIFIED                         = src.SeekRequest_NAMED_TARGET_UNSPECIFIED
	SeekSubscriptionRequest_HEAD                                 = src.SeekSubscriptionRequest_HEAD
	SeekSubscriptionRequest_NAMED_TARGET_UNSPECIFIED             = src.SeekSubscriptionRequest_NAMED_TARGET_UNSPECIFIED
	SeekSubscriptionRequest_TAIL                                 = src.SeekSubscriptionRequest_TAIL
	Subscription_DeliveryConfig_DELIVERY_REQUIREMENT_UNSPECIFIED = src.Subscription_DeliveryConfig_DELIVERY_REQUIREMENT_UNSPECIFIED
	Subscription_DeliveryConfig_DELIVER_AFTER_STORED             = src.Subscription_DeliveryConfig_DELIVER_AFTER_STORED
	Subscription_DeliveryConfig_DELIVER_IMMEDIATELY              = src.Subscription_DeliveryConfig_DELIVER_IMMEDIATELY
)

// Deprecated: Please use vars in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
var (
	ExportConfig_State_name                               = src.ExportConfig_State_name
	ExportConfig_State_value                              = src.ExportConfig_State_value
	File_google_cloud_pubsublite_v1_admin_proto           = src.File_google_cloud_pubsublite_v1_admin_proto
	File_google_cloud_pubsublite_v1_common_proto          = src.File_google_cloud_pubsublite_v1_common_proto
	File_google_cloud_pubsublite_v1_cursor_proto          = src.File_google_cloud_pubsublite_v1_cursor_proto
	File_google_cloud_pubsublite_v1_publisher_proto       = src.File_google_cloud_pubsublite_v1_publisher_proto
	File_google_cloud_pubsublite_v1_subscriber_proto      = src.File_google_cloud_pubsublite_v1_subscriber_proto
	File_google_cloud_pubsublite_v1_topic_stats_proto     = src.File_google_cloud_pubsublite_v1_topic_stats_proto
	SeekRequest_NamedTarget_name                          = src.SeekRequest_NamedTarget_name
	SeekRequest_NamedTarget_value                         = src.SeekRequest_NamedTarget_value
	SeekSubscriptionRequest_NamedTarget_name              = src.SeekSubscriptionRequest_NamedTarget_name
	SeekSubscriptionRequest_NamedTarget_value             = src.SeekSubscriptionRequest_NamedTarget_value
	Subscription_DeliveryConfig_DeliveryRequirement_name  = src.Subscription_DeliveryConfig_DeliveryRequirement_name
	Subscription_DeliveryConfig_DeliveryRequirement_value = src.Subscription_DeliveryConfig_DeliveryRequirement_value
)

// AdminServiceClient is the client API for AdminService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type AdminServiceClient = src.AdminServiceClient

// AdminServiceServer is the server API for AdminService service.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type AdminServiceServer = src.AdminServiceServer

// The values associated with a key of an attribute.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type AttributeValues = src.AttributeValues

// Request for CommitCursor.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type CommitCursorRequest = src.CommitCursorRequest

// Response for CommitCursor.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type CommitCursorResponse = src.CommitCursorResponse

// Compute the current head cursor for a partition.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ComputeHeadCursorRequest = src.ComputeHeadCursorRequest

// Response containing the head cursor for the requested topic and partition.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ComputeHeadCursorResponse = src.ComputeHeadCursorResponse

// Compute statistics about a range of messages in a given topic and
// partition.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ComputeMessageStatsRequest = src.ComputeMessageStatsRequest

// Response containing stats for messages in the requested topic and
// partition.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ComputeMessageStatsResponse = src.ComputeMessageStatsResponse

// Compute the corresponding cursor for a publish or event time in a topic
// partition.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ComputeTimeCursorRequest = src.ComputeTimeCursorRequest

// Response containing the cursor corresponding to a publish or event time in
// a topic partition.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ComputeTimeCursorResponse = src.ComputeTimeCursorResponse

// Request for CreateReservation.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type CreateReservationRequest = src.CreateReservationRequest

// Request for CreateSubscription.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type CreateSubscriptionRequest = src.CreateSubscriptionRequest

// Request for CreateTopic.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type CreateTopicRequest = src.CreateTopicRequest

// A cursor that describes the position of a message within a topic partition.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type Cursor = src.Cursor

// CursorServiceClient is the client API for CursorService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type CursorServiceClient = src.CursorServiceClient

// CursorServiceServer is the server API for CursorService service.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type CursorServiceServer = src.CursorServiceServer
type CursorService_StreamingCommitCursorClient = src.CursorService_StreamingCommitCursorClient
type CursorService_StreamingCommitCursorServer = src.CursorService_StreamingCommitCursorServer

// Request for DeleteReservation.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type DeleteReservationRequest = src.DeleteReservationRequest

// Request for DeleteSubscription.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type DeleteSubscriptionRequest = src.DeleteSubscriptionRequest

// Request for DeleteTopic.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type DeleteTopicRequest = src.DeleteTopicRequest

// Configuration for a Pub/Sub Lite subscription that writes messages to a
// destination. User subscriber clients must not connect to this subscription.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ExportConfig = src.ExportConfig

// Configuration for exporting to a Pub/Sub topic.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ExportConfig_PubSubConfig = src.ExportConfig_PubSubConfig
type ExportConfig_PubsubConfig = src.ExportConfig_PubsubConfig

// The desired export state.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ExportConfig_State = src.ExportConfig_State

// Request to grant tokens to the server, requesting delivery of messages when
// they become available.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type FlowControlRequest = src.FlowControlRequest

// Request for GetReservation.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type GetReservationRequest = src.GetReservationRequest

// Request for GetSubscription.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type GetSubscriptionRequest = src.GetSubscriptionRequest

// Request for GetTopicPartitions.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type GetTopicPartitionsRequest = src.GetTopicPartitionsRequest

// Request for GetTopic.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type GetTopicRequest = src.GetTopicRequest

// The first streaming request that must be sent on a newly-opened stream. The
// client must wait for the response before sending subsequent requests on the
// stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type InitialCommitCursorRequest = src.InitialCommitCursorRequest

// Response to an InitialCommitCursorRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type InitialCommitCursorResponse = src.InitialCommitCursorResponse

// The first request that must be sent on a newly-opened stream. The client
// must wait for the response before sending subsequent requests on the stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type InitialPartitionAssignmentRequest = src.InitialPartitionAssignmentRequest

// The first request that must be sent on a newly-opened stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type InitialPublishRequest = src.InitialPublishRequest

// Response to an InitialPublishRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type InitialPublishResponse = src.InitialPublishResponse

// The first request that must be sent on a newly-opened stream. The client
// must wait for the response before sending subsequent requests on the stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type InitialSubscribeRequest = src.InitialSubscribeRequest

// Response to an InitialSubscribeRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type InitialSubscribeResponse = src.InitialSubscribeResponse

// Request for ListPartitionCursors.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListPartitionCursorsRequest = src.ListPartitionCursorsRequest

// Response for ListPartitionCursors
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListPartitionCursorsResponse = src.ListPartitionCursorsResponse

// Request for ListReservationTopics.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListReservationTopicsRequest = src.ListReservationTopicsRequest

// Response for ListReservationTopics.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListReservationTopicsResponse = src.ListReservationTopicsResponse

// Request for ListReservations.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListReservationsRequest = src.ListReservationsRequest

// Response for ListReservations.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListReservationsResponse = src.ListReservationsResponse

// Request for ListSubscriptions.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListSubscriptionsRequest = src.ListSubscriptionsRequest

// Response for ListSubscriptions.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListSubscriptionsResponse = src.ListSubscriptionsResponse

// Request for ListTopicSubscriptions.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListTopicSubscriptionsRequest = src.ListTopicSubscriptionsRequest

// Response for ListTopicSubscriptions.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListTopicSubscriptionsResponse = src.ListTopicSubscriptionsResponse

// Request for ListTopics.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListTopicsRequest = src.ListTopicsRequest

// Response for ListTopics.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type ListTopicsResponse = src.ListTopicsResponse

// Request to publish messages to the topic.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type MessagePublishRequest = src.MessagePublishRequest

// Response to a MessagePublishRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type MessagePublishResponse = src.MessagePublishResponse

// Response containing a list of messages. Upon delivering a MessageResponse
// to the client, the server: - Updates the stream's delivery cursor to one
// greater than the cursor of the last message in the list. - Subtracts the
// total number of bytes and messages from the tokens available to the server.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type MessageResponse = src.MessageResponse

// Metadata for long running operations.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type OperationMetadata = src.OperationMetadata

// PartitionAssignments should not race with acknowledgements. There should be
// exactly one unacknowledged PartitionAssignment at a time. If not, the client
// must break the stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PartitionAssignment = src.PartitionAssignment

// Acknowledge receipt and handling of the previous assignment. If not sent
// within a short period after receiving the assignment, partitions may remain
// unassigned for a period of time until the client is known to be inactive,
// after which time the server will break the stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PartitionAssignmentAck = src.PartitionAssignmentAck

// A request on the PartitionAssignment stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PartitionAssignmentRequest = src.PartitionAssignmentRequest
type PartitionAssignmentRequest_Ack = src.PartitionAssignmentRequest_Ack
type PartitionAssignmentRequest_Initial = src.PartitionAssignmentRequest_Initial

// PartitionAssignmentServiceClient is the client API for
// PartitionAssignmentService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PartitionAssignmentServiceClient = src.PartitionAssignmentServiceClient

// PartitionAssignmentServiceServer is the server API for
// PartitionAssignmentService service.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PartitionAssignmentServiceServer = src.PartitionAssignmentServiceServer
type PartitionAssignmentService_AssignPartitionsClient = src.PartitionAssignmentService_AssignPartitionsClient
type PartitionAssignmentService_AssignPartitionsServer = src.PartitionAssignmentService_AssignPartitionsServer

// A pair of a Cursor and the partition it is for.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PartitionCursor = src.PartitionCursor

// A message that is published by publishers and delivered to subscribers.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PubSubMessage = src.PubSubMessage

// Request sent from the client to the server on a stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PublishRequest = src.PublishRequest
type PublishRequest_InitialRequest = src.PublishRequest_InitialRequest
type PublishRequest_MessagePublishRequest = src.PublishRequest_MessagePublishRequest

// Response to a PublishRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PublishResponse = src.PublishResponse
type PublishResponse_InitialResponse = src.PublishResponse_InitialResponse
type PublishResponse_MessageResponse = src.PublishResponse_MessageResponse

// PublisherServiceClient is the client API for PublisherService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PublisherServiceClient = src.PublisherServiceClient

// PublisherServiceServer is the server API for PublisherService service.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type PublisherServiceServer = src.PublisherServiceServer
type PublisherService_PublishClient = src.PublisherService_PublishClient
type PublisherService_PublishServer = src.PublisherService_PublishServer

// Metadata about a reservation resource.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type Reservation = src.Reservation

// Request to update the stream's delivery cursor based on the given target.
// Resets the server available tokens to 0. SeekRequests past head result in
// stream breakage. SeekRequests may not be sent while another SeekRequest is
// outstanding (i.e., has not received a SeekResponse) on the same stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SeekRequest = src.SeekRequest
type SeekRequest_Cursor = src.SeekRequest_Cursor

// A special target in the partition that takes no other parameters.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SeekRequest_NamedTarget = src.SeekRequest_NamedTarget
type SeekRequest_NamedTarget_ = src.SeekRequest_NamedTarget_

// Response to a SeekRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SeekResponse = src.SeekResponse

// Request for SeekSubscription.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SeekSubscriptionRequest = src.SeekSubscriptionRequest

// A named position with respect to the message backlog.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SeekSubscriptionRequest_NamedTarget = src.SeekSubscriptionRequest_NamedTarget
type SeekSubscriptionRequest_NamedTarget_ = src.SeekSubscriptionRequest_NamedTarget_
type SeekSubscriptionRequest_TimeTarget = src.SeekSubscriptionRequest_TimeTarget

// Response for SeekSubscription long running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SeekSubscriptionResponse = src.SeekSubscriptionResponse

// Streaming request to update the committed cursor. Subsequent
// SequencedCommitCursorRequests override outstanding ones.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SequencedCommitCursorRequest = src.SequencedCommitCursorRequest

// Response to a SequencedCommitCursorRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SequencedCommitCursorResponse = src.SequencedCommitCursorResponse

// A message that has been stored and sequenced by the Pub/Sub Lite system.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SequencedMessage = src.SequencedMessage

// A request sent from the client to the server on a stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type StreamingCommitCursorRequest = src.StreamingCommitCursorRequest
type StreamingCommitCursorRequest_Commit = src.StreamingCommitCursorRequest_Commit
type StreamingCommitCursorRequest_Initial = src.StreamingCommitCursorRequest_Initial

// Response to a StreamingCommitCursorRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type StreamingCommitCursorResponse = src.StreamingCommitCursorResponse
type StreamingCommitCursorResponse_Commit = src.StreamingCommitCursorResponse_Commit
type StreamingCommitCursorResponse_Initial = src.StreamingCommitCursorResponse_Initial

// A request sent from the client to the server on a stream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SubscribeRequest = src.SubscribeRequest
type SubscribeRequest_FlowControl = src.SubscribeRequest_FlowControl
type SubscribeRequest_Initial = src.SubscribeRequest_Initial
type SubscribeRequest_Seek = src.SubscribeRequest_Seek

// Response to SubscribeRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SubscribeResponse = src.SubscribeResponse
type SubscribeResponse_Initial = src.SubscribeResponse_Initial
type SubscribeResponse_Messages = src.SubscribeResponse_Messages
type SubscribeResponse_Seek = src.SubscribeResponse_Seek

// SubscriberServiceClient is the client API for SubscriberService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SubscriberServiceClient = src.SubscriberServiceClient

// SubscriberServiceServer is the server API for SubscriberService service.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type SubscriberServiceServer = src.SubscriberServiceServer
type SubscriberService_SubscribeClient = src.SubscriberService_SubscribeClient
type SubscriberService_SubscribeServer = src.SubscriberService_SubscribeServer

// Metadata about a subscription resource.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type Subscription = src.Subscription

// The settings for a subscription's message delivery.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type Subscription_DeliveryConfig = src.Subscription_DeliveryConfig

// When this subscription should send messages to subscribers relative to
// messages persistence in storage. For details, see [Creating Lite
// subscriptions](https://cloud.google.com/pubsub/lite/docs/subscriptions#creating_lite_subscriptions).
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type Subscription_DeliveryConfig_DeliveryRequirement = src.Subscription_DeliveryConfig_DeliveryRequirement

// A target publish or event time. Can be used for seeking to or retrieving
// the corresponding cursor.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type TimeTarget = src.TimeTarget
type TimeTarget_EventTime = src.TimeTarget_EventTime
type TimeTarget_PublishTime = src.TimeTarget_PublishTime

// Metadata about a topic resource.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type Topic = src.Topic

// Response for GetTopicPartitions.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type TopicPartitions = src.TopicPartitions

// TopicStatsServiceClient is the client API for TopicStatsService service.
// For semantics around ctx use and closing/ending streaming RPCs, please refer
// to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type TopicStatsServiceClient = src.TopicStatsServiceClient

// TopicStatsServiceServer is the server API for TopicStatsService service.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type TopicStatsServiceServer = src.TopicStatsServiceServer

// The settings for a topic's partitions.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type Topic_PartitionConfig = src.Topic_PartitionConfig

// The throughput capacity configuration for each partition.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type Topic_PartitionConfig_Capacity = src.Topic_PartitionConfig_Capacity
type Topic_PartitionConfig_Capacity_ = src.Topic_PartitionConfig_Capacity_
type Topic_PartitionConfig_Scale = src.Topic_PartitionConfig_Scale

// The settings for this topic's Reservation usage.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type Topic_ReservationConfig = src.Topic_ReservationConfig

// The settings for a topic's message retention.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type Topic_RetentionConfig = src.Topic_RetentionConfig

// UnimplementedAdminServiceServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type UnimplementedAdminServiceServer = src.UnimplementedAdminServiceServer

// UnimplementedCursorServiceServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type UnimplementedCursorServiceServer = src.UnimplementedCursorServiceServer

// UnimplementedPartitionAssignmentServiceServer can be embedded to have
// forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type UnimplementedPartitionAssignmentServiceServer = src.UnimplementedPartitionAssignmentServiceServer

// UnimplementedPublisherServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type UnimplementedPublisherServiceServer = src.UnimplementedPublisherServiceServer

// UnimplementedSubscriberServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type UnimplementedSubscriberServiceServer = src.UnimplementedSubscriberServiceServer

// UnimplementedTopicStatsServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type UnimplementedTopicStatsServiceServer = src.UnimplementedTopicStatsServiceServer

// Request for UpdateReservation.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type UpdateReservationRequest = src.UpdateReservationRequest

// Request for UpdateSubscription.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type UpdateSubscriptionRequest = src.UpdateSubscriptionRequest

// Request for UpdateTopic.
//
// Deprecated: Please use types in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
type UpdateTopicRequest = src.UpdateTopicRequest

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func NewAdminServiceClient(cc grpc.ClientConnInterface) AdminServiceClient {
	return src.NewAdminServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func NewCursorServiceClient(cc grpc.ClientConnInterface) CursorServiceClient {
	return src.NewCursorServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func NewPartitionAssignmentServiceClient(cc grpc.ClientConnInterface) PartitionAssignmentServiceClient {
	return src.NewPartitionAssignmentServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func NewPublisherServiceClient(cc grpc.ClientConnInterface) PublisherServiceClient {
	return src.NewPublisherServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func NewSubscriberServiceClient(cc grpc.ClientConnInterface) SubscriberServiceClient {
	return src.NewSubscriberServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func NewTopicStatsServiceClient(cc grpc.ClientConnInterface) TopicStatsServiceClient {
	return src.NewTopicStatsServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func RegisterAdminServiceServer(s *grpc.Server, srv AdminServiceServer) {
	src.RegisterAdminServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func RegisterCursorServiceServer(s *grpc.Server, srv CursorServiceServer) {
	src.RegisterCursorServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func RegisterPartitionAssignmentServiceServer(s *grpc.Server, srv PartitionAssignmentServiceServer) {
	src.RegisterPartitionAssignmentServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func RegisterPublisherServiceServer(s *grpc.Server, srv PublisherServiceServer) {
	src.RegisterPublisherServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func RegisterSubscriberServiceServer(s *grpc.Server, srv SubscriberServiceServer) {
	src.RegisterSubscriberServiceServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/pubsublite/apiv1/pubsublitepb
func RegisterTopicStatsServiceServer(s *grpc.Server, srv TopicStatsServiceServer) {
	src.RegisterTopicStatsServiceServer(s, srv)
}
