// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package privatecatalog aliases all exported identifiers in package
// "cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb".
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package privatecatalog

import (
	src "cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
const (
	AssetReference_ASSET_VALIDATION_STATE_UNSPECIFIED = src.AssetReference_ASSET_VALIDATION_STATE_UNSPECIFIED
	AssetReference_INVALID                            = src.AssetReference_INVALID
	AssetReference_PENDING                            = src.AssetReference_PENDING
	AssetReference_VALID                              = src.AssetReference_VALID
)

// Deprecated: Please use vars in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
var (
	AssetReference_AssetValidationState_name                       = src.AssetReference_AssetValidationState_name
	AssetReference_AssetValidationState_value                      = src.AssetReference_AssetValidationState_value
	File_google_cloud_privatecatalog_v1beta1_private_catalog_proto = src.File_google_cloud_privatecatalog_v1beta1_private_catalog_proto
)

// Defines the reference of an asset belonging to a product.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type AssetReference = src.AssetReference
type AssetReference_Asset = src.AssetReference_Asset

// Possible validation steates of an asset reference.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type AssetReference_AssetValidationState = src.AssetReference_AssetValidationState
type AssetReference_GcsPath = src.AssetReference_GcsPath
type AssetReference_GitSource = src.AssetReference_GitSource

// The readonly representation of a catalog computed with a given resource
// context.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type Catalog = src.Catalog

// Defines how to access Cloud Storage source.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type GcsSource = src.GcsSource

// Defines how to access a Git Source.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type GitSource = src.GitSource
type GitSource_Branch = src.GitSource_Branch
type GitSource_Commit = src.GitSource_Commit
type GitSource_Tag = src.GitSource_Tag

// Defines definition of input parameters of asset templates.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type Inputs = src.Inputs

// PrivateCatalogClient is the client API for PrivateCatalog service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type PrivateCatalogClient = src.PrivateCatalogClient

// PrivateCatalogServer is the server API for PrivateCatalog service.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type PrivateCatalogServer = src.PrivateCatalogServer

// The readonly representation of a product computed with a given resource
// context.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type Product = src.Product

// Request message for
// [PrivateCatalog.SearchCatalogs][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchCatalogs].
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type SearchCatalogsRequest = src.SearchCatalogsRequest

// Response message for
// [PrivateCatalog.SearchCatalogs][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchCatalogs].
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type SearchCatalogsResponse = src.SearchCatalogsResponse

// Request message for
// [PrivateCatalog.SearchProducts][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchProducts].
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type SearchProductsRequest = src.SearchProductsRequest

// Response message for
// [PrivateCatalog.SearchProducts][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchProducts].
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type SearchProductsResponse = src.SearchProductsResponse

// Request message for
// [PrivateCatalog.SearchVersions][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type SearchVersionsRequest = src.SearchVersionsRequest

// Response message for
// [PrivateCatalog.SearchVersions][google.cloud.privatecatalog.v1beta1.PrivateCatalog.SearchVersions].
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type SearchVersionsResponse = src.SearchVersionsResponse

// UnimplementedPrivateCatalogServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type UnimplementedPrivateCatalogServer = src.UnimplementedPrivateCatalogServer

// The consumer representation of a version which is a child resource under a
// `Product` with asset data.
//
// Deprecated: Please use types in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
type Version = src.Version

// Deprecated: Please use funcs in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
func NewPrivateCatalogClient(cc grpc.ClientConnInterface) PrivateCatalogClient {
	return src.NewPrivateCatalogClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/privatecatalog/apiv1beta1/privatecatalogpb
func RegisterPrivateCatalogServer(s *grpc.Server, srv PrivateCatalogServer) {
	src.RegisterPrivateCatalogServer(s, srv)
}
