// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package language aliases all exported identifiers in package
// "cloud.google.com/go/language/apiv1beta2/languagepb".
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package language

import (
	src "cloud.google.com/go/language/apiv1beta2/languagepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/language/apiv1beta2/languagepb
const (
	ClassificationModelOptions_V2Model_CONTENT_CATEGORIES_VERSION_UNSPECIFIED = src.ClassificationModelOptions_V2Model_CONTENT_CATEGORIES_VERSION_UNSPECIFIED
	ClassificationModelOptions_V2Model_V1                                     = src.ClassificationModelOptions_V2Model_V1
	ClassificationModelOptions_V2Model_V2                                     = src.ClassificationModelOptions_V2Model_V2
	DependencyEdge_ABBREV                                                     = src.DependencyEdge_ABBREV
	DependencyEdge_ACOMP                                                      = src.DependencyEdge_ACOMP
	DependencyEdge_ADVCL                                                      = src.DependencyEdge_ADVCL
	DependencyEdge_ADVMOD                                                     = src.DependencyEdge_ADVMOD
	DependencyEdge_ADVPHMOD                                                   = src.DependencyEdge_ADVPHMOD
	DependencyEdge_AMOD                                                       = src.DependencyEdge_AMOD
	DependencyEdge_APPOS                                                      = src.DependencyEdge_APPOS
	DependencyEdge_ASP                                                        = src.DependencyEdge_ASP
	DependencyEdge_ATTR                                                       = src.DependencyEdge_ATTR
	DependencyEdge_AUX                                                        = src.DependencyEdge_AUX
	DependencyEdge_AUXCAUS                                                    = src.DependencyEdge_AUXCAUS
	DependencyEdge_AUXPASS                                                    = src.DependencyEdge_AUXPASS
	DependencyEdge_AUXVV                                                      = src.DependencyEdge_AUXVV
	DependencyEdge_CC                                                         = src.DependencyEdge_CC
	DependencyEdge_CCOMP                                                      = src.DependencyEdge_CCOMP
	DependencyEdge_CONJ                                                       = src.DependencyEdge_CONJ
	DependencyEdge_COP                                                        = src.DependencyEdge_COP
	DependencyEdge_CSUBJ                                                      = src.DependencyEdge_CSUBJ
	DependencyEdge_CSUBJPASS                                                  = src.DependencyEdge_CSUBJPASS
	DependencyEdge_DEP                                                        = src.DependencyEdge_DEP
	DependencyEdge_DET                                                        = src.DependencyEdge_DET
	DependencyEdge_DISCOURSE                                                  = src.DependencyEdge_DISCOURSE
	DependencyEdge_DISLOCATED                                                 = src.DependencyEdge_DISLOCATED
	DependencyEdge_DOBJ                                                       = src.DependencyEdge_DOBJ
	DependencyEdge_DTMOD                                                      = src.DependencyEdge_DTMOD
	DependencyEdge_EXPL                                                       = src.DependencyEdge_EXPL
	DependencyEdge_FOREIGN                                                    = src.DependencyEdge_FOREIGN
	DependencyEdge_GMOD                                                       = src.DependencyEdge_GMOD
	DependencyEdge_GOBJ                                                       = src.DependencyEdge_GOBJ
	DependencyEdge_GOESWITH                                                   = src.DependencyEdge_GOESWITH
	DependencyEdge_INFMOD                                                     = src.DependencyEdge_INFMOD
	DependencyEdge_IOBJ                                                       = src.DependencyEdge_IOBJ
	DependencyEdge_KW                                                         = src.DependencyEdge_KW
	DependencyEdge_LIST                                                       = src.DependencyEdge_LIST
	DependencyEdge_MARK                                                       = src.DependencyEdge_MARK
	DependencyEdge_MES                                                        = src.DependencyEdge_MES
	DependencyEdge_MWE                                                        = src.DependencyEdge_MWE
	DependencyEdge_MWV                                                        = src.DependencyEdge_MWV
	DependencyEdge_NCOMP                                                      = src.DependencyEdge_NCOMP
	DependencyEdge_NEG                                                        = src.DependencyEdge_NEG
	DependencyEdge_NN                                                         = src.DependencyEdge_NN
	DependencyEdge_NOMC                                                       = src.DependencyEdge_NOMC
	DependencyEdge_NOMCSUBJ                                                   = src.DependencyEdge_NOMCSUBJ
	DependencyEdge_NOMCSUBJPASS                                               = src.DependencyEdge_NOMCSUBJPASS
	DependencyEdge_NPADVMOD                                                   = src.DependencyEdge_NPADVMOD
	DependencyEdge_NSUBJ                                                      = src.DependencyEdge_NSUBJ
	DependencyEdge_NSUBJPASS                                                  = src.DependencyEdge_NSUBJPASS
	DependencyEdge_NUM                                                        = src.DependencyEdge_NUM
	DependencyEdge_NUMBER                                                     = src.DependencyEdge_NUMBER
	DependencyEdge_NUMC                                                       = src.DependencyEdge_NUMC
	DependencyEdge_P                                                          = src.DependencyEdge_P
	DependencyEdge_PARATAXIS                                                  = src.DependencyEdge_PARATAXIS
	DependencyEdge_PARTMOD                                                    = src.DependencyEdge_PARTMOD
	DependencyEdge_PCOMP                                                      = src.DependencyEdge_PCOMP
	DependencyEdge_POBJ                                                       = src.DependencyEdge_POBJ
	DependencyEdge_POSS                                                       = src.DependencyEdge_POSS
	DependencyEdge_POSTNEG                                                    = src.DependencyEdge_POSTNEG
	DependencyEdge_PRECOMP                                                    = src.DependencyEdge_PRECOMP
	DependencyEdge_PRECONJ                                                    = src.DependencyEdge_PRECONJ
	DependencyEdge_PREDET                                                     = src.DependencyEdge_PREDET
	DependencyEdge_PREF                                                       = src.DependencyEdge_PREF
	DependencyEdge_PREP                                                       = src.DependencyEdge_PREP
	DependencyEdge_PRONL                                                      = src.DependencyEdge_PRONL
	DependencyEdge_PRT                                                        = src.DependencyEdge_PRT
	DependencyEdge_PS                                                         = src.DependencyEdge_PS
	DependencyEdge_QUANTMOD                                                   = src.DependencyEdge_QUANTMOD
	DependencyEdge_RCMOD                                                      = src.DependencyEdge_RCMOD
	DependencyEdge_RCMODREL                                                   = src.DependencyEdge_RCMODREL
	DependencyEdge_RDROP                                                      = src.DependencyEdge_RDROP
	DependencyEdge_REF                                                        = src.DependencyEdge_REF
	DependencyEdge_REMNANT                                                    = src.DependencyEdge_REMNANT
	DependencyEdge_REPARANDUM                                                 = src.DependencyEdge_REPARANDUM
	DependencyEdge_ROOT                                                       = src.DependencyEdge_ROOT
	DependencyEdge_SNUM                                                       = src.DependencyEdge_SNUM
	DependencyEdge_SUFF                                                       = src.DependencyEdge_SUFF
	DependencyEdge_SUFFIX                                                     = src.DependencyEdge_SUFFIX
	DependencyEdge_TITLE                                                      = src.DependencyEdge_TITLE
	DependencyEdge_TMOD                                                       = src.DependencyEdge_TMOD
	DependencyEdge_TOPIC                                                      = src.DependencyEdge_TOPIC
	DependencyEdge_UNKNOWN                                                    = src.DependencyEdge_UNKNOWN
	DependencyEdge_VMOD                                                       = src.DependencyEdge_VMOD
	DependencyEdge_VOCATIVE                                                   = src.DependencyEdge_VOCATIVE
	DependencyEdge_XCOMP                                                      = src.DependencyEdge_XCOMP
	Document_BOILERPLATE_HANDLING_UNSPECIFIED                                 = src.Document_BOILERPLATE_HANDLING_UNSPECIFIED
	Document_HTML                                                             = src.Document_HTML
	Document_KEEP_BOILERPLATE                                                 = src.Document_KEEP_BOILERPLATE
	Document_PLAIN_TEXT                                                       = src.Document_PLAIN_TEXT
	Document_SKIP_BOILERPLATE                                                 = src.Document_SKIP_BOILERPLATE
	Document_TYPE_UNSPECIFIED                                                 = src.Document_TYPE_UNSPECIFIED
	EncodingType_NONE                                                         = src.EncodingType_NONE
	EncodingType_UTF16                                                        = src.EncodingType_UTF16
	EncodingType_UTF32                                                        = src.EncodingType_UTF32
	EncodingType_UTF8                                                         = src.EncodingType_UTF8
	EntityMention_COMMON                                                      = src.EntityMention_COMMON
	EntityMention_PROPER                                                      = src.EntityMention_PROPER
	EntityMention_TYPE_UNKNOWN                                                = src.EntityMention_TYPE_UNKNOWN
	Entity_ADDRESS                                                            = src.Entity_ADDRESS
	Entity_CONSUMER_GOOD                                                      = src.Entity_CONSUMER_GOOD
	Entity_DATE                                                               = src.Entity_DATE
	Entity_EVENT                                                              = src.Entity_EVENT
	Entity_LOCATION                                                           = src.Entity_LOCATION
	Entity_NUMBER                                                             = src.Entity_NUMBER
	Entity_ORGANIZATION                                                       = src.Entity_ORGANIZATION
	Entity_OTHER                                                              = src.Entity_OTHER
	Entity_PERSON                                                             = src.Entity_PERSON
	Entity_PHONE_NUMBER                                                       = src.Entity_PHONE_NUMBER
	Entity_PRICE                                                              = src.Entity_PRICE
	Entity_UNKNOWN                                                            = src.Entity_UNKNOWN
	Entity_WORK_OF_ART                                                        = src.Entity_WORK_OF_ART
	PartOfSpeech_ACCUSATIVE                                                   = src.PartOfSpeech_ACCUSATIVE
	PartOfSpeech_ACTIVE                                                       = src.PartOfSpeech_ACTIVE
	PartOfSpeech_ADJ                                                          = src.PartOfSpeech_ADJ
	PartOfSpeech_ADNOMIAL                                                     = src.PartOfSpeech_ADNOMIAL
	PartOfSpeech_ADP                                                          = src.PartOfSpeech_ADP
	PartOfSpeech_ADV                                                          = src.PartOfSpeech_ADV
	PartOfSpeech_ADVERBIAL                                                    = src.PartOfSpeech_ADVERBIAL
	PartOfSpeech_AFFIX                                                        = src.PartOfSpeech_AFFIX
	PartOfSpeech_ASPECT_UNKNOWN                                               = src.PartOfSpeech_ASPECT_UNKNOWN
	PartOfSpeech_AUXILIARY                                                    = src.PartOfSpeech_AUXILIARY
	PartOfSpeech_CASE_UNKNOWN                                                 = src.PartOfSpeech_CASE_UNKNOWN
	PartOfSpeech_CAUSATIVE                                                    = src.PartOfSpeech_CAUSATIVE
	PartOfSpeech_COMPLEMENTIVE                                                = src.PartOfSpeech_COMPLEMENTIVE
	PartOfSpeech_COMPLEMENTIZER                                               = src.PartOfSpeech_COMPLEMENTIZER
	PartOfSpeech_CONDITIONAL_MOOD                                             = src.PartOfSpeech_CONDITIONAL_MOOD
	PartOfSpeech_CONDITIONAL_TENSE                                            = src.PartOfSpeech_CONDITIONAL_TENSE
	PartOfSpeech_CONJ                                                         = src.PartOfSpeech_CONJ
	PartOfSpeech_DATIVE                                                       = src.PartOfSpeech_DATIVE
	PartOfSpeech_DET                                                          = src.PartOfSpeech_DET
	PartOfSpeech_DUAL                                                         = src.PartOfSpeech_DUAL
	PartOfSpeech_FEMININE                                                     = src.PartOfSpeech_FEMININE
	PartOfSpeech_FINAL_ENDING                                                 = src.PartOfSpeech_FINAL_ENDING
	PartOfSpeech_FIRST                                                        = src.PartOfSpeech_FIRST
	PartOfSpeech_FORM_UNKNOWN                                                 = src.PartOfSpeech_FORM_UNKNOWN
	PartOfSpeech_FUTURE                                                       = src.PartOfSpeech_FUTURE
	PartOfSpeech_GENDER_UNKNOWN                                               = src.PartOfSpeech_GENDER_UNKNOWN
	PartOfSpeech_GENITIVE                                                     = src.PartOfSpeech_GENITIVE
	PartOfSpeech_GERUND                                                       = src.PartOfSpeech_GERUND
	PartOfSpeech_IMPERATIVE                                                   = src.PartOfSpeech_IMPERATIVE
	PartOfSpeech_IMPERFECT                                                    = src.PartOfSpeech_IMPERFECT
	PartOfSpeech_IMPERFECTIVE                                                 = src.PartOfSpeech_IMPERFECTIVE
	PartOfSpeech_INDICATIVE                                                   = src.PartOfSpeech_INDICATIVE
	PartOfSpeech_INSTRUMENTAL                                                 = src.PartOfSpeech_INSTRUMENTAL
	PartOfSpeech_INTERROGATIVE                                                = src.PartOfSpeech_INTERROGATIVE
	PartOfSpeech_IRREALIS                                                     = src.PartOfSpeech_IRREALIS
	PartOfSpeech_JUSSIVE                                                      = src.PartOfSpeech_JUSSIVE
	PartOfSpeech_LOCATIVE                                                     = src.PartOfSpeech_LOCATIVE
	PartOfSpeech_LONG                                                         = src.PartOfSpeech_LONG
	PartOfSpeech_MASCULINE                                                    = src.PartOfSpeech_MASCULINE
	PartOfSpeech_MOOD_UNKNOWN                                                 = src.PartOfSpeech_MOOD_UNKNOWN
	PartOfSpeech_NEUTER                                                       = src.PartOfSpeech_NEUTER
	PartOfSpeech_NOMINATIVE                                                   = src.PartOfSpeech_NOMINATIVE
	PartOfSpeech_NON_RECIPROCAL                                               = src.PartOfSpeech_NON_RECIPROCAL
	PartOfSpeech_NOT_PROPER                                                   = src.PartOfSpeech_NOT_PROPER
	PartOfSpeech_NOUN                                                         = src.PartOfSpeech_NOUN
	PartOfSpeech_NUM                                                          = src.PartOfSpeech_NUM
	PartOfSpeech_NUMBER_UNKNOWN                                               = src.PartOfSpeech_NUMBER_UNKNOWN
	PartOfSpeech_OBLIQUE                                                      = src.PartOfSpeech_OBLIQUE
	PartOfSpeech_ORDER                                                        = src.PartOfSpeech_ORDER
	PartOfSpeech_PARTITIVE                                                    = src.PartOfSpeech_PARTITIVE
	PartOfSpeech_PASSIVE                                                      = src.PartOfSpeech_PASSIVE
	PartOfSpeech_PAST                                                         = src.PartOfSpeech_PAST
	PartOfSpeech_PERFECTIVE                                                   = src.PartOfSpeech_PERFECTIVE
	PartOfSpeech_PERSON_UNKNOWN                                               = src.PartOfSpeech_PERSON_UNKNOWN
	PartOfSpeech_PLUPERFECT                                                   = src.PartOfSpeech_PLUPERFECT
	PartOfSpeech_PLURAL                                                       = src.PartOfSpeech_PLURAL
	PartOfSpeech_PREPOSITIONAL                                                = src.PartOfSpeech_PREPOSITIONAL
	PartOfSpeech_PRESENT                                                      = src.PartOfSpeech_PRESENT
	PartOfSpeech_PROGRESSIVE                                                  = src.PartOfSpeech_PROGRESSIVE
	PartOfSpeech_PRON                                                         = src.PartOfSpeech_PRON
	PartOfSpeech_PROPER                                                       = src.PartOfSpeech_PROPER
	PartOfSpeech_PROPER_UNKNOWN                                               = src.PartOfSpeech_PROPER_UNKNOWN
	PartOfSpeech_PRT                                                          = src.PartOfSpeech_PRT
	PartOfSpeech_PUNCT                                                        = src.PartOfSpeech_PUNCT
	PartOfSpeech_REALIS                                                       = src.PartOfSpeech_REALIS
	PartOfSpeech_RECIPROCAL                                                   = src.PartOfSpeech_RECIPROCAL
	PartOfSpeech_RECIPROCITY_UNKNOWN                                          = src.PartOfSpeech_RECIPROCITY_UNKNOWN
	PartOfSpeech_REFLEXIVE_CASE                                               = src.PartOfSpeech_REFLEXIVE_CASE
	PartOfSpeech_REFLEXIVE_PERSON                                             = src.PartOfSpeech_REFLEXIVE_PERSON
	PartOfSpeech_RELATIVE_CASE                                                = src.PartOfSpeech_RELATIVE_CASE
	PartOfSpeech_SECOND                                                       = src.PartOfSpeech_SECOND
	PartOfSpeech_SHORT                                                        = src.PartOfSpeech_SHORT
	PartOfSpeech_SINGULAR                                                     = src.PartOfSpeech_SINGULAR
	PartOfSpeech_SPECIFIC                                                     = src.PartOfSpeech_SPECIFIC
	PartOfSpeech_SUBJUNCTIVE                                                  = src.PartOfSpeech_SUBJUNCTIVE
	PartOfSpeech_TENSE_UNKNOWN                                                = src.PartOfSpeech_TENSE_UNKNOWN
	PartOfSpeech_THIRD                                                        = src.PartOfSpeech_THIRD
	PartOfSpeech_UNKNOWN                                                      = src.PartOfSpeech_UNKNOWN
	PartOfSpeech_VERB                                                         = src.PartOfSpeech_VERB
	PartOfSpeech_VOCATIVE                                                     = src.PartOfSpeech_VOCATIVE
	PartOfSpeech_VOICE_UNKNOWN                                                = src.PartOfSpeech_VOICE_UNKNOWN
	PartOfSpeech_X                                                            = src.PartOfSpeech_X
)

// Deprecated: Please use vars in: cloud.google.com/go/language/apiv1beta2/languagepb
var (
	ClassificationModelOptions_V2Model_ContentCategoriesVersion_name  = src.ClassificationModelOptions_V2Model_ContentCategoriesVersion_name
	ClassificationModelOptions_V2Model_ContentCategoriesVersion_value = src.ClassificationModelOptions_V2Model_ContentCategoriesVersion_value
	DependencyEdge_Label_name                                         = src.DependencyEdge_Label_name
	DependencyEdge_Label_value                                        = src.DependencyEdge_Label_value
	Document_BoilerplateHandling_name                                 = src.Document_BoilerplateHandling_name
	Document_BoilerplateHandling_value                                = src.Document_BoilerplateHandling_value
	Document_Type_name                                                = src.Document_Type_name
	Document_Type_value                                               = src.Document_Type_value
	EncodingType_name                                                 = src.EncodingType_name
	EncodingType_value                                                = src.EncodingType_value
	EntityMention_Type_name                                           = src.EntityMention_Type_name
	EntityMention_Type_value                                          = src.EntityMention_Type_value
	Entity_Type_name                                                  = src.Entity_Type_name
	Entity_Type_value                                                 = src.Entity_Type_value
	File_google_cloud_language_v1beta2_language_service_proto         = src.File_google_cloud_language_v1beta2_language_service_proto
	PartOfSpeech_Aspect_name                                          = src.PartOfSpeech_Aspect_name
	PartOfSpeech_Aspect_value                                         = src.PartOfSpeech_Aspect_value
	PartOfSpeech_Case_name                                            = src.PartOfSpeech_Case_name
	PartOfSpeech_Case_value                                           = src.PartOfSpeech_Case_value
	PartOfSpeech_Form_name                                            = src.PartOfSpeech_Form_name
	PartOfSpeech_Form_value                                           = src.PartOfSpeech_Form_value
	PartOfSpeech_Gender_name                                          = src.PartOfSpeech_Gender_name
	PartOfSpeech_Gender_value                                         = src.PartOfSpeech_Gender_value
	PartOfSpeech_Mood_name                                            = src.PartOfSpeech_Mood_name
	PartOfSpeech_Mood_value                                           = src.PartOfSpeech_Mood_value
	PartOfSpeech_Number_name                                          = src.PartOfSpeech_Number_name
	PartOfSpeech_Number_value                                         = src.PartOfSpeech_Number_value
	PartOfSpeech_Person_name                                          = src.PartOfSpeech_Person_name
	PartOfSpeech_Person_value                                         = src.PartOfSpeech_Person_value
	PartOfSpeech_Proper_name                                          = src.PartOfSpeech_Proper_name
	PartOfSpeech_Proper_value                                         = src.PartOfSpeech_Proper_value
	PartOfSpeech_Reciprocity_name                                     = src.PartOfSpeech_Reciprocity_name
	PartOfSpeech_Reciprocity_value                                    = src.PartOfSpeech_Reciprocity_value
	PartOfSpeech_Tag_name                                             = src.PartOfSpeech_Tag_name
	PartOfSpeech_Tag_value                                            = src.PartOfSpeech_Tag_value
	PartOfSpeech_Tense_name                                           = src.PartOfSpeech_Tense_name
	PartOfSpeech_Tense_value                                          = src.PartOfSpeech_Tense_value
	PartOfSpeech_Voice_name                                           = src.PartOfSpeech_Voice_name
	PartOfSpeech_Voice_value                                          = src.PartOfSpeech_Voice_value
)

// The entity analysis request message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnalyzeEntitiesRequest = src.AnalyzeEntitiesRequest

// The entity analysis response message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnalyzeEntitiesResponse = src.AnalyzeEntitiesResponse

// The entity-level sentiment analysis request message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnalyzeEntitySentimentRequest = src.AnalyzeEntitySentimentRequest

// The entity-level sentiment analysis response message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnalyzeEntitySentimentResponse = src.AnalyzeEntitySentimentResponse

// The sentiment analysis request message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnalyzeSentimentRequest = src.AnalyzeSentimentRequest

// The sentiment analysis response message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnalyzeSentimentResponse = src.AnalyzeSentimentResponse

// The syntax analysis request message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnalyzeSyntaxRequest = src.AnalyzeSyntaxRequest

// The syntax analysis response message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnalyzeSyntaxResponse = src.AnalyzeSyntaxResponse

// The request message for the text annotation API, which can perform multiple
// analysis types (sentiment, entities, and syntax) in one call.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnnotateTextRequest = src.AnnotateTextRequest

// All available features for sentiment, syntax, and semantic analysis.
// Setting each one to true will enable that specific analysis for the input.
// Next ID: 11
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnnotateTextRequest_Features = src.AnnotateTextRequest_Features

// The text annotations response message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type AnnotateTextResponse = src.AnnotateTextResponse

// Represents a category returned from the text classifier.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type ClassificationCategory = src.ClassificationCategory

// Model options available for classification requests.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type ClassificationModelOptions = src.ClassificationModelOptions

// Options for the V1 model.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type ClassificationModelOptions_V1Model = src.ClassificationModelOptions_V1Model
type ClassificationModelOptions_V1Model_ = src.ClassificationModelOptions_V1Model_

// Options for the V2 model.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type ClassificationModelOptions_V2Model = src.ClassificationModelOptions_V2Model
type ClassificationModelOptions_V2Model_ = src.ClassificationModelOptions_V2Model_

// The content categories used for classification.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type ClassificationModelOptions_V2Model_ContentCategoriesVersion = src.ClassificationModelOptions_V2Model_ContentCategoriesVersion

// The document classification request message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type ClassifyTextRequest = src.ClassifyTextRequest

// The document classification response message.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type ClassifyTextResponse = src.ClassifyTextResponse

// Represents dependency parse tree information for a token.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type DependencyEdge = src.DependencyEdge

// The parse label enum for the token.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type DependencyEdge_Label = src.DependencyEdge_Label

// Represents the input to API methods.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type Document = src.Document

// Ways of handling boilerplate detected in the document
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type Document_BoilerplateHandling = src.Document_BoilerplateHandling
type Document_Content = src.Document_Content
type Document_GcsContentUri = src.Document_GcsContentUri

// The document types enum.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type Document_Type = src.Document_Type

// Represents the text encoding that the caller uses to process the output.
// Providing an `EncodingType` is recommended because the API provides the
// beginning offsets for various outputs, such as tokens and mentions, and
// languages that natively use different text encodings may access offsets
// differently.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type EncodingType = src.EncodingType

// Represents a phrase in the text that is a known entity, such as a person,
// an organization, or location. The API associates information, such as
// salience and mentions, with entities.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type Entity = src.Entity

// Represents a mention for an entity in the text. Currently, proper noun
// mentions are supported.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type EntityMention = src.EntityMention

// The supported types of mentions.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type EntityMention_Type = src.EntityMention_Type

// The type of the entity. For most entity types, the associated metadata is a
// Wikipedia URL (`wikipedia_url`) and Knowledge Graph MID (`mid`). The table
// below lists the associated fields for entities that have different metadata.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type Entity_Type = src.Entity_Type

// LanguageServiceClient is the client API for LanguageService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type LanguageServiceClient = src.LanguageServiceClient

// LanguageServiceServer is the server API for LanguageService service.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type LanguageServiceServer = src.LanguageServiceServer

// Represents part of speech information for a token.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech = src.PartOfSpeech

// The characteristic of a verb that expresses time flow during an event.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Aspect = src.PartOfSpeech_Aspect

// The grammatical function performed by a noun or pronoun in a phrase,
// clause, or sentence. In some languages, other parts of speech, such as
// adjective and determiner, take case inflection in agreement with the noun.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Case = src.PartOfSpeech_Case

// Depending on the language, Form can be categorizing different forms of
// verbs, adjectives, adverbs, etc. For example, categorizing inflected endings
// of verbs and adjectives or distinguishing between short and long forms of
// adjectives and participles
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Form = src.PartOfSpeech_Form

// Gender classes of nouns reflected in the behaviour of associated words.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Gender = src.PartOfSpeech_Gender

// The grammatical feature of verbs, used for showing modality and attitude.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Mood = src.PartOfSpeech_Mood

// Count distinctions.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Number = src.PartOfSpeech_Number

// The distinction between the speaker, second person, third person, etc.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Person = src.PartOfSpeech_Person

// This category shows if the token is part of a proper name.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Proper = src.PartOfSpeech_Proper

// Reciprocal features of a pronoun.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Reciprocity = src.PartOfSpeech_Reciprocity

// The part of speech tags enum.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Tag = src.PartOfSpeech_Tag

// Time reference.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Tense = src.PartOfSpeech_Tense

// The relationship between the action that a verb expresses and the
// participants identified by its arguments.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type PartOfSpeech_Voice = src.PartOfSpeech_Voice

// Represents a sentence in the input document.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type Sentence = src.Sentence

// Represents the feeling associated with the entire text or entities in the
// text. Next ID: 6
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type Sentiment = src.Sentiment

// Represents an output piece of text.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type TextSpan = src.TextSpan

// Represents the smallest syntactic building block of the text.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type Token = src.Token

// UnimplementedLanguageServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/language/apiv1beta2/languagepb
type UnimplementedLanguageServiceServer = src.UnimplementedLanguageServiceServer

// Deprecated: Please use funcs in: cloud.google.com/go/language/apiv1beta2/languagepb
func NewLanguageServiceClient(cc grpc.ClientConnInterface) LanguageServiceClient {
	return src.NewLanguageServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/language/apiv1beta2/languagepb
func RegisterLanguageServiceServer(s *grpc.Server, srv LanguageServiceServer) {
	src.RegisterLanguageServiceServer(s, srv)
}
