// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package service aliases all exported identifiers in package
// "cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb".
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package service

import (
	src "cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
const (
	CheckUpgradeResponse_CONFLICT                    = src.CheckUpgradeResponse_CONFLICT
	CheckUpgradeResponse_CONFLICT_RESULT_UNSPECIFIED = src.CheckUpgradeResponse_CONFLICT_RESULT_UNSPECIFIED
	CheckUpgradeResponse_NO_CONFLICT                 = src.CheckUpgradeResponse_NO_CONFLICT
	Environment_CREATING                             = src.Environment_CREATING
	Environment_DELETING                             = src.Environment_DELETING
	Environment_ERROR                                = src.Environment_ERROR
	Environment_RUNNING                              = src.Environment_RUNNING
	Environment_STATE_UNSPECIFIED                    = src.Environment_STATE_UNSPECIFIED
	Environment_UPDATING                             = src.Environment_UPDATING
	OperationMetadata_CHECK                          = src.OperationMetadata_CHECK
	OperationMetadata_CREATE                         = src.OperationMetadata_CREATE
	OperationMetadata_DELETE                         = src.OperationMetadata_DELETE
	OperationMetadata_FAILED                         = src.OperationMetadata_FAILED
	OperationMetadata_PENDING                        = src.OperationMetadata_PENDING
	OperationMetadata_RUNNING                        = src.OperationMetadata_RUNNING
	OperationMetadata_STATE_UNSPECIFIED              = src.OperationMetadata_STATE_UNSPECIFIED
	OperationMetadata_SUCCEEDED                      = src.OperationMetadata_SUCCEEDED
	OperationMetadata_SUCCESSFUL                     = src.OperationMetadata_SUCCESSFUL
	OperationMetadata_TYPE_UNSPECIFIED               = src.OperationMetadata_TYPE_UNSPECIFIED
	OperationMetadata_UPDATE                         = src.OperationMetadata_UPDATE
)

// Deprecated: Please use vars in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
var (
	CheckUpgradeResponse_ConflictResult_name                                = src.CheckUpgradeResponse_ConflictResult_name
	CheckUpgradeResponse_ConflictResult_value                               = src.CheckUpgradeResponse_ConflictResult_value
	Environment_State_name                                                  = src.Environment_State_name
	Environment_State_value                                                 = src.Environment_State_value
	File_google_cloud_orchestration_airflow_service_v1_environments_proto   = src.File_google_cloud_orchestration_airflow_service_v1_environments_proto
	File_google_cloud_orchestration_airflow_service_v1_image_versions_proto = src.File_google_cloud_orchestration_airflow_service_v1_image_versions_proto
	File_google_cloud_orchestration_airflow_service_v1_operations_proto     = src.File_google_cloud_orchestration_airflow_service_v1_operations_proto
	OperationMetadata_State_name                                            = src.OperationMetadata_State_name
	OperationMetadata_State_value                                           = src.OperationMetadata_State_value
	OperationMetadata_Type_name                                             = src.OperationMetadata_Type_name
	OperationMetadata_Type_value                                            = src.OperationMetadata_Type_value
)

// Message containing information about the result of an upgrade check
// operation.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type CheckUpgradeResponse = src.CheckUpgradeResponse

// Whether there were python modules conflict during image build.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type CheckUpgradeResponse_ConflictResult = src.CheckUpgradeResponse_ConflictResult

// Create a new environment.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type CreateEnvironmentRequest = src.CreateEnvironmentRequest

// The configuration of Cloud SQL instance that is used by the Apache Airflow
// software.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type DatabaseConfig = src.DatabaseConfig

// Delete an environment.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type DeleteEnvironmentRequest = src.DeleteEnvironmentRequest

// The encryption options for the Cloud Composer environment and its
// dependencies.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type EncryptionConfig = src.EncryptionConfig

// An environment for running orchestration tasks.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type Environment = src.Environment

// Configuration information for an environment.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type EnvironmentConfig = src.EnvironmentConfig

// State of the environment.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type Environment_State = src.Environment_State

// EnvironmentsClient is the client API for Environments service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type EnvironmentsClient = src.EnvironmentsClient

// EnvironmentsServer is the server API for Environments service.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type EnvironmentsServer = src.EnvironmentsServer

// Get an environment.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type GetEnvironmentRequest = src.GetEnvironmentRequest

// Configuration for controlling how IPs are allocated in the GKE cluster
// running the Apache Airflow software.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type IPAllocationPolicy = src.IPAllocationPolicy
type IPAllocationPolicy_ClusterIpv4CidrBlock = src.IPAllocationPolicy_ClusterIpv4CidrBlock
type IPAllocationPolicy_ClusterSecondaryRangeName = src.IPAllocationPolicy_ClusterSecondaryRangeName
type IPAllocationPolicy_ServicesIpv4CidrBlock = src.IPAllocationPolicy_ServicesIpv4CidrBlock
type IPAllocationPolicy_ServicesSecondaryRangeName = src.IPAllocationPolicy_ServicesSecondaryRangeName

// ImageVersion information
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type ImageVersion = src.ImageVersion

// ImageVersionsClient is the client API for ImageVersions service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type ImageVersionsClient = src.ImageVersionsClient

// ImageVersionsServer is the server API for ImageVersions service.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type ImageVersionsServer = src.ImageVersionsServer

// List environments in a project and location.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type ListEnvironmentsRequest = src.ListEnvironmentsRequest

// The environments in a project and location.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type ListEnvironmentsResponse = src.ListEnvironmentsResponse

// List ImageVersions in a project and location.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type ListImageVersionsRequest = src.ListImageVersionsRequest

// The ImageVersions in a project and location.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type ListImageVersionsResponse = src.ListImageVersionsResponse

// The configuration information for the Kubernetes Engine nodes running the
// Apache Airflow software.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type NodeConfig = src.NodeConfig

// Metadata describing an operation.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type OperationMetadata = src.OperationMetadata

// An enum describing the overall state of an operation.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type OperationMetadata_State = src.OperationMetadata_State

// Type of longrunning operation.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type OperationMetadata_Type = src.OperationMetadata_Type

// Configuration options for the private GKE cluster in a Cloud Composer
// environment.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type PrivateClusterConfig = src.PrivateClusterConfig

// The configuration information for configuring a Private IP Cloud Composer
// environment.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type PrivateEnvironmentConfig = src.PrivateEnvironmentConfig

// Specifies the selection and configuration of software inside the
// environment.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type SoftwareConfig = src.SoftwareConfig

// UnimplementedEnvironmentsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type UnimplementedEnvironmentsServer = src.UnimplementedEnvironmentsServer

// UnimplementedImageVersionsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type UnimplementedImageVersionsServer = src.UnimplementedImageVersionsServer

// Update an environment.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type UpdateEnvironmentRequest = src.UpdateEnvironmentRequest

// The configuration settings for the Airflow web server App Engine instance.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type WebServerConfig = src.WebServerConfig

// Network-level access control policy for the Airflow web server.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type WebServerNetworkAccessControl = src.WebServerNetworkAccessControl

// Allowed IP range with user-provided description.
//
// Deprecated: Please use types in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
type WebServerNetworkAccessControl_AllowedIpRange = src.WebServerNetworkAccessControl_AllowedIpRange

// Deprecated: Please use funcs in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
func NewEnvironmentsClient(cc grpc.ClientConnInterface) EnvironmentsClient {
	return src.NewEnvironmentsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
func NewImageVersionsClient(cc grpc.ClientConnInterface) ImageVersionsClient {
	return src.NewImageVersionsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
func RegisterEnvironmentsServer(s *grpc.Server, srv EnvironmentsServer) {
	src.RegisterEnvironmentsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/orchestration/airflow/service/apiv1/servicepb
func RegisterImageVersionsServer(s *grpc.Server, srv ImageVersionsServer) {
	src.RegisterImageVersionsServer(s, srv)
}
