// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package recaptchaenterprise aliases all exported identifiers in package
// "cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb".
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package recaptchaenterprise

import (
	src "cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
const (
	AccountDefenderAssessment_ACCOUNT_DEFENDER_LABEL_UNSPECIFIED = src.AccountDefenderAssessment_ACCOUNT_DEFENDER_LABEL_UNSPECIFIED
	AccountDefenderAssessment_PROFILE_MATCH                      = src.AccountDefenderAssessment_PROFILE_MATCH
	AccountDefenderAssessment_RELATED_ACCOUNTS_NUMBER_HIGH       = src.AccountDefenderAssessment_RELATED_ACCOUNTS_NUMBER_HIGH
	AccountDefenderAssessment_SUSPICIOUS_ACCOUNT_CREATION        = src.AccountDefenderAssessment_SUSPICIOUS_ACCOUNT_CREATION
	AccountDefenderAssessment_SUSPICIOUS_LOGIN_ACTIVITY          = src.AccountDefenderAssessment_SUSPICIOUS_LOGIN_ACTIVITY
	AnnotateAssessmentRequest_ANNOTATION_UNSPECIFIED             = src.AnnotateAssessmentRequest_ANNOTATION_UNSPECIFIED
	AnnotateAssessmentRequest_CHARGEBACK                         = src.AnnotateAssessmentRequest_CHARGEBACK
	AnnotateAssessmentRequest_CHARGEBACK_DISPUTE                 = src.AnnotateAssessmentRequest_CHARGEBACK_DISPUTE
	AnnotateAssessmentRequest_CHARGEBACK_FRAUD                   = src.AnnotateAssessmentRequest_CHARGEBACK_FRAUD
	AnnotateAssessmentRequest_CORRECT_PASSWORD                   = src.AnnotateAssessmentRequest_CORRECT_PASSWORD
	AnnotateAssessmentRequest_FAILED_TWO_FACTOR                  = src.AnnotateAssessmentRequest_FAILED_TWO_FACTOR
	AnnotateAssessmentRequest_FRAUDULENT                         = src.AnnotateAssessmentRequest_FRAUDULENT
	AnnotateAssessmentRequest_INCORRECT_PASSWORD                 = src.AnnotateAssessmentRequest_INCORRECT_PASSWORD
	AnnotateAssessmentRequest_INITIATED_TWO_FACTOR               = src.AnnotateAssessmentRequest_INITIATED_TWO_FACTOR
	AnnotateAssessmentRequest_LEGITIMATE                         = src.AnnotateAssessmentRequest_LEGITIMATE
	AnnotateAssessmentRequest_PASSED_TWO_FACTOR                  = src.AnnotateAssessmentRequest_PASSED_TWO_FACTOR
	AnnotateAssessmentRequest_PASSWORD_CORRECT                   = src.AnnotateAssessmentRequest_PASSWORD_CORRECT
	AnnotateAssessmentRequest_PASSWORD_INCORRECT                 = src.AnnotateAssessmentRequest_PASSWORD_INCORRECT
	AnnotateAssessmentRequest_PAYMENT_HEURISTICS                 = src.AnnotateAssessmentRequest_PAYMENT_HEURISTICS
	AnnotateAssessmentRequest_REASON_UNSPECIFIED                 = src.AnnotateAssessmentRequest_REASON_UNSPECIFIED
	Assessment_AUTOMATION                                        = src.Assessment_AUTOMATION
	Assessment_CLASSIFICATION_REASON_UNSPECIFIED                 = src.Assessment_CLASSIFICATION_REASON_UNSPECIFIED
	Assessment_LOW_CONFIDENCE_SCORE                              = src.Assessment_LOW_CONFIDENCE_SCORE
	Assessment_TOO_MUCH_TRAFFIC                                  = src.Assessment_TOO_MUCH_TRAFFIC
	Assessment_UNEXPECTED_ENVIRONMENT                            = src.Assessment_UNEXPECTED_ENVIRONMENT
	Assessment_UNEXPECTED_USAGE_PATTERNS                         = src.Assessment_UNEXPECTED_USAGE_PATTERNS
	TokenProperties_BROWSER_ERROR                                = src.TokenProperties_BROWSER_ERROR
	TokenProperties_DUPE                                         = src.TokenProperties_DUPE
	TokenProperties_EXPIRED                                      = src.TokenProperties_EXPIRED
	TokenProperties_INVALID_REASON_UNSPECIFIED                   = src.TokenProperties_INVALID_REASON_UNSPECIFIED
	TokenProperties_MALFORMED                                    = src.TokenProperties_MALFORMED
	TokenProperties_MISSING                                      = src.TokenProperties_MISSING
	TokenProperties_SITE_MISMATCH                                = src.TokenProperties_SITE_MISMATCH
	TokenProperties_UNKNOWN_INVALID_REASON                       = src.TokenProperties_UNKNOWN_INVALID_REASON
)

// Deprecated: Please use vars in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
var (
	AccountDefenderAssessment_AccountDefenderLabel_name                     = src.AccountDefenderAssessment_AccountDefenderLabel_name
	AccountDefenderAssessment_AccountDefenderLabel_value                    = src.AccountDefenderAssessment_AccountDefenderLabel_value
	AnnotateAssessmentRequest_Annotation_name                               = src.AnnotateAssessmentRequest_Annotation_name
	AnnotateAssessmentRequest_Annotation_value                              = src.AnnotateAssessmentRequest_Annotation_value
	AnnotateAssessmentRequest_Reason_name                                   = src.AnnotateAssessmentRequest_Reason_name
	AnnotateAssessmentRequest_Reason_value                                  = src.AnnotateAssessmentRequest_Reason_value
	Assessment_ClassificationReason_name                                    = src.Assessment_ClassificationReason_name
	Assessment_ClassificationReason_value                                   = src.Assessment_ClassificationReason_value
	File_google_cloud_recaptchaenterprise_v1beta1_recaptchaenterprise_proto = src.File_google_cloud_recaptchaenterprise_v1beta1_recaptchaenterprise_proto
	TokenProperties_InvalidReason_name                                      = src.TokenProperties_InvalidReason_name
	TokenProperties_InvalidReason_value                                     = src.TokenProperties_InvalidReason_value
)

// Account Defender risk assessment.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type AccountDefenderAssessment = src.AccountDefenderAssessment

// Labels returned by Account Defender for this request.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type AccountDefenderAssessment_AccountDefenderLabel = src.AccountDefenderAssessment_AccountDefenderLabel

// The request message to annotate an Assessment.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type AnnotateAssessmentRequest = src.AnnotateAssessmentRequest

// Enum that represents the types of annotations.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type AnnotateAssessmentRequest_Annotation = src.AnnotateAssessmentRequest_Annotation

// Enum that represents potential reasons for annotating an assessment.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type AnnotateAssessmentRequest_Reason = src.AnnotateAssessmentRequest_Reason

// Empty response for AnnotateAssessment.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type AnnotateAssessmentResponse = src.AnnotateAssessmentResponse

// A recaptcha assessment resource.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type Assessment = src.Assessment

// Reasons contributing to the risk analysis verdict.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type Assessment_ClassificationReason = src.Assessment_ClassificationReason

// The create assessment request message.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type CreateAssessmentRequest = src.CreateAssessmentRequest
type Event = src.Event

// Password leak verification info.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type PasswordLeakVerification = src.PasswordLeakVerification

// RecaptchaEnterpriseServiceV1Beta1Client is the client API for
// RecaptchaEnterpriseServiceV1Beta1 service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type RecaptchaEnterpriseServiceV1Beta1Client = src.RecaptchaEnterpriseServiceV1Beta1Client

// RecaptchaEnterpriseServiceV1Beta1Server is the server API for
// RecaptchaEnterpriseServiceV1Beta1 service.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type RecaptchaEnterpriseServiceV1Beta1Server = src.RecaptchaEnterpriseServiceV1Beta1Server
type TokenProperties = src.TokenProperties

// Enum that represents the types of invalid token reasons.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type TokenProperties_InvalidReason = src.TokenProperties_InvalidReason

// UnimplementedRecaptchaEnterpriseServiceV1Beta1Server can be embedded to
// have forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
type UnimplementedRecaptchaEnterpriseServiceV1Beta1Server = src.UnimplementedRecaptchaEnterpriseServiceV1Beta1Server

// Deprecated: Please use funcs in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
func NewRecaptchaEnterpriseServiceV1Beta1Client(cc grpc.ClientConnInterface) RecaptchaEnterpriseServiceV1Beta1Client {
	return src.NewRecaptchaEnterpriseServiceV1Beta1Client(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/recaptchaenterprise/v2/apiv1beta1/recaptchaenterprisepb
func RegisterRecaptchaEnterpriseServiceV1Beta1Server(s *grpc.Server, srv RecaptchaEnterpriseServiceV1Beta1Server) {
	src.RegisterRecaptchaEnterpriseServiceV1Beta1Server(s, srv)
}
