// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package eventarc aliases all exported identifiers in package
// "cloud.google.com/go/eventarc/apiv1/eventarcpb".
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package eventarc

import (
	src "cloud.google.com/go/eventarc/apiv1/eventarcpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/eventarc/apiv1/eventarcpb
const (
	Channel_ACTIVE            = src.Channel_ACTIVE
	Channel_INACTIVE          = src.Channel_INACTIVE
	Channel_PENDING           = src.Channel_PENDING
	Channel_STATE_UNSPECIFIED = src.Channel_STATE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/eventarc/apiv1/eventarcpb
var (
	Channel_State_name                                     = src.Channel_State_name
	Channel_State_value                                    = src.Channel_State_value
	File_google_cloud_eventarc_v1_channel_connection_proto = src.File_google_cloud_eventarc_v1_channel_connection_proto
	File_google_cloud_eventarc_v1_channel_proto            = src.File_google_cloud_eventarc_v1_channel_proto
	File_google_cloud_eventarc_v1_discovery_proto          = src.File_google_cloud_eventarc_v1_discovery_proto
	File_google_cloud_eventarc_v1_eventarc_proto           = src.File_google_cloud_eventarc_v1_eventarc_proto
	File_google_cloud_eventarc_v1_trigger_proto            = src.File_google_cloud_eventarc_v1_trigger_proto
)

// A representation of the Channel resource. A Channel is a resource on which
// event providers publish their events. The published events are delivered
// through the transport associated with the channel. Note that a channel is
// associated with exactly one event provider.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type Channel = src.Channel

// A representation of the ChannelConnection resource. A ChannelConnection is
// a resource which event providers create during the activation process to
// establish a connection between the provider and the subscriber channel.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type ChannelConnection = src.ChannelConnection
type Channel_PubsubTopic = src.Channel_PubsubTopic

// State lists all the possible states of a Channel
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type Channel_State = src.Channel_State

// Represents a Cloud Run destination.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type CloudRun = src.CloudRun

// The request message for the CreateChannelConnection method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type CreateChannelConnectionRequest = src.CreateChannelConnectionRequest

// The request message for the CreateChannel method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type CreateChannelRequest = src.CreateChannelRequest

// The request message for the CreateTrigger method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type CreateTriggerRequest = src.CreateTriggerRequest

// The request message for the DeleteChannelConnection method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type DeleteChannelConnectionRequest = src.DeleteChannelConnectionRequest

// The request message for the DeleteChannel method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type DeleteChannelRequest = src.DeleteChannelRequest

// The request message for the DeleteTrigger method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type DeleteTriggerRequest = src.DeleteTriggerRequest

// Represents a target of an invocation over HTTP.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type Destination = src.Destination
type Destination_CloudFunction = src.Destination_CloudFunction
type Destination_CloudRun = src.Destination_CloudRun
type Destination_Gke = src.Destination_Gke

// Filters events based on exact matches on the CloudEvents attributes.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type EventFilter = src.EventFilter

// A representation of the event type resource.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type EventType = src.EventType

// EventarcClient is the client API for Eventarc service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type EventarcClient = src.EventarcClient

// EventarcServer is the server API for Eventarc service.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type EventarcServer = src.EventarcServer

// A representation of the FilteringAttribute resource. Filtering attributes
// are per event type.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type FilteringAttribute = src.FilteringAttribute

// Represents a GKE destination.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type GKE = src.GKE

// The request message for the GetChannelConnection method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type GetChannelConnectionRequest = src.GetChannelConnectionRequest

// The request message for the GetChannel method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type GetChannelRequest = src.GetChannelRequest

// The request message for the GetProvider method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type GetProviderRequest = src.GetProviderRequest

// The request message for the GetTrigger method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type GetTriggerRequest = src.GetTriggerRequest

// The request message for the ListChannelConnections method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type ListChannelConnectionsRequest = src.ListChannelConnectionsRequest

// The response message for the `ListChannelConnections` method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type ListChannelConnectionsResponse = src.ListChannelConnectionsResponse

// The request message for the ListChannels method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type ListChannelsRequest = src.ListChannelsRequest

// The response message for the `ListChannels` method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type ListChannelsResponse = src.ListChannelsResponse

// The request message for the ListProviders method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type ListProvidersRequest = src.ListProvidersRequest

// The response message for the `ListProviders` method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type ListProvidersResponse = src.ListProvidersResponse

// The request message for the ListTriggers method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type ListTriggersRequest = src.ListTriggersRequest

// The response message for the `ListTriggers` method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type ListTriggersResponse = src.ListTriggersResponse

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type OperationMetadata = src.OperationMetadata

// A representation of the Provider resource.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type Provider = src.Provider

// Represents a Pub/Sub transport.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type Pubsub = src.Pubsub

// Represents the transport intermediaries created for the trigger to deliver
// events.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type Transport = src.Transport
type Transport_Pubsub = src.Transport_Pubsub

// A representation of the trigger resource.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type Trigger = src.Trigger

// UnimplementedEventarcServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type UnimplementedEventarcServer = src.UnimplementedEventarcServer

// The request message for the UpdateChannel method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type UpdateChannelRequest = src.UpdateChannelRequest

// The request message for the UpdateTrigger method.
//
// Deprecated: Please use types in: cloud.google.com/go/eventarc/apiv1/eventarcpb
type UpdateTriggerRequest = src.UpdateTriggerRequest

// Deprecated: Please use funcs in: cloud.google.com/go/eventarc/apiv1/eventarcpb
func NewEventarcClient(cc grpc.ClientConnInterface) EventarcClient { return src.NewEventarcClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/eventarc/apiv1/eventarcpb
func RegisterEventarcServer(s *grpc.Server, srv EventarcServer) { src.RegisterEventarcServer(s, srv) }
