// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package run aliases all exported identifiers in package
// "cloud.google.com/go/run/apiv2/runpb".
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package run

import (
	src "cloud.google.com/go/run/apiv2/runpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/run/apiv2/runpb
const (
	Condition_ACTIVE_REVISION_LIMIT_REACHED                                = src.Condition_ACTIVE_REVISION_LIMIT_REACHED
	Condition_CANCELLED                                                    = src.Condition_CANCELLED
	Condition_COMMON_REASON_UNDEFINED                                      = src.Condition_COMMON_REASON_UNDEFINED
	Condition_CONDITION_FAILED                                             = src.Condition_CONDITION_FAILED
	Condition_CONDITION_PENDING                                            = src.Condition_CONDITION_PENDING
	Condition_CONDITION_RECONCILING                                        = src.Condition_CONDITION_RECONCILING
	Condition_CONDITION_SUCCEEDED                                          = src.Condition_CONDITION_SUCCEEDED
	Condition_CONTAINER_IMAGE_AUTHORIZATION_CHECK_FAILED                   = src.Condition_CONTAINER_IMAGE_AUTHORIZATION_CHECK_FAILED
	Condition_CONTAINER_IMAGE_UNAUTHORIZED                                 = src.Condition_CONTAINER_IMAGE_UNAUTHORIZED
	Condition_CONTAINER_MISSING                                            = src.Condition_CONTAINER_MISSING
	Condition_CONTAINER_PERMISSION_DENIED                                  = src.Condition_CONTAINER_PERMISSION_DENIED
	Condition_CUSTOMIZED_PATH_RESPONSE_PENDING                             = src.Condition_CUSTOMIZED_PATH_RESPONSE_PENDING
	Condition_ENCRYPTION_KEY_CHECK_FAILED                                  = src.Condition_ENCRYPTION_KEY_CHECK_FAILED
	Condition_ENCRYPTION_KEY_PERMISSION_DENIED                             = src.Condition_ENCRYPTION_KEY_PERMISSION_DENIED
	Condition_ERROR                                                        = src.Condition_ERROR
	Condition_EXECUTION_REASON_UNDEFINED                                   = src.Condition_EXECUTION_REASON_UNDEFINED
	Condition_HEALTH_CHECK_CONTAINER_ERROR                                 = src.Condition_HEALTH_CHECK_CONTAINER_ERROR
	Condition_HEALTH_CHECK_SKIPPED                                         = src.Condition_HEALTH_CHECK_SKIPPED
	Condition_IMMEDIATE_RETRY                                              = src.Condition_IMMEDIATE_RETRY
	Condition_INFO                                                         = src.Condition_INFO
	Condition_INTERNAL                                                     = src.Condition_INTERNAL
	Condition_JOB_STATUS_SERVICE_POLLING_ERROR                             = src.Condition_JOB_STATUS_SERVICE_POLLING_ERROR
	Condition_MIN_INSTANCES_NOT_PROVISIONED                                = src.Condition_MIN_INSTANCES_NOT_PROVISIONED
	Condition_NON_ZERO_EXIT_CODE                                           = src.Condition_NON_ZERO_EXIT_CODE
	Condition_NO_DEPLOYMENT                                                = src.Condition_NO_DEPLOYMENT
	Condition_PENDING                                                      = src.Condition_PENDING
	Condition_POSTPONED_RETRY                                              = src.Condition_POSTPONED_RETRY
	Condition_PROGRESS_DEADLINE_EXCEEDED                                   = src.Condition_PROGRESS_DEADLINE_EXCEEDED
	Condition_RECREATING                                                   = src.Condition_RECREATING
	Condition_RESERVE                                                      = src.Condition_RESERVE
	Condition_RETIRED                                                      = src.Condition_RETIRED
	Condition_RETIRING                                                     = src.Condition_RETIRING
	Condition_REVISION_FAILED                                              = src.Condition_REVISION_FAILED
	Condition_REVISION_REASON_UNDEFINED                                    = src.Condition_REVISION_REASON_UNDEFINED
	Condition_SECRETS_ACCESS_CHECK_FAILED                                  = src.Condition_SECRETS_ACCESS_CHECK_FAILED
	Condition_SEVERITY_UNSPECIFIED                                         = src.Condition_SEVERITY_UNSPECIFIED
	Condition_STATE_UNSPECIFIED                                            = src.Condition_STATE_UNSPECIFIED
	Condition_UNKNOWN                                                      = src.Condition_UNKNOWN
	Condition_WAITING_FOR_OPERATION                                        = src.Condition_WAITING_FOR_OPERATION
	Condition_WARNING                                                      = src.Condition_WARNING
	ExecutionEnvironment_EXECUTION_ENVIRONMENT_GEN1                        = src.ExecutionEnvironment_EXECUTION_ENVIRONMENT_GEN1
	ExecutionEnvironment_EXECUTION_ENVIRONMENT_GEN2                        = src.ExecutionEnvironment_EXECUTION_ENVIRONMENT_GEN2
	ExecutionEnvironment_EXECUTION_ENVIRONMENT_UNSPECIFIED                 = src.ExecutionEnvironment_EXECUTION_ENVIRONMENT_UNSPECIFIED
	IngressTraffic_INGRESS_TRAFFIC_ALL                                     = src.IngressTraffic_INGRESS_TRAFFIC_ALL
	IngressTraffic_INGRESS_TRAFFIC_INTERNAL_LOAD_BALANCER                  = src.IngressTraffic_INGRESS_TRAFFIC_INTERNAL_LOAD_BALANCER
	IngressTraffic_INGRESS_TRAFFIC_INTERNAL_ONLY                           = src.IngressTraffic_INGRESS_TRAFFIC_INTERNAL_ONLY
	IngressTraffic_INGRESS_TRAFFIC_UNSPECIFIED                             = src.IngressTraffic_INGRESS_TRAFFIC_UNSPECIFIED
	TrafficTargetAllocationType_TRAFFIC_TARGET_ALLOCATION_TYPE_LATEST      = src.TrafficTargetAllocationType_TRAFFIC_TARGET_ALLOCATION_TYPE_LATEST
	TrafficTargetAllocationType_TRAFFIC_TARGET_ALLOCATION_TYPE_REVISION    = src.TrafficTargetAllocationType_TRAFFIC_TARGET_ALLOCATION_TYPE_REVISION
	TrafficTargetAllocationType_TRAFFIC_TARGET_ALLOCATION_TYPE_UNSPECIFIED = src.TrafficTargetAllocationType_TRAFFIC_TARGET_ALLOCATION_TYPE_UNSPECIFIED
	VpcAccess_ALL_TRAFFIC                                                  = src.VpcAccess_ALL_TRAFFIC
	VpcAccess_PRIVATE_RANGES_ONLY                                          = src.VpcAccess_PRIVATE_RANGES_ONLY
	VpcAccess_VPC_EGRESS_UNSPECIFIED                                       = src.VpcAccess_VPC_EGRESS_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/run/apiv2/runpb
var (
	Condition_CommonReason_name                      = src.Condition_CommonReason_name
	Condition_CommonReason_value                     = src.Condition_CommonReason_value
	Condition_ExecutionReason_name                   = src.Condition_ExecutionReason_name
	Condition_ExecutionReason_value                  = src.Condition_ExecutionReason_value
	Condition_RevisionReason_name                    = src.Condition_RevisionReason_name
	Condition_RevisionReason_value                   = src.Condition_RevisionReason_value
	Condition_Severity_name                          = src.Condition_Severity_name
	Condition_Severity_value                         = src.Condition_Severity_value
	Condition_State_name                             = src.Condition_State_name
	Condition_State_value                            = src.Condition_State_value
	ExecutionEnvironment_name                        = src.ExecutionEnvironment_name
	ExecutionEnvironment_value                       = src.ExecutionEnvironment_value
	File_google_cloud_run_v2_condition_proto         = src.File_google_cloud_run_v2_condition_proto
	File_google_cloud_run_v2_k8s_min_proto           = src.File_google_cloud_run_v2_k8s_min_proto
	File_google_cloud_run_v2_revision_proto          = src.File_google_cloud_run_v2_revision_proto
	File_google_cloud_run_v2_revision_template_proto = src.File_google_cloud_run_v2_revision_template_proto
	File_google_cloud_run_v2_service_proto           = src.File_google_cloud_run_v2_service_proto
	File_google_cloud_run_v2_traffic_target_proto    = src.File_google_cloud_run_v2_traffic_target_proto
	File_google_cloud_run_v2_vendor_settings_proto   = src.File_google_cloud_run_v2_vendor_settings_proto
	IngressTraffic_name                              = src.IngressTraffic_name
	IngressTraffic_value                             = src.IngressTraffic_value
	TrafficTargetAllocationType_name                 = src.TrafficTargetAllocationType_name
	TrafficTargetAllocationType_value                = src.TrafficTargetAllocationType_value
	VpcAccess_VpcEgress_name                         = src.VpcAccess_VpcEgress_name
	VpcAccess_VpcEgress_value                        = src.VpcAccess_VpcEgress_value
)

// Settings for Binary Authorization feature.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type BinaryAuthorization = src.BinaryAuthorization
type BinaryAuthorization_UseDefault = src.BinaryAuthorization_UseDefault

// Represents a specific Cloud SQL instance.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type CloudSqlInstance = src.CloudSqlInstance

// Defines a status condition for a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Condition = src.Condition

// Reasons common to all types of conditions.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Condition_CommonReason = src.Condition_CommonReason

// Reasons specific to Execution resource.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Condition_ExecutionReason = src.Condition_ExecutionReason
type Condition_ExecutionReason_ = src.Condition_ExecutionReason_
type Condition_Reason = src.Condition_Reason

// Reasons specific to Revision resource.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Condition_RevisionReason = src.Condition_RevisionReason
type Condition_RevisionReason_ = src.Condition_RevisionReason_

// Represents the severity of the condition failures.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Condition_Severity = src.Condition_Severity

// Represents the possible Condition states.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Condition_State = src.Condition_State

// A single application container. This specifies both the container to run,
// the command to run in the container and the arguments to supply to it. Note
// that additional arguments may be supplied by the system to the container at
// runtime.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Container = src.Container

// ContainerPort represents a network port in a single container.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type ContainerPort = src.ContainerPort

// Request message for creating a Service.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type CreateServiceRequest = src.CreateServiceRequest

// Request message for deleting a retired Revision. Revision lifecycle is
// usually managed by making changes to the parent Service. Only retired
// revisions can be deleted with this API.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type DeleteRevisionRequest = src.DeleteRevisionRequest

// Request message to delete a Service by its full name.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type DeleteServiceRequest = src.DeleteServiceRequest

// EnvVar represents an environment variable present in a Container.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type EnvVar = src.EnvVar

// EnvVarSource represents a source for the value of an EnvVar.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type EnvVarSource = src.EnvVarSource
type EnvVar_Value = src.EnvVar_Value
type EnvVar_ValueSource = src.EnvVar_ValueSource

// Alternatives for execution environments.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type ExecutionEnvironment = src.ExecutionEnvironment

// Request message for obtaining a Revision by its full name.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type GetRevisionRequest = src.GetRevisionRequest

// Request message for obtaining a Service by its full name.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type GetServiceRequest = src.GetServiceRequest

// HTTPGetAction describes an action based on HTTP Get requests.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type HTTPGetAction = src.HTTPGetAction

// HTTPHeader describes a custom header to be used in HTTP probes
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type HTTPHeader = src.HTTPHeader

// Allowed ingress traffic for the Container.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type IngressTraffic = src.IngressTraffic

// Request message for retrieving a list of Revisions.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type ListRevisionsRequest = src.ListRevisionsRequest

// Response message containing a list of Revisions.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type ListRevisionsResponse = src.ListRevisionsResponse

// Request message for retrieving a list of Services.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type ListServicesRequest = src.ListServicesRequest

// Response message containing a list of Services.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type ListServicesResponse = src.ListServicesResponse

// Probe describes a health check to be performed against a container to
// determine whether it is alive or ready to receive traffic.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Probe = src.Probe
type Probe_HttpGet = src.Probe_HttpGet
type Probe_TcpSocket = src.Probe_TcpSocket

// ResourceRequirements describes the compute resource requirements.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type ResourceRequirements = src.ResourceRequirements

// A Revision is an immutable snapshot of code and configuration. A Revision
// references a container image. Revisions are only created by updates to its
// parent Service.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Revision = src.Revision

// Settings for revision-level scaling settings.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type RevisionScaling = src.RevisionScaling

// RevisionTemplate describes the data a revision should have when created
// from a template.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type RevisionTemplate = src.RevisionTemplate

// RevisionsClient is the client API for Revisions service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type RevisionsClient = src.RevisionsClient

// RevisionsServer is the server API for Revisions service.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type RevisionsServer = src.RevisionsServer

// SecretEnvVarSource represents a source for the value of an EnvVar.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type SecretKeySelector = src.SecretKeySelector

// The secret's value will be presented as the content of a file whose name is
// defined in the item path. If no items are defined, the name of the file is
// the secret.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type SecretVolumeSource = src.SecretVolumeSource

// Service acts as a top-level container that manages a set of configurations
// and revision templates which implement a network service. Service exists to
// provide a singular abstraction which can be access controlled, reasoned
// about, and which encapsulates software lifecycle decisions such as rollout
// policy and team resource ownership.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Service = src.Service

// ServicesClient is the client API for Services service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type ServicesClient = src.ServicesClient

// ServicesServer is the server API for Services service.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type ServicesServer = src.ServicesServer

// TCPSocketAction describes an action based on opening a socket
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type TCPSocketAction = src.TCPSocketAction

// Holds a single traffic routing entry for the Service. Allocations can be
// done to a specific Revision name, or pointing to the latest Ready Revision.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type TrafficTarget = src.TrafficTarget

// The type of instance allocation.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type TrafficTargetAllocationType = src.TrafficTargetAllocationType

// Represents the observed state of a single `TrafficTarget` entry.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type TrafficTargetStatus = src.TrafficTargetStatus

// UnimplementedRevisionsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type UnimplementedRevisionsServer = src.UnimplementedRevisionsServer

// UnimplementedServicesServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type UnimplementedServicesServer = src.UnimplementedServicesServer

// Request message for updating a service.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type UpdateServiceRequest = src.UpdateServiceRequest

// VersionToPath maps a specific version of a secret to a relative file to
// mount to, relative to VolumeMount's mount_path.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type VersionToPath = src.VersionToPath

// Volume represents a named volume in a container.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type Volume = src.Volume

// VolumeMount describes a mounting of a Volume within a container.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type VolumeMount = src.VolumeMount
type Volume_CloudSqlInstance = src.Volume_CloudSqlInstance
type Volume_Secret = src.Volume_Secret

// VPC Access settings. For more information on creating a VPC Connector,
// visit https://cloud.google.com/vpc/docs/configure-serverless-vpc-access For
// information on how to configure Cloud Run with an existing VPC Connector,
// visit https://cloud.google.com/run/docs/configuring/connecting-vpc
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type VpcAccess = src.VpcAccess

// Egress options for VPC access.
//
// Deprecated: Please use types in: cloud.google.com/go/run/apiv2/runpb
type VpcAccess_VpcEgress = src.VpcAccess_VpcEgress

// Deprecated: Please use funcs in: cloud.google.com/go/run/apiv2/runpb
func NewRevisionsClient(cc grpc.ClientConnInterface) RevisionsClient {
	return src.NewRevisionsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/run/apiv2/runpb
func NewServicesClient(cc grpc.ClientConnInterface) ServicesClient { return src.NewServicesClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/run/apiv2/runpb
func RegisterRevisionsServer(s *grpc.Server, srv RevisionsServer) {
	src.RegisterRevisionsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/run/apiv2/runpb
func RegisterServicesServer(s *grpc.Server, srv ServicesServer) { src.RegisterServicesServer(s, srv) }
