// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package datatransfer aliases all exported identifiers in package
// "cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb".
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package datatransfer

import (
	src "cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
const (
	DataSourceParameter_BOOLEAN                     = src.DataSourceParameter_BOOLEAN
	DataSourceParameter_DOUBLE                      = src.DataSourceParameter_DOUBLE
	DataSourceParameter_INTEGER                     = src.DataSourceParameter_INTEGER
	DataSourceParameter_PLUS_PAGE                   = src.DataSourceParameter_PLUS_PAGE
	DataSourceParameter_RECORD                      = src.DataSourceParameter_RECORD
	DataSourceParameter_STRING                      = src.DataSourceParameter_STRING
	DataSourceParameter_TYPE_UNSPECIFIED            = src.DataSourceParameter_TYPE_UNSPECIFIED
	DataSource_AUTHORIZATION_CODE                   = src.DataSource_AUTHORIZATION_CODE
	DataSource_AUTHORIZATION_TYPE_UNSPECIFIED       = src.DataSource_AUTHORIZATION_TYPE_UNSPECIFIED
	DataSource_CUSTOM_SLIDING_WINDOW                = src.DataSource_CUSTOM_SLIDING_WINDOW
	DataSource_DATA_REFRESH_TYPE_UNSPECIFIED        = src.DataSource_DATA_REFRESH_TYPE_UNSPECIFIED
	DataSource_FIRST_PARTY_OAUTH                    = src.DataSource_FIRST_PARTY_OAUTH
	DataSource_GOOGLE_PLUS_AUTHORIZATION_CODE       = src.DataSource_GOOGLE_PLUS_AUTHORIZATION_CODE
	DataSource_SLIDING_WINDOW                       = src.DataSource_SLIDING_WINDOW
	ListTransferRunsRequest_LATEST                  = src.ListTransferRunsRequest_LATEST
	ListTransferRunsRequest_RUN_ATTEMPT_UNSPECIFIED = src.ListTransferRunsRequest_RUN_ATTEMPT_UNSPECIFIED
	TransferMessage_ERROR                           = src.TransferMessage_ERROR
	TransferMessage_INFO                            = src.TransferMessage_INFO
	TransferMessage_MESSAGE_SEVERITY_UNSPECIFIED    = src.TransferMessage_MESSAGE_SEVERITY_UNSPECIFIED
	TransferMessage_WARNING                         = src.TransferMessage_WARNING
	TransferState_CANCELLED                         = src.TransferState_CANCELLED
	TransferState_FAILED                            = src.TransferState_FAILED
	TransferState_PENDING                           = src.TransferState_PENDING
	TransferState_RUNNING                           = src.TransferState_RUNNING
	TransferState_SUCCEEDED                         = src.TransferState_SUCCEEDED
	TransferState_TRANSFER_STATE_UNSPECIFIED        = src.TransferState_TRANSFER_STATE_UNSPECIFIED
	TransferType_BATCH                              = src.TransferType_BATCH
	TransferType_STREAMING                          = src.TransferType_STREAMING
	TransferType_TRANSFER_TYPE_UNSPECIFIED          = src.TransferType_TRANSFER_TYPE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
var (
	DataSourceParameter_Type_name                                 = src.DataSourceParameter_Type_name
	DataSourceParameter_Type_value                                = src.DataSourceParameter_Type_value
	DataSource_AuthorizationType_name                             = src.DataSource_AuthorizationType_name
	DataSource_AuthorizationType_value                            = src.DataSource_AuthorizationType_value
	DataSource_DataRefreshType_name                               = src.DataSource_DataRefreshType_name
	DataSource_DataRefreshType_value                              = src.DataSource_DataRefreshType_value
	File_google_cloud_bigquery_datatransfer_v1_datatransfer_proto = src.File_google_cloud_bigquery_datatransfer_v1_datatransfer_proto
	File_google_cloud_bigquery_datatransfer_v1_transfer_proto     = src.File_google_cloud_bigquery_datatransfer_v1_transfer_proto
	ListTransferRunsRequest_RunAttempt_name                       = src.ListTransferRunsRequest_RunAttempt_name
	ListTransferRunsRequest_RunAttempt_value                      = src.ListTransferRunsRequest_RunAttempt_value
	TransferMessage_MessageSeverity_name                          = src.TransferMessage_MessageSeverity_name
	TransferMessage_MessageSeverity_value                         = src.TransferMessage_MessageSeverity_value
	TransferState_name                                            = src.TransferState_name
	TransferState_value                                           = src.TransferState_value
	TransferType_name                                             = src.TransferType_name
	TransferType_value                                            = src.TransferType_value
)

// A request to determine whether the user has valid credentials. This method
// is used to limit the number of OAuth popups in the user interface. The user
// id is inferred from the API call context. If the data source has the Google+
// authorization type, this method returns false, as it cannot be determined
// whether the credentials are already valid merely based on the user id.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type CheckValidCredsRequest = src.CheckValidCredsRequest

// A response indicating whether the credentials exist and are valid.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type CheckValidCredsResponse = src.CheckValidCredsResponse

// A request to create a data transfer configuration. If new credentials are
// needed for this transfer configuration, authorization info must be provided.
// If authorization info is provided, the transfer configuration will be
// associated with the user id corresponding to the authorization info.
// Otherwise, the transfer configuration will be associated with the calling
// user.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type CreateTransferConfigRequest = src.CreateTransferConfigRequest

// Defines the properties and custom parameters for a data source.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type DataSource = src.DataSource

// A parameter used to define custom fields in a data source definition.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type DataSourceParameter = src.DataSourceParameter

// Parameter type.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type DataSourceParameter_Type = src.DataSourceParameter_Type

// The type of authorization needed for this data source.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type DataSource_AuthorizationType = src.DataSource_AuthorizationType

// Represents how the data source supports data auto refresh.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type DataSource_DataRefreshType = src.DataSource_DataRefreshType

// DataTransferServiceClient is the client API for DataTransferService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type DataTransferServiceClient = src.DataTransferServiceClient

// DataTransferServiceServer is the server API for DataTransferService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type DataTransferServiceServer = src.DataTransferServiceServer

// A request to delete data transfer information. All associated transfer runs
// and log messages will be deleted as well.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type DeleteTransferConfigRequest = src.DeleteTransferConfigRequest

// A request to delete data transfer run information.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type DeleteTransferRunRequest = src.DeleteTransferRunRequest

// Represents preferences for sending email notifications for transfer run
// events.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type EmailPreferences = src.EmailPreferences

// A request to enroll a set of data sources so they are visible in the
// BigQuery UI's `Transfer` tab.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type EnrollDataSourcesRequest = src.EnrollDataSourcesRequest

// A request to get data source info.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type GetDataSourceRequest = src.GetDataSourceRequest

// A request to get data transfer information.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type GetTransferConfigRequest = src.GetTransferConfigRequest

// A request to get data transfer run information.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type GetTransferRunRequest = src.GetTransferRunRequest

// Request to list supported data sources and their data transfer settings.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ListDataSourcesRequest = src.ListDataSourcesRequest

// Returns list of supported data sources and their metadata.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ListDataSourcesResponse = src.ListDataSourcesResponse

// A request to list data transfers configured for a BigQuery project.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ListTransferConfigsRequest = src.ListTransferConfigsRequest

// The returned list of pipelines in the project.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ListTransferConfigsResponse = src.ListTransferConfigsResponse

// A request to get user facing log messages associated with data transfer
// run.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ListTransferLogsRequest = src.ListTransferLogsRequest

// The returned list transfer run messages.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ListTransferLogsResponse = src.ListTransferLogsResponse

// A request to list data transfer runs.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ListTransferRunsRequest = src.ListTransferRunsRequest

// Represents which runs should be pulled.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ListTransferRunsRequest_RunAttempt = src.ListTransferRunsRequest_RunAttempt

// The returned list of pipelines in the project.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ListTransferRunsResponse = src.ListTransferRunsResponse

// Options customizing the data transfer schedule.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ScheduleOptions = src.ScheduleOptions

// A request to schedule transfer runs for a time range.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ScheduleTransferRunsRequest = src.ScheduleTransferRunsRequest

// A response to schedule transfer runs for a time range.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type ScheduleTransferRunsResponse = src.ScheduleTransferRunsResponse

// A request to start manual transfer runs.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type StartManualTransferRunsRequest = src.StartManualTransferRunsRequest
type StartManualTransferRunsRequest_RequestedRunTime = src.StartManualTransferRunsRequest_RequestedRunTime
type StartManualTransferRunsRequest_RequestedTimeRange = src.StartManualTransferRunsRequest_RequestedTimeRange

// A specification for a time range, this will request transfer runs with
// run_time between start_time (inclusive) and end_time (exclusive).
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type StartManualTransferRunsRequest_TimeRange = src.StartManualTransferRunsRequest_TimeRange

// A response to start manual transfer runs.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type StartManualTransferRunsResponse = src.StartManualTransferRunsResponse

// Represents a data transfer configuration. A transfer configuration contains
// all metadata needed to perform a data transfer. For example,
// `destination_dataset_id` specifies where data should be stored. When a new
// transfer configuration is created, the specified `destination_dataset_id` is
// created when needed and shared with the appropriate data source service
// account.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type TransferConfig = src.TransferConfig
type TransferConfig_DestinationDatasetId = src.TransferConfig_DestinationDatasetId

// Represents a user facing message for a particular data transfer run.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type TransferMessage = src.TransferMessage

// Represents data transfer user facing message severity.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type TransferMessage_MessageSeverity = src.TransferMessage_MessageSeverity

// Represents a data transfer run.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type TransferRun = src.TransferRun
type TransferRun_DestinationDatasetId = src.TransferRun_DestinationDatasetId

// Represents data transfer run state.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type TransferState = src.TransferState

// DEPRECATED. Represents data transfer type. Deprecated: Do not use.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type TransferType = src.TransferType

// UnimplementedDataTransferServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type UnimplementedDataTransferServiceServer = src.UnimplementedDataTransferServiceServer

// A request to update a transfer configuration. To update the user id of the
// transfer configuration, authorization info needs to be provided.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type UpdateTransferConfigRequest = src.UpdateTransferConfigRequest

// Information about a user.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
type UserInfo = src.UserInfo

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
func NewDataTransferServiceClient(cc grpc.ClientConnInterface) DataTransferServiceClient {
	return src.NewDataTransferServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/datatransfer/apiv1/datatransferpb
func RegisterDataTransferServiceServer(s *grpc.Server, srv DataTransferServiceServer) {
	src.RegisterDataTransferServiceServer(s, srv)
}
