// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package storage aliases all exported identifiers in package
// "cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb".
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package storage

import (
	src "cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
const (
	DataFormat_ARROW                               = src.DataFormat_ARROW
	DataFormat_AVRO                                = src.DataFormat_AVRO
	DataFormat_DATA_FORMAT_UNSPECIFIED             = src.DataFormat_DATA_FORMAT_UNSPECIFIED
	ShardingStrategy_BALANCED                      = src.ShardingStrategy_BALANCED
	ShardingStrategy_LIQUID                        = src.ShardingStrategy_LIQUID
	ShardingStrategy_SHARDING_STRATEGY_UNSPECIFIED = src.ShardingStrategy_SHARDING_STRATEGY_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
var (
	DataFormat_name                                                  = src.DataFormat_name
	DataFormat_value                                                 = src.DataFormat_value
	File_google_cloud_bigquery_storage_v1beta1_arrow_proto           = src.File_google_cloud_bigquery_storage_v1beta1_arrow_proto
	File_google_cloud_bigquery_storage_v1beta1_avro_proto            = src.File_google_cloud_bigquery_storage_v1beta1_avro_proto
	File_google_cloud_bigquery_storage_v1beta1_read_options_proto    = src.File_google_cloud_bigquery_storage_v1beta1_read_options_proto
	File_google_cloud_bigquery_storage_v1beta1_storage_proto         = src.File_google_cloud_bigquery_storage_v1beta1_storage_proto
	File_google_cloud_bigquery_storage_v1beta1_table_reference_proto = src.File_google_cloud_bigquery_storage_v1beta1_table_reference_proto
	ShardingStrategy_name                                            = src.ShardingStrategy_name
	ShardingStrategy_value                                           = src.ShardingStrategy_value
)

// Arrow RecordBatch.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type ArrowRecordBatch = src.ArrowRecordBatch

// Arrow schema.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type ArrowSchema = src.ArrowSchema

// Avro rows.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type AvroRows = src.AvroRows

// Avro schema.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type AvroSchema = src.AvroSchema

// Information needed to request additional streams for an established read
// session.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type BatchCreateReadSessionStreamsRequest = src.BatchCreateReadSessionStreamsRequest

// The response from `BatchCreateReadSessionStreams` returns the stream
// identifiers for the newly created streams.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type BatchCreateReadSessionStreamsResponse = src.BatchCreateReadSessionStreamsResponse

// BigQueryStorageClient is the client API for BigQueryStorage service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type BigQueryStorageClient = src.BigQueryStorageClient

// BigQueryStorageServer is the server API for BigQueryStorage service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type BigQueryStorageServer = src.BigQueryStorageServer
type BigQueryStorage_ReadRowsClient = src.BigQueryStorage_ReadRowsClient
type BigQueryStorage_ReadRowsServer = src.BigQueryStorage_ReadRowsServer

// Creates a new read session, which may include additional options such as
// requested parallelism, projection filters and constraints.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type CreateReadSessionRequest = src.CreateReadSessionRequest

// Data format for input or output data.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type DataFormat = src.DataFormat

// Request information for invoking `FinalizeStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type FinalizeStreamRequest = src.FinalizeStreamRequest
type Progress = src.Progress

// Requesting row data via `ReadRows` must provide Stream position
// information.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type ReadRowsRequest = src.ReadRowsRequest

// Response from calling `ReadRows` may include row data, progress and
// throttling information.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type ReadRowsResponse = src.ReadRowsResponse
type ReadRowsResponse_ArrowRecordBatch = src.ReadRowsResponse_ArrowRecordBatch
type ReadRowsResponse_AvroRows = src.ReadRowsResponse_AvroRows

// Information returned from a `CreateReadSession` request.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type ReadSession = src.ReadSession
type ReadSession_ArrowSchema = src.ReadSession_ArrowSchema
type ReadSession_AvroSchema = src.ReadSession_AvroSchema

// Strategy for distributing data among multiple streams in a read session.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type ShardingStrategy = src.ShardingStrategy

// Request information for `SplitReadStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type SplitReadStreamRequest = src.SplitReadStreamRequest

// Response from `SplitReadStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type SplitReadStreamResponse = src.SplitReadStreamResponse

// Information about a single data stream within a read session.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type Stream = src.Stream

// Expresses a point within a given stream using an offset position.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type StreamPosition = src.StreamPosition

// Progress information for a given Stream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type StreamStatus = src.StreamStatus

// All fields in this message optional.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type TableModifiers = src.TableModifiers

// Options dictating how we read a table.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type TableReadOptions = src.TableReadOptions

// Table reference that includes just the 3 strings needed to identify a
// table.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type TableReference = src.TableReference

// Information on if the current connection is being throttled.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type ThrottleStatus = src.ThrottleStatus

// UnimplementedBigQueryStorageServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
type UnimplementedBigQueryStorageServer = src.UnimplementedBigQueryStorageServer

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
func NewBigQueryStorageClient(cc grpc.ClientConnInterface) BigQueryStorageClient {
	return src.NewBigQueryStorageClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/storage/apiv1beta1/storagepb
func RegisterBigQueryStorageServer(s *grpc.Server, srv BigQueryStorageServer) {
	src.RegisterBigQueryStorageServer(s, srv)
}
