// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package edgecontainer aliases all exported identifiers in package
// "cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb".
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package edgecontainer

import (
	src "cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
const (
	KmsKeyState_KMS_KEY_STATE_KEY_AVAILABLE    = src.KmsKeyState_KMS_KEY_STATE_KEY_AVAILABLE
	KmsKeyState_KMS_KEY_STATE_KEY_UNAVAILABLE  = src.KmsKeyState_KMS_KEY_STATE_KEY_UNAVAILABLE
	KmsKeyState_KMS_KEY_STATE_UNSPECIFIED      = src.KmsKeyState_KMS_KEY_STATE_UNSPECIFIED
	VpnConnection_BGP_ROUTING_MODE_UNSPECIFIED = src.VpnConnection_BGP_ROUTING_MODE_UNSPECIFIED
	VpnConnection_Details_STATE_CONNECTED      = src.VpnConnection_Details_STATE_CONNECTED
	VpnConnection_Details_STATE_CONNECTING     = src.VpnConnection_Details_STATE_CONNECTING
	VpnConnection_Details_STATE_ERROR          = src.VpnConnection_Details_STATE_ERROR
	VpnConnection_Details_STATE_UNSPECIFIED    = src.VpnConnection_Details_STATE_UNSPECIFIED
	VpnConnection_GLOBAL                       = src.VpnConnection_GLOBAL
	VpnConnection_REGIONAL                     = src.VpnConnection_REGIONAL
)

// Deprecated: Please use vars in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
var (
	File_google_cloud_edgecontainer_v1_resources_proto = src.File_google_cloud_edgecontainer_v1_resources_proto
	File_google_cloud_edgecontainer_v1_service_proto   = src.File_google_cloud_edgecontainer_v1_service_proto
	KmsKeyState_name                                   = src.KmsKeyState_name
	KmsKeyState_value                                  = src.KmsKeyState_value
	VpnConnection_BgpRoutingMode_name                  = src.VpnConnection_BgpRoutingMode_name
	VpnConnection_BgpRoutingMode_value                 = src.VpnConnection_BgpRoutingMode_value
	VpnConnection_Details_State_name                   = src.VpnConnection_Details_State_name
	VpnConnection_Details_State_value                  = src.VpnConnection_Details_State_value
)

// RBAC policy that will be applied and managed by GEC.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type Authorization = src.Authorization

// A Google Distributed Cloud Edge Kubernetes cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type Cluster = src.Cluster

// Cluster-wide networking configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ClusterNetworking = src.ClusterNetworking

// A user principal for an RBAC policy.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ClusterUser = src.ClusterUser

// Creates a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type CreateClusterRequest = src.CreateClusterRequest

// Creates a node pool.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type CreateNodePoolRequest = src.CreateNodePoolRequest

// Creates a VPN connection.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type CreateVpnConnectionRequest = src.CreateVpnConnectionRequest

// Deletes a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type DeleteClusterRequest = src.DeleteClusterRequest

// Deletes a node pool.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type DeleteNodePoolRequest = src.DeleteNodePoolRequest

// Deletes a vpn connection.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type DeleteVpnConnectionRequest = src.DeleteVpnConnectionRequest

// EdgeContainerClient is the client API for EdgeContainer service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type EdgeContainerClient = src.EdgeContainerClient

// EdgeContainerServer is the server API for EdgeContainer service.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type EdgeContainerServer = src.EdgeContainerServer

// Fleet related configuration. Fleets are a Google Cloud concept for
// logically organizing clusters, letting you use and manage multi-cluster
// capabilities and apply consistent policies across your systems.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type Fleet = src.Fleet

// Generates an access token for a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type GenerateAccessTokenRequest = src.GenerateAccessTokenRequest

// An access token for a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type GenerateAccessTokenResponse = src.GenerateAccessTokenResponse

// Gets a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type GetClusterRequest = src.GetClusterRequest

// Gets a machine.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type GetMachineRequest = src.GetMachineRequest

// Gets a node pool.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type GetNodePoolRequest = src.GetNodePoolRequest

// Gets a VPN connection.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type GetVpnConnectionRequest = src.GetVpnConnectionRequest

// Represents the accessibility state of a customer-managed KMS key used for
// CMEK integration.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type KmsKeyState = src.KmsKeyState

// Lists clusters in a location.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ListClustersRequest = src.ListClustersRequest

// List of clusters in a location.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ListClustersResponse = src.ListClustersResponse

// Lists machines in a site.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ListMachinesRequest = src.ListMachinesRequest

// List of machines in a site.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ListMachinesResponse = src.ListMachinesResponse

// Lists node pools in a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ListNodePoolsRequest = src.ListNodePoolsRequest

// List of node pools in a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ListNodePoolsResponse = src.ListNodePoolsResponse

// Lists VPN connections.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ListVpnConnectionsRequest = src.ListVpnConnectionsRequest

// List of VPN connections in a location.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ListVpnConnectionsResponse = src.ListVpnConnectionsResponse

// Metadata for a given
// [google.cloud.location.Location][google.cloud.location.Location].
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type LocationMetadata = src.LocationMetadata

// A Google Distributed Cloud Edge machine capable of acting as a Kubernetes
// node.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type Machine = src.Machine

// Maintenance policy configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type MaintenancePolicy = src.MaintenancePolicy

// Maintenance window configuration
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type MaintenanceWindow = src.MaintenanceWindow

// A set of Kubernetes nodes in a cluster with common configuration and
// specification.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type NodePool = src.NodePool

// Configuration for CMEK support for edge machine local disk encryption.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type NodePool_LocalDiskEncryption = src.NodePool_LocalDiskEncryption

// Long-running operation metadata for Edge Container API methods.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type OperationMetadata = src.OperationMetadata

// Represents quota for Edge Container resources.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type Quota = src.Quota

// Represents an arbitrary window of time that recurs.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type RecurringTimeWindow = src.RecurringTimeWindow

// Represents an arbitrary window of time.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type TimeWindow = src.TimeWindow

// UnimplementedEdgeContainerServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type UnimplementedEdgeContainerServer = src.UnimplementedEdgeContainerServer

// Updates a cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type UpdateClusterRequest = src.UpdateClusterRequest

// Updates a node pool.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type UpdateNodePoolRequest = src.UpdateNodePoolRequest

// A VPN connection .
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type VpnConnection = src.VpnConnection

// Routing mode.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type VpnConnection_BgpRoutingMode = src.VpnConnection_BgpRoutingMode

// The created connection details.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type VpnConnection_Details = src.VpnConnection_Details

// The Cloud Router info.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type VpnConnection_Details_CloudRouter = src.VpnConnection_Details_CloudRouter

// The Cloud VPN info.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type VpnConnection_Details_CloudVpn = src.VpnConnection_Details_CloudVpn

// The current connection state.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type VpnConnection_Details_State = src.VpnConnection_Details_State

// Project detail of the VPC network.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type VpnConnection_VpcProject = src.VpnConnection_VpcProject

// A Google Distributed Cloud Edge zone where edge machines are located.
//
// Deprecated: Please use types in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
type ZoneMetadata = src.ZoneMetadata

// Deprecated: Please use funcs in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
func NewEdgeContainerClient(cc grpc.ClientConnInterface) EdgeContainerClient {
	return src.NewEdgeContainerClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/edgecontainer/apiv1/edgecontainerpb
func RegisterEdgeContainerServer(s *grpc.Server, srv EdgeContainerServer) {
	src.RegisterEdgeContainerServer(s, srv)
}
