// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package networksecurity aliases all exported identifiers in package
// "cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb".
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package networksecurity

import (
	src "cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
const (
	AuthorizationPolicy_ACTION_UNSPECIFIED = src.AuthorizationPolicy_ACTION_UNSPECIFIED
	AuthorizationPolicy_ALLOW              = src.AuthorizationPolicy_ALLOW
	AuthorizationPolicy_DENY               = src.AuthorizationPolicy_DENY
)

// Deprecated: Please use vars in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
var (
	AuthorizationPolicy_Action_name                                      = src.AuthorizationPolicy_Action_name
	AuthorizationPolicy_Action_value                                     = src.AuthorizationPolicy_Action_value
	File_google_cloud_networksecurity_v1beta1_authorization_policy_proto = src.File_google_cloud_networksecurity_v1beta1_authorization_policy_proto
	File_google_cloud_networksecurity_v1beta1_client_tls_policy_proto    = src.File_google_cloud_networksecurity_v1beta1_client_tls_policy_proto
	File_google_cloud_networksecurity_v1beta1_common_proto               = src.File_google_cloud_networksecurity_v1beta1_common_proto
	File_google_cloud_networksecurity_v1beta1_network_security_proto     = src.File_google_cloud_networksecurity_v1beta1_network_security_proto
	File_google_cloud_networksecurity_v1beta1_server_tls_policy_proto    = src.File_google_cloud_networksecurity_v1beta1_server_tls_policy_proto
	File_google_cloud_networksecurity_v1beta1_tls_proto                  = src.File_google_cloud_networksecurity_v1beta1_tls_proto
)

// AuthorizationPolicy is a resource that specifies how a server should
// authorize incoming connections. This resource in itself does not change the
// configuration unless it's attached to a target https proxy or endpoint
// config selector resource.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type AuthorizationPolicy = src.AuthorizationPolicy

// Possible values that define what action to take.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type AuthorizationPolicy_Action = src.AuthorizationPolicy_Action

// Specification of rules.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type AuthorizationPolicy_Rule = src.AuthorizationPolicy_Rule

// Specification of traffic destination attributes.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type AuthorizationPolicy_Rule_Destination = src.AuthorizationPolicy_Rule_Destination

// Specification of HTTP header match attributes.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type AuthorizationPolicy_Rule_Destination_HttpHeaderMatch = src.AuthorizationPolicy_Rule_Destination_HttpHeaderMatch
type AuthorizationPolicy_Rule_Destination_HttpHeaderMatch_RegexMatch = src.AuthorizationPolicy_Rule_Destination_HttpHeaderMatch_RegexMatch

// Specification of traffic source attributes.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type AuthorizationPolicy_Rule_Source = src.AuthorizationPolicy_Rule_Source

// Specification of certificate provider. Defines the mechanism to obtain the
// certificate and private key for peer to peer authentication.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type CertificateProvider = src.CertificateProvider

// Specification of a TLS certificate provider instance. Workloads may have
// one or more CertificateProvider instances (plugins) and one of them is
// enabled and configured by specifying this message. Workloads use the values
// from this message to locate and load the CertificateProvider instance
// configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type CertificateProviderInstance = src.CertificateProviderInstance
type CertificateProvider_CertificateProviderInstance = src.CertificateProvider_CertificateProviderInstance
type CertificateProvider_GrpcEndpoint = src.CertificateProvider_GrpcEndpoint

// ClientTlsPolicy is a resource that specifies how a client should
// authenticate connections to backends of a service. This resource itself does
// not affect configuration unless it is attached to a backend service
// resource.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type ClientTlsPolicy = src.ClientTlsPolicy

// Request used by the CreateAuthorizationPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type CreateAuthorizationPolicyRequest = src.CreateAuthorizationPolicyRequest

// Request used by the CreateClientTlsPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type CreateClientTlsPolicyRequest = src.CreateClientTlsPolicyRequest

// Request used by the CreateServerTlsPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type CreateServerTlsPolicyRequest = src.CreateServerTlsPolicyRequest

// Request used by the DeleteAuthorizationPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type DeleteAuthorizationPolicyRequest = src.DeleteAuthorizationPolicyRequest

// Request used by the DeleteClientTlsPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type DeleteClientTlsPolicyRequest = src.DeleteClientTlsPolicyRequest

// Request used by the DeleteServerTlsPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type DeleteServerTlsPolicyRequest = src.DeleteServerTlsPolicyRequest

// Request used by the GetAuthorizationPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type GetAuthorizationPolicyRequest = src.GetAuthorizationPolicyRequest

// Request used by the GetClientTlsPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type GetClientTlsPolicyRequest = src.GetClientTlsPolicyRequest

// Request used by the GetServerTlsPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type GetServerTlsPolicyRequest = src.GetServerTlsPolicyRequest

// Specification of the GRPC Endpoint.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type GrpcEndpoint = src.GrpcEndpoint

// Request used with the ListAuthorizationPolicies method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type ListAuthorizationPoliciesRequest = src.ListAuthorizationPoliciesRequest

// Response returned by the ListAuthorizationPolicies method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type ListAuthorizationPoliciesResponse = src.ListAuthorizationPoliciesResponse

// Request used by the ListClientTlsPolicies method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type ListClientTlsPoliciesRequest = src.ListClientTlsPoliciesRequest

// Response returned by the ListClientTlsPolicies method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type ListClientTlsPoliciesResponse = src.ListClientTlsPoliciesResponse

// Request used by the ListServerTlsPolicies method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type ListServerTlsPoliciesRequest = src.ListServerTlsPoliciesRequest

// Response returned by the ListServerTlsPolicies method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type ListServerTlsPoliciesResponse = src.ListServerTlsPoliciesResponse

// NetworkSecurityClient is the client API for NetworkSecurity service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type NetworkSecurityClient = src.NetworkSecurityClient

// NetworkSecurityServer is the server API for NetworkSecurity service.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type NetworkSecurityServer = src.NetworkSecurityServer

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type OperationMetadata = src.OperationMetadata

// ServerTlsPolicy is a resource that specifies how a server should
// authenticate incoming requests. This resource itself does not affect
// configuration unless it is attached to a target https proxy or endpoint
// config selector resource.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type ServerTlsPolicy = src.ServerTlsPolicy

// Specification of the MTLSPolicy.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type ServerTlsPolicy_MTLSPolicy = src.ServerTlsPolicy_MTLSPolicy

// UnimplementedNetworkSecurityServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type UnimplementedNetworkSecurityServer = src.UnimplementedNetworkSecurityServer

// Request used by the UpdateAuthorizationPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type UpdateAuthorizationPolicyRequest = src.UpdateAuthorizationPolicyRequest

// Request used by UpdateClientTlsPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type UpdateClientTlsPolicyRequest = src.UpdateClientTlsPolicyRequest

// Request used by UpdateServerTlsPolicy method.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type UpdateServerTlsPolicyRequest = src.UpdateServerTlsPolicyRequest

// Specification of ValidationCA. Defines the mechanism to obtain the
// Certificate Authority certificate to validate the peer certificate.
//
// Deprecated: Please use types in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
type ValidationCA = src.ValidationCA
type ValidationCA_CertificateProviderInstance = src.ValidationCA_CertificateProviderInstance
type ValidationCA_GrpcEndpoint = src.ValidationCA_GrpcEndpoint

// Deprecated: Please use funcs in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
func NewNetworkSecurityClient(cc grpc.ClientConnInterface) NetworkSecurityClient {
	return src.NewNetworkSecurityClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/networksecurity/apiv1beta1/networksecuritypb
func RegisterNetworkSecurityServer(s *grpc.Server, srv NetworkSecurityServer) {
	src.RegisterNetworkSecurityServer(s, srv)
}
