// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package asset aliases all exported identifiers in package
// "cloud.google.com/go/asset/apiv1p5beta1/assetpb".
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1p5beta1/assetpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package asset

import (
	src "cloud.google.com/go/asset/apiv1p5beta1/assetpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
const (
	ContentType_ACCESS_POLICY            = src.ContentType_ACCESS_POLICY
	ContentType_CONTENT_TYPE_UNSPECIFIED = src.ContentType_CONTENT_TYPE_UNSPECIFIED
	ContentType_IAM_POLICY               = src.ContentType_IAM_POLICY
	ContentType_ORG_POLICY               = src.ContentType_ORG_POLICY
	ContentType_RESOURCE                 = src.ContentType_RESOURCE
)

// Deprecated: Please use vars in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
var (
	ContentType_name                                      = src.ContentType_name
	ContentType_value                                     = src.ContentType_value
	File_google_cloud_asset_v1p5beta1_asset_service_proto = src.File_google_cloud_asset_v1p5beta1_asset_service_proto
	File_google_cloud_asset_v1p5beta1_assets_proto        = src.File_google_cloud_asset_v1p5beta1_assets_proto
)

// Cloud asset. This includes all Google Cloud Platform resources, Cloud IAM
// policies, and other non-GCP assets.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
type Asset = src.Asset

// AssetServiceClient is the client API for AssetService service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
type AssetServiceClient = src.AssetServiceClient

// AssetServiceServer is the server API for AssetService service.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
type AssetServiceServer = src.AssetServiceServer
type Asset_AccessLevel = src.Asset_AccessLevel
type Asset_AccessPolicy = src.Asset_AccessPolicy
type Asset_ServicePerimeter = src.Asset_ServicePerimeter

// Asset content type.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
type ContentType = src.ContentType

// ListAssets request.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
type ListAssetsRequest = src.ListAssetsRequest

// ListAssets response.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
type ListAssetsResponse = src.ListAssetsResponse

// Representation of a cloud resource.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
type Resource = src.Resource

// UnimplementedAssetServiceServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
type UnimplementedAssetServiceServer = src.UnimplementedAssetServiceServer

// Deprecated: Please use funcs in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
func NewAssetServiceClient(cc grpc.ClientConnInterface) AssetServiceClient {
	return src.NewAssetServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/asset/apiv1p5beta1/assetpb
func RegisterAssetServiceServer(s *grpc.Server, srv AssetServiceServer) {
	src.RegisterAssetServiceServer(s, srv)
}
