// Copyright 2021 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.26.0
// 	protoc        v3.12.2
// source: google/appengine/v1beta/firewall.proto

package appengine

import (
	reflect "reflect"
	sync "sync"

	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

// Available actions to take on matching requests.
type FirewallRule_Action int32

const (
	FirewallRule_UNSPECIFIED_ACTION FirewallRule_Action = 0
	// Matching requests are allowed.
	FirewallRule_ALLOW FirewallRule_Action = 1
	// Matching requests are denied.
	FirewallRule_DENY FirewallRule_Action = 2
)

// Enum value maps for FirewallRule_Action.
var (
	FirewallRule_Action_name = map[int32]string{
		0: "UNSPECIFIED_ACTION",
		1: "ALLOW",
		2: "DENY",
	}
	FirewallRule_Action_value = map[string]int32{
		"UNSPECIFIED_ACTION": 0,
		"ALLOW":              1,
		"DENY":               2,
	}
)

func (x FirewallRule_Action) Enum() *FirewallRule_Action {
	p := new(FirewallRule_Action)
	*p = x
	return p
}

func (x FirewallRule_Action) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (FirewallRule_Action) Descriptor() protoreflect.EnumDescriptor {
	return file_google_appengine_v1beta_firewall_proto_enumTypes[0].Descriptor()
}

func (FirewallRule_Action) Type() protoreflect.EnumType {
	return &file_google_appengine_v1beta_firewall_proto_enumTypes[0]
}

func (x FirewallRule_Action) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use FirewallRule_Action.Descriptor instead.
func (FirewallRule_Action) EnumDescriptor() ([]byte, []int) {
	return file_google_appengine_v1beta_firewall_proto_rawDescGZIP(), []int{0, 0}
}

// A single firewall rule that is evaluated against incoming traffic
// and provides an action to take on matched requests.
type FirewallRule struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// A positive integer between [1, Int32.MaxValue-1] that defines the order of
	// rule evaluation. Rules with the lowest priority are evaluated first.
	//
	// A default rule at priority Int32.MaxValue matches all IPv4 and IPv6 traffic
	// when no previous rule matches. Only the action of this rule can be modified
	// by the user.
	Priority int32 `protobuf:"varint,1,opt,name=priority,proto3" json:"priority,omitempty"`
	// The action to take on matched requests.
	Action FirewallRule_Action `protobuf:"varint,2,opt,name=action,proto3,enum=google.appengine.v1beta.FirewallRule_Action" json:"action,omitempty"`
	// IP address or range, defined using CIDR notation, of requests that this
	// rule applies to. You can use the wildcard character "*" to match all IPs
	// equivalent to "0/0" and "::/0" together.
	// Examples: `192.168.1.1` or `192.168.0.0/16` or `2001:db8::/32`
	//
	//	or `2001:0db8:0000:0042:0000:8a2e:0370:7334`.
	//
	// <p>Truncation will be silently performed on addresses which are not
	// properly truncated. For example, `1.2.3.4/24` is accepted as the same
	// address as `1.2.3.0/24`. Similarly, for IPv6, `2001:db8::1/32` is accepted
	// as the same address as `2001:db8::/32`.
	SourceRange string `protobuf:"bytes,3,opt,name=source_range,json=sourceRange,proto3" json:"source_range,omitempty"`
	// An optional string description of this rule.
	// This field has a maximum length of 100 characters.
	Description string `protobuf:"bytes,4,opt,name=description,proto3" json:"description,omitempty"`
}

func (x *FirewallRule) Reset() {
	*x = FirewallRule{}
	if protoimpl.UnsafeEnabled {
		mi := &file_google_appengine_v1beta_firewall_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *FirewallRule) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*FirewallRule) ProtoMessage() {}

func (x *FirewallRule) ProtoReflect() protoreflect.Message {
	mi := &file_google_appengine_v1beta_firewall_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use FirewallRule.ProtoReflect.Descriptor instead.
func (*FirewallRule) Descriptor() ([]byte, []int) {
	return file_google_appengine_v1beta_firewall_proto_rawDescGZIP(), []int{0}
}

func (x *FirewallRule) GetPriority() int32 {
	if x != nil {
		return x.Priority
	}
	return 0
}

func (x *FirewallRule) GetAction() FirewallRule_Action {
	if x != nil {
		return x.Action
	}
	return FirewallRule_UNSPECIFIED_ACTION
}

func (x *FirewallRule) GetSourceRange() string {
	if x != nil {
		return x.SourceRange
	}
	return ""
}

func (x *FirewallRule) GetDescription() string {
	if x != nil {
		return x.Description
	}
	return ""
}

var File_google_appengine_v1beta_firewall_proto protoreflect.FileDescriptor

var file_google_appengine_v1beta_firewall_proto_rawDesc = []byte{
	0x0a, 0x26, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2f, 0x61, 0x70, 0x70, 0x65, 0x6e, 0x67, 0x69,
	0x6e, 0x65, 0x2f, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x2f, 0x66, 0x69, 0x72, 0x65, 0x77, 0x61,
	0x6c, 0x6c, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x17, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65,
	0x2e, 0x61, 0x70, 0x70, 0x65, 0x6e, 0x67, 0x69, 0x6e, 0x65, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74,
	0x61, 0x22, 0xec, 0x01, 0x0a, 0x0c, 0x46, 0x69, 0x72, 0x65, 0x77, 0x61, 0x6c, 0x6c, 0x52, 0x75,
	0x6c, 0x65, 0x12, 0x1a, 0x0a, 0x08, 0x70, 0x72, 0x69, 0x6f, 0x72, 0x69, 0x74, 0x79, 0x18, 0x01,
	0x20, 0x01, 0x28, 0x05, 0x52, 0x08, 0x70, 0x72, 0x69, 0x6f, 0x72, 0x69, 0x74, 0x79, 0x12, 0x44,
	0x0a, 0x06, 0x61, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0e, 0x32, 0x2c,
	0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x61, 0x70, 0x70, 0x65, 0x6e, 0x67, 0x69, 0x6e,
	0x65, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61, 0x2e, 0x46, 0x69, 0x72, 0x65, 0x77, 0x61, 0x6c,
	0x6c, 0x52, 0x75, 0x6c, 0x65, 0x2e, 0x41, 0x63, 0x74, 0x69, 0x6f, 0x6e, 0x52, 0x06, 0x61, 0x63,
	0x74, 0x69, 0x6f, 0x6e, 0x12, 0x21, 0x0a, 0x0c, 0x73, 0x6f, 0x75, 0x72, 0x63, 0x65, 0x5f, 0x72,
	0x61, 0x6e, 0x67, 0x65, 0x18, 0x03, 0x20, 0x01, 0x28, 0x09, 0x52, 0x0b, 0x73, 0x6f, 0x75, 0x72,
	0x63, 0x65, 0x52, 0x61, 0x6e, 0x67, 0x65, 0x12, 0x20, 0x0a, 0x0b, 0x64, 0x65, 0x73, 0x63, 0x72,
	0x69, 0x70, 0x74, 0x69, 0x6f, 0x6e, 0x18, 0x04, 0x20, 0x01, 0x28, 0x09, 0x52, 0x0b, 0x64, 0x65,
	0x73, 0x63, 0x72, 0x69, 0x70, 0x74, 0x69, 0x6f, 0x6e, 0x22, 0x35, 0x0a, 0x06, 0x41, 0x63, 0x74,
	0x69, 0x6f, 0x6e, 0x12, 0x16, 0x0a, 0x12, 0x55, 0x4e, 0x53, 0x50, 0x45, 0x43, 0x49, 0x46, 0x49,
	0x45, 0x44, 0x5f, 0x41, 0x43, 0x54, 0x49, 0x4f, 0x4e, 0x10, 0x00, 0x12, 0x09, 0x0a, 0x05, 0x41,
	0x4c, 0x4c, 0x4f, 0x57, 0x10, 0x01, 0x12, 0x08, 0x0a, 0x04, 0x44, 0x45, 0x4e, 0x59, 0x10, 0x02,
	0x42, 0xdc, 0x01, 0x0a, 0x24, 0x63, 0x6f, 0x6d, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e,
	0x61, 0x70, 0x70, 0x65, 0x6e, 0x67, 0x69, 0x6e, 0x65, 0x2e, 0x76, 0x31, 0x62, 0x65, 0x74, 0x61,
	0x2e, 0x66, 0x69, 0x72, 0x65, 0x77, 0x61, 0x6c, 0x6c, 0x42, 0x0d, 0x46, 0x69, 0x72, 0x65, 0x77,
	0x61, 0x6c, 0x6c, 0x50, 0x72, 0x6f, 0x74, 0x6f, 0x50, 0x01, 0x5a, 0x40, 0x67, 0x6f, 0x6f, 0x67,
	0x6c, 0x65, 0x2e, 0x67, 0x6f, 0x6c, 0x61, 0x6e, 0x67, 0x2e, 0x6f, 0x72, 0x67, 0x2f, 0x67, 0x65,
	0x6e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2f, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70, 0x69,
	0x73, 0x2f, 0x61, 0x70, 0x70, 0x65, 0x6e, 0x67, 0x69, 0x6e, 0x65, 0x2f, 0x76, 0x31, 0x62, 0x65,
	0x74, 0x61, 0x3b, 0x61, 0x70, 0x70, 0x65, 0x6e, 0x67, 0x69, 0x6e, 0x65, 0xaa, 0x02, 0x1d, 0x47,
	0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x43, 0x6c, 0x6f, 0x75, 0x64, 0x2e, 0x41, 0x70, 0x70, 0x45,
	0x6e, 0x67, 0x69, 0x6e, 0x65, 0x2e, 0x56, 0x31, 0x42, 0x65, 0x74, 0x61, 0xca, 0x02, 0x1d, 0x47,
	0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x5c, 0x43, 0x6c, 0x6f, 0x75, 0x64, 0x5c, 0x41, 0x70, 0x70, 0x45,
	0x6e, 0x67, 0x69, 0x6e, 0x65, 0x5c, 0x56, 0x31, 0x62, 0x65, 0x74, 0x61, 0xea, 0x02, 0x20, 0x47,
	0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x3a, 0x3a, 0x43, 0x6c, 0x6f, 0x75, 0x64, 0x3a, 0x3a, 0x41, 0x70,
	0x70, 0x45, 0x6e, 0x67, 0x69, 0x6e, 0x65, 0x3a, 0x3a, 0x56, 0x31, 0x62, 0x65, 0x74, 0x61, 0x62,
	0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
}

var (
	file_google_appengine_v1beta_firewall_proto_rawDescOnce sync.Once
	file_google_appengine_v1beta_firewall_proto_rawDescData = file_google_appengine_v1beta_firewall_proto_rawDesc
)

func file_google_appengine_v1beta_firewall_proto_rawDescGZIP() []byte {
	file_google_appengine_v1beta_firewall_proto_rawDescOnce.Do(func() {
		file_google_appengine_v1beta_firewall_proto_rawDescData = protoimpl.X.CompressGZIP(file_google_appengine_v1beta_firewall_proto_rawDescData)
	})
	return file_google_appengine_v1beta_firewall_proto_rawDescData
}

var file_google_appengine_v1beta_firewall_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
var file_google_appengine_v1beta_firewall_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_google_appengine_v1beta_firewall_proto_goTypes = []interface{}{
	(FirewallRule_Action)(0), // 0: google.appengine.v1beta.FirewallRule.Action
	(*FirewallRule)(nil),     // 1: google.appengine.v1beta.FirewallRule
}
var file_google_appengine_v1beta_firewall_proto_depIdxs = []int32{
	0, // 0: google.appengine.v1beta.FirewallRule.action:type_name -> google.appengine.v1beta.FirewallRule.Action
	1, // [1:1] is the sub-list for method output_type
	1, // [1:1] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_google_appengine_v1beta_firewall_proto_init() }
func file_google_appengine_v1beta_firewall_proto_init() {
	if File_google_appengine_v1beta_firewall_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_google_appengine_v1beta_firewall_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*FirewallRule); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_google_appengine_v1beta_firewall_proto_rawDesc,
			NumEnums:      1,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_google_appengine_v1beta_firewall_proto_goTypes,
		DependencyIndexes: file_google_appengine_v1beta_firewall_proto_depIdxs,
		EnumInfos:         file_google_appengine_v1beta_firewall_proto_enumTypes,
		MessageInfos:      file_google_appengine_v1beta_firewall_proto_msgTypes,
	}.Build()
	File_google_appengine_v1beta_firewall_proto = out.File
	file_google_appengine_v1beta_firewall_proto_rawDesc = nil
	file_google_appengine_v1beta_firewall_proto_goTypes = nil
	file_google_appengine_v1beta_firewall_proto_depIdxs = nil
}
