// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package gkehub aliases all exported identifiers in package
// "cloud.google.com/go/gkehub/apiv1beta1/gkehubpb".
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package gkehub

import (
	src "cloud.google.com/go/gkehub/apiv1beta1/gkehubpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
const (
	MembershipState_CODE_UNSPECIFIED           = src.MembershipState_CODE_UNSPECIFIED
	MembershipState_CREATING                   = src.MembershipState_CREATING
	MembershipState_DELETING                   = src.MembershipState_DELETING
	MembershipState_READY                      = src.MembershipState_READY
	MembershipState_SERVICE_UPDATING           = src.MembershipState_SERVICE_UPDATING
	MembershipState_UPDATING                   = src.MembershipState_UPDATING
	Membership_INFRASTRUCTURE_TYPE_UNSPECIFIED = src.Membership_INFRASTRUCTURE_TYPE_UNSPECIFIED
	Membership_MULTI_CLOUD                     = src.Membership_MULTI_CLOUD
	Membership_ON_PREM                         = src.Membership_ON_PREM
	OnPremCluster_BOOTSTRAP                    = src.OnPremCluster_BOOTSTRAP
	OnPremCluster_CLUSTERTYPE_UNSPECIFIED      = src.OnPremCluster_CLUSTERTYPE_UNSPECIFIED
	OnPremCluster_HYBRID                       = src.OnPremCluster_HYBRID
	OnPremCluster_STANDALONE                   = src.OnPremCluster_STANDALONE
	OnPremCluster_USER                         = src.OnPremCluster_USER
)

// Deprecated: Please use vars in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
var (
	File_google_cloud_gkehub_v1beta1_membership_proto = src.File_google_cloud_gkehub_v1beta1_membership_proto
	MembershipState_Code_name                         = src.MembershipState_Code_name
	MembershipState_Code_value                        = src.MembershipState_Code_value
	Membership_InfrastructureType_name                = src.Membership_InfrastructureType_name
	Membership_InfrastructureType_value               = src.Membership_InfrastructureType_value
	OnPremCluster_ClusterType_name                    = src.OnPremCluster_ClusterType_name
	OnPremCluster_ClusterType_value                   = src.OnPremCluster_ClusterType_value
)

// ApplianceCluster contains information specific to GDC Edge Appliance
// Clusters.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type ApplianceCluster = src.ApplianceCluster

// Authority encodes how Google will recognize identities from this
// Membership. See the workload identity documentation for more details:
// https://cloud.google.com/kubernetes-engine/docs/how-to/workload-identity
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type Authority = src.Authority

// The information required from end users to use GKE Connect.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type ConnectAgent = src.ConnectAgent

// ConnectAgentResource represents a Kubernetes resource manifest for Connect
// Agent deployment.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type ConnectAgentResource = src.ConnectAgentResource

// Request message for the `GkeHubMembershipService.CreateMembership` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type CreateMembershipRequest = src.CreateMembershipRequest

// Request message for `GkeHubMembershipService.DeleteMembership` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type DeleteMembershipRequest = src.DeleteMembershipRequest

// EdgeCluster contains information specific to Google Edge Clusters.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type EdgeCluster = src.EdgeCluster

// Request message for `GkeHubMembershipService.GenerateConnectManifest`
// method. .
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type GenerateConnectManifestRequest = src.GenerateConnectManifestRequest

// GenerateConnectManifestResponse contains manifest information for
// installing/upgrading a Connect agent.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type GenerateConnectManifestResponse = src.GenerateConnectManifestResponse

// The request to generate the manifests for exclusivity artifacts.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type GenerateExclusivityManifestRequest = src.GenerateExclusivityManifestRequest

// The response of the exclusivity artifacts manifests for the client to
// apply.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type GenerateExclusivityManifestResponse = src.GenerateExclusivityManifestResponse

// Request message for `GkeHubMembershipService.GetMembership` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type GetMembershipRequest = src.GetMembershipRequest

// GkeCluster contains information specific to GKE clusters.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type GkeCluster = src.GkeCluster

// GkeHubMembershipServiceClient is the client API for GkeHubMembershipService
// service. For semantics around ctx use and closing/ending streaming RPCs,
// please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type GkeHubMembershipServiceClient = src.GkeHubMembershipServiceClient

// GkeHubMembershipServiceServer is the server API for GkeHubMembershipService
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type GkeHubMembershipServiceServer = src.GkeHubMembershipServiceServer

// KubernetesMetadata provides informational metadata for Memberships
// representing Kubernetes clusters.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type KubernetesMetadata = src.KubernetesMetadata

// KubernetesResource contains the YAML manifests and configuration for
// Membership Kubernetes resources in the cluster. After CreateMembership or
// UpdateMembership, these resources should be re-applied in the cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type KubernetesResource = src.KubernetesResource

// Request message for `GkeHubMembershipService.ListMemberships` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type ListMembershipsRequest = src.ListMembershipsRequest

// Response message for the `GkeHubMembershipService.ListMemberships` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type ListMembershipsResponse = src.ListMembershipsResponse

// Membership contains information about a member cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type Membership = src.Membership

// MembershipEndpoint contains information needed to contact a Kubernetes API,
// endpoint and any additional Kubernetes metadata.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type MembershipEndpoint = src.MembershipEndpoint
type MembershipEndpoint_ApplianceCluster = src.MembershipEndpoint_ApplianceCluster
type MembershipEndpoint_EdgeCluster = src.MembershipEndpoint_EdgeCluster
type MembershipEndpoint_GkeCluster = src.MembershipEndpoint_GkeCluster
type MembershipEndpoint_MultiCloudCluster = src.MembershipEndpoint_MultiCloudCluster
type MembershipEndpoint_OnPremCluster = src.MembershipEndpoint_OnPremCluster

// State of the Membership resource.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type MembershipState = src.MembershipState

// Code describes the state of a Membership resource.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type MembershipState_Code = src.MembershipState_Code
type Membership_Endpoint = src.Membership_Endpoint

// Specifies the infrastructure type of a Membership. Infrastructure type is
// used by Hub to control infrastructure-specific behavior, including pricing.
// Each GKE distribution (on-GCP, on-Prem, on-X,...) will set this field
// automatically, but Attached Clusters customers should specify a type during
// registration.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type Membership_InfrastructureType = src.Membership_InfrastructureType

// MultiCloudCluster contains information specific to GKE Multi-Cloud
// clusters.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type MultiCloudCluster = src.MultiCloudCluster

// OnPremCluster contains information specific to GKE On-Prem clusters.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type OnPremCluster = src.OnPremCluster

// ClusterType describes on prem cluster's type.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type OnPremCluster_ClusterType = src.OnPremCluster_ClusterType

// Represents the metadata of the long-running operation.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type OperationMetadata = src.OperationMetadata

// ResourceManifest represents a single Kubernetes resource to be applied to
// the cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type ResourceManifest = src.ResourceManifest

// ResourceOptions represent options for Kubernetes resource generation.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type ResourceOptions = src.ResourceOptions

// TypeMeta is the type information needed for content unmarshalling of
// Kubernetes resources in the manifest.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type TypeMeta = src.TypeMeta

// UnimplementedGkeHubMembershipServiceServer can be embedded to have forward
// compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type UnimplementedGkeHubMembershipServiceServer = src.UnimplementedGkeHubMembershipServiceServer

// Request message for `GkeHubMembershipService.UpdateMembership` method.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type UpdateMembershipRequest = src.UpdateMembershipRequest

// The request to validate the existing state of the membership CR in the
// cluster.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type ValidateExclusivityRequest = src.ValidateExclusivityRequest

// The response of exclusivity artifacts validation result status.
//
// Deprecated: Please use types in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
type ValidateExclusivityResponse = src.ValidateExclusivityResponse

// Deprecated: Please use funcs in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
func NewGkeHubMembershipServiceClient(cc grpc.ClientConnInterface) GkeHubMembershipServiceClient {
	return src.NewGkeHubMembershipServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/gkehub/apiv1beta1/gkehubpb
func RegisterGkeHubMembershipServiceServer(s *grpc.Server, srv GkeHubMembershipServiceServer) {
	src.RegisterGkeHubMembershipServiceServer(s, srv)
}
