// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package recaptchaenterprise aliases all exported identifiers in package
// "cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb".
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package recaptchaenterprise

import (
	src "cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
const (
	AccountDefenderAssessment_ACCOUNT_DEFENDER_LABEL_UNSPECIFIED = src.AccountDefenderAssessment_ACCOUNT_DEFENDER_LABEL_UNSPECIFIED
	AccountDefenderAssessment_PROFILE_MATCH                      = src.AccountDefenderAssessment_PROFILE_MATCH
	AccountDefenderAssessment_RELATED_ACCOUNTS_NUMBER_HIGH       = src.AccountDefenderAssessment_RELATED_ACCOUNTS_NUMBER_HIGH
	AccountDefenderAssessment_SUSPICIOUS_ACCOUNT_CREATION        = src.AccountDefenderAssessment_SUSPICIOUS_ACCOUNT_CREATION
	AccountDefenderAssessment_SUSPICIOUS_LOGIN_ACTIVITY          = src.AccountDefenderAssessment_SUSPICIOUS_LOGIN_ACTIVITY
	AnnotateAssessmentRequest_ANNOTATION_UNSPECIFIED             = src.AnnotateAssessmentRequest_ANNOTATION_UNSPECIFIED
	AnnotateAssessmentRequest_CHARGEBACK                         = src.AnnotateAssessmentRequest_CHARGEBACK
	AnnotateAssessmentRequest_CHARGEBACK_DISPUTE                 = src.AnnotateAssessmentRequest_CHARGEBACK_DISPUTE
	AnnotateAssessmentRequest_CHARGEBACK_FRAUD                   = src.AnnotateAssessmentRequest_CHARGEBACK_FRAUD
	AnnotateAssessmentRequest_CORRECT_PASSWORD                   = src.AnnotateAssessmentRequest_CORRECT_PASSWORD
	AnnotateAssessmentRequest_FAILED_TWO_FACTOR                  = src.AnnotateAssessmentRequest_FAILED_TWO_FACTOR
	AnnotateAssessmentRequest_FRAUDULENT                         = src.AnnotateAssessmentRequest_FRAUDULENT
	AnnotateAssessmentRequest_INCORRECT_PASSWORD                 = src.AnnotateAssessmentRequest_INCORRECT_PASSWORD
	AnnotateAssessmentRequest_INITIATED_TWO_FACTOR               = src.AnnotateAssessmentRequest_INITIATED_TWO_FACTOR
	AnnotateAssessmentRequest_LEGITIMATE                         = src.AnnotateAssessmentRequest_LEGITIMATE
	AnnotateAssessmentRequest_PASSED_TWO_FACTOR                  = src.AnnotateAssessmentRequest_PASSED_TWO_FACTOR
	AnnotateAssessmentRequest_PASSWORD_CORRECT                   = src.AnnotateAssessmentRequest_PASSWORD_CORRECT
	AnnotateAssessmentRequest_PASSWORD_INCORRECT                 = src.AnnotateAssessmentRequest_PASSWORD_INCORRECT
	AnnotateAssessmentRequest_PAYMENT_HEURISTICS                 = src.AnnotateAssessmentRequest_PAYMENT_HEURISTICS
	AnnotateAssessmentRequest_REASON_UNSPECIFIED                 = src.AnnotateAssessmentRequest_REASON_UNSPECIFIED
	AnnotateAssessmentRequest_REFUND                             = src.AnnotateAssessmentRequest_REFUND
	AnnotateAssessmentRequest_REFUND_FRAUD                       = src.AnnotateAssessmentRequest_REFUND_FRAUD
	AnnotateAssessmentRequest_SOCIAL_SPAM                        = src.AnnotateAssessmentRequest_SOCIAL_SPAM
	AnnotateAssessmentRequest_TRANSACTION_ACCEPTED               = src.AnnotateAssessmentRequest_TRANSACTION_ACCEPTED
	AnnotateAssessmentRequest_TRANSACTION_DECLINED               = src.AnnotateAssessmentRequest_TRANSACTION_DECLINED
	RiskAnalysis_AUTOMATION                                      = src.RiskAnalysis_AUTOMATION
	RiskAnalysis_CLASSIFICATION_REASON_UNSPECIFIED               = src.RiskAnalysis_CLASSIFICATION_REASON_UNSPECIFIED
	RiskAnalysis_LOW_CONFIDENCE_SCORE                            = src.RiskAnalysis_LOW_CONFIDENCE_SCORE
	RiskAnalysis_TOO_MUCH_TRAFFIC                                = src.RiskAnalysis_TOO_MUCH_TRAFFIC
	RiskAnalysis_UNEXPECTED_ENVIRONMENT                          = src.RiskAnalysis_UNEXPECTED_ENVIRONMENT
	RiskAnalysis_UNEXPECTED_USAGE_PATTERNS                       = src.RiskAnalysis_UNEXPECTED_USAGE_PATTERNS
	TestingOptions_NOCAPTCHA                                     = src.TestingOptions_NOCAPTCHA
	TestingOptions_TESTING_CHALLENGE_UNSPECIFIED                 = src.TestingOptions_TESTING_CHALLENGE_UNSPECIFIED
	TestingOptions_UNSOLVABLE_CHALLENGE                          = src.TestingOptions_UNSOLVABLE_CHALLENGE
	TokenProperties_BROWSER_ERROR                                = src.TokenProperties_BROWSER_ERROR
	TokenProperties_DUPE                                         = src.TokenProperties_DUPE
	TokenProperties_EXPIRED                                      = src.TokenProperties_EXPIRED
	TokenProperties_INVALID_REASON_UNSPECIFIED                   = src.TokenProperties_INVALID_REASON_UNSPECIFIED
	TokenProperties_MALFORMED                                    = src.TokenProperties_MALFORMED
	TokenProperties_MISSING                                      = src.TokenProperties_MISSING
	TokenProperties_UNKNOWN_INVALID_REASON                       = src.TokenProperties_UNKNOWN_INVALID_REASON
	WafSettings_ACTION_TOKEN                                     = src.WafSettings_ACTION_TOKEN
	WafSettings_CA                                               = src.WafSettings_CA
	WafSettings_CHALLENGE_PAGE                                   = src.WafSettings_CHALLENGE_PAGE
	WafSettings_SESSION_TOKEN                                    = src.WafSettings_SESSION_TOKEN
	WafSettings_WAF_FEATURE_UNSPECIFIED                          = src.WafSettings_WAF_FEATURE_UNSPECIFIED
	WafSettings_WAF_SERVICE_UNSPECIFIED                          = src.WafSettings_WAF_SERVICE_UNSPECIFIED
	WebKeySettings_BALANCE                                       = src.WebKeySettings_BALANCE
	WebKeySettings_CHALLENGE_SECURITY_PREFERENCE_UNSPECIFIED     = src.WebKeySettings_CHALLENGE_SECURITY_PREFERENCE_UNSPECIFIED
	WebKeySettings_CHECKBOX                                      = src.WebKeySettings_CHECKBOX
	WebKeySettings_INTEGRATION_TYPE_UNSPECIFIED                  = src.WebKeySettings_INTEGRATION_TYPE_UNSPECIFIED
	WebKeySettings_INVISIBLE                                     = src.WebKeySettings_INVISIBLE
	WebKeySettings_SCORE                                         = src.WebKeySettings_SCORE
	WebKeySettings_SECURITY                                      = src.WebKeySettings_SECURITY
	WebKeySettings_USABILITY                                     = src.WebKeySettings_USABILITY
)

// Deprecated: Please use vars in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
var (
	AccountDefenderAssessment_AccountDefenderLabel_name                = src.AccountDefenderAssessment_AccountDefenderLabel_name
	AccountDefenderAssessment_AccountDefenderLabel_value               = src.AccountDefenderAssessment_AccountDefenderLabel_value
	AnnotateAssessmentRequest_Annotation_name                          = src.AnnotateAssessmentRequest_Annotation_name
	AnnotateAssessmentRequest_Annotation_value                         = src.AnnotateAssessmentRequest_Annotation_value
	AnnotateAssessmentRequest_Reason_name                              = src.AnnotateAssessmentRequest_Reason_name
	AnnotateAssessmentRequest_Reason_value                             = src.AnnotateAssessmentRequest_Reason_value
	File_google_cloud_recaptchaenterprise_v1_recaptchaenterprise_proto = src.File_google_cloud_recaptchaenterprise_v1_recaptchaenterprise_proto
	RiskAnalysis_ClassificationReason_name                             = src.RiskAnalysis_ClassificationReason_name
	RiskAnalysis_ClassificationReason_value                            = src.RiskAnalysis_ClassificationReason_value
	TestingOptions_TestingChallenge_name                               = src.TestingOptions_TestingChallenge_name
	TestingOptions_TestingChallenge_value                              = src.TestingOptions_TestingChallenge_value
	TokenProperties_InvalidReason_name                                 = src.TokenProperties_InvalidReason_name
	TokenProperties_InvalidReason_value                                = src.TokenProperties_InvalidReason_value
	WafSettings_WafFeature_name                                        = src.WafSettings_WafFeature_name
	WafSettings_WafFeature_value                                       = src.WafSettings_WafFeature_value
	WafSettings_WafService_name                                        = src.WafSettings_WafService_name
	WafSettings_WafService_value                                       = src.WafSettings_WafService_value
	WebKeySettings_ChallengeSecurityPreference_name                    = src.WebKeySettings_ChallengeSecurityPreference_name
	WebKeySettings_ChallengeSecurityPreference_value                   = src.WebKeySettings_ChallengeSecurityPreference_value
	WebKeySettings_IntegrationType_name                                = src.WebKeySettings_IntegrationType_name
	WebKeySettings_IntegrationType_value                               = src.WebKeySettings_IntegrationType_value
)

// Account defender risk assessment.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type AccountDefenderAssessment = src.AccountDefenderAssessment

// Labels returned by account defender for this request.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type AccountDefenderAssessment_AccountDefenderLabel = src.AccountDefenderAssessment_AccountDefenderLabel

// Settings specific to keys that can be used by Android apps.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type AndroidKeySettings = src.AndroidKeySettings

// The request message to annotate an Assessment.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type AnnotateAssessmentRequest = src.AnnotateAssessmentRequest

// Enum that represents the types of annotations.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type AnnotateAssessmentRequest_Annotation = src.AnnotateAssessmentRequest_Annotation

// Enum that represents potential reasons for annotating an assessment.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type AnnotateAssessmentRequest_Reason = src.AnnotateAssessmentRequest_Reason

// Empty response for AnnotateAssessment.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type AnnotateAssessmentResponse = src.AnnotateAssessmentResponse

// A recaptcha assessment resource.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type Assessment = src.Assessment

// Metrics related to challenges.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type ChallengeMetrics = src.ChallengeMetrics

// The create assessment request message.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type CreateAssessmentRequest = src.CreateAssessmentRequest

// The create key request message.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type CreateKeyRequest = src.CreateKeyRequest

// The delete key request message.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type DeleteKeyRequest = src.DeleteKeyRequest
type Event = src.Event

// The get key request message.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type GetKeyRequest = src.GetKeyRequest

// The get metrics request message.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type GetMetricsRequest = src.GetMetricsRequest

// Settings specific to keys that can be used by iOS apps.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type IOSKeySettings = src.IOSKeySettings

// A key used to identify and configure applications (web and/or mobile) that
// use reCAPTCHA Enterprise.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type Key = src.Key
type Key_AndroidSettings = src.Key_AndroidSettings
type Key_IosSettings = src.Key_IosSettings
type Key_WebSettings = src.Key_WebSettings

// The list keys request message.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type ListKeysRequest = src.ListKeysRequest

// Response to request to list keys in a project.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type ListKeysResponse = src.ListKeysResponse

// The request message to list memberships in a related account group.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type ListRelatedAccountGroupMembershipsRequest = src.ListRelatedAccountGroupMembershipsRequest

// The response to a `ListRelatedAccountGroupMemberships` call.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type ListRelatedAccountGroupMembershipsResponse = src.ListRelatedAccountGroupMembershipsResponse

// The request message to list related account groups.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type ListRelatedAccountGroupsRequest = src.ListRelatedAccountGroupsRequest

// The response to a `ListRelatedAccountGroups` call.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type ListRelatedAccountGroupsResponse = src.ListRelatedAccountGroupsResponse

// Metrics for a single Key.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type Metrics = src.Metrics

// The migrate key request message.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type MigrateKeyRequest = src.MigrateKeyRequest

// Private password leak verification info.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type PrivatePasswordLeakVerification = src.PrivatePasswordLeakVerification

// RecaptchaEnterpriseServiceClient is the client API for
// RecaptchaEnterpriseService service. For semantics around ctx use and
// closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type RecaptchaEnterpriseServiceClient = src.RecaptchaEnterpriseServiceClient

// RecaptchaEnterpriseServiceServer is the server API for
// RecaptchaEnterpriseService service.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type RecaptchaEnterpriseServiceServer = src.RecaptchaEnterpriseServiceServer

// A group of related accounts.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type RelatedAccountGroup = src.RelatedAccountGroup

// A membership in a group of related accounts.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type RelatedAccountGroupMembership = src.RelatedAccountGroupMembership

// The retrieve legacy secret key request message.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type RetrieveLegacySecretKeyRequest = src.RetrieveLegacySecretKeyRequest

// Secret key is used only in legacy reCAPTCHA. It must be used in a 3rd party
// integration with legacy reCAPTCHA.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type RetrieveLegacySecretKeyResponse = src.RetrieveLegacySecretKeyResponse

// Risk analysis result for an event.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type RiskAnalysis = src.RiskAnalysis

// Reasons contributing to the risk analysis verdict.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type RiskAnalysis_ClassificationReason = src.RiskAnalysis_ClassificationReason

// Score distribution.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type ScoreDistribution = src.ScoreDistribution

// Metrics related to scoring.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type ScoreMetrics = src.ScoreMetrics

// The request message to search related account group memberships.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type SearchRelatedAccountGroupMembershipsRequest = src.SearchRelatedAccountGroupMembershipsRequest

// The response to a `SearchRelatedAccountGroupMemberships` call.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type SearchRelatedAccountGroupMembershipsResponse = src.SearchRelatedAccountGroupMembershipsResponse

// Options for user acceptance testing.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type TestingOptions = src.TestingOptions

// Enum that represents the challenge option for challenge-based (CHECKBOX,
// INVISIBLE) testing keys.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type TestingOptions_TestingChallenge = src.TestingOptions_TestingChallenge
type TokenProperties = src.TokenProperties

// Enum that represents the types of invalid token reasons.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type TokenProperties_InvalidReason = src.TokenProperties_InvalidReason

// UnimplementedRecaptchaEnterpriseServiceServer can be embedded to have
// forward compatible implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type UnimplementedRecaptchaEnterpriseServiceServer = src.UnimplementedRecaptchaEnterpriseServiceServer

// The update key request message.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type UpdateKeyRequest = src.UpdateKeyRequest

// Settings specific to keys that can be used for WAF (Web Application
// Firewall).
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type WafSettings = src.WafSettings

// Supported WAF features. For more information, see
// https://cloud.google.com/recaptcha-enterprise/docs/usecase#comparison_of_features.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type WafSettings_WafFeature = src.WafSettings_WafFeature

// Web Application Firewalls supported by reCAPTCHA Enterprise.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type WafSettings_WafService = src.WafSettings_WafService

// Settings specific to keys that can be used by websites.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type WebKeySettings = src.WebKeySettings

// Enum that represents the possible challenge frequency and difficulty
// configurations for a web key.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type WebKeySettings_ChallengeSecurityPreference = src.WebKeySettings_ChallengeSecurityPreference

// Enum that represents the integration types for web keys.
//
// Deprecated: Please use types in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
type WebKeySettings_IntegrationType = src.WebKeySettings_IntegrationType

// Deprecated: Please use funcs in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
func NewRecaptchaEnterpriseServiceClient(cc grpc.ClientConnInterface) RecaptchaEnterpriseServiceClient {
	return src.NewRecaptchaEnterpriseServiceClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/recaptchaenterprise/v2/apiv1/recaptchaenterprisepb
func RegisterRecaptchaEnterpriseServiceServer(s *grpc.Server, srv RecaptchaEnterpriseServiceServer) {
	src.RegisterRecaptchaEnterpriseServiceServer(s, srv)
}
