// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package resourcemanager aliases all exported identifiers in package
// "cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb".
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package resourcemanager

import (
	src "cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
const (
	Folder_ACTIVE                  = src.Folder_ACTIVE
	Folder_DELETE_REQUESTED        = src.Folder_DELETE_REQUESTED
	Folder_STATE_UNSPECIFIED       = src.Folder_STATE_UNSPECIFIED
	Organization_ACTIVE            = src.Organization_ACTIVE
	Organization_DELETE_REQUESTED  = src.Organization_DELETE_REQUESTED
	Organization_STATE_UNSPECIFIED = src.Organization_STATE_UNSPECIFIED
	Project_ACTIVE                 = src.Project_ACTIVE
	Project_DELETE_REQUESTED       = src.Project_DELETE_REQUESTED
	Project_STATE_UNSPECIFIED      = src.Project_STATE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
var (
	File_google_cloud_resourcemanager_v3_folders_proto       = src.File_google_cloud_resourcemanager_v3_folders_proto
	File_google_cloud_resourcemanager_v3_organizations_proto = src.File_google_cloud_resourcemanager_v3_organizations_proto
	File_google_cloud_resourcemanager_v3_projects_proto      = src.File_google_cloud_resourcemanager_v3_projects_proto
	File_google_cloud_resourcemanager_v3_tag_bindings_proto  = src.File_google_cloud_resourcemanager_v3_tag_bindings_proto
	File_google_cloud_resourcemanager_v3_tag_keys_proto      = src.File_google_cloud_resourcemanager_v3_tag_keys_proto
	File_google_cloud_resourcemanager_v3_tag_values_proto    = src.File_google_cloud_resourcemanager_v3_tag_values_proto
	Folder_State_name                                        = src.Folder_State_name
	Folder_State_value                                       = src.Folder_State_value
	Organization_State_name                                  = src.Organization_State_name
	Organization_State_value                                 = src.Organization_State_value
	Project_State_name                                       = src.Project_State_name
	Project_State_value                                      = src.Project_State_value
)

// Metadata pertaining to the Folder creation process.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type CreateFolderMetadata = src.CreateFolderMetadata

// The CreateFolder request message.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type CreateFolderRequest = src.CreateFolderRequest

// A status object which is used as the `metadata` field for the Operation
// returned by CreateProject. It provides insight for when significant phases
// of Project creation have completed.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type CreateProjectMetadata = src.CreateProjectMetadata

// The request sent to the
// [CreateProject][google.cloud.resourcemanager.v3.Projects.CreateProject]
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type CreateProjectRequest = src.CreateProjectRequest

// Runtime operation information for creating a TagValue.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type CreateTagBindingMetadata = src.CreateTagBindingMetadata

// The request message to create a TagBinding.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type CreateTagBindingRequest = src.CreateTagBindingRequest

// Runtime operation information for creating a TagKey.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type CreateTagKeyMetadata = src.CreateTagKeyMetadata

// The request message for creating a TagKey.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type CreateTagKeyRequest = src.CreateTagKeyRequest

// Runtime operation information for creating a TagValue.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type CreateTagValueMetadata = src.CreateTagValueMetadata

// The request message for creating a TagValue.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type CreateTagValueRequest = src.CreateTagValueRequest

// A status object which is used as the `metadata` field for the `Operation`
// returned by `DeleteFolder`.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteFolderMetadata = src.DeleteFolderMetadata

// The DeleteFolder request message.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteFolderRequest = src.DeleteFolderRequest

// A status object which is used as the `metadata` field for the operation
// returned by DeleteOrganization.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteOrganizationMetadata = src.DeleteOrganizationMetadata

// A status object which is used as the `metadata` field for the Operation
// returned by `DeleteProject`.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteProjectMetadata = src.DeleteProjectMetadata

// [DeleteProject][google.cloud.resourcemanager.v3.Projects.DeleteProject]
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteProjectRequest = src.DeleteProjectRequest

// Runtime operation information for deleting a TagBinding.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteTagBindingMetadata = src.DeleteTagBindingMetadata

// The request message to delete a TagBinding.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteTagBindingRequest = src.DeleteTagBindingRequest

// Runtime operation information for deleting a TagKey.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteTagKeyMetadata = src.DeleteTagKeyMetadata

// The request message for deleting a TagKey.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteTagKeyRequest = src.DeleteTagKeyRequest

// Runtime operation information for deleting a TagValue.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteTagValueMetadata = src.DeleteTagValueMetadata

// The request message for deleting a TagValue.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type DeleteTagValueRequest = src.DeleteTagValueRequest

// A folder in an organization's resource hierarchy, used to organize that
// organization's resources.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type Folder = src.Folder

// Folder lifecycle states.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type Folder_State = src.Folder_State

// FoldersClient is the client API for Folders service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type FoldersClient = src.FoldersClient

// FoldersServer is the server API for Folders service.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type FoldersServer = src.FoldersServer

// The GetFolder request message.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type GetFolderRequest = src.GetFolderRequest

// The request sent to the `GetOrganization` method. The `name` field is
// required. `organization_id` is no longer accepted.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type GetOrganizationRequest = src.GetOrganizationRequest

// The request sent to the
// [GetProject][google.cloud.resourcemanager.v3.Projects.GetProject] method.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type GetProjectRequest = src.GetProjectRequest

// The request message for getting a TagKey.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type GetTagKeyRequest = src.GetTagKeyRequest

// The request message for getting a TagValue.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type GetTagValueRequest = src.GetTagValueRequest

// The ListFolders request message.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ListFoldersRequest = src.ListFoldersRequest

// The ListFolders response message.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ListFoldersResponse = src.ListFoldersResponse

// The request sent to the
// [ListProjects][google.cloud.resourcemanager.v3.Projects.ListProjects]
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ListProjectsRequest = src.ListProjectsRequest

// A page of the response received from the
// [ListProjects][google.cloud.resourcemanager.v3.Projects.ListProjects]
// method. A paginated response where more pages are available has
// `next_page_token` set. This token can be used in a subsequent request to
// retrieve the next request page. NOTE: A response may contain fewer elements
// than the request `page_size` and still have a `next_page_token`.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ListProjectsResponse = src.ListProjectsResponse

// The request message to list all TagBindings for a parent.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ListTagBindingsRequest = src.ListTagBindingsRequest

// The ListTagBindings response.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ListTagBindingsResponse = src.ListTagBindingsResponse

// The request message for listing all TagKeys under a parent resource.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ListTagKeysRequest = src.ListTagKeysRequest

// The ListTagKeys response message.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ListTagKeysResponse = src.ListTagKeysResponse

// The request message for listing TagValues for the specified TagKey.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ListTagValuesRequest = src.ListTagValuesRequest

// The ListTagValues response.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ListTagValuesResponse = src.ListTagValuesResponse

// Metadata pertaining to the folder move process.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type MoveFolderMetadata = src.MoveFolderMetadata

// The MoveFolder request message.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type MoveFolderRequest = src.MoveFolderRequest

// A status object which is used as the `metadata` field for the Operation
// returned by MoveProject.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type MoveProjectMetadata = src.MoveProjectMetadata

// The request sent to
// [MoveProject][google.cloud.resourcemanager.v3.Projects.MoveProject] method.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type MoveProjectRequest = src.MoveProjectRequest

// The root node in the resource hierarchy to which a particular entity's (a
// company, for example) resources belong.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type Organization = src.Organization
type Organization_DirectoryCustomerId = src.Organization_DirectoryCustomerId

// Organization lifecycle states.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type Organization_State = src.Organization_State

// OrganizationsClient is the client API for Organizations service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type OrganizationsClient = src.OrganizationsClient

// OrganizationsServer is the server API for Organizations service.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type OrganizationsServer = src.OrganizationsServer

// A project is a high-level Google Cloud entity. It is a container for ACLs,
// APIs, App Engine Apps, VMs, and other Google Cloud Platform resources.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type Project = src.Project

// Project lifecycle states.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type Project_State = src.Project_State

// ProjectsClient is the client API for Projects service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ProjectsClient = src.ProjectsClient

// ProjectsServer is the server API for Projects service.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type ProjectsServer = src.ProjectsServer

// The request message for searching folders.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type SearchFoldersRequest = src.SearchFoldersRequest

// The response message for searching folders.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type SearchFoldersResponse = src.SearchFoldersResponse

// The request sent to the `SearchOrganizations` method.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type SearchOrganizationsRequest = src.SearchOrganizationsRequest

// The response returned from the `SearchOrganizations` method.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type SearchOrganizationsResponse = src.SearchOrganizationsResponse

// The request sent to the
// [SearchProjects][google.cloud.resourcemanager.v3.Projects.SearchProjects]
// method.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type SearchProjectsRequest = src.SearchProjectsRequest

// A page of the response received from the
// [SearchProjects][google.cloud.resourcemanager.v3.Projects.SearchProjects]
// method. A paginated response where more pages are available has
// `next_page_token` set. This token can be used in a subsequent request to
// retrieve the next request page.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type SearchProjectsResponse = src.SearchProjectsResponse

// A TagBinding represents a connection between a TagValue and a cloud
// resource (currently project, folder, or organization). Once a TagBinding is
// created, the TagValue is applied to all the descendants of the cloud
// resource.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type TagBinding = src.TagBinding

// TagBindingsClient is the client API for TagBindings service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type TagBindingsClient = src.TagBindingsClient

// TagBindingsServer is the server API for TagBindings service.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type TagBindingsServer = src.TagBindingsServer

// A TagKey, used to group a set of TagValues.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type TagKey = src.TagKey

// TagKeysClient is the client API for TagKeys service. For semantics around
// ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type TagKeysClient = src.TagKeysClient

// TagKeysServer is the server API for TagKeys service.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type TagKeysServer = src.TagKeysServer

// A TagValue is a child of a particular TagKey. This is used to group cloud
// resources for the purpose of controlling them using policies.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type TagValue = src.TagValue

// TagValuesClient is the client API for TagValues service. For semantics
// around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type TagValuesClient = src.TagValuesClient

// TagValuesServer is the server API for TagValues service.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type TagValuesServer = src.TagValuesServer

// A status object which is used as the `metadata` field for the `Operation`
// returned by `UndeleteFolder`.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UndeleteFolderMetadata = src.UndeleteFolderMetadata

// The UndeleteFolder request message.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UndeleteFolderRequest = src.UndeleteFolderRequest

// A status object which is used as the `metadata` field for the Operation
// returned by UndeleteOrganization.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UndeleteOrganizationMetadata = src.UndeleteOrganizationMetadata

// A status object which is used as the `metadata` field for the Operation
// returned by `UndeleteProject`.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UndeleteProjectMetadata = src.UndeleteProjectMetadata

// The request sent to the [UndeleteProject]
// [google.cloud.resourcemanager.v3.Projects.UndeleteProject] method.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UndeleteProjectRequest = src.UndeleteProjectRequest

// UnimplementedFoldersServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UnimplementedFoldersServer = src.UnimplementedFoldersServer

// UnimplementedOrganizationsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UnimplementedOrganizationsServer = src.UnimplementedOrganizationsServer

// UnimplementedProjectsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UnimplementedProjectsServer = src.UnimplementedProjectsServer

// UnimplementedTagBindingsServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UnimplementedTagBindingsServer = src.UnimplementedTagBindingsServer

// UnimplementedTagKeysServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UnimplementedTagKeysServer = src.UnimplementedTagKeysServer

// UnimplementedTagValuesServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UnimplementedTagValuesServer = src.UnimplementedTagValuesServer

// A status object which is used as the `metadata` field for the Operation
// returned by UpdateFolder.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UpdateFolderMetadata = src.UpdateFolderMetadata

// The request sent to the
// [UpdateFolder][google.cloud.resourcemanager.v3.Folder.UpdateFolder] method.
// Only the `display_name` field can be changed. All other fields will be
// ignored. Use the
// [MoveFolder][google.cloud.resourcemanager.v3.Folders.MoveFolder] method to
// change the `parent` field.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UpdateFolderRequest = src.UpdateFolderRequest

// A status object which is used as the `metadata` field for the Operation
// returned by UpdateProject.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UpdateProjectMetadata = src.UpdateProjectMetadata

// The request sent to the
// [UpdateProject][google.cloud.resourcemanager.v3.Projects.UpdateProject]
// method. Only the `display_name` and `labels` fields can be change. Use the
// [MoveProject][google.cloud.resourcemanager.v3.Projects.MoveProject] method
// to change the `parent` field.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UpdateProjectRequest = src.UpdateProjectRequest

// Runtime operation information for updating a TagKey.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UpdateTagKeyMetadata = src.UpdateTagKeyMetadata

// The request message for updating a TagKey.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UpdateTagKeyRequest = src.UpdateTagKeyRequest

// Runtime operation information for updating a TagValue.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UpdateTagValueMetadata = src.UpdateTagValueMetadata

// The request message for updating a TagValue.
//
// Deprecated: Please use types in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
type UpdateTagValueRequest = src.UpdateTagValueRequest

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func NewFoldersClient(cc grpc.ClientConnInterface) FoldersClient { return src.NewFoldersClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func NewOrganizationsClient(cc grpc.ClientConnInterface) OrganizationsClient {
	return src.NewOrganizationsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func NewProjectsClient(cc grpc.ClientConnInterface) ProjectsClient { return src.NewProjectsClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func NewTagBindingsClient(cc grpc.ClientConnInterface) TagBindingsClient {
	return src.NewTagBindingsClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func NewTagKeysClient(cc grpc.ClientConnInterface) TagKeysClient { return src.NewTagKeysClient(cc) }

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func NewTagValuesClient(cc grpc.ClientConnInterface) TagValuesClient {
	return src.NewTagValuesClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func RegisterFoldersServer(s *grpc.Server, srv FoldersServer) { src.RegisterFoldersServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func RegisterOrganizationsServer(s *grpc.Server, srv OrganizationsServer) {
	src.RegisterOrganizationsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func RegisterProjectsServer(s *grpc.Server, srv ProjectsServer) { src.RegisterProjectsServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func RegisterTagBindingsServer(s *grpc.Server, srv TagBindingsServer) {
	src.RegisterTagBindingsServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func RegisterTagKeysServer(s *grpc.Server, srv TagKeysServer) { src.RegisterTagKeysServer(s, srv) }

// Deprecated: Please use funcs in: cloud.google.com/go/resourcemanager/apiv3/resourcemanagerpb
func RegisterTagValuesServer(s *grpc.Server, srv TagValuesServer) {
	src.RegisterTagValuesServer(s, srv)
}
