// Copyright 2022 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package storage aliases all exported identifiers in package
// "cloud.google.com/go/bigquery/storage/apiv1/storagepb".
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package storage

import (
	src "cloud.google.com/go/bigquery/storage/apiv1/storagepb"
	grpc "google.golang.org/grpc"
)

// Deprecated: Please use consts in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
const (
	AppendRowsRequest_DEFAULT_VALUE                            = src.AppendRowsRequest_DEFAULT_VALUE
	AppendRowsRequest_MISSING_VALUE_INTERPRETATION_UNSPECIFIED = src.AppendRowsRequest_MISSING_VALUE_INTERPRETATION_UNSPECIFIED
	AppendRowsRequest_NULL_VALUE                               = src.AppendRowsRequest_NULL_VALUE
	ArrowSerializationOptions_COMPRESSION_UNSPECIFIED          = src.ArrowSerializationOptions_COMPRESSION_UNSPECIFIED
	ArrowSerializationOptions_LZ4_FRAME                        = src.ArrowSerializationOptions_LZ4_FRAME
	ArrowSerializationOptions_ZSTD                             = src.ArrowSerializationOptions_ZSTD
	DataFormat_ARROW                                           = src.DataFormat_ARROW
	DataFormat_AVRO                                            = src.DataFormat_AVRO
	DataFormat_DATA_FORMAT_UNSPECIFIED                         = src.DataFormat_DATA_FORMAT_UNSPECIFIED
	RowError_FIELDS_ERROR                                      = src.RowError_FIELDS_ERROR
	RowError_ROW_ERROR_CODE_UNSPECIFIED                        = src.RowError_ROW_ERROR_CODE_UNSPECIFIED
	StorageError_INVALID_STREAM_STATE                          = src.StorageError_INVALID_STREAM_STATE
	StorageError_INVALID_STREAM_TYPE                           = src.StorageError_INVALID_STREAM_TYPE
	StorageError_OFFSET_ALREADY_EXISTS                         = src.StorageError_OFFSET_ALREADY_EXISTS
	StorageError_OFFSET_OUT_OF_RANGE                           = src.StorageError_OFFSET_OUT_OF_RANGE
	StorageError_SCHEMA_MISMATCH_EXTRA_FIELDS                  = src.StorageError_SCHEMA_MISMATCH_EXTRA_FIELDS
	StorageError_STORAGE_ERROR_CODE_UNSPECIFIED                = src.StorageError_STORAGE_ERROR_CODE_UNSPECIFIED
	StorageError_STREAM_ALREADY_COMMITTED                      = src.StorageError_STREAM_ALREADY_COMMITTED
	StorageError_STREAM_FINALIZED                              = src.StorageError_STREAM_FINALIZED
	StorageError_STREAM_NOT_FOUND                              = src.StorageError_STREAM_NOT_FOUND
	StorageError_TABLE_NOT_FOUND                               = src.StorageError_TABLE_NOT_FOUND
	TableFieldSchema_BIGNUMERIC                                = src.TableFieldSchema_BIGNUMERIC
	TableFieldSchema_BOOL                                      = src.TableFieldSchema_BOOL
	TableFieldSchema_BYTES                                     = src.TableFieldSchema_BYTES
	TableFieldSchema_DATE                                      = src.TableFieldSchema_DATE
	TableFieldSchema_DATETIME                                  = src.TableFieldSchema_DATETIME
	TableFieldSchema_DOUBLE                                    = src.TableFieldSchema_DOUBLE
	TableFieldSchema_GEOGRAPHY                                 = src.TableFieldSchema_GEOGRAPHY
	TableFieldSchema_INT64                                     = src.TableFieldSchema_INT64
	TableFieldSchema_INTERVAL                                  = src.TableFieldSchema_INTERVAL
	TableFieldSchema_JSON                                      = src.TableFieldSchema_JSON
	TableFieldSchema_MODE_UNSPECIFIED                          = src.TableFieldSchema_MODE_UNSPECIFIED
	TableFieldSchema_NULLABLE                                  = src.TableFieldSchema_NULLABLE
	TableFieldSchema_NUMERIC                                   = src.TableFieldSchema_NUMERIC
	TableFieldSchema_REPEATED                                  = src.TableFieldSchema_REPEATED
	TableFieldSchema_REQUIRED                                  = src.TableFieldSchema_REQUIRED
	TableFieldSchema_STRING                                    = src.TableFieldSchema_STRING
	TableFieldSchema_STRUCT                                    = src.TableFieldSchema_STRUCT
	TableFieldSchema_TIME                                      = src.TableFieldSchema_TIME
	TableFieldSchema_TIMESTAMP                                 = src.TableFieldSchema_TIMESTAMP
	TableFieldSchema_TYPE_UNSPECIFIED                          = src.TableFieldSchema_TYPE_UNSPECIFIED
	WriteStreamView_BASIC                                      = src.WriteStreamView_BASIC
	WriteStreamView_FULL                                       = src.WriteStreamView_FULL
	WriteStreamView_WRITE_STREAM_VIEW_UNSPECIFIED              = src.WriteStreamView_WRITE_STREAM_VIEW_UNSPECIFIED
	WriteStream_BUFFERED                                       = src.WriteStream_BUFFERED
	WriteStream_COMMITTED                                      = src.WriteStream_COMMITTED
	WriteStream_INSERT                                         = src.WriteStream_INSERT
	WriteStream_PENDING                                        = src.WriteStream_PENDING
	WriteStream_TYPE_UNSPECIFIED                               = src.WriteStream_TYPE_UNSPECIFIED
	WriteStream_WRITE_MODE_UNSPECIFIED                         = src.WriteStream_WRITE_MODE_UNSPECIFIED
)

// Deprecated: Please use vars in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
var (
	AppendRowsRequest_MissingValueInterpretation_name       = src.AppendRowsRequest_MissingValueInterpretation_name
	AppendRowsRequest_MissingValueInterpretation_value      = src.AppendRowsRequest_MissingValueInterpretation_value
	ArrowSerializationOptions_CompressionCodec_name         = src.ArrowSerializationOptions_CompressionCodec_name
	ArrowSerializationOptions_CompressionCodec_value        = src.ArrowSerializationOptions_CompressionCodec_value
	DataFormat_name                                         = src.DataFormat_name
	DataFormat_value                                        = src.DataFormat_value
	E_ColumnName                                            = src.E_ColumnName
	File_google_cloud_bigquery_storage_v1_annotations_proto = src.File_google_cloud_bigquery_storage_v1_annotations_proto
	File_google_cloud_bigquery_storage_v1_arrow_proto       = src.File_google_cloud_bigquery_storage_v1_arrow_proto
	File_google_cloud_bigquery_storage_v1_avro_proto        = src.File_google_cloud_bigquery_storage_v1_avro_proto
	File_google_cloud_bigquery_storage_v1_protobuf_proto    = src.File_google_cloud_bigquery_storage_v1_protobuf_proto
	File_google_cloud_bigquery_storage_v1_storage_proto     = src.File_google_cloud_bigquery_storage_v1_storage_proto
	File_google_cloud_bigquery_storage_v1_stream_proto      = src.File_google_cloud_bigquery_storage_v1_stream_proto
	File_google_cloud_bigquery_storage_v1_table_proto       = src.File_google_cloud_bigquery_storage_v1_table_proto
	RowError_RowErrorCode_name                              = src.RowError_RowErrorCode_name
	RowError_RowErrorCode_value                             = src.RowError_RowErrorCode_value
	StorageError_StorageErrorCode_name                      = src.StorageError_StorageErrorCode_name
	StorageError_StorageErrorCode_value                     = src.StorageError_StorageErrorCode_value
	TableFieldSchema_Mode_name                              = src.TableFieldSchema_Mode_name
	TableFieldSchema_Mode_value                             = src.TableFieldSchema_Mode_value
	TableFieldSchema_Type_name                              = src.TableFieldSchema_Type_name
	TableFieldSchema_Type_value                             = src.TableFieldSchema_Type_value
	WriteStreamView_name                                    = src.WriteStreamView_name
	WriteStreamView_value                                   = src.WriteStreamView_value
	WriteStream_Type_name                                   = src.WriteStream_Type_name
	WriteStream_Type_value                                  = src.WriteStream_Type_value
	WriteStream_WriteMode_name                              = src.WriteStream_WriteMode_name
	WriteStream_WriteMode_value                             = src.WriteStream_WriteMode_value
)

// Request message for `AppendRows`. Due to the nature of AppendRows being a
// bidirectional streaming RPC, certain parts of the AppendRowsRequest need
// only be specified for the first request sent each time the gRPC network
// connection is opened/reopened. The size of a single AppendRowsRequest must
// be less than 10 MB in size. Requests larger than this return an error,
// typically `INVALID_ARGUMENT`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type AppendRowsRequest = src.AppendRowsRequest

// An enum to indicate how to interpret missing values. Missing values are
// fields present in user schema but missing in rows. A missing value can
// represent a NULL or a column default value defined in BigQuery table schema.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type AppendRowsRequest_MissingValueInterpretation = src.AppendRowsRequest_MissingValueInterpretation

// ProtoData contains the data rows and schema when constructing append
// requests.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type AppendRowsRequest_ProtoData = src.AppendRowsRequest_ProtoData
type AppendRowsRequest_ProtoRows = src.AppendRowsRequest_ProtoRows

// Response message for `AppendRows`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type AppendRowsResponse = src.AppendRowsResponse

// AppendResult is returned for successful append requests.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type AppendRowsResponse_AppendResult = src.AppendRowsResponse_AppendResult
type AppendRowsResponse_AppendResult_ = src.AppendRowsResponse_AppendResult_
type AppendRowsResponse_Error = src.AppendRowsResponse_Error

// Arrow RecordBatch.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ArrowRecordBatch = src.ArrowRecordBatch

// Arrow schema as specified in
// https://arrow.apache.org/docs/python/api/datatypes.html and serialized to
// bytes using IPC:
// https://arrow.apache.org/docs/format/Columnar.html#serialization-and-interprocess-communication-ipc
// See code samples on how this message can be deserialized.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ArrowSchema = src.ArrowSchema

// Contains options specific to Arrow Serialization.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ArrowSerializationOptions = src.ArrowSerializationOptions

// Compression codec's supported by Arrow.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ArrowSerializationOptions_CompressionCodec = src.ArrowSerializationOptions_CompressionCodec

// Avro rows.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type AvroRows = src.AvroRows

// Avro schema.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type AvroSchema = src.AvroSchema

// Contains options specific to Avro Serialization.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type AvroSerializationOptions = src.AvroSerializationOptions

// Request message for `BatchCommitWriteStreams`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type BatchCommitWriteStreamsRequest = src.BatchCommitWriteStreamsRequest

// Response message for `BatchCommitWriteStreams`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type BatchCommitWriteStreamsResponse = src.BatchCommitWriteStreamsResponse

// BigQueryReadClient is the client API for BigQueryRead service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type BigQueryReadClient = src.BigQueryReadClient

// BigQueryReadServer is the server API for BigQueryRead service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type BigQueryReadServer = src.BigQueryReadServer
type BigQueryRead_ReadRowsClient = src.BigQueryRead_ReadRowsClient
type BigQueryRead_ReadRowsServer = src.BigQueryRead_ReadRowsServer

// BigQueryWriteClient is the client API for BigQueryWrite service. For
// semantics around ctx use and closing/ending streaming RPCs, please refer to
// https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type BigQueryWriteClient = src.BigQueryWriteClient

// BigQueryWriteServer is the server API for BigQueryWrite service.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type BigQueryWriteServer = src.BigQueryWriteServer
type BigQueryWrite_AppendRowsClient = src.BigQueryWrite_AppendRowsClient
type BigQueryWrite_AppendRowsServer = src.BigQueryWrite_AppendRowsServer

// Request message for `CreateReadSession`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type CreateReadSessionRequest = src.CreateReadSessionRequest

// Request message for `CreateWriteStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type CreateWriteStreamRequest = src.CreateWriteStreamRequest

// Data format for input or output data.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type DataFormat = src.DataFormat

// Request message for invoking `FinalizeWriteStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type FinalizeWriteStreamRequest = src.FinalizeWriteStreamRequest

// Response message for `FinalizeWriteStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type FinalizeWriteStreamResponse = src.FinalizeWriteStreamResponse

// Request message for `FlushRows`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type FlushRowsRequest = src.FlushRowsRequest

// Respond message for `FlushRows`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type FlushRowsResponse = src.FlushRowsResponse

// Request message for `GetWriteStreamRequest`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type GetWriteStreamRequest = src.GetWriteStreamRequest
type ProtoRows = src.ProtoRows

// ProtoSchema describes the schema of the serialized protocol buffer data
// rows.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ProtoSchema = src.ProtoSchema

// Request message for `ReadRows`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ReadRowsRequest = src.ReadRowsRequest

// Response from calling `ReadRows` may include row data, progress and
// throttling information.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ReadRowsResponse = src.ReadRowsResponse
type ReadRowsResponse_ArrowRecordBatch = src.ReadRowsResponse_ArrowRecordBatch
type ReadRowsResponse_ArrowSchema = src.ReadRowsResponse_ArrowSchema
type ReadRowsResponse_AvroRows = src.ReadRowsResponse_AvroRows
type ReadRowsResponse_AvroSchema = src.ReadRowsResponse_AvroSchema

// Information about the ReadSession.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ReadSession = src.ReadSession
type ReadSession_ArrowSchema = src.ReadSession_ArrowSchema
type ReadSession_AvroSchema = src.ReadSession_AvroSchema

// Additional attributes when reading a table.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ReadSession_TableModifiers = src.ReadSession_TableModifiers

// Options dictating how we read a table.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ReadSession_TableReadOptions = src.ReadSession_TableReadOptions
type ReadSession_TableReadOptions_ArrowSerializationOptions = src.ReadSession_TableReadOptions_ArrowSerializationOptions
type ReadSession_TableReadOptions_AvroSerializationOptions = src.ReadSession_TableReadOptions_AvroSerializationOptions

// Information about a single stream that gets data out of the storage system.
// Most of the information about `ReadStream` instances is aggregated, making
// `ReadStream` lightweight.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ReadStream = src.ReadStream

// The message that presents row level error info in a request.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type RowError = src.RowError

// Error code for `RowError`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type RowError_RowErrorCode = src.RowError_RowErrorCode

// Request message for `SplitReadStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type SplitReadStreamRequest = src.SplitReadStreamRequest

// Response message for `SplitReadStream`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type SplitReadStreamResponse = src.SplitReadStreamResponse

// Structured custom BigQuery Storage error message. The error can be attached
// as error details in the returned rpc Status. In particular, the use of error
// codes allows more structured error handling, and reduces the need to
// evaluate unstructured error text strings.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type StorageError = src.StorageError

// Error code for `StorageError`.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type StorageError_StorageErrorCode = src.StorageError_StorageErrorCode

// Estimated stream statistics for a given read Stream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type StreamStats = src.StreamStats
type StreamStats_Progress = src.StreamStats_Progress

// TableFieldSchema defines a single field/column within a table schema.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type TableFieldSchema = src.TableFieldSchema
type TableFieldSchema_Mode = src.TableFieldSchema_Mode
type TableFieldSchema_Type = src.TableFieldSchema_Type

// Schema of a table. This schema is a subset of
// google.cloud.bigquery.v2.TableSchema containing information necessary to
// generate valid message to write to BigQuery.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type TableSchema = src.TableSchema

// Information on if the current connection is being throttled.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type ThrottleState = src.ThrottleState

// UnimplementedBigQueryReadServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type UnimplementedBigQueryReadServer = src.UnimplementedBigQueryReadServer

// UnimplementedBigQueryWriteServer can be embedded to have forward compatible
// implementations.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type UnimplementedBigQueryWriteServer = src.UnimplementedBigQueryWriteServer

// Information about a single stream that gets data inside the storage system.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type WriteStream = src.WriteStream

// WriteStreamView is a view enum that controls what details about a write
// stream should be returned.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type WriteStreamView = src.WriteStreamView

// Type enum of the stream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type WriteStream_Type = src.WriteStream_Type

// Mode enum of the stream.
//
// Deprecated: Please use types in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
type WriteStream_WriteMode = src.WriteStream_WriteMode

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
func NewBigQueryReadClient(cc grpc.ClientConnInterface) BigQueryReadClient {
	return src.NewBigQueryReadClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
func NewBigQueryWriteClient(cc grpc.ClientConnInterface) BigQueryWriteClient {
	return src.NewBigQueryWriteClient(cc)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
func RegisterBigQueryReadServer(s *grpc.Server, srv BigQueryReadServer) {
	src.RegisterBigQueryReadServer(s, srv)
}

// Deprecated: Please use funcs in: cloud.google.com/go/bigquery/storage/apiv1/storagepb
func RegisterBigQueryWriteServer(s *grpc.Server, srv BigQueryWriteServer) {
	src.RegisterBigQueryWriteServer(s, srv)
}
