// Copyright 2024 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Code generated by aliasgen. DO NOT EDIT.

// Package compute aliases all exported identifiers in package
// "cloud.google.com/go/compute/apiv1/computepb".
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb.
// Please read https://github.com/googleapis/google-cloud-go/blob/main/migration.md
// for more details.
package compute

import (
	src "cloud.google.com/go/compute/apiv1/computepb"
)

// Deprecated: Please use consts in: cloud.google.com/go/compute/apiv1/computepb
const (
	AccessConfig_DIRECT_IPV6                                                                                              = src.AccessConfig_DIRECT_IPV6
	AccessConfig_FIXED_STANDARD                                                                                           = src.AccessConfig_FIXED_STANDARD
	AccessConfig_ONE_TO_ONE_NAT                                                                                           = src.AccessConfig_ONE_TO_ONE_NAT
	AccessConfig_PREMIUM                                                                                                  = src.AccessConfig_PREMIUM
	AccessConfig_STANDARD                                                                                                 = src.AccessConfig_STANDARD
	AccessConfig_STANDARD_OVERRIDES_FIXED_STANDARD                                                                        = src.AccessConfig_STANDARD_OVERRIDES_FIXED_STANDARD
	AccessConfig_UNDEFINED_NETWORK_TIER                                                                                   = src.AccessConfig_UNDEFINED_NETWORK_TIER
	AccessConfig_UNDEFINED_TYPE                                                                                           = src.AccessConfig_UNDEFINED_TYPE
	Address_DNS_RESOLVER                                                                                                  = src.Address_DNS_RESOLVER
	Address_EXTERNAL                                                                                                      = src.Address_EXTERNAL
	Address_FIXED_STANDARD                                                                                                = src.Address_FIXED_STANDARD
	Address_GCE_ENDPOINT                                                                                                  = src.Address_GCE_ENDPOINT
	Address_INTERNAL                                                                                                      = src.Address_INTERNAL
	Address_IN_USE                                                                                                        = src.Address_IN_USE
	Address_IPSEC_INTERCONNECT                                                                                            = src.Address_IPSEC_INTERCONNECT
	Address_IPV4                                                                                                          = src.Address_IPV4
	Address_IPV6                                                                                                          = src.Address_IPV6
	Address_NAT_AUTO                                                                                                      = src.Address_NAT_AUTO
	Address_NETLB                                                                                                         = src.Address_NETLB
	Address_PREMIUM                                                                                                       = src.Address_PREMIUM
	Address_PRIVATE_SERVICE_CONNECT                                                                                       = src.Address_PRIVATE_SERVICE_CONNECT
	Address_RESERVED                                                                                                      = src.Address_RESERVED
	Address_RESERVING                                                                                                     = src.Address_RESERVING
	Address_SERVERLESS                                                                                                    = src.Address_SERVERLESS
	Address_SHARED_LOADBALANCER_VIP                                                                                       = src.Address_SHARED_LOADBALANCER_VIP
	Address_STANDARD                                                                                                      = src.Address_STANDARD
	Address_STANDARD_OVERRIDES_FIXED_STANDARD                                                                             = src.Address_STANDARD_OVERRIDES_FIXED_STANDARD
	Address_UNDEFINED_ADDRESS_TYPE                                                                                        = src.Address_UNDEFINED_ADDRESS_TYPE
	Address_UNDEFINED_IPV6_ENDPOINT_TYPE                                                                                  = src.Address_UNDEFINED_IPV6_ENDPOINT_TYPE
	Address_UNDEFINED_IP_VERSION                                                                                          = src.Address_UNDEFINED_IP_VERSION
	Address_UNDEFINED_NETWORK_TIER                                                                                        = src.Address_UNDEFINED_NETWORK_TIER
	Address_UNDEFINED_PURPOSE                                                                                             = src.Address_UNDEFINED_PURPOSE
	Address_UNDEFINED_STATUS                                                                                              = src.Address_UNDEFINED_STATUS
	Address_UNSPECIFIED_TYPE                                                                                              = src.Address_UNSPECIFIED_TYPE
	Address_UNSPECIFIED_VERSION                                                                                           = src.Address_UNSPECIFIED_VERSION
	Address_VM                                                                                                            = src.Address_VM
	Address_VPC_PEERING                                                                                                   = src.Address_VPC_PEERING
	AdvancedMachineFeatures_ARCHITECTURAL                                                                                 = src.AdvancedMachineFeatures_ARCHITECTURAL
	AdvancedMachineFeatures_ENHANCED                                                                                      = src.AdvancedMachineFeatures_ENHANCED
	AdvancedMachineFeatures_PERFORMANCE_MONITORING_UNIT_UNSPECIFIED                                                       = src.AdvancedMachineFeatures_PERFORMANCE_MONITORING_UNIT_UNSPECIFIED
	AdvancedMachineFeatures_STANDARD                                                                                      = src.AdvancedMachineFeatures_STANDARD
	AdvancedMachineFeatures_UNDEFINED_PERFORMANCE_MONITORING_UNIT                                                         = src.AdvancedMachineFeatures_UNDEFINED_PERFORMANCE_MONITORING_UNIT
	AllocationAggregateReservation_BATCH                                                                                  = src.AllocationAggregateReservation_BATCH
	AllocationAggregateReservation_SERVING                                                                                = src.AllocationAggregateReservation_SERVING
	AllocationAggregateReservation_UNDEFINED_VM_FAMILY                                                                    = src.AllocationAggregateReservation_UNDEFINED_VM_FAMILY
	AllocationAggregateReservation_UNDEFINED_WORKLOAD_TYPE                                                                = src.AllocationAggregateReservation_UNDEFINED_WORKLOAD_TYPE
	AllocationAggregateReservation_UNSPECIFIED                                                                            = src.AllocationAggregateReservation_UNSPECIFIED
	AllocationAggregateReservation_VM_FAMILY_CLOUD_TPU_DEVICE_CT3                                                         = src.AllocationAggregateReservation_VM_FAMILY_CLOUD_TPU_DEVICE_CT3
	AllocationAggregateReservation_VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L                                                   = src.AllocationAggregateReservation_VM_FAMILY_CLOUD_TPU_LITE_DEVICE_CT5L
	AllocationAggregateReservation_VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP                                               = src.AllocationAggregateReservation_VM_FAMILY_CLOUD_TPU_LITE_POD_SLICE_CT5LP
	AllocationAggregateReservation_VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P                                                     = src.AllocationAggregateReservation_VM_FAMILY_CLOUD_TPU_POD_SLICE_CT3P
	AllocationAggregateReservation_VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P                                                     = src.AllocationAggregateReservation_VM_FAMILY_CLOUD_TPU_POD_SLICE_CT4P
	AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_NVME                                           = src.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_NVME
	AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_SCSI                                           = src.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_SCSI
	AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_UNDEFINED_INTERFACE                            = src.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_UNDEFINED_INTERFACE
	AttachedDiskInitializeParams_ARCHITECTURE_UNSPECIFIED                                                                 = src.AttachedDiskInitializeParams_ARCHITECTURE_UNSPECIFIED
	AttachedDiskInitializeParams_ARM64                                                                                    = src.AttachedDiskInitializeParams_ARM64
	AttachedDiskInitializeParams_RECREATE_DISK                                                                            = src.AttachedDiskInitializeParams_RECREATE_DISK
	AttachedDiskInitializeParams_RECREATE_DISK_IF_SOURCE_CHANGED                                                          = src.AttachedDiskInitializeParams_RECREATE_DISK_IF_SOURCE_CHANGED
	AttachedDiskInitializeParams_UNDEFINED_ARCHITECTURE                                                                   = src.AttachedDiskInitializeParams_UNDEFINED_ARCHITECTURE
	AttachedDiskInitializeParams_UNDEFINED_ON_UPDATE_ACTION                                                               = src.AttachedDiskInitializeParams_UNDEFINED_ON_UPDATE_ACTION
	AttachedDiskInitializeParams_USE_EXISTING_DISK                                                                        = src.AttachedDiskInitializeParams_USE_EXISTING_DISK
	AttachedDiskInitializeParams_X86_64                                                                                   = src.AttachedDiskInitializeParams_X86_64
	AttachedDisk_ARCHITECTURE_UNSPECIFIED                                                                                 = src.AttachedDisk_ARCHITECTURE_UNSPECIFIED
	AttachedDisk_ARM64                                                                                                    = src.AttachedDisk_ARM64
	AttachedDisk_DISK_SAVED_STATE_UNSPECIFIED                                                                             = src.AttachedDisk_DISK_SAVED_STATE_UNSPECIFIED
	AttachedDisk_NVME                                                                                                     = src.AttachedDisk_NVME
	AttachedDisk_PERSISTENT                                                                                               = src.AttachedDisk_PERSISTENT
	AttachedDisk_PRESERVED                                                                                                = src.AttachedDisk_PRESERVED
	AttachedDisk_READ_ONLY                                                                                                = src.AttachedDisk_READ_ONLY
	AttachedDisk_READ_WRITE                                                                                               = src.AttachedDisk_READ_WRITE
	AttachedDisk_SCRATCH                                                                                                  = src.AttachedDisk_SCRATCH
	AttachedDisk_SCSI                                                                                                     = src.AttachedDisk_SCSI
	AttachedDisk_UNDEFINED_ARCHITECTURE                                                                                   = src.AttachedDisk_UNDEFINED_ARCHITECTURE
	AttachedDisk_UNDEFINED_INTERFACE                                                                                      = src.AttachedDisk_UNDEFINED_INTERFACE
	AttachedDisk_UNDEFINED_MODE                                                                                           = src.AttachedDisk_UNDEFINED_MODE
	AttachedDisk_UNDEFINED_SAVED_STATE                                                                                    = src.AttachedDisk_UNDEFINED_SAVED_STATE
	AttachedDisk_UNDEFINED_TYPE                                                                                           = src.AttachedDisk_UNDEFINED_TYPE
	AttachedDisk_X86_64                                                                                                   = src.AttachedDisk_X86_64
	AuditLogConfig_ADMIN_READ                                                                                             = src.AuditLogConfig_ADMIN_READ
	AuditLogConfig_DATA_READ                                                                                              = src.AuditLogConfig_DATA_READ
	AuditLogConfig_DATA_WRITE                                                                                             = src.AuditLogConfig_DATA_WRITE
	AuditLogConfig_LOG_TYPE_UNSPECIFIED                                                                                   = src.AuditLogConfig_LOG_TYPE_UNSPECIFIED
	AuditLogConfig_UNDEFINED_LOG_TYPE                                                                                     = src.AuditLogConfig_UNDEFINED_LOG_TYPE
	AutoscalerStatusDetails_ALL_INSTANCES_UNHEALTHY                                                                       = src.AutoscalerStatusDetails_ALL_INSTANCES_UNHEALTHY
	AutoscalerStatusDetails_BACKEND_SERVICE_DOES_NOT_EXIST                                                                = src.AutoscalerStatusDetails_BACKEND_SERVICE_DOES_NOT_EXIST
	AutoscalerStatusDetails_CAPPED_AT_MAX_NUM_REPLICAS                                                                    = src.AutoscalerStatusDetails_CAPPED_AT_MAX_NUM_REPLICAS
	AutoscalerStatusDetails_CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE                                                          = src.AutoscalerStatusDetails_CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE
	AutoscalerStatusDetails_CUSTOM_METRIC_INVALID                                                                         = src.AutoscalerStatusDetails_CUSTOM_METRIC_INVALID
	AutoscalerStatusDetails_MIN_EQUALS_MAX                                                                                = src.AutoscalerStatusDetails_MIN_EQUALS_MAX
	AutoscalerStatusDetails_MISSING_CUSTOM_METRIC_DATA_POINTS                                                             = src.AutoscalerStatusDetails_MISSING_CUSTOM_METRIC_DATA_POINTS
	AutoscalerStatusDetails_MISSING_LOAD_BALANCING_DATA_POINTS                                                            = src.AutoscalerStatusDetails_MISSING_LOAD_BALANCING_DATA_POINTS
	AutoscalerStatusDetails_MODE_OFF                                                                                      = src.AutoscalerStatusDetails_MODE_OFF
	AutoscalerStatusDetails_MODE_ONLY_SCALE_OUT                                                                           = src.AutoscalerStatusDetails_MODE_ONLY_SCALE_OUT
	AutoscalerStatusDetails_MODE_ONLY_UP                                                                                  = src.AutoscalerStatusDetails_MODE_ONLY_UP
	AutoscalerStatusDetails_MORE_THAN_ONE_BACKEND_SERVICE                                                                 = src.AutoscalerStatusDetails_MORE_THAN_ONE_BACKEND_SERVICE
	AutoscalerStatusDetails_NOT_ENOUGH_QUOTA_AVAILABLE                                                                    = src.AutoscalerStatusDetails_NOT_ENOUGH_QUOTA_AVAILABLE
	AutoscalerStatusDetails_REGION_RESOURCE_STOCKOUT                                                                      = src.AutoscalerStatusDetails_REGION_RESOURCE_STOCKOUT
	AutoscalerStatusDetails_SCALING_TARGET_DOES_NOT_EXIST                                                                 = src.AutoscalerStatusDetails_SCALING_TARGET_DOES_NOT_EXIST
	AutoscalerStatusDetails_SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX                                               = src.AutoscalerStatusDetails_SCHEDULED_INSTANCES_GREATER_THAN_AUTOSCALER_MAX
	AutoscalerStatusDetails_SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN                                                  = src.AutoscalerStatusDetails_SCHEDULED_INSTANCES_LESS_THAN_AUTOSCALER_MIN
	AutoscalerStatusDetails_UNDEFINED_TYPE                                                                                = src.AutoscalerStatusDetails_UNDEFINED_TYPE
	AutoscalerStatusDetails_UNKNOWN                                                                                       = src.AutoscalerStatusDetails_UNKNOWN
	AutoscalerStatusDetails_UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION                                             = src.AutoscalerStatusDetails_UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION
	AutoscalerStatusDetails_ZONE_RESOURCE_STOCKOUT                                                                        = src.AutoscalerStatusDetails_ZONE_RESOURCE_STOCKOUT
	Autoscaler_ACTIVE                                                                                                     = src.Autoscaler_ACTIVE
	Autoscaler_DELETING                                                                                                   = src.Autoscaler_DELETING
	Autoscaler_ERROR                                                                                                      = src.Autoscaler_ERROR
	Autoscaler_PENDING                                                                                                    = src.Autoscaler_PENDING
	Autoscaler_UNDEFINED_STATUS                                                                                           = src.Autoscaler_UNDEFINED_STATUS
	AutoscalingPolicyCpuUtilization_NONE                                                                                  = src.AutoscalingPolicyCpuUtilization_NONE
	AutoscalingPolicyCpuUtilization_OPTIMIZE_AVAILABILITY                                                                 = src.AutoscalingPolicyCpuUtilization_OPTIMIZE_AVAILABILITY
	AutoscalingPolicyCpuUtilization_UNDEFINED_PREDICTIVE_METHOD                                                           = src.AutoscalingPolicyCpuUtilization_UNDEFINED_PREDICTIVE_METHOD
	AutoscalingPolicyCustomMetricUtilization_DELTA_PER_MINUTE                                                             = src.AutoscalingPolicyCustomMetricUtilization_DELTA_PER_MINUTE
	AutoscalingPolicyCustomMetricUtilization_DELTA_PER_SECOND                                                             = src.AutoscalingPolicyCustomMetricUtilization_DELTA_PER_SECOND
	AutoscalingPolicyCustomMetricUtilization_GAUGE                                                                        = src.AutoscalingPolicyCustomMetricUtilization_GAUGE
	AutoscalingPolicyCustomMetricUtilization_UNDEFINED_UTILIZATION_TARGET_TYPE                                            = src.AutoscalingPolicyCustomMetricUtilization_UNDEFINED_UTILIZATION_TARGET_TYPE
	AutoscalingPolicy_OFF                                                                                                 = src.AutoscalingPolicy_OFF
	AutoscalingPolicy_ON                                                                                                  = src.AutoscalingPolicy_ON
	AutoscalingPolicy_ONLY_SCALE_OUT                                                                                      = src.AutoscalingPolicy_ONLY_SCALE_OUT
	AutoscalingPolicy_ONLY_UP                                                                                             = src.AutoscalingPolicy_ONLY_UP
	AutoscalingPolicy_UNDEFINED_MODE                                                                                      = src.AutoscalingPolicy_UNDEFINED_MODE
	BackendBucketCdnPolicy_CACHE_ALL_STATIC                                                                               = src.BackendBucketCdnPolicy_CACHE_ALL_STATIC
	BackendBucketCdnPolicy_FORCE_CACHE_ALL                                                                                = src.BackendBucketCdnPolicy_FORCE_CACHE_ALL
	BackendBucketCdnPolicy_INVALID_CACHE_MODE                                                                             = src.BackendBucketCdnPolicy_INVALID_CACHE_MODE
	BackendBucketCdnPolicy_UNDEFINED_CACHE_MODE                                                                           = src.BackendBucketCdnPolicy_UNDEFINED_CACHE_MODE
	BackendBucketCdnPolicy_USE_ORIGIN_HEADERS                                                                             = src.BackendBucketCdnPolicy_USE_ORIGIN_HEADERS
	BackendBucket_AUTOMATIC                                                                                               = src.BackendBucket_AUTOMATIC
	BackendBucket_DISABLED                                                                                                = src.BackendBucket_DISABLED
	BackendBucket_UNDEFINED_COMPRESSION_MODE                                                                              = src.BackendBucket_UNDEFINED_COMPRESSION_MODE
	BackendServiceCdnPolicy_CACHE_ALL_STATIC                                                                              = src.BackendServiceCdnPolicy_CACHE_ALL_STATIC
	BackendServiceCdnPolicy_FORCE_CACHE_ALL                                                                               = src.BackendServiceCdnPolicy_FORCE_CACHE_ALL
	BackendServiceCdnPolicy_INVALID_CACHE_MODE                                                                            = src.BackendServiceCdnPolicy_INVALID_CACHE_MODE
	BackendServiceCdnPolicy_UNDEFINED_CACHE_MODE                                                                          = src.BackendServiceCdnPolicy_UNDEFINED_CACHE_MODE
	BackendServiceCdnPolicy_USE_ORIGIN_HEADERS                                                                            = src.BackendServiceCdnPolicy_USE_ORIGIN_HEADERS
	BackendServiceConnectionTrackingPolicy_ALWAYS_PERSIST                                                                 = src.BackendServiceConnectionTrackingPolicy_ALWAYS_PERSIST
	BackendServiceConnectionTrackingPolicy_DEFAULT_FOR_PROTOCOL                                                           = src.BackendServiceConnectionTrackingPolicy_DEFAULT_FOR_PROTOCOL
	BackendServiceConnectionTrackingPolicy_INVALID_TRACKING_MODE                                                          = src.BackendServiceConnectionTrackingPolicy_INVALID_TRACKING_MODE
	BackendServiceConnectionTrackingPolicy_NEVER_PERSIST                                                                  = src.BackendServiceConnectionTrackingPolicy_NEVER_PERSIST
	BackendServiceConnectionTrackingPolicy_PER_CONNECTION                                                                 = src.BackendServiceConnectionTrackingPolicy_PER_CONNECTION
	BackendServiceConnectionTrackingPolicy_PER_SESSION                                                                    = src.BackendServiceConnectionTrackingPolicy_PER_SESSION
	BackendServiceConnectionTrackingPolicy_UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS                         = src.BackendServiceConnectionTrackingPolicy_UNDEFINED_CONNECTION_PERSISTENCE_ON_UNHEALTHY_BACKENDS
	BackendServiceConnectionTrackingPolicy_UNDEFINED_TRACKING_MODE                                                        = src.BackendServiceConnectionTrackingPolicy_UNDEFINED_TRACKING_MODE
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_INVALID_LB_POLICY                                               = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_INVALID_LB_POLICY
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_LEAST_REQUEST                                                   = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_LEAST_REQUEST
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_MAGLEV                                                          = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_MAGLEV
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_ORIGINAL_DESTINATION                                            = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_ORIGINAL_DESTINATION
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_RANDOM                                                          = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_RANDOM
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_RING_HASH                                                       = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_RING_HASH
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_ROUND_ROBIN                                                     = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_ROUND_ROBIN
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_UNDEFINED_NAME                                                  = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_UNDEFINED_NAME
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_WEIGHTED_MAGLEV                                                 = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_WEIGHTED_MAGLEV
	BackendServiceLogConfig_CUSTOM                                                                                        = src.BackendServiceLogConfig_CUSTOM
	BackendServiceLogConfig_EXCLUDE_ALL_OPTIONAL                                                                          = src.BackendServiceLogConfig_EXCLUDE_ALL_OPTIONAL
	BackendServiceLogConfig_INCLUDE_ALL_OPTIONAL                                                                          = src.BackendServiceLogConfig_INCLUDE_ALL_OPTIONAL
	BackendServiceLogConfig_UNDEFINED_OPTIONAL_MODE                                                                       = src.BackendServiceLogConfig_UNDEFINED_OPTIONAL_MODE
	BackendService_AUTOMATIC                                                                                              = src.BackendService_AUTOMATIC
	BackendService_CLIENT_IP                                                                                              = src.BackendService_CLIENT_IP
	BackendService_CLIENT_IP_NO_DESTINATION                                                                               = src.BackendService_CLIENT_IP_NO_DESTINATION
	BackendService_CLIENT_IP_PORT_PROTO                                                                                   = src.BackendService_CLIENT_IP_PORT_PROTO
	BackendService_CLIENT_IP_PROTO                                                                                        = src.BackendService_CLIENT_IP_PROTO
	BackendService_DISABLED                                                                                               = src.BackendService_DISABLED
	BackendService_EXTERNAL                                                                                               = src.BackendService_EXTERNAL
	BackendService_EXTERNAL_MANAGED                                                                                       = src.BackendService_EXTERNAL_MANAGED
	BackendService_GENERATED_COOKIE                                                                                       = src.BackendService_GENERATED_COOKIE
	BackendService_GRPC                                                                                                   = src.BackendService_GRPC
	BackendService_HEADER_FIELD                                                                                           = src.BackendService_HEADER_FIELD
	BackendService_HTTP                                                                                                   = src.BackendService_HTTP
	BackendService_HTTP2                                                                                                  = src.BackendService_HTTP2
	BackendService_HTTPS                                                                                                  = src.BackendService_HTTPS
	BackendService_HTTP_COOKIE                                                                                            = src.BackendService_HTTP_COOKIE
	BackendService_INTERNAL                                                                                               = src.BackendService_INTERNAL
	BackendService_INTERNAL_MANAGED                                                                                       = src.BackendService_INTERNAL_MANAGED
	BackendService_INTERNAL_SELF_MANAGED                                                                                  = src.BackendService_INTERNAL_SELF_MANAGED
	BackendService_INVALID_LB_POLICY                                                                                      = src.BackendService_INVALID_LB_POLICY
	BackendService_INVALID_LOAD_BALANCING_SCHEME                                                                          = src.BackendService_INVALID_LOAD_BALANCING_SCHEME
	BackendService_IPV4_ONLY                                                                                              = src.BackendService_IPV4_ONLY
	BackendService_IPV6_ONLY                                                                                              = src.BackendService_IPV6_ONLY
	BackendService_IP_ADDRESS_SELECTION_POLICY_UNSPECIFIED                                                                = src.BackendService_IP_ADDRESS_SELECTION_POLICY_UNSPECIFIED
	BackendService_LEAST_REQUEST                                                                                          = src.BackendService_LEAST_REQUEST
	BackendService_MAGLEV                                                                                                 = src.BackendService_MAGLEV
	BackendService_NONE                                                                                                   = src.BackendService_NONE
	BackendService_ORIGINAL_DESTINATION                                                                                   = src.BackendService_ORIGINAL_DESTINATION
	BackendService_PREFER_IPV6                                                                                            = src.BackendService_PREFER_IPV6
	BackendService_RANDOM                                                                                                 = src.BackendService_RANDOM
	BackendService_RING_HASH                                                                                              = src.BackendService_RING_HASH
	BackendService_ROUND_ROBIN                                                                                            = src.BackendService_ROUND_ROBIN
	BackendService_SSL                                                                                                    = src.BackendService_SSL
	BackendService_STRONG_COOKIE_AFFINITY                                                                                 = src.BackendService_STRONG_COOKIE_AFFINITY
	BackendService_TCP                                                                                                    = src.BackendService_TCP
	BackendService_UDP                                                                                                    = src.BackendService_UDP
	BackendService_UNDEFINED_COMPRESSION_MODE                                                                             = src.BackendService_UNDEFINED_COMPRESSION_MODE
	BackendService_UNDEFINED_IP_ADDRESS_SELECTION_POLICY                                                                  = src.BackendService_UNDEFINED_IP_ADDRESS_SELECTION_POLICY
	BackendService_UNDEFINED_LOAD_BALANCING_SCHEME                                                                        = src.BackendService_UNDEFINED_LOAD_BALANCING_SCHEME
	BackendService_UNDEFINED_LOCALITY_LB_POLICY                                                                           = src.BackendService_UNDEFINED_LOCALITY_LB_POLICY
	BackendService_UNDEFINED_PROTOCOL                                                                                     = src.BackendService_UNDEFINED_PROTOCOL
	BackendService_UNDEFINED_SESSION_AFFINITY                                                                             = src.BackendService_UNDEFINED_SESSION_AFFINITY
	BackendService_UNSPECIFIED                                                                                            = src.BackendService_UNSPECIFIED
	BackendService_WEIGHTED_MAGLEV                                                                                        = src.BackendService_WEIGHTED_MAGLEV
	Backend_CONNECTION                                                                                                    = src.Backend_CONNECTION
	Backend_DEFAULT                                                                                                       = src.Backend_DEFAULT
	Backend_PREFERENCE_UNSPECIFIED                                                                                        = src.Backend_PREFERENCE_UNSPECIFIED
	Backend_PREFERRED                                                                                                     = src.Backend_PREFERRED
	Backend_RATE                                                                                                          = src.Backend_RATE
	Backend_UNDEFINED_BALANCING_MODE                                                                                      = src.Backend_UNDEFINED_BALANCING_MODE
	Backend_UNDEFINED_PREFERENCE                                                                                          = src.Backend_UNDEFINED_PREFERENCE
	Backend_UTILIZATION                                                                                                   = src.Backend_UTILIZATION
	BfdPacket_ADMINISTRATIVELY_DOWN                                                                                       = src.BfdPacket_ADMINISTRATIVELY_DOWN
	BfdPacket_ADMIN_DOWN                                                                                                  = src.BfdPacket_ADMIN_DOWN
	BfdPacket_CONCATENATED_PATH_DOWN                                                                                      = src.BfdPacket_CONCATENATED_PATH_DOWN
	BfdPacket_CONTROL_DETECTION_TIME_EXPIRED                                                                              = src.BfdPacket_CONTROL_DETECTION_TIME_EXPIRED
	BfdPacket_DIAGNOSTIC_UNSPECIFIED                                                                                      = src.BfdPacket_DIAGNOSTIC_UNSPECIFIED
	BfdPacket_DOWN                                                                                                        = src.BfdPacket_DOWN
	BfdPacket_ECHO_FUNCTION_FAILED                                                                                        = src.BfdPacket_ECHO_FUNCTION_FAILED
	BfdPacket_FORWARDING_PLANE_RESET                                                                                      = src.BfdPacket_FORWARDING_PLANE_RESET
	BfdPacket_INIT                                                                                                        = src.BfdPacket_INIT
	BfdPacket_NEIGHBOR_SIGNALED_SESSION_DOWN                                                                              = src.BfdPacket_NEIGHBOR_SIGNALED_SESSION_DOWN
	BfdPacket_NO_DIAGNOSTIC                                                                                               = src.BfdPacket_NO_DIAGNOSTIC
	BfdPacket_PATH_DOWN                                                                                                   = src.BfdPacket_PATH_DOWN
	BfdPacket_REVERSE_CONCATENATED_PATH_DOWN                                                                              = src.BfdPacket_REVERSE_CONCATENATED_PATH_DOWN
	BfdPacket_STATE_UNSPECIFIED                                                                                           = src.BfdPacket_STATE_UNSPECIFIED
	BfdPacket_UNDEFINED_DIAGNOSTIC                                                                                        = src.BfdPacket_UNDEFINED_DIAGNOSTIC
	BfdPacket_UNDEFINED_STATE                                                                                             = src.BfdPacket_UNDEFINED_STATE
	BfdPacket_UP                                                                                                          = src.BfdPacket_UP
	BfdStatus_ACTIVE                                                                                                      = src.BfdStatus_ACTIVE
	BfdStatus_ADMINISTRATIVELY_DOWN                                                                                       = src.BfdStatus_ADMINISTRATIVELY_DOWN
	BfdStatus_ADMIN_DOWN                                                                                                  = src.BfdStatus_ADMIN_DOWN
	BfdStatus_CONCATENATED_PATH_DOWN                                                                                      = src.BfdStatus_CONCATENATED_PATH_DOWN
	BfdStatus_CONTROL_DETECTION_TIME_EXPIRED                                                                              = src.BfdStatus_CONTROL_DETECTION_TIME_EXPIRED
	BfdStatus_DIAGNOSTIC_UNSPECIFIED                                                                                      = src.BfdStatus_DIAGNOSTIC_UNSPECIFIED
	BfdStatus_DISABLED                                                                                                    = src.BfdStatus_DISABLED
	BfdStatus_DOWN                                                                                                        = src.BfdStatus_DOWN
	BfdStatus_ECHO_FUNCTION_FAILED                                                                                        = src.BfdStatus_ECHO_FUNCTION_FAILED
	BfdStatus_FORWARDING_PLANE_RESET                                                                                      = src.BfdStatus_FORWARDING_PLANE_RESET
	BfdStatus_INIT                                                                                                        = src.BfdStatus_INIT
	BfdStatus_NEIGHBOR_SIGNALED_SESSION_DOWN                                                                              = src.BfdStatus_NEIGHBOR_SIGNALED_SESSION_DOWN
	BfdStatus_NO_DIAGNOSTIC                                                                                               = src.BfdStatus_NO_DIAGNOSTIC
	BfdStatus_PASSIVE                                                                                                     = src.BfdStatus_PASSIVE
	BfdStatus_PATH_DOWN                                                                                                   = src.BfdStatus_PATH_DOWN
	BfdStatus_REVERSE_CONCATENATED_PATH_DOWN                                                                              = src.BfdStatus_REVERSE_CONCATENATED_PATH_DOWN
	BfdStatus_STATE_UNSPECIFIED                                                                                           = src.BfdStatus_STATE_UNSPECIFIED
	BfdStatus_UNDEFINED_BFD_SESSION_INITIALIZATION_MODE                                                                   = src.BfdStatus_UNDEFINED_BFD_SESSION_INITIALIZATION_MODE
	BfdStatus_UNDEFINED_LOCAL_DIAGNOSTIC                                                                                  = src.BfdStatus_UNDEFINED_LOCAL_DIAGNOSTIC
	BfdStatus_UNDEFINED_LOCAL_STATE                                                                                       = src.BfdStatus_UNDEFINED_LOCAL_STATE
	BfdStatus_UP                                                                                                          = src.BfdStatus_UP
	BulkInsertOperationStatus_CREATING                                                                                    = src.BulkInsertOperationStatus_CREATING
	BulkInsertOperationStatus_DONE                                                                                        = src.BulkInsertOperationStatus_DONE
	BulkInsertOperationStatus_ROLLING_BACK                                                                                = src.BulkInsertOperationStatus_ROLLING_BACK
	BulkInsertOperationStatus_STATUS_UNSPECIFIED                                                                          = src.BulkInsertOperationStatus_STATUS_UNSPECIFIED
	BulkInsertOperationStatus_UNDEFINED_STATUS                                                                            = src.BulkInsertOperationStatus_UNDEFINED_STATUS
	Commitment_ACCELERATOR_OPTIMIZED                                                                                      = src.Commitment_ACCELERATOR_OPTIMIZED
	Commitment_ACCELERATOR_OPTIMIZED_A3                                                                                   = src.Commitment_ACCELERATOR_OPTIMIZED_A3
	Commitment_ACCELERATOR_OPTIMIZED_A3_MEGA                                                                              = src.Commitment_ACCELERATOR_OPTIMIZED_A3_MEGA
	Commitment_ACTIVE                                                                                                     = src.Commitment_ACTIVE
	Commitment_CANCELLED                                                                                                  = src.Commitment_CANCELLED
	Commitment_CATEGORY_UNSPECIFIED                                                                                       = src.Commitment_CATEGORY_UNSPECIFIED
	Commitment_COMPUTE_OPTIMIZED                                                                                          = src.Commitment_COMPUTE_OPTIMIZED
	Commitment_COMPUTE_OPTIMIZED_C2D                                                                                      = src.Commitment_COMPUTE_OPTIMIZED_C2D
	Commitment_COMPUTE_OPTIMIZED_C3                                                                                       = src.Commitment_COMPUTE_OPTIMIZED_C3
	Commitment_COMPUTE_OPTIMIZED_C3D                                                                                      = src.Commitment_COMPUTE_OPTIMIZED_C3D
	Commitment_COMPUTE_OPTIMIZED_H3                                                                                       = src.Commitment_COMPUTE_OPTIMIZED_H3
	Commitment_CREATING                                                                                                   = src.Commitment_CREATING
	Commitment_EXPIRED                                                                                                    = src.Commitment_EXPIRED
	Commitment_GENERAL_PURPOSE                                                                                            = src.Commitment_GENERAL_PURPOSE
	Commitment_GENERAL_PURPOSE_C4                                                                                         = src.Commitment_GENERAL_PURPOSE_C4
	Commitment_GENERAL_PURPOSE_E2                                                                                         = src.Commitment_GENERAL_PURPOSE_E2
	Commitment_GENERAL_PURPOSE_N2                                                                                         = src.Commitment_GENERAL_PURPOSE_N2
	Commitment_GENERAL_PURPOSE_N2D                                                                                        = src.Commitment_GENERAL_PURPOSE_N2D
	Commitment_GENERAL_PURPOSE_N4                                                                                         = src.Commitment_GENERAL_PURPOSE_N4
	Commitment_GENERAL_PURPOSE_T2D                                                                                        = src.Commitment_GENERAL_PURPOSE_T2D
	Commitment_GRAPHICS_OPTIMIZED                                                                                         = src.Commitment_GRAPHICS_OPTIMIZED
	Commitment_INVALID                                                                                                    = src.Commitment_INVALID
	Commitment_LICENSE                                                                                                    = src.Commitment_LICENSE
	Commitment_MACHINE                                                                                                    = src.Commitment_MACHINE
	Commitment_MEMORY_OPTIMIZED                                                                                           = src.Commitment_MEMORY_OPTIMIZED
	Commitment_MEMORY_OPTIMIZED_M3                                                                                        = src.Commitment_MEMORY_OPTIMIZED_M3
	Commitment_NOT_YET_ACTIVE                                                                                             = src.Commitment_NOT_YET_ACTIVE
	Commitment_STORAGE_OPTIMIZED_Z3                                                                                       = src.Commitment_STORAGE_OPTIMIZED_Z3
	Commitment_THIRTY_SIX_MONTH                                                                                           = src.Commitment_THIRTY_SIX_MONTH
	Commitment_TWELVE_MONTH                                                                                               = src.Commitment_TWELVE_MONTH
	Commitment_TYPE_UNSPECIFIED                                                                                           = src.Commitment_TYPE_UNSPECIFIED
	Commitment_UNDEFINED_CATEGORY                                                                                         = src.Commitment_UNDEFINED_CATEGORY
	Commitment_UNDEFINED_PLAN                                                                                             = src.Commitment_UNDEFINED_PLAN
	Commitment_UNDEFINED_STATUS                                                                                           = src.Commitment_UNDEFINED_STATUS
	Commitment_UNDEFINED_TYPE                                                                                             = src.Commitment_UNDEFINED_TYPE
	ConfidentialInstanceConfig_CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED                                                     = src.ConfidentialInstanceConfig_CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED
	ConfidentialInstanceConfig_SEV                                                                                        = src.ConfidentialInstanceConfig_SEV
	ConfidentialInstanceConfig_SEV_SNP                                                                                    = src.ConfidentialInstanceConfig_SEV_SNP
	ConfidentialInstanceConfig_TDX                                                                                        = src.ConfidentialInstanceConfig_TDX
	ConfidentialInstanceConfig_UNDEFINED_CONFIDENTIAL_INSTANCE_TYPE                                                       = src.ConfidentialInstanceConfig_UNDEFINED_CONFIDENTIAL_INSTANCE_TYPE
	DeprecationStatus_ACTIVE                                                                                              = src.DeprecationStatus_ACTIVE
	DeprecationStatus_DELETED                                                                                             = src.DeprecationStatus_DELETED
	DeprecationStatus_DEPRECATED                                                                                          = src.DeprecationStatus_DEPRECATED
	DeprecationStatus_OBSOLETE                                                                                            = src.DeprecationStatus_OBSOLETE
	DeprecationStatus_UNDEFINED_STATE                                                                                     = src.DeprecationStatus_UNDEFINED_STATE
	DiskInstantiationConfig_ATTACH_READ_ONLY                                                                              = src.DiskInstantiationConfig_ATTACH_READ_ONLY
	DiskInstantiationConfig_BLANK                                                                                         = src.DiskInstantiationConfig_BLANK
	DiskInstantiationConfig_CUSTOM_IMAGE                                                                                  = src.DiskInstantiationConfig_CUSTOM_IMAGE
	DiskInstantiationConfig_DEFAULT                                                                                       = src.DiskInstantiationConfig_DEFAULT
	DiskInstantiationConfig_DO_NOT_INCLUDE                                                                                = src.DiskInstantiationConfig_DO_NOT_INCLUDE
	DiskInstantiationConfig_SOURCE_IMAGE                                                                                  = src.DiskInstantiationConfig_SOURCE_IMAGE
	DiskInstantiationConfig_SOURCE_IMAGE_FAMILY                                                                           = src.DiskInstantiationConfig_SOURCE_IMAGE_FAMILY
	DiskInstantiationConfig_UNDEFINED_INSTANTIATE_FROM                                                                    = src.DiskInstantiationConfig_UNDEFINED_INSTANTIATE_FROM
	DiskResourceStatusAsyncReplicationStatus_ACTIVE                                                                       = src.DiskResourceStatusAsyncReplicationStatus_ACTIVE
	DiskResourceStatusAsyncReplicationStatus_CREATED                                                                      = src.DiskResourceStatusAsyncReplicationStatus_CREATED
	DiskResourceStatusAsyncReplicationStatus_STARTING                                                                     = src.DiskResourceStatusAsyncReplicationStatus_STARTING
	DiskResourceStatusAsyncReplicationStatus_STATE_UNSPECIFIED                                                            = src.DiskResourceStatusAsyncReplicationStatus_STATE_UNSPECIFIED
	DiskResourceStatusAsyncReplicationStatus_STOPPED                                                                      = src.DiskResourceStatusAsyncReplicationStatus_STOPPED
	DiskResourceStatusAsyncReplicationStatus_STOPPING                                                                     = src.DiskResourceStatusAsyncReplicationStatus_STOPPING
	DiskResourceStatusAsyncReplicationStatus_UNDEFINED_STATE                                                              = src.DiskResourceStatusAsyncReplicationStatus_UNDEFINED_STATE
	Disk_ARCHITECTURE_UNSPECIFIED                                                                                         = src.Disk_ARCHITECTURE_UNSPECIFIED
	Disk_ARM64                                                                                                            = src.Disk_ARM64
	Disk_CREATING                                                                                                         = src.Disk_CREATING
	Disk_DELETING                                                                                                         = src.Disk_DELETING
	Disk_FAILED                                                                                                           = src.Disk_FAILED
	Disk_READY                                                                                                            = src.Disk_READY
	Disk_READ_ONLY_MANY                                                                                                   = src.Disk_READ_ONLY_MANY
	Disk_READ_WRITE_MANY                                                                                                  = src.Disk_READ_WRITE_MANY
	Disk_READ_WRITE_SINGLE                                                                                                = src.Disk_READ_WRITE_SINGLE
	Disk_RESTORING                                                                                                        = src.Disk_RESTORING
	Disk_UNAVAILABLE                                                                                                      = src.Disk_UNAVAILABLE
	Disk_UNDEFINED_ACCESS_MODE                                                                                            = src.Disk_UNDEFINED_ACCESS_MODE
	Disk_UNDEFINED_ARCHITECTURE                                                                                           = src.Disk_UNDEFINED_ARCHITECTURE
	Disk_UNDEFINED_STATUS                                                                                                 = src.Disk_UNDEFINED_STATUS
	Disk_X86_64                                                                                                           = src.Disk_X86_64
	DistributionPolicy_ANY                                                                                                = src.DistributionPolicy_ANY
	DistributionPolicy_ANY_SINGLE_ZONE                                                                                    = src.DistributionPolicy_ANY_SINGLE_ZONE
	DistributionPolicy_BALANCED                                                                                           = src.DistributionPolicy_BALANCED
	DistributionPolicy_EVEN                                                                                               = src.DistributionPolicy_EVEN
	DistributionPolicy_UNDEFINED_TARGET_SHAPE                                                                             = src.DistributionPolicy_UNDEFINED_TARGET_SHAPE
	ExchangedPeeringRoute_DYNAMIC_PEERING_ROUTE                                                                           = src.ExchangedPeeringRoute_DYNAMIC_PEERING_ROUTE
	ExchangedPeeringRoute_STATIC_PEERING_ROUTE                                                                            = src.ExchangedPeeringRoute_STATIC_PEERING_ROUTE
	ExchangedPeeringRoute_SUBNET_PEERING_ROUTE                                                                            = src.ExchangedPeeringRoute_SUBNET_PEERING_ROUTE
	ExchangedPeeringRoute_UNDEFINED_TYPE                                                                                  = src.ExchangedPeeringRoute_UNDEFINED_TYPE
	ExternalVpnGateway_FOUR_IPS_REDUNDANCY                                                                                = src.ExternalVpnGateway_FOUR_IPS_REDUNDANCY
	ExternalVpnGateway_SINGLE_IP_INTERNALLY_REDUNDANT                                                                     = src.ExternalVpnGateway_SINGLE_IP_INTERNALLY_REDUNDANT
	ExternalVpnGateway_TWO_IPS_REDUNDANCY                                                                                 = src.ExternalVpnGateway_TWO_IPS_REDUNDANCY
	ExternalVpnGateway_UNDEFINED_REDUNDANCY_TYPE                                                                          = src.ExternalVpnGateway_UNDEFINED_REDUNDANCY_TYPE
	FileContentBuffer_BIN                                                                                                 = src.FileContentBuffer_BIN
	FileContentBuffer_UNDEFINED                                                                                           = src.FileContentBuffer_UNDEFINED
	FileContentBuffer_UNDEFINED_FILE_TYPE                                                                                 = src.FileContentBuffer_UNDEFINED_FILE_TYPE
	FileContentBuffer_X509                                                                                                = src.FileContentBuffer_X509
	FirewallLogConfig_EXCLUDE_ALL_METADATA                                                                                = src.FirewallLogConfig_EXCLUDE_ALL_METADATA
	FirewallLogConfig_INCLUDE_ALL_METADATA                                                                                = src.FirewallLogConfig_INCLUDE_ALL_METADATA
	FirewallLogConfig_UNDEFINED_METADATA                                                                                  = src.FirewallLogConfig_UNDEFINED_METADATA
	FirewallPolicyRuleSecureTag_EFFECTIVE                                                                                 = src.FirewallPolicyRuleSecureTag_EFFECTIVE
	FirewallPolicyRuleSecureTag_INEFFECTIVE                                                                               = src.FirewallPolicyRuleSecureTag_INEFFECTIVE
	FirewallPolicyRuleSecureTag_UNDEFINED_STATE                                                                           = src.FirewallPolicyRuleSecureTag_UNDEFINED_STATE
	FirewallPolicyRule_EGRESS                                                                                             = src.FirewallPolicyRule_EGRESS
	FirewallPolicyRule_INGRESS                                                                                            = src.FirewallPolicyRule_INGRESS
	FirewallPolicyRule_UNDEFINED_DIRECTION                                                                                = src.FirewallPolicyRule_UNDEFINED_DIRECTION
	Firewall_EGRESS                                                                                                       = src.Firewall_EGRESS
	Firewall_INGRESS                                                                                                      = src.Firewall_INGRESS
	Firewall_UNDEFINED_DIRECTION                                                                                          = src.Firewall_UNDEFINED_DIRECTION
	ForwardingRule_ACCEPTED                                                                                               = src.ForwardingRule_ACCEPTED
	ForwardingRule_AH                                                                                                     = src.ForwardingRule_AH
	ForwardingRule_CLOSED                                                                                                 = src.ForwardingRule_CLOSED
	ForwardingRule_ESP                                                                                                    = src.ForwardingRule_ESP
	ForwardingRule_EXTERNAL                                                                                               = src.ForwardingRule_EXTERNAL
	ForwardingRule_EXTERNAL_MANAGED                                                                                       = src.ForwardingRule_EXTERNAL_MANAGED
	ForwardingRule_FIXED_STANDARD                                                                                         = src.ForwardingRule_FIXED_STANDARD
	ForwardingRule_ICMP                                                                                                   = src.ForwardingRule_ICMP
	ForwardingRule_INTERNAL                                                                                               = src.ForwardingRule_INTERNAL
	ForwardingRule_INTERNAL_MANAGED                                                                                       = src.ForwardingRule_INTERNAL_MANAGED
	ForwardingRule_INTERNAL_SELF_MANAGED                                                                                  = src.ForwardingRule_INTERNAL_SELF_MANAGED
	ForwardingRule_INVALID                                                                                                = src.ForwardingRule_INVALID
	ForwardingRule_IPV4                                                                                                   = src.ForwardingRule_IPV4
	ForwardingRule_IPV6                                                                                                   = src.ForwardingRule_IPV6
	ForwardingRule_L3_DEFAULT                                                                                             = src.ForwardingRule_L3_DEFAULT
	ForwardingRule_NEEDS_ATTENTION                                                                                        = src.ForwardingRule_NEEDS_ATTENTION
	ForwardingRule_PENDING                                                                                                = src.ForwardingRule_PENDING
	ForwardingRule_PREMIUM                                                                                                = src.ForwardingRule_PREMIUM
	ForwardingRule_REJECTED                                                                                               = src.ForwardingRule_REJECTED
	ForwardingRule_SCTP                                                                                                   = src.ForwardingRule_SCTP
	ForwardingRule_STANDARD                                                                                               = src.ForwardingRule_STANDARD
	ForwardingRule_STANDARD_OVERRIDES_FIXED_STANDARD                                                                      = src.ForwardingRule_STANDARD_OVERRIDES_FIXED_STANDARD
	ForwardingRule_STATUS_UNSPECIFIED                                                                                     = src.ForwardingRule_STATUS_UNSPECIFIED
	ForwardingRule_TCP                                                                                                    = src.ForwardingRule_TCP
	ForwardingRule_UDP                                                                                                    = src.ForwardingRule_UDP
	ForwardingRule_UNDEFINED_IP_VERSION                                                                                   = src.ForwardingRule_UNDEFINED_IP_VERSION
	ForwardingRule_UNDEFINED_I_P_PROTOCOL_ENUM                                                                            = src.ForwardingRule_UNDEFINED_I_P_PROTOCOL_ENUM
	ForwardingRule_UNDEFINED_LOAD_BALANCING_SCHEME                                                                        = src.ForwardingRule_UNDEFINED_LOAD_BALANCING_SCHEME
	ForwardingRule_UNDEFINED_NETWORK_TIER                                                                                 = src.ForwardingRule_UNDEFINED_NETWORK_TIER
	ForwardingRule_UNDEFINED_PSC_CONNECTION_STATUS                                                                        = src.ForwardingRule_UNDEFINED_PSC_CONNECTION_STATUS
	ForwardingRule_UNSPECIFIED_VERSION                                                                                    = src.ForwardingRule_UNSPECIFIED_VERSION
	GRPCHealthCheck_UNDEFINED_PORT_SPECIFICATION                                                                          = src.GRPCHealthCheck_UNDEFINED_PORT_SPECIFICATION
	GRPCHealthCheck_USE_FIXED_PORT                                                                                        = src.GRPCHealthCheck_USE_FIXED_PORT
	GRPCHealthCheck_USE_NAMED_PORT                                                                                        = src.GRPCHealthCheck_USE_NAMED_PORT
	GRPCHealthCheck_USE_SERVING_PORT                                                                                      = src.GRPCHealthCheck_USE_SERVING_PORT
	GuestOsFeature_FEATURE_TYPE_UNSPECIFIED                                                                               = src.GuestOsFeature_FEATURE_TYPE_UNSPECIFIED
	GuestOsFeature_GVNIC                                                                                                  = src.GuestOsFeature_GVNIC
	GuestOsFeature_IDPF                                                                                                   = src.GuestOsFeature_IDPF
	GuestOsFeature_MULTI_IP_SUBNET                                                                                        = src.GuestOsFeature_MULTI_IP_SUBNET
	GuestOsFeature_SECURE_BOOT                                                                                            = src.GuestOsFeature_SECURE_BOOT
	GuestOsFeature_SEV_CAPABLE                                                                                            = src.GuestOsFeature_SEV_CAPABLE
	GuestOsFeature_SEV_LIVE_MIGRATABLE                                                                                    = src.GuestOsFeature_SEV_LIVE_MIGRATABLE
	GuestOsFeature_SEV_LIVE_MIGRATABLE_V2                                                                                 = src.GuestOsFeature_SEV_LIVE_MIGRATABLE_V2
	GuestOsFeature_SEV_SNP_CAPABLE                                                                                        = src.GuestOsFeature_SEV_SNP_CAPABLE
	GuestOsFeature_TDX_CAPABLE                                                                                            = src.GuestOsFeature_TDX_CAPABLE
	GuestOsFeature_UEFI_COMPATIBLE                                                                                        = src.GuestOsFeature_UEFI_COMPATIBLE
	GuestOsFeature_UNDEFINED_TYPE                                                                                         = src.GuestOsFeature_UNDEFINED_TYPE
	GuestOsFeature_VIRTIO_SCSI_MULTIQUEUE                                                                                 = src.GuestOsFeature_VIRTIO_SCSI_MULTIQUEUE
	GuestOsFeature_WINDOWS                                                                                                = src.GuestOsFeature_WINDOWS
	HTTP2HealthCheck_NONE                                                                                                 = src.HTTP2HealthCheck_NONE
	HTTP2HealthCheck_PROXY_V1                                                                                             = src.HTTP2HealthCheck_PROXY_V1
	HTTP2HealthCheck_UNDEFINED_PORT_SPECIFICATION                                                                         = src.HTTP2HealthCheck_UNDEFINED_PORT_SPECIFICATION
	HTTP2HealthCheck_UNDEFINED_PROXY_HEADER                                                                               = src.HTTP2HealthCheck_UNDEFINED_PROXY_HEADER
	HTTP2HealthCheck_USE_FIXED_PORT                                                                                       = src.HTTP2HealthCheck_USE_FIXED_PORT
	HTTP2HealthCheck_USE_NAMED_PORT                                                                                       = src.HTTP2HealthCheck_USE_NAMED_PORT
	HTTP2HealthCheck_USE_SERVING_PORT                                                                                     = src.HTTP2HealthCheck_USE_SERVING_PORT
	HTTPHealthCheck_NONE                                                                                                  = src.HTTPHealthCheck_NONE
	HTTPHealthCheck_PROXY_V1                                                                                              = src.HTTPHealthCheck_PROXY_V1
	HTTPHealthCheck_UNDEFINED_PORT_SPECIFICATION                                                                          = src.HTTPHealthCheck_UNDEFINED_PORT_SPECIFICATION
	HTTPHealthCheck_UNDEFINED_PROXY_HEADER                                                                                = src.HTTPHealthCheck_UNDEFINED_PROXY_HEADER
	HTTPHealthCheck_USE_FIXED_PORT                                                                                        = src.HTTPHealthCheck_USE_FIXED_PORT
	HTTPHealthCheck_USE_NAMED_PORT                                                                                        = src.HTTPHealthCheck_USE_NAMED_PORT
	HTTPHealthCheck_USE_SERVING_PORT                                                                                      = src.HTTPHealthCheck_USE_SERVING_PORT
	HTTPSHealthCheck_NONE                                                                                                 = src.HTTPSHealthCheck_NONE
	HTTPSHealthCheck_PROXY_V1                                                                                             = src.HTTPSHealthCheck_PROXY_V1
	HTTPSHealthCheck_UNDEFINED_PORT_SPECIFICATION                                                                         = src.HTTPSHealthCheck_UNDEFINED_PORT_SPECIFICATION
	HTTPSHealthCheck_UNDEFINED_PROXY_HEADER                                                                               = src.HTTPSHealthCheck_UNDEFINED_PROXY_HEADER
	HTTPSHealthCheck_USE_FIXED_PORT                                                                                       = src.HTTPSHealthCheck_USE_FIXED_PORT
	HTTPSHealthCheck_USE_NAMED_PORT                                                                                       = src.HTTPSHealthCheck_USE_NAMED_PORT
	HTTPSHealthCheck_USE_SERVING_PORT                                                                                     = src.HTTPSHealthCheck_USE_SERVING_PORT
	HealthCheckService_AND                                                                                                = src.HealthCheckService_AND
	HealthCheckService_NO_AGGREGATION                                                                                     = src.HealthCheckService_NO_AGGREGATION
	HealthCheckService_UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY                                                         = src.HealthCheckService_UNDEFINED_HEALTH_STATUS_AGGREGATION_POLICY
	HealthCheck_GRPC                                                                                                      = src.HealthCheck_GRPC
	HealthCheck_HTTP                                                                                                      = src.HealthCheck_HTTP
	HealthCheck_HTTP2                                                                                                     = src.HealthCheck_HTTP2
	HealthCheck_HTTPS                                                                                                     = src.HealthCheck_HTTPS
	HealthCheck_INVALID                                                                                                   = src.HealthCheck_INVALID
	HealthCheck_SSL                                                                                                       = src.HealthCheck_SSL
	HealthCheck_TCP                                                                                                       = src.HealthCheck_TCP
	HealthCheck_UNDEFINED_TYPE                                                                                            = src.HealthCheck_UNDEFINED_TYPE
	HealthStatusForNetworkEndpoint_DRAINING                                                                               = src.HealthStatusForNetworkEndpoint_DRAINING
	HealthStatusForNetworkEndpoint_HEALTHY                                                                                = src.HealthStatusForNetworkEndpoint_HEALTHY
	HealthStatusForNetworkEndpoint_UNDEFINED_HEALTH_STATE                                                                 = src.HealthStatusForNetworkEndpoint_UNDEFINED_HEALTH_STATE
	HealthStatusForNetworkEndpoint_UNDEFINED_IPV6_HEALTH_STATE                                                            = src.HealthStatusForNetworkEndpoint_UNDEFINED_IPV6_HEALTH_STATE
	HealthStatusForNetworkEndpoint_UNHEALTHY                                                                              = src.HealthStatusForNetworkEndpoint_UNHEALTHY
	HealthStatusForNetworkEndpoint_UNKNOWN                                                                                = src.HealthStatusForNetworkEndpoint_UNKNOWN
	HealthStatus_HEALTHY                                                                                                  = src.HealthStatus_HEALTHY
	HealthStatus_INVALID_WEIGHT                                                                                           = src.HealthStatus_INVALID_WEIGHT
	HealthStatus_MISSING_WEIGHT                                                                                           = src.HealthStatus_MISSING_WEIGHT
	HealthStatus_UNAVAILABLE_WEIGHT                                                                                       = src.HealthStatus_UNAVAILABLE_WEIGHT
	HealthStatus_UNDEFINED_HEALTH_STATE                                                                                   = src.HealthStatus_UNDEFINED_HEALTH_STATE
	HealthStatus_UNDEFINED_IPV6_HEALTH_STATE                                                                              = src.HealthStatus_UNDEFINED_IPV6_HEALTH_STATE
	HealthStatus_UNDEFINED_WEIGHT_ERROR                                                                                   = src.HealthStatus_UNDEFINED_WEIGHT_ERROR
	HealthStatus_UNHEALTHY                                                                                                = src.HealthStatus_UNHEALTHY
	HealthStatus_WEIGHT_NONE                                                                                              = src.HealthStatus_WEIGHT_NONE
	HttpRedirectAction_FOUND                                                                                              = src.HttpRedirectAction_FOUND
	HttpRedirectAction_MOVED_PERMANENTLY_DEFAULT                                                                          = src.HttpRedirectAction_MOVED_PERMANENTLY_DEFAULT
	HttpRedirectAction_PERMANENT_REDIRECT                                                                                 = src.HttpRedirectAction_PERMANENT_REDIRECT
	HttpRedirectAction_SEE_OTHER                                                                                          = src.HttpRedirectAction_SEE_OTHER
	HttpRedirectAction_TEMPORARY_REDIRECT                                                                                 = src.HttpRedirectAction_TEMPORARY_REDIRECT
	HttpRedirectAction_UNDEFINED_REDIRECT_RESPONSE_CODE                                                                   = src.HttpRedirectAction_UNDEFINED_REDIRECT_RESPONSE_CODE
	Image_ARCHITECTURE_UNSPECIFIED                                                                                        = src.Image_ARCHITECTURE_UNSPECIFIED
	Image_ARM64                                                                                                           = src.Image_ARM64
	Image_DELETING                                                                                                        = src.Image_DELETING
	Image_FAILED                                                                                                          = src.Image_FAILED
	Image_PENDING                                                                                                         = src.Image_PENDING
	Image_RAW                                                                                                             = src.Image_RAW
	Image_READY                                                                                                           = src.Image_READY
	Image_UNDEFINED_ARCHITECTURE                                                                                          = src.Image_UNDEFINED_ARCHITECTURE
	Image_UNDEFINED_SOURCE_TYPE                                                                                           = src.Image_UNDEFINED_SOURCE_TYPE
	Image_UNDEFINED_STATUS                                                                                                = src.Image_UNDEFINED_STATUS
	Image_X86_64                                                                                                          = src.Image_X86_64
	InstanceGroupManagerInstanceLifecyclePolicy_DO_NOTHING                                                                = src.InstanceGroupManagerInstanceLifecyclePolicy_DO_NOTHING
	InstanceGroupManagerInstanceLifecyclePolicy_NO                                                                        = src.InstanceGroupManagerInstanceLifecyclePolicy_NO
	InstanceGroupManagerInstanceLifecyclePolicy_REPAIR                                                                    = src.InstanceGroupManagerInstanceLifecyclePolicy_REPAIR
	InstanceGroupManagerInstanceLifecyclePolicy_UNDEFINED_DEFAULT_ACTION_ON_FAILURE                                       = src.InstanceGroupManagerInstanceLifecyclePolicy_UNDEFINED_DEFAULT_ACTION_ON_FAILURE
	InstanceGroupManagerInstanceLifecyclePolicy_UNDEFINED_FORCE_UPDATE_ON_REPAIR                                          = src.InstanceGroupManagerInstanceLifecyclePolicy_UNDEFINED_FORCE_UPDATE_ON_REPAIR
	InstanceGroupManagerInstanceLifecyclePolicy_YES                                                                       = src.InstanceGroupManagerInstanceLifecyclePolicy_YES
	InstanceGroupManagerResizeRequest_ACCEPTED                                                                            = src.InstanceGroupManagerResizeRequest_ACCEPTED
	InstanceGroupManagerResizeRequest_CANCELLED                                                                           = src.InstanceGroupManagerResizeRequest_CANCELLED
	InstanceGroupManagerResizeRequest_CREATING                                                                            = src.InstanceGroupManagerResizeRequest_CREATING
	InstanceGroupManagerResizeRequest_FAILED                                                                              = src.InstanceGroupManagerResizeRequest_FAILED
	InstanceGroupManagerResizeRequest_STATE_UNSPECIFIED                                                                   = src.InstanceGroupManagerResizeRequest_STATE_UNSPECIFIED
	InstanceGroupManagerResizeRequest_SUCCEEDED                                                                           = src.InstanceGroupManagerResizeRequest_SUCCEEDED
	InstanceGroupManagerResizeRequest_UNDEFINED_STATE                                                                     = src.InstanceGroupManagerResizeRequest_UNDEFINED_STATE
	InstanceGroupManagerUpdatePolicy_OPPORTUNISTIC                                                                        = src.InstanceGroupManagerUpdatePolicy_OPPORTUNISTIC
	InstanceGroupManagerUpdatePolicy_RECREATE                                                                             = src.InstanceGroupManagerUpdatePolicy_RECREATE
	InstanceGroupManagerUpdatePolicy_SUBSTITUTE                                                                           = src.InstanceGroupManagerUpdatePolicy_SUBSTITUTE
	InstanceGroupManagerUpdatePolicy_UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE                                               = src.InstanceGroupManagerUpdatePolicy_UNDEFINED_INSTANCE_REDISTRIBUTION_TYPE
	InstanceGroupManagerUpdatePolicy_UNDEFINED_MINIMAL_ACTION                                                             = src.InstanceGroupManagerUpdatePolicy_UNDEFINED_MINIMAL_ACTION
	InstanceGroupManagerUpdatePolicy_UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION                                             = src.InstanceGroupManagerUpdatePolicy_UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION
	InstanceGroupManagerUpdatePolicy_UNDEFINED_REPLACEMENT_METHOD                                                         = src.InstanceGroupManagerUpdatePolicy_UNDEFINED_REPLACEMENT_METHOD
	InstanceGroupManagerUpdatePolicy_UNDEFINED_TYPE                                                                       = src.InstanceGroupManagerUpdatePolicy_UNDEFINED_TYPE
	InstanceGroupManager_PAGELESS                                                                                         = src.InstanceGroupManager_PAGELESS
	InstanceGroupManager_PAGINATED                                                                                        = src.InstanceGroupManager_PAGINATED
	InstanceGroupManager_UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS                                                         = src.InstanceGroupManager_UNDEFINED_LIST_MANAGED_INSTANCES_RESULTS
	InstanceGroupManagersApplyUpdatesRequest_UNDEFINED_MINIMAL_ACTION                                                     = src.InstanceGroupManagersApplyUpdatesRequest_UNDEFINED_MINIMAL_ACTION
	InstanceGroupManagersApplyUpdatesRequest_UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION                                     = src.InstanceGroupManagersApplyUpdatesRequest_UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION
	InstanceGroupsListInstancesRequest_ALL                                                                                = src.InstanceGroupsListInstancesRequest_ALL
	InstanceGroupsListInstancesRequest_RUNNING                                                                            = src.InstanceGroupsListInstancesRequest_RUNNING
	InstanceGroupsListInstancesRequest_UNDEFINED_INSTANCE_STATE                                                           = src.InstanceGroupsListInstancesRequest_UNDEFINED_INSTANCE_STATE
	InstanceManagedByIgmErrorInstanceActionDetails_ABANDONING                                                             = src.InstanceManagedByIgmErrorInstanceActionDetails_ABANDONING
	InstanceManagedByIgmErrorInstanceActionDetails_CREATING                                                               = src.InstanceManagedByIgmErrorInstanceActionDetails_CREATING
	InstanceManagedByIgmErrorInstanceActionDetails_CREATING_WITHOUT_RETRIES                                               = src.InstanceManagedByIgmErrorInstanceActionDetails_CREATING_WITHOUT_RETRIES
	InstanceManagedByIgmErrorInstanceActionDetails_DELETING                                                               = src.InstanceManagedByIgmErrorInstanceActionDetails_DELETING
	InstanceManagedByIgmErrorInstanceActionDetails_NONE                                                                   = src.InstanceManagedByIgmErrorInstanceActionDetails_NONE
	InstanceManagedByIgmErrorInstanceActionDetails_RECREATING                                                             = src.InstanceManagedByIgmErrorInstanceActionDetails_RECREATING
	InstanceManagedByIgmErrorInstanceActionDetails_REFRESHING                                                             = src.InstanceManagedByIgmErrorInstanceActionDetails_REFRESHING
	InstanceManagedByIgmErrorInstanceActionDetails_RESTARTING                                                             = src.InstanceManagedByIgmErrorInstanceActionDetails_RESTARTING
	InstanceManagedByIgmErrorInstanceActionDetails_RESUMING                                                               = src.InstanceManagedByIgmErrorInstanceActionDetails_RESUMING
	InstanceManagedByIgmErrorInstanceActionDetails_STARTING                                                               = src.InstanceManagedByIgmErrorInstanceActionDetails_STARTING
	InstanceManagedByIgmErrorInstanceActionDetails_STOPPING                                                               = src.InstanceManagedByIgmErrorInstanceActionDetails_STOPPING
	InstanceManagedByIgmErrorInstanceActionDetails_SUSPENDING                                                             = src.InstanceManagedByIgmErrorInstanceActionDetails_SUSPENDING
	InstanceManagedByIgmErrorInstanceActionDetails_UNDEFINED_ACTION                                                       = src.InstanceManagedByIgmErrorInstanceActionDetails_UNDEFINED_ACTION
	InstanceManagedByIgmErrorInstanceActionDetails_VERIFYING                                                              = src.InstanceManagedByIgmErrorInstanceActionDetails_VERIFYING
	InstanceProperties_ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE                                                              = src.InstanceProperties_ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE
	InstanceProperties_ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE                                                                = src.InstanceProperties_ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE
	InstanceProperties_INHERIT_FROM_SUBNETWORK                                                                            = src.InstanceProperties_INHERIT_FROM_SUBNETWORK
	InstanceProperties_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED                                                             = src.InstanceProperties_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED
	InstanceProperties_NONE                                                                                               = src.InstanceProperties_NONE
	InstanceProperties_STOP                                                                                               = src.InstanceProperties_STOP
	InstanceProperties_UNDEFINED_KEY_REVOCATION_ACTION_TYPE                                                               = src.InstanceProperties_UNDEFINED_KEY_REVOCATION_ACTION_TYPE
	InstanceProperties_UNDEFINED_PRIVATE_IPV6_GOOGLE_ACCESS                                                               = src.InstanceProperties_UNDEFINED_PRIVATE_IPV6_GOOGLE_ACCESS
	InstanceWithNamedPorts_DEPROVISIONING                                                                                 = src.InstanceWithNamedPorts_DEPROVISIONING
	InstanceWithNamedPorts_PROVISIONING                                                                                   = src.InstanceWithNamedPorts_PROVISIONING
	InstanceWithNamedPorts_REPAIRING                                                                                      = src.InstanceWithNamedPorts_REPAIRING
	InstanceWithNamedPorts_RUNNING                                                                                        = src.InstanceWithNamedPorts_RUNNING
	InstanceWithNamedPorts_STAGING                                                                                        = src.InstanceWithNamedPorts_STAGING
	InstanceWithNamedPorts_STOPPED                                                                                        = src.InstanceWithNamedPorts_STOPPED
	InstanceWithNamedPorts_STOPPING                                                                                       = src.InstanceWithNamedPorts_STOPPING
	InstanceWithNamedPorts_SUSPENDED                                                                                      = src.InstanceWithNamedPorts_SUSPENDED
	InstanceWithNamedPorts_SUSPENDING                                                                                     = src.InstanceWithNamedPorts_SUSPENDING
	InstanceWithNamedPorts_TERMINATED                                                                                     = src.InstanceWithNamedPorts_TERMINATED
	InstanceWithNamedPorts_UNDEFINED_STATUS                                                                               = src.InstanceWithNamedPorts_UNDEFINED_STATUS
	Instance_DEPROVISIONING                                                                                               = src.Instance_DEPROVISIONING
	Instance_ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE                                                                        = src.Instance_ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE
	Instance_ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE                                                                          = src.Instance_ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE
	Instance_INHERIT_FROM_SUBNETWORK                                                                                      = src.Instance_INHERIT_FROM_SUBNETWORK
	Instance_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED                                                                       = src.Instance_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED
	Instance_NONE                                                                                                         = src.Instance_NONE
	Instance_PROVISIONING                                                                                                 = src.Instance_PROVISIONING
	Instance_REPAIRING                                                                                                    = src.Instance_REPAIRING
	Instance_RUNNING                                                                                                      = src.Instance_RUNNING
	Instance_STAGING                                                                                                      = src.Instance_STAGING
	Instance_STOP                                                                                                         = src.Instance_STOP
	Instance_STOPPED                                                                                                      = src.Instance_STOPPED
	Instance_STOPPING                                                                                                     = src.Instance_STOPPING
	Instance_SUSPENDED                                                                                                    = src.Instance_SUSPENDED
	Instance_SUSPENDING                                                                                                   = src.Instance_SUSPENDING
	Instance_TERMINATED                                                                                                   = src.Instance_TERMINATED
	Instance_UNDEFINED_KEY_REVOCATION_ACTION_TYPE                                                                         = src.Instance_UNDEFINED_KEY_REVOCATION_ACTION_TYPE
	Instance_UNDEFINED_PRIVATE_IPV6_GOOGLE_ACCESS                                                                         = src.Instance_UNDEFINED_PRIVATE_IPV6_GOOGLE_ACCESS
	Instance_UNDEFINED_STATUS                                                                                             = src.Instance_UNDEFINED_STATUS
	InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_HIERARCHY                                               = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_HIERARCHY
	InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_NETWORK                                                 = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_NETWORK
	InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_NETWORK_REGIONAL                                        = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_NETWORK_REGIONAL
	InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_SYSTEM_GLOBAL                                           = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_SYSTEM_GLOBAL
	InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_SYSTEM_REGIONAL                                         = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_SYSTEM_REGIONAL
	InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNDEFINED_TYPE                                          = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNDEFINED_TYPE
	InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNSPECIFIED                                             = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNSPECIFIED
	InstantSnapshot_ARCHITECTURE_UNSPECIFIED                                                                              = src.InstantSnapshot_ARCHITECTURE_UNSPECIFIED
	InstantSnapshot_ARM64                                                                                                 = src.InstantSnapshot_ARM64
	InstantSnapshot_CREATING                                                                                              = src.InstantSnapshot_CREATING
	InstantSnapshot_DELETING                                                                                              = src.InstantSnapshot_DELETING
	InstantSnapshot_FAILED                                                                                                = src.InstantSnapshot_FAILED
	InstantSnapshot_READY                                                                                                 = src.InstantSnapshot_READY
	InstantSnapshot_UNAVAILABLE                                                                                           = src.InstantSnapshot_UNAVAILABLE
	InstantSnapshot_UNDEFINED_ARCHITECTURE                                                                                = src.InstantSnapshot_UNDEFINED_ARCHITECTURE
	InstantSnapshot_UNDEFINED_STATUS                                                                                      = src.InstantSnapshot_UNDEFINED_STATUS
	InstantSnapshot_X86_64                                                                                                = src.InstantSnapshot_X86_64
	InterconnectAttachmentConfigurationConstraints_MD5_OPTIONAL                                                           = src.InterconnectAttachmentConfigurationConstraints_MD5_OPTIONAL
	InterconnectAttachmentConfigurationConstraints_MD5_REQUIRED                                                           = src.InterconnectAttachmentConfigurationConstraints_MD5_REQUIRED
	InterconnectAttachmentConfigurationConstraints_MD5_UNSUPPORTED                                                        = src.InterconnectAttachmentConfigurationConstraints_MD5_UNSUPPORTED
	InterconnectAttachmentConfigurationConstraints_UNDEFINED_BGP_MD5                                                      = src.InterconnectAttachmentConfigurationConstraints_UNDEFINED_BGP_MD5
	InterconnectAttachment_ACTIVE                                                                                         = src.InterconnectAttachment_ACTIVE
	InterconnectAttachment_AVAILABILITY_DOMAIN_1                                                                          = src.InterconnectAttachment_AVAILABILITY_DOMAIN_1
	InterconnectAttachment_AVAILABILITY_DOMAIN_2                                                                          = src.InterconnectAttachment_AVAILABILITY_DOMAIN_2
	InterconnectAttachment_AVAILABILITY_DOMAIN_ANY                                                                        = src.InterconnectAttachment_AVAILABILITY_DOMAIN_ANY
	InterconnectAttachment_BPS_100M                                                                                       = src.InterconnectAttachment_BPS_100M
	InterconnectAttachment_BPS_10G                                                                                        = src.InterconnectAttachment_BPS_10G
	InterconnectAttachment_BPS_1G                                                                                         = src.InterconnectAttachment_BPS_1G
	InterconnectAttachment_BPS_200M                                                                                       = src.InterconnectAttachment_BPS_200M
	InterconnectAttachment_BPS_20G                                                                                        = src.InterconnectAttachment_BPS_20G
	InterconnectAttachment_BPS_2G                                                                                         = src.InterconnectAttachment_BPS_2G
	InterconnectAttachment_BPS_300M                                                                                       = src.InterconnectAttachment_BPS_300M
	InterconnectAttachment_BPS_400M                                                                                       = src.InterconnectAttachment_BPS_400M
	InterconnectAttachment_BPS_500M                                                                                       = src.InterconnectAttachment_BPS_500M
	InterconnectAttachment_BPS_50G                                                                                        = src.InterconnectAttachment_BPS_50G
	InterconnectAttachment_BPS_50M                                                                                        = src.InterconnectAttachment_BPS_50M
	InterconnectAttachment_BPS_5G                                                                                         = src.InterconnectAttachment_BPS_5G
	InterconnectAttachment_DEDICATED                                                                                      = src.InterconnectAttachment_DEDICATED
	InterconnectAttachment_DEFUNCT                                                                                        = src.InterconnectAttachment_DEFUNCT
	InterconnectAttachment_IPSEC                                                                                          = src.InterconnectAttachment_IPSEC
	InterconnectAttachment_IPV4_IPV6                                                                                      = src.InterconnectAttachment_IPV4_IPV6
	InterconnectAttachment_IPV4_ONLY                                                                                      = src.InterconnectAttachment_IPV4_ONLY
	InterconnectAttachment_NONE                                                                                           = src.InterconnectAttachment_NONE
	InterconnectAttachment_OS_ACTIVE                                                                                      = src.InterconnectAttachment_OS_ACTIVE
	InterconnectAttachment_OS_UNPROVISIONED                                                                               = src.InterconnectAttachment_OS_UNPROVISIONED
	InterconnectAttachment_PARTNER                                                                                        = src.InterconnectAttachment_PARTNER
	InterconnectAttachment_PARTNER_PROVIDER                                                                               = src.InterconnectAttachment_PARTNER_PROVIDER
	InterconnectAttachment_PARTNER_REQUEST_RECEIVED                                                                       = src.InterconnectAttachment_PARTNER_REQUEST_RECEIVED
	InterconnectAttachment_PENDING_CUSTOMER                                                                               = src.InterconnectAttachment_PENDING_CUSTOMER
	InterconnectAttachment_PENDING_PARTNER                                                                                = src.InterconnectAttachment_PENDING_PARTNER
	InterconnectAttachment_STATE_UNSPECIFIED                                                                              = src.InterconnectAttachment_STATE_UNSPECIFIED
	InterconnectAttachment_UNDEFINED_BANDWIDTH                                                                            = src.InterconnectAttachment_UNDEFINED_BANDWIDTH
	InterconnectAttachment_UNDEFINED_EDGE_AVAILABILITY_DOMAIN                                                             = src.InterconnectAttachment_UNDEFINED_EDGE_AVAILABILITY_DOMAIN
	InterconnectAttachment_UNDEFINED_ENCRYPTION                                                                           = src.InterconnectAttachment_UNDEFINED_ENCRYPTION
	InterconnectAttachment_UNDEFINED_OPERATIONAL_STATUS                                                                   = src.InterconnectAttachment_UNDEFINED_OPERATIONAL_STATUS
	InterconnectAttachment_UNDEFINED_STACK_TYPE                                                                           = src.InterconnectAttachment_UNDEFINED_STACK_TYPE
	InterconnectAttachment_UNDEFINED_STATE                                                                                = src.InterconnectAttachment_UNDEFINED_STATE
	InterconnectAttachment_UNDEFINED_TYPE                                                                                 = src.InterconnectAttachment_UNDEFINED_TYPE
	InterconnectAttachment_UNPROVISIONED                                                                                  = src.InterconnectAttachment_UNPROVISIONED
	InterconnectDiagnosticsLinkLACPStatus_ACTIVE                                                                          = src.InterconnectDiagnosticsLinkLACPStatus_ACTIVE
	InterconnectDiagnosticsLinkLACPStatus_DETACHED                                                                        = src.InterconnectDiagnosticsLinkLACPStatus_DETACHED
	InterconnectDiagnosticsLinkLACPStatus_UNDEFINED_STATE                                                                 = src.InterconnectDiagnosticsLinkLACPStatus_UNDEFINED_STATE
	InterconnectDiagnosticsLinkOpticalPower_HIGH_ALARM                                                                    = src.InterconnectDiagnosticsLinkOpticalPower_HIGH_ALARM
	InterconnectDiagnosticsLinkOpticalPower_HIGH_WARNING                                                                  = src.InterconnectDiagnosticsLinkOpticalPower_HIGH_WARNING
	InterconnectDiagnosticsLinkOpticalPower_LOW_ALARM                                                                     = src.InterconnectDiagnosticsLinkOpticalPower_LOW_ALARM
	InterconnectDiagnosticsLinkOpticalPower_LOW_WARNING                                                                   = src.InterconnectDiagnosticsLinkOpticalPower_LOW_WARNING
	InterconnectDiagnosticsLinkOpticalPower_OK                                                                            = src.InterconnectDiagnosticsLinkOpticalPower_OK
	InterconnectDiagnosticsLinkOpticalPower_UNDEFINED_STATE                                                               = src.InterconnectDiagnosticsLinkOpticalPower_UNDEFINED_STATE
	InterconnectDiagnosticsLinkStatus_LINK_OPERATIONAL_STATUS_DOWN                                                        = src.InterconnectDiagnosticsLinkStatus_LINK_OPERATIONAL_STATUS_DOWN
	InterconnectDiagnosticsLinkStatus_LINK_OPERATIONAL_STATUS_UP                                                          = src.InterconnectDiagnosticsLinkStatus_LINK_OPERATIONAL_STATUS_UP
	InterconnectDiagnosticsLinkStatus_UNDEFINED_OPERATIONAL_STATUS                                                        = src.InterconnectDiagnosticsLinkStatus_UNDEFINED_OPERATIONAL_STATUS
	InterconnectDiagnostics_BUNDLE_AGGREGATION_TYPE_LACP                                                                  = src.InterconnectDiagnostics_BUNDLE_AGGREGATION_TYPE_LACP
	InterconnectDiagnostics_BUNDLE_AGGREGATION_TYPE_STATIC                                                                = src.InterconnectDiagnostics_BUNDLE_AGGREGATION_TYPE_STATIC
	InterconnectDiagnostics_BUNDLE_OPERATIONAL_STATUS_DOWN                                                                = src.InterconnectDiagnostics_BUNDLE_OPERATIONAL_STATUS_DOWN
	InterconnectDiagnostics_BUNDLE_OPERATIONAL_STATUS_UP                                                                  = src.InterconnectDiagnostics_BUNDLE_OPERATIONAL_STATUS_UP
	InterconnectDiagnostics_UNDEFINED_BUNDLE_AGGREGATION_TYPE                                                             = src.InterconnectDiagnostics_UNDEFINED_BUNDLE_AGGREGATION_TYPE
	InterconnectDiagnostics_UNDEFINED_BUNDLE_OPERATIONAL_STATUS                                                           = src.InterconnectDiagnostics_UNDEFINED_BUNDLE_OPERATIONAL_STATUS
	InterconnectLocationRegionInfo_GLOBAL                                                                                 = src.InterconnectLocationRegionInfo_GLOBAL
	InterconnectLocationRegionInfo_LOCAL_REGION                                                                           = src.InterconnectLocationRegionInfo_LOCAL_REGION
	InterconnectLocationRegionInfo_LP_GLOBAL                                                                              = src.InterconnectLocationRegionInfo_LP_GLOBAL
	InterconnectLocationRegionInfo_LP_LOCAL_REGION                                                                        = src.InterconnectLocationRegionInfo_LP_LOCAL_REGION
	InterconnectLocationRegionInfo_UNDEFINED_LOCATION_PRESENCE                                                            = src.InterconnectLocationRegionInfo_UNDEFINED_LOCATION_PRESENCE
	InterconnectLocation_AFRICA                                                                                           = src.InterconnectLocation_AFRICA
	InterconnectLocation_ASIA_PAC                                                                                         = src.InterconnectLocation_ASIA_PAC
	InterconnectLocation_AVAILABLE                                                                                        = src.InterconnectLocation_AVAILABLE
	InterconnectLocation_CLOSED                                                                                           = src.InterconnectLocation_CLOSED
	InterconnectLocation_C_AFRICA                                                                                         = src.InterconnectLocation_C_AFRICA
	InterconnectLocation_C_ASIA_PAC                                                                                       = src.InterconnectLocation_C_ASIA_PAC
	InterconnectLocation_C_EUROPE                                                                                         = src.InterconnectLocation_C_EUROPE
	InterconnectLocation_C_NORTH_AMERICA                                                                                  = src.InterconnectLocation_C_NORTH_AMERICA
	InterconnectLocation_C_SOUTH_AMERICA                                                                                  = src.InterconnectLocation_C_SOUTH_AMERICA
	InterconnectLocation_EUROPE                                                                                           = src.InterconnectLocation_EUROPE
	InterconnectLocation_IF_MACSEC                                                                                        = src.InterconnectLocation_IF_MACSEC
	InterconnectLocation_LINK_TYPE_ETHERNET_100G_LR                                                                       = src.InterconnectLocation_LINK_TYPE_ETHERNET_100G_LR
	InterconnectLocation_LINK_TYPE_ETHERNET_10G_LR                                                                        = src.InterconnectLocation_LINK_TYPE_ETHERNET_10G_LR
	InterconnectLocation_NORTH_AMERICA                                                                                    = src.InterconnectLocation_NORTH_AMERICA
	InterconnectLocation_SOUTH_AMERICA                                                                                    = src.InterconnectLocation_SOUTH_AMERICA
	InterconnectLocation_UNDEFINED_AVAILABLE_FEATURES                                                                     = src.InterconnectLocation_UNDEFINED_AVAILABLE_FEATURES
	InterconnectLocation_UNDEFINED_AVAILABLE_LINK_TYPES                                                                   = src.InterconnectLocation_UNDEFINED_AVAILABLE_LINK_TYPES
	InterconnectLocation_UNDEFINED_CONTINENT                                                                              = src.InterconnectLocation_UNDEFINED_CONTINENT
	InterconnectLocation_UNDEFINED_STATUS                                                                                 = src.InterconnectLocation_UNDEFINED_STATUS
	InterconnectOutageNotification_ACTIVE                                                                                 = src.InterconnectOutageNotification_ACTIVE
	InterconnectOutageNotification_CANCELLED                                                                              = src.InterconnectOutageNotification_CANCELLED
	InterconnectOutageNotification_COMPLETED                                                                              = src.InterconnectOutageNotification_COMPLETED
	InterconnectOutageNotification_GOOGLE                                                                                 = src.InterconnectOutageNotification_GOOGLE
	InterconnectOutageNotification_IT_OUTAGE                                                                              = src.InterconnectOutageNotification_IT_OUTAGE
	InterconnectOutageNotification_IT_PARTIAL_OUTAGE                                                                      = src.InterconnectOutageNotification_IT_PARTIAL_OUTAGE
	InterconnectOutageNotification_NSRC_GOOGLE                                                                            = src.InterconnectOutageNotification_NSRC_GOOGLE
	InterconnectOutageNotification_NS_ACTIVE                                                                              = src.InterconnectOutageNotification_NS_ACTIVE
	InterconnectOutageNotification_NS_CANCELED                                                                            = src.InterconnectOutageNotification_NS_CANCELED
	InterconnectOutageNotification_OUTAGE                                                                                 = src.InterconnectOutageNotification_OUTAGE
	InterconnectOutageNotification_PARTIAL_OUTAGE                                                                         = src.InterconnectOutageNotification_PARTIAL_OUTAGE
	InterconnectOutageNotification_UNDEFINED_ISSUE_TYPE                                                                   = src.InterconnectOutageNotification_UNDEFINED_ISSUE_TYPE
	InterconnectOutageNotification_UNDEFINED_SOURCE                                                                       = src.InterconnectOutageNotification_UNDEFINED_SOURCE
	InterconnectOutageNotification_UNDEFINED_STATE                                                                        = src.InterconnectOutageNotification_UNDEFINED_STATE
	InterconnectRemoteLocationConstraints_PORT_PAIR_MATCHING_REMOTE_LOCATION                                              = src.InterconnectRemoteLocationConstraints_PORT_PAIR_MATCHING_REMOTE_LOCATION
	InterconnectRemoteLocationConstraints_PORT_PAIR_MATCHING_VLAN                                                         = src.InterconnectRemoteLocationConstraints_PORT_PAIR_MATCHING_VLAN
	InterconnectRemoteLocationConstraints_PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION                                         = src.InterconnectRemoteLocationConstraints_PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION
	InterconnectRemoteLocationConstraints_PORT_PAIR_UNCONSTRAINED_VLAN                                                    = src.InterconnectRemoteLocationConstraints_PORT_PAIR_UNCONSTRAINED_VLAN
	InterconnectRemoteLocationConstraints_UNDEFINED_PORT_PAIR_REMOTE_LOCATION                                             = src.InterconnectRemoteLocationConstraints_UNDEFINED_PORT_PAIR_REMOTE_LOCATION
	InterconnectRemoteLocationConstraints_UNDEFINED_PORT_PAIR_VLAN                                                        = src.InterconnectRemoteLocationConstraints_UNDEFINED_PORT_PAIR_VLAN
	InterconnectRemoteLocation_AFRICA                                                                                     = src.InterconnectRemoteLocation_AFRICA
	InterconnectRemoteLocation_ASIA_PAC                                                                                   = src.InterconnectRemoteLocation_ASIA_PAC
	InterconnectRemoteLocation_AVAILABLE                                                                                  = src.InterconnectRemoteLocation_AVAILABLE
	InterconnectRemoteLocation_CLOSED                                                                                     = src.InterconnectRemoteLocation_CLOSED
	InterconnectRemoteLocation_EUROPE                                                                                     = src.InterconnectRemoteLocation_EUROPE
	InterconnectRemoteLocation_LACP_SUPPORTED                                                                             = src.InterconnectRemoteLocation_LACP_SUPPORTED
	InterconnectRemoteLocation_LACP_UNSUPPORTED                                                                           = src.InterconnectRemoteLocation_LACP_UNSUPPORTED
	InterconnectRemoteLocation_NORTH_AMERICA                                                                              = src.InterconnectRemoteLocation_NORTH_AMERICA
	InterconnectRemoteLocation_SOUTH_AMERICA                                                                              = src.InterconnectRemoteLocation_SOUTH_AMERICA
	InterconnectRemoteLocation_UNDEFINED_CONTINENT                                                                        = src.InterconnectRemoteLocation_UNDEFINED_CONTINENT
	InterconnectRemoteLocation_UNDEFINED_LACP                                                                             = src.InterconnectRemoteLocation_UNDEFINED_LACP
	InterconnectRemoteLocation_UNDEFINED_STATUS                                                                           = src.InterconnectRemoteLocation_UNDEFINED_STATUS
	Interconnect_ACTIVE                                                                                                   = src.Interconnect_ACTIVE
	Interconnect_DEDICATED                                                                                                = src.Interconnect_DEDICATED
	Interconnect_IT_PRIVATE                                                                                               = src.Interconnect_IT_PRIVATE
	Interconnect_LINK_TYPE_ETHERNET_100G_LR                                                                               = src.Interconnect_LINK_TYPE_ETHERNET_100G_LR
	Interconnect_LINK_TYPE_ETHERNET_10G_LR                                                                                = src.Interconnect_LINK_TYPE_ETHERNET_10G_LR
	Interconnect_OS_ACTIVE                                                                                                = src.Interconnect_OS_ACTIVE
	Interconnect_OS_UNPROVISIONED                                                                                         = src.Interconnect_OS_UNPROVISIONED
	Interconnect_PARTNER                                                                                                  = src.Interconnect_PARTNER
	Interconnect_UNDEFINED_AVAILABLE_FEATURES                                                                             = src.Interconnect_UNDEFINED_AVAILABLE_FEATURES
	Interconnect_UNDEFINED_INTERCONNECT_TYPE                                                                              = src.Interconnect_UNDEFINED_INTERCONNECT_TYPE
	Interconnect_UNDEFINED_LINK_TYPE                                                                                      = src.Interconnect_UNDEFINED_LINK_TYPE
	Interconnect_UNDEFINED_OPERATIONAL_STATUS                                                                             = src.Interconnect_UNDEFINED_OPERATIONAL_STATUS
	Interconnect_UNDEFINED_REQUESTED_FEATURES                                                                             = src.Interconnect_UNDEFINED_REQUESTED_FEATURES
	Interconnect_UNDEFINED_STATE                                                                                          = src.Interconnect_UNDEFINED_STATE
	Interconnect_UNPROVISIONED                                                                                            = src.Interconnect_UNPROVISIONED
	LicenseCode_DISABLED                                                                                                  = src.LicenseCode_DISABLED
	LicenseCode_ENABLED                                                                                                   = src.LicenseCode_ENABLED
	LicenseCode_RESTRICTED                                                                                                = src.LicenseCode_RESTRICTED
	LicenseCode_STATE_UNSPECIFIED                                                                                         = src.LicenseCode_STATE_UNSPECIFIED
	LicenseCode_TERMINATED                                                                                                = src.LicenseCode_TERMINATED
	LicenseCode_UNDEFINED_STATE                                                                                           = src.LicenseCode_UNDEFINED_STATE
	ListPeeringRoutesNetworksRequest_INCOMING                                                                             = src.ListPeeringRoutesNetworksRequest_INCOMING
	ListPeeringRoutesNetworksRequest_OUTGOING                                                                             = src.ListPeeringRoutesNetworksRequest_OUTGOING
	ListPeeringRoutesNetworksRequest_UNDEFINED_DIRECTION                                                                  = src.ListPeeringRoutesNetworksRequest_UNDEFINED_DIRECTION
	LocationPolicyLocation_ALLOW                                                                                          = src.LocationPolicyLocation_ALLOW
	LocationPolicyLocation_DENY                                                                                           = src.LocationPolicyLocation_DENY
	LocationPolicyLocation_PREFERENCE_UNSPECIFIED                                                                         = src.LocationPolicyLocation_PREFERENCE_UNSPECIFIED
	LocationPolicyLocation_UNDEFINED_PREFERENCE                                                                           = src.LocationPolicyLocation_UNDEFINED_PREFERENCE
	LocationPolicy_ANY                                                                                                    = src.LocationPolicy_ANY
	LocationPolicy_ANY_SINGLE_ZONE                                                                                        = src.LocationPolicy_ANY_SINGLE_ZONE
	LocationPolicy_BALANCED                                                                                               = src.LocationPolicy_BALANCED
	LocationPolicy_UNDEFINED_TARGET_SHAPE                                                                                 = src.LocationPolicy_UNDEFINED_TARGET_SHAPE
	MachineImage_CREATING                                                                                                 = src.MachineImage_CREATING
	MachineImage_DELETING                                                                                                 = src.MachineImage_DELETING
	MachineImage_INVALID                                                                                                  = src.MachineImage_INVALID
	MachineImage_READY                                                                                                    = src.MachineImage_READY
	MachineImage_UNDEFINED_STATUS                                                                                         = src.MachineImage_UNDEFINED_STATUS
	MachineImage_UPLOADING                                                                                                = src.MachineImage_UPLOADING
	MachineType_ARCHITECTURE_UNSPECIFIED                                                                                  = src.MachineType_ARCHITECTURE_UNSPECIFIED
	MachineType_ARM64                                                                                                     = src.MachineType_ARM64
	MachineType_UNDEFINED_ARCHITECTURE                                                                                    = src.MachineType_UNDEFINED_ARCHITECTURE
	MachineType_X86_64                                                                                                    = src.MachineType_X86_64
	ManagedInstanceInstanceHealth_DRAINING                                                                                = src.ManagedInstanceInstanceHealth_DRAINING
	ManagedInstanceInstanceHealth_HEALTHY                                                                                 = src.ManagedInstanceInstanceHealth_HEALTHY
	ManagedInstanceInstanceHealth_TIMEOUT                                                                                 = src.ManagedInstanceInstanceHealth_TIMEOUT
	ManagedInstanceInstanceHealth_UNDEFINED_DETAILED_HEALTH_STATE                                                         = src.ManagedInstanceInstanceHealth_UNDEFINED_DETAILED_HEALTH_STATE
	ManagedInstanceInstanceHealth_UNHEALTHY                                                                               = src.ManagedInstanceInstanceHealth_UNHEALTHY
	ManagedInstanceInstanceHealth_UNKNOWN                                                                                 = src.ManagedInstanceInstanceHealth_UNKNOWN
	ManagedInstance_ABANDONING                                                                                            = src.ManagedInstance_ABANDONING
	ManagedInstance_CREATING                                                                                              = src.ManagedInstance_CREATING
	ManagedInstance_CREATING_WITHOUT_RETRIES                                                                              = src.ManagedInstance_CREATING_WITHOUT_RETRIES
	ManagedInstance_DELETING                                                                                              = src.ManagedInstance_DELETING
	ManagedInstance_DEPROVISIONING                                                                                        = src.ManagedInstance_DEPROVISIONING
	ManagedInstance_NONE                                                                                                  = src.ManagedInstance_NONE
	ManagedInstance_PROVISIONING                                                                                          = src.ManagedInstance_PROVISIONING
	ManagedInstance_RECREATING                                                                                            = src.ManagedInstance_RECREATING
	ManagedInstance_REFRESHING                                                                                            = src.ManagedInstance_REFRESHING
	ManagedInstance_REPAIRING                                                                                             = src.ManagedInstance_REPAIRING
	ManagedInstance_RESTARTING                                                                                            = src.ManagedInstance_RESTARTING
	ManagedInstance_RESUMING                                                                                              = src.ManagedInstance_RESUMING
	ManagedInstance_RUNNING                                                                                               = src.ManagedInstance_RUNNING
	ManagedInstance_STAGING                                                                                               = src.ManagedInstance_STAGING
	ManagedInstance_STARTING                                                                                              = src.ManagedInstance_STARTING
	ManagedInstance_STOPPED                                                                                               = src.ManagedInstance_STOPPED
	ManagedInstance_STOPPING                                                                                              = src.ManagedInstance_STOPPING
	ManagedInstance_SUSPENDED                                                                                             = src.ManagedInstance_SUSPENDED
	ManagedInstance_SUSPENDING                                                                                            = src.ManagedInstance_SUSPENDING
	ManagedInstance_TERMINATED                                                                                            = src.ManagedInstance_TERMINATED
	ManagedInstance_UNDEFINED_CURRENT_ACTION                                                                              = src.ManagedInstance_UNDEFINED_CURRENT_ACTION
	ManagedInstance_UNDEFINED_INSTANCE_STATUS                                                                             = src.ManagedInstance_UNDEFINED_INSTANCE_STATUS
	ManagedInstance_VERIFYING                                                                                             = src.ManagedInstance_VERIFYING
	MetadataFilter_MATCH_ALL                                                                                              = src.MetadataFilter_MATCH_ALL
	MetadataFilter_MATCH_ANY                                                                                              = src.MetadataFilter_MATCH_ANY
	MetadataFilter_NOT_SET                                                                                                = src.MetadataFilter_NOT_SET
	MetadataFilter_UNDEFINED_FILTER_MATCH_CRITERIA                                                                        = src.MetadataFilter_UNDEFINED_FILTER_MATCH_CRITERIA
	NatIpInfoNatIpInfoMapping_AUTO                                                                                        = src.NatIpInfoNatIpInfoMapping_AUTO
	NatIpInfoNatIpInfoMapping_IN_USE                                                                                      = src.NatIpInfoNatIpInfoMapping_IN_USE
	NatIpInfoNatIpInfoMapping_MANUAL                                                                                      = src.NatIpInfoNatIpInfoMapping_MANUAL
	NatIpInfoNatIpInfoMapping_UNDEFINED_MODE                                                                              = src.NatIpInfoNatIpInfoMapping_UNDEFINED_MODE
	NatIpInfoNatIpInfoMapping_UNDEFINED_USAGE                                                                             = src.NatIpInfoNatIpInfoMapping_UNDEFINED_USAGE
	NatIpInfoNatIpInfoMapping_UNUSED                                                                                      = src.NatIpInfoNatIpInfoMapping_UNUSED
	NetworkAttachmentConnectedEndpoint_ACCEPTED                                                                           = src.NetworkAttachmentConnectedEndpoint_ACCEPTED
	NetworkAttachmentConnectedEndpoint_CLOSED                                                                             = src.NetworkAttachmentConnectedEndpoint_CLOSED
	NetworkAttachmentConnectedEndpoint_NEEDS_ATTENTION                                                                    = src.NetworkAttachmentConnectedEndpoint_NEEDS_ATTENTION
	NetworkAttachmentConnectedEndpoint_PENDING                                                                            = src.NetworkAttachmentConnectedEndpoint_PENDING
	NetworkAttachmentConnectedEndpoint_REJECTED                                                                           = src.NetworkAttachmentConnectedEndpoint_REJECTED
	NetworkAttachmentConnectedEndpoint_STATUS_UNSPECIFIED                                                                 = src.NetworkAttachmentConnectedEndpoint_STATUS_UNSPECIFIED
	NetworkAttachmentConnectedEndpoint_UNDEFINED_STATUS                                                                   = src.NetworkAttachmentConnectedEndpoint_UNDEFINED_STATUS
	NetworkAttachment_ACCEPT_AUTOMATIC                                                                                    = src.NetworkAttachment_ACCEPT_AUTOMATIC
	NetworkAttachment_ACCEPT_MANUAL                                                                                       = src.NetworkAttachment_ACCEPT_MANUAL
	NetworkAttachment_INVALID                                                                                             = src.NetworkAttachment_INVALID
	NetworkAttachment_UNDEFINED_CONNECTION_PREFERENCE                                                                     = src.NetworkAttachment_UNDEFINED_CONNECTION_PREFERENCE
	NetworkEndpointGroupPscData_ACCEPTED                                                                                  = src.NetworkEndpointGroupPscData_ACCEPTED
	NetworkEndpointGroupPscData_CLOSED                                                                                    = src.NetworkEndpointGroupPscData_CLOSED
	NetworkEndpointGroupPscData_NEEDS_ATTENTION                                                                           = src.NetworkEndpointGroupPscData_NEEDS_ATTENTION
	NetworkEndpointGroupPscData_PENDING                                                                                   = src.NetworkEndpointGroupPscData_PENDING
	NetworkEndpointGroupPscData_REJECTED                                                                                  = src.NetworkEndpointGroupPscData_REJECTED
	NetworkEndpointGroupPscData_STATUS_UNSPECIFIED                                                                        = src.NetworkEndpointGroupPscData_STATUS_UNSPECIFIED
	NetworkEndpointGroupPscData_UNDEFINED_PSC_CONNECTION_STATUS                                                           = src.NetworkEndpointGroupPscData_UNDEFINED_PSC_CONNECTION_STATUS
	NetworkEndpointGroup_GCE_VM_IP                                                                                        = src.NetworkEndpointGroup_GCE_VM_IP
	NetworkEndpointGroup_GCE_VM_IP_PORT                                                                                   = src.NetworkEndpointGroup_GCE_VM_IP_PORT
	NetworkEndpointGroup_GCE_VM_IP_PORTMAP                                                                                = src.NetworkEndpointGroup_GCE_VM_IP_PORTMAP
	NetworkEndpointGroup_INTERNET_FQDN_PORT                                                                               = src.NetworkEndpointGroup_INTERNET_FQDN_PORT
	NetworkEndpointGroup_INTERNET_IP_PORT                                                                                 = src.NetworkEndpointGroup_INTERNET_IP_PORT
	NetworkEndpointGroup_NON_GCP_PRIVATE_IP_PORT                                                                          = src.NetworkEndpointGroup_NON_GCP_PRIVATE_IP_PORT
	NetworkEndpointGroup_PRIVATE_SERVICE_CONNECT                                                                          = src.NetworkEndpointGroup_PRIVATE_SERVICE_CONNECT
	NetworkEndpointGroup_SERVERLESS                                                                                       = src.NetworkEndpointGroup_SERVERLESS
	NetworkEndpointGroup_UNDEFINED_NETWORK_ENDPOINT_TYPE                                                                  = src.NetworkEndpointGroup_UNDEFINED_NETWORK_ENDPOINT_TYPE
	NetworkEndpointGroupsListEndpointsRequest_SHOW                                                                        = src.NetworkEndpointGroupsListEndpointsRequest_SHOW
	NetworkEndpointGroupsListEndpointsRequest_SKIP                                                                        = src.NetworkEndpointGroupsListEndpointsRequest_SKIP
	NetworkEndpointGroupsListEndpointsRequest_UNDEFINED_HEALTH_STATUS                                                     = src.NetworkEndpointGroupsListEndpointsRequest_UNDEFINED_HEALTH_STATUS
	NetworkInterface_EXTERNAL                                                                                             = src.NetworkInterface_EXTERNAL
	NetworkInterface_GVNIC                                                                                                = src.NetworkInterface_GVNIC
	NetworkInterface_IDPF                                                                                                 = src.NetworkInterface_IDPF
	NetworkInterface_INTERNAL                                                                                             = src.NetworkInterface_INTERNAL
	NetworkInterface_IPV4_IPV6                                                                                            = src.NetworkInterface_IPV4_IPV6
	NetworkInterface_IPV4_ONLY                                                                                            = src.NetworkInterface_IPV4_ONLY
	NetworkInterface_IPV6_ONLY                                                                                            = src.NetworkInterface_IPV6_ONLY
	NetworkInterface_UNDEFINED_IPV6_ACCESS_TYPE                                                                           = src.NetworkInterface_UNDEFINED_IPV6_ACCESS_TYPE
	NetworkInterface_UNDEFINED_NIC_TYPE                                                                                   = src.NetworkInterface_UNDEFINED_NIC_TYPE
	NetworkInterface_UNDEFINED_STACK_TYPE                                                                                 = src.NetworkInterface_UNDEFINED_STACK_TYPE
	NetworkInterface_UNSPECIFIED_IPV6_ACCESS_TYPE                                                                         = src.NetworkInterface_UNSPECIFIED_IPV6_ACCESS_TYPE
	NetworkInterface_UNSPECIFIED_NIC_TYPE                                                                                 = src.NetworkInterface_UNSPECIFIED_NIC_TYPE
	NetworkInterface_UNSPECIFIED_STACK_TYPE                                                                               = src.NetworkInterface_UNSPECIFIED_STACK_TYPE
	NetworkInterface_VIRTIO_NET                                                                                           = src.NetworkInterface_VIRTIO_NET
	NetworkPeering_ACTIVE                                                                                                 = src.NetworkPeering_ACTIVE
	NetworkPeering_INACTIVE                                                                                               = src.NetworkPeering_INACTIVE
	NetworkPeering_IPV4_IPV6                                                                                              = src.NetworkPeering_IPV4_IPV6
	NetworkPeering_IPV4_ONLY                                                                                              = src.NetworkPeering_IPV4_ONLY
	NetworkPeering_UNDEFINED_STACK_TYPE                                                                                   = src.NetworkPeering_UNDEFINED_STACK_TYPE
	NetworkPeering_UNDEFINED_STATE                                                                                        = src.NetworkPeering_UNDEFINED_STATE
	NetworkPerformanceConfig_DEFAULT                                                                                      = src.NetworkPerformanceConfig_DEFAULT
	NetworkPerformanceConfig_TIER_1                                                                                       = src.NetworkPerformanceConfig_TIER_1
	NetworkPerformanceConfig_UNDEFINED_TOTAL_EGRESS_BANDWIDTH_TIER                                                        = src.NetworkPerformanceConfig_UNDEFINED_TOTAL_EGRESS_BANDWIDTH_TIER
	NetworkRoutingConfig_GLOBAL                                                                                           = src.NetworkRoutingConfig_GLOBAL
	NetworkRoutingConfig_REGIONAL                                                                                         = src.NetworkRoutingConfig_REGIONAL
	NetworkRoutingConfig_UNDEFINED_ROUTING_MODE                                                                           = src.NetworkRoutingConfig_UNDEFINED_ROUTING_MODE
	Network_AFTER_CLASSIC_FIREWALL                                                                                        = src.Network_AFTER_CLASSIC_FIREWALL
	Network_BEFORE_CLASSIC_FIREWALL                                                                                       = src.Network_BEFORE_CLASSIC_FIREWALL
	Network_UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER                                                           = src.Network_UNDEFINED_NETWORK_FIREWALL_POLICY_ENFORCEMENT_ORDER
	NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_HIERARCHY                                                = src.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_HIERARCHY
	NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_NETWORK                                                  = src.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_NETWORK
	NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_SYSTEM                                                   = src.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_SYSTEM
	NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNDEFINED_TYPE                                           = src.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNDEFINED_TYPE
	NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNSPECIFIED                                              = src.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNSPECIFIED
	NodeGroupAutoscalingPolicy_MODE_UNSPECIFIED                                                                           = src.NodeGroupAutoscalingPolicy_MODE_UNSPECIFIED
	NodeGroupAutoscalingPolicy_OFF                                                                                        = src.NodeGroupAutoscalingPolicy_OFF
	NodeGroupAutoscalingPolicy_ON                                                                                         = src.NodeGroupAutoscalingPolicy_ON
	NodeGroupAutoscalingPolicy_ONLY_SCALE_OUT                                                                             = src.NodeGroupAutoscalingPolicy_ONLY_SCALE_OUT
	NodeGroupAutoscalingPolicy_UNDEFINED_MODE                                                                             = src.NodeGroupAutoscalingPolicy_UNDEFINED_MODE
	NodeGroupNode_CPU_OVERCOMMIT_TYPE_UNSPECIFIED                                                                         = src.NodeGroupNode_CPU_OVERCOMMIT_TYPE_UNSPECIFIED
	NodeGroupNode_CREATING                                                                                                = src.NodeGroupNode_CREATING
	NodeGroupNode_DELETING                                                                                                = src.NodeGroupNode_DELETING
	NodeGroupNode_ENABLED                                                                                                 = src.NodeGroupNode_ENABLED
	NodeGroupNode_INVALID                                                                                                 = src.NodeGroupNode_INVALID
	NodeGroupNode_NONE                                                                                                    = src.NodeGroupNode_NONE
	NodeGroupNode_READY                                                                                                   = src.NodeGroupNode_READY
	NodeGroupNode_REPAIRING                                                                                               = src.NodeGroupNode_REPAIRING
	NodeGroupNode_UNDEFINED_CPU_OVERCOMMIT_TYPE                                                                           = src.NodeGroupNode_UNDEFINED_CPU_OVERCOMMIT_TYPE
	NodeGroupNode_UNDEFINED_STATUS                                                                                        = src.NodeGroupNode_UNDEFINED_STATUS
	NodeGroup_AS_NEEDED                                                                                                   = src.NodeGroup_AS_NEEDED
	NodeGroup_CREATING                                                                                                    = src.NodeGroup_CREATING
	NodeGroup_DEFAULT                                                                                                     = src.NodeGroup_DEFAULT
	NodeGroup_DELETING                                                                                                    = src.NodeGroup_DELETING
	NodeGroup_INVALID                                                                                                     = src.NodeGroup_INVALID
	NodeGroup_MAINTENANCE_POLICY_UNSPECIFIED                                                                              = src.NodeGroup_MAINTENANCE_POLICY_UNSPECIFIED
	NodeGroup_MIGRATE_WITHIN_NODE_GROUP                                                                                   = src.NodeGroup_MIGRATE_WITHIN_NODE_GROUP
	NodeGroup_READY                                                                                                       = src.NodeGroup_READY
	NodeGroup_RECURRENT                                                                                                   = src.NodeGroup_RECURRENT
	NodeGroup_RESTART_IN_PLACE                                                                                            = src.NodeGroup_RESTART_IN_PLACE
	NodeGroup_UNDEFINED_MAINTENANCE_INTERVAL                                                                              = src.NodeGroup_UNDEFINED_MAINTENANCE_INTERVAL
	NodeGroup_UNDEFINED_MAINTENANCE_POLICY                                                                                = src.NodeGroup_UNDEFINED_MAINTENANCE_POLICY
	NodeGroup_UNDEFINED_STATUS                                                                                            = src.NodeGroup_UNDEFINED_STATUS
	NodeTemplate_CPU_OVERCOMMIT_TYPE_UNSPECIFIED                                                                          = src.NodeTemplate_CPU_OVERCOMMIT_TYPE_UNSPECIFIED
	NodeTemplate_CREATING                                                                                                 = src.NodeTemplate_CREATING
	NodeTemplate_DELETING                                                                                                 = src.NodeTemplate_DELETING
	NodeTemplate_ENABLED                                                                                                  = src.NodeTemplate_ENABLED
	NodeTemplate_INVALID                                                                                                  = src.NodeTemplate_INVALID
	NodeTemplate_NONE                                                                                                     = src.NodeTemplate_NONE
	NodeTemplate_READY                                                                                                    = src.NodeTemplate_READY
	NodeTemplate_UNDEFINED_CPU_OVERCOMMIT_TYPE                                                                            = src.NodeTemplate_UNDEFINED_CPU_OVERCOMMIT_TYPE
	NodeTemplate_UNDEFINED_STATUS                                                                                         = src.NodeTemplate_UNDEFINED_STATUS
	Operation_DONE                                                                                                        = src.Operation_DONE
	Operation_PENDING                                                                                                     = src.Operation_PENDING
	Operation_RUNNING                                                                                                     = src.Operation_RUNNING
	Operation_UNDEFINED_STATUS                                                                                            = src.Operation_UNDEFINED_STATUS
	PacketIntervals_DURATION_UNSPECIFIED                                                                                  = src.PacketIntervals_DURATION_UNSPECIFIED
	PacketIntervals_HOUR                                                                                                  = src.PacketIntervals_HOUR
	PacketIntervals_LOOPBACK                                                                                              = src.PacketIntervals_LOOPBACK
	PacketIntervals_MAX                                                                                                   = src.PacketIntervals_MAX
	PacketIntervals_MINUTE                                                                                                = src.PacketIntervals_MINUTE
	PacketIntervals_RECEIVE                                                                                               = src.PacketIntervals_RECEIVE
	PacketIntervals_TRANSMIT                                                                                              = src.PacketIntervals_TRANSMIT
	PacketIntervals_TYPE_UNSPECIFIED                                                                                      = src.PacketIntervals_TYPE_UNSPECIFIED
	PacketIntervals_UNDEFINED_DURATION                                                                                    = src.PacketIntervals_UNDEFINED_DURATION
	PacketIntervals_UNDEFINED_TYPE                                                                                        = src.PacketIntervals_UNDEFINED_TYPE
	PacketMirroringFilter_BOTH                                                                                            = src.PacketMirroringFilter_BOTH
	PacketMirroringFilter_EGRESS                                                                                          = src.PacketMirroringFilter_EGRESS
	PacketMirroringFilter_INGRESS                                                                                         = src.PacketMirroringFilter_INGRESS
	PacketMirroringFilter_UNDEFINED_DIRECTION                                                                             = src.PacketMirroringFilter_UNDEFINED_DIRECTION
	PacketMirroring_FALSE                                                                                                 = src.PacketMirroring_FALSE
	PacketMirroring_TRUE                                                                                                  = src.PacketMirroring_TRUE
	PacketMirroring_UNDEFINED_ENABLE                                                                                      = src.PacketMirroring_UNDEFINED_ENABLE
	PerInstanceConfig_APPLYING                                                                                            = src.PerInstanceConfig_APPLYING
	PerInstanceConfig_DELETING                                                                                            = src.PerInstanceConfig_DELETING
	PerInstanceConfig_EFFECTIVE                                                                                           = src.PerInstanceConfig_EFFECTIVE
	PerInstanceConfig_NONE                                                                                                = src.PerInstanceConfig_NONE
	PerInstanceConfig_UNAPPLIED                                                                                           = src.PerInstanceConfig_UNAPPLIED
	PerInstanceConfig_UNAPPLIED_DELETION                                                                                  = src.PerInstanceConfig_UNAPPLIED_DELETION
	PerInstanceConfig_UNDEFINED_STATUS                                                                                    = src.PerInstanceConfig_UNDEFINED_STATUS
	PreservedStatePreservedDisk_NEVER                                                                                     = src.PreservedStatePreservedDisk_NEVER
	PreservedStatePreservedDisk_ON_PERMANENT_INSTANCE_DELETION                                                            = src.PreservedStatePreservedDisk_ON_PERMANENT_INSTANCE_DELETION
	PreservedStatePreservedDisk_READ_ONLY                                                                                 = src.PreservedStatePreservedDisk_READ_ONLY
	PreservedStatePreservedDisk_READ_WRITE                                                                                = src.PreservedStatePreservedDisk_READ_WRITE
	PreservedStatePreservedDisk_UNDEFINED_AUTO_DELETE                                                                     = src.PreservedStatePreservedDisk_UNDEFINED_AUTO_DELETE
	PreservedStatePreservedDisk_UNDEFINED_MODE                                                                            = src.PreservedStatePreservedDisk_UNDEFINED_MODE
	PreservedStatePreservedNetworkIp_NEVER                                                                                = src.PreservedStatePreservedNetworkIp_NEVER
	PreservedStatePreservedNetworkIp_ON_PERMANENT_INSTANCE_DELETION                                                       = src.PreservedStatePreservedNetworkIp_ON_PERMANENT_INSTANCE_DELETION
	PreservedStatePreservedNetworkIp_UNDEFINED_AUTO_DELETE                                                                = src.PreservedStatePreservedNetworkIp_UNDEFINED_AUTO_DELETE
	Project_CA_ENTERPRISE_ANNUAL                                                                                          = src.Project_CA_ENTERPRISE_ANNUAL
	Project_CA_ENTERPRISE_PAYGO                                                                                           = src.Project_CA_ENTERPRISE_PAYGO
	Project_CA_STANDARD                                                                                                   = src.Project_CA_STANDARD
	Project_FIXED_STANDARD                                                                                                = src.Project_FIXED_STANDARD
	Project_GLOBAL_DEFAULT                                                                                                = src.Project_GLOBAL_DEFAULT
	Project_HOST                                                                                                          = src.Project_HOST
	Project_PREMIUM                                                                                                       = src.Project_PREMIUM
	Project_STANDARD                                                                                                      = src.Project_STANDARD
	Project_STANDARD_OVERRIDES_FIXED_STANDARD                                                                             = src.Project_STANDARD_OVERRIDES_FIXED_STANDARD
	Project_UNDEFINED_CLOUD_ARMOR_TIER                                                                                    = src.Project_UNDEFINED_CLOUD_ARMOR_TIER
	Project_UNDEFINED_DEFAULT_NETWORK_TIER                                                                                = src.Project_UNDEFINED_DEFAULT_NETWORK_TIER
	Project_UNDEFINED_VM_DNS_SETTING                                                                                      = src.Project_UNDEFINED_VM_DNS_SETTING
	Project_UNDEFINED_XPN_PROJECT_STATUS                                                                                  = src.Project_UNDEFINED_XPN_PROJECT_STATUS
	Project_UNSPECIFIED_VM_DNS_SETTING                                                                                    = src.Project_UNSPECIFIED_VM_DNS_SETTING
	Project_UNSPECIFIED_XPN_PROJECT_STATUS                                                                                = src.Project_UNSPECIFIED_XPN_PROJECT_STATUS
	Project_ZONAL_DEFAULT                                                                                                 = src.Project_ZONAL_DEFAULT
	Project_ZONAL_ONLY                                                                                                    = src.Project_ZONAL_ONLY
	ProjectsSetCloudArmorTierRequest_CA_ENTERPRISE_ANNUAL                                                                 = src.ProjectsSetCloudArmorTierRequest_CA_ENTERPRISE_ANNUAL
	ProjectsSetCloudArmorTierRequest_CA_ENTERPRISE_PAYGO                                                                  = src.ProjectsSetCloudArmorTierRequest_CA_ENTERPRISE_PAYGO
	ProjectsSetCloudArmorTierRequest_CA_STANDARD                                                                          = src.ProjectsSetCloudArmorTierRequest_CA_STANDARD
	ProjectsSetCloudArmorTierRequest_UNDEFINED_CLOUD_ARMOR_TIER                                                           = src.ProjectsSetCloudArmorTierRequest_UNDEFINED_CLOUD_ARMOR_TIER
	ProjectsSetDefaultNetworkTierRequest_FIXED_STANDARD                                                                   = src.ProjectsSetDefaultNetworkTierRequest_FIXED_STANDARD
	ProjectsSetDefaultNetworkTierRequest_PREMIUM                                                                          = src.ProjectsSetDefaultNetworkTierRequest_PREMIUM
	ProjectsSetDefaultNetworkTierRequest_STANDARD                                                                         = src.ProjectsSetDefaultNetworkTierRequest_STANDARD
	ProjectsSetDefaultNetworkTierRequest_STANDARD_OVERRIDES_FIXED_STANDARD                                                = src.ProjectsSetDefaultNetworkTierRequest_STANDARD_OVERRIDES_FIXED_STANDARD
	ProjectsSetDefaultNetworkTierRequest_UNDEFINED_NETWORK_TIER                                                           = src.ProjectsSetDefaultNetworkTierRequest_UNDEFINED_NETWORK_TIER
	PublicAdvertisedPrefix_ANNOUNCED_TO_INTERNET                                                                          = src.PublicAdvertisedPrefix_ANNOUNCED_TO_INTERNET
	PublicAdvertisedPrefix_GLOBAL                                                                                         = src.PublicAdvertisedPrefix_GLOBAL
	PublicAdvertisedPrefix_GLOBAL_AND_REGIONAL                                                                            = src.PublicAdvertisedPrefix_GLOBAL_AND_REGIONAL
	PublicAdvertisedPrefix_INITIAL                                                                                        = src.PublicAdvertisedPrefix_INITIAL
	PublicAdvertisedPrefix_PREFIX_CONFIGURATION_COMPLETE                                                                  = src.PublicAdvertisedPrefix_PREFIX_CONFIGURATION_COMPLETE
	PublicAdvertisedPrefix_PREFIX_CONFIGURATION_IN_PROGRESS                                                               = src.PublicAdvertisedPrefix_PREFIX_CONFIGURATION_IN_PROGRESS
	PublicAdvertisedPrefix_PREFIX_REMOVAL_IN_PROGRESS                                                                     = src.PublicAdvertisedPrefix_PREFIX_REMOVAL_IN_PROGRESS
	PublicAdvertisedPrefix_PTR_CONFIGURED                                                                                 = src.PublicAdvertisedPrefix_PTR_CONFIGURED
	PublicAdvertisedPrefix_READY_TO_ANNOUNCE                                                                              = src.PublicAdvertisedPrefix_READY_TO_ANNOUNCE
	PublicAdvertisedPrefix_REGIONAL                                                                                       = src.PublicAdvertisedPrefix_REGIONAL
	PublicAdvertisedPrefix_REVERSE_DNS_LOOKUP_FAILED                                                                      = src.PublicAdvertisedPrefix_REVERSE_DNS_LOOKUP_FAILED
	PublicAdvertisedPrefix_UNDEFINED_BYOIP_API_VERSION                                                                    = src.PublicAdvertisedPrefix_UNDEFINED_BYOIP_API_VERSION
	PublicAdvertisedPrefix_UNDEFINED_PDP_SCOPE                                                                            = src.PublicAdvertisedPrefix_UNDEFINED_PDP_SCOPE
	PublicAdvertisedPrefix_UNDEFINED_STATUS                                                                               = src.PublicAdvertisedPrefix_UNDEFINED_STATUS
	PublicAdvertisedPrefix_V1                                                                                             = src.PublicAdvertisedPrefix_V1
	PublicAdvertisedPrefix_V2                                                                                             = src.PublicAdvertisedPrefix_V2
	PublicAdvertisedPrefix_VALIDATED                                                                                      = src.PublicAdvertisedPrefix_VALIDATED
	PublicDelegatedPrefixPublicDelegatedSubPrefix_ACTIVE                                                                  = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_ACTIVE
	PublicDelegatedPrefixPublicDelegatedSubPrefix_DELEGATION                                                              = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_DELEGATION
	PublicDelegatedPrefixPublicDelegatedSubPrefix_EXTERNAL_IPV6_FORWARDING_RULE_CREATION                                  = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_EXTERNAL_IPV6_FORWARDING_RULE_CREATION
	PublicDelegatedPrefixPublicDelegatedSubPrefix_INACTIVE                                                                = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_INACTIVE
	PublicDelegatedPrefixPublicDelegatedSubPrefix_UNDEFINED_MODE                                                          = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_UNDEFINED_MODE
	PublicDelegatedPrefixPublicDelegatedSubPrefix_UNDEFINED_STATUS                                                        = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_UNDEFINED_STATUS
	PublicDelegatedPrefix_ANNOUNCED                                                                                       = src.PublicDelegatedPrefix_ANNOUNCED
	PublicDelegatedPrefix_ANNOUNCED_TO_GOOGLE                                                                             = src.PublicDelegatedPrefix_ANNOUNCED_TO_GOOGLE
	PublicDelegatedPrefix_ANNOUNCED_TO_INTERNET                                                                           = src.PublicDelegatedPrefix_ANNOUNCED_TO_INTERNET
	PublicDelegatedPrefix_DELEGATION                                                                                      = src.PublicDelegatedPrefix_DELEGATION
	PublicDelegatedPrefix_DELETING                                                                                        = src.PublicDelegatedPrefix_DELETING
	PublicDelegatedPrefix_EXTERNAL_IPV6_FORWARDING_RULE_CREATION                                                          = src.PublicDelegatedPrefix_EXTERNAL_IPV6_FORWARDING_RULE_CREATION
	PublicDelegatedPrefix_INITIALIZING                                                                                    = src.PublicDelegatedPrefix_INITIALIZING
	PublicDelegatedPrefix_READY_TO_ANNOUNCE                                                                               = src.PublicDelegatedPrefix_READY_TO_ANNOUNCE
	PublicDelegatedPrefix_UNDEFINED_BYOIP_API_VERSION                                                                     = src.PublicDelegatedPrefix_UNDEFINED_BYOIP_API_VERSION
	PublicDelegatedPrefix_UNDEFINED_MODE                                                                                  = src.PublicDelegatedPrefix_UNDEFINED_MODE
	PublicDelegatedPrefix_UNDEFINED_STATUS                                                                                = src.PublicDelegatedPrefix_UNDEFINED_STATUS
	PublicDelegatedPrefix_V1                                                                                              = src.PublicDelegatedPrefix_V1
	PublicDelegatedPrefix_V2                                                                                              = src.PublicDelegatedPrefix_V2
	QuotaExceededInfo_IN_PROGRESS                                                                                         = src.QuotaExceededInfo_IN_PROGRESS
	QuotaExceededInfo_ROLLOUT_STATUS_UNSPECIFIED                                                                          = src.QuotaExceededInfo_ROLLOUT_STATUS_UNSPECIFIED
	QuotaExceededInfo_UNDEFINED_ROLLOUT_STATUS                                                                            = src.QuotaExceededInfo_UNDEFINED_ROLLOUT_STATUS
	QuotaStatusWarning_CLEANUP_FAILED                                                                                     = src.QuotaStatusWarning_CLEANUP_FAILED
	QuotaStatusWarning_DEPRECATED_RESOURCE_USED                                                                           = src.QuotaStatusWarning_DEPRECATED_RESOURCE_USED
	QuotaStatusWarning_DEPRECATED_TYPE_USED                                                                               = src.QuotaStatusWarning_DEPRECATED_TYPE_USED
	QuotaStatusWarning_DISK_SIZE_LARGER_THAN_IMAGE_SIZE                                                                   = src.QuotaStatusWarning_DISK_SIZE_LARGER_THAN_IMAGE_SIZE
	QuotaStatusWarning_EXPERIMENTAL_TYPE_USED                                                                             = src.QuotaStatusWarning_EXPERIMENTAL_TYPE_USED
	QuotaStatusWarning_EXTERNAL_API_WARNING                                                                               = src.QuotaStatusWarning_EXTERNAL_API_WARNING
	QuotaStatusWarning_FIELD_VALUE_OVERRIDEN                                                                              = src.QuotaStatusWarning_FIELD_VALUE_OVERRIDEN
	QuotaStatusWarning_INJECTED_KERNELS_DEPRECATED                                                                        = src.QuotaStatusWarning_INJECTED_KERNELS_DEPRECATED
	QuotaStatusWarning_INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB                                                       = src.QuotaStatusWarning_INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB
	QuotaStatusWarning_LARGE_DEPLOYMENT_WARNING                                                                           = src.QuotaStatusWarning_LARGE_DEPLOYMENT_WARNING
	QuotaStatusWarning_LIST_OVERHEAD_QUOTA_EXCEED                                                                         = src.QuotaStatusWarning_LIST_OVERHEAD_QUOTA_EXCEED
	QuotaStatusWarning_MISSING_TYPE_DEPENDENCY                                                                            = src.QuotaStatusWarning_MISSING_TYPE_DEPENDENCY
	QuotaStatusWarning_NEXT_HOP_ADDRESS_NOT_ASSIGNED                                                                      = src.QuotaStatusWarning_NEXT_HOP_ADDRESS_NOT_ASSIGNED
	QuotaStatusWarning_NEXT_HOP_CANNOT_IP_FORWARD                                                                         = src.QuotaStatusWarning_NEXT_HOP_CANNOT_IP_FORWARD
	QuotaStatusWarning_NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE                                                            = src.QuotaStatusWarning_NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE
	QuotaStatusWarning_NEXT_HOP_INSTANCE_NOT_FOUND                                                                        = src.QuotaStatusWarning_NEXT_HOP_INSTANCE_NOT_FOUND
	QuotaStatusWarning_NEXT_HOP_INSTANCE_NOT_ON_NETWORK                                                                   = src.QuotaStatusWarning_NEXT_HOP_INSTANCE_NOT_ON_NETWORK
	QuotaStatusWarning_NEXT_HOP_NOT_RUNNING                                                                               = src.QuotaStatusWarning_NEXT_HOP_NOT_RUNNING
	QuotaStatusWarning_NOT_CRITICAL_ERROR                                                                                 = src.QuotaStatusWarning_NOT_CRITICAL_ERROR
	QuotaStatusWarning_NO_RESULTS_ON_PAGE                                                                                 = src.QuotaStatusWarning_NO_RESULTS_ON_PAGE
	QuotaStatusWarning_PARTIAL_SUCCESS                                                                                    = src.QuotaStatusWarning_PARTIAL_SUCCESS
	QuotaStatusWarning_REQUIRED_TOS_AGREEMENT                                                                             = src.QuotaStatusWarning_REQUIRED_TOS_AGREEMENT
	QuotaStatusWarning_RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING                                                          = src.QuotaStatusWarning_RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING
	QuotaStatusWarning_RESOURCE_NOT_DELETED                                                                               = src.QuotaStatusWarning_RESOURCE_NOT_DELETED
	QuotaStatusWarning_SCHEMA_VALIDATION_IGNORED                                                                          = src.QuotaStatusWarning_SCHEMA_VALIDATION_IGNORED
	QuotaStatusWarning_SINGLE_INSTANCE_PROPERTY_TEMPLATE                                                                  = src.QuotaStatusWarning_SINGLE_INSTANCE_PROPERTY_TEMPLATE
	QuotaStatusWarning_UNDECLARED_PROPERTIES                                                                              = src.QuotaStatusWarning_UNDECLARED_PROPERTIES
	QuotaStatusWarning_UNDEFINED_CODE                                                                                     = src.QuotaStatusWarning_UNDEFINED_CODE
	QuotaStatusWarning_UNREACHABLE                                                                                        = src.QuotaStatusWarning_UNREACHABLE
	Quota_A2_CPUS                                                                                                         = src.Quota_A2_CPUS
	Quota_AFFINITY_GROUPS                                                                                                 = src.Quota_AFFINITY_GROUPS
	Quota_AUTOSCALERS                                                                                                     = src.Quota_AUTOSCALERS
	Quota_BACKEND_BUCKETS                                                                                                 = src.Quota_BACKEND_BUCKETS
	Quota_BACKEND_SERVICES                                                                                                = src.Quota_BACKEND_SERVICES
	Quota_C2D_CPUS                                                                                                        = src.Quota_C2D_CPUS
	Quota_C2_CPUS                                                                                                         = src.Quota_C2_CPUS
	Quota_C3_CPUS                                                                                                         = src.Quota_C3_CPUS
	Quota_COMMITMENTS                                                                                                     = src.Quota_COMMITMENTS
	Quota_COMMITTED_A2_CPUS                                                                                               = src.Quota_COMMITTED_A2_CPUS
	Quota_COMMITTED_C2D_CPUS                                                                                              = src.Quota_COMMITTED_C2D_CPUS
	Quota_COMMITTED_C2_CPUS                                                                                               = src.Quota_COMMITTED_C2_CPUS
	Quota_COMMITTED_C3_CPUS                                                                                               = src.Quota_COMMITTED_C3_CPUS
	Quota_COMMITTED_CPUS                                                                                                  = src.Quota_COMMITTED_CPUS
	Quota_COMMITTED_E2_CPUS                                                                                               = src.Quota_COMMITTED_E2_CPUS
	Quota_COMMITTED_LICENSES                                                                                              = src.Quota_COMMITTED_LICENSES
	Quota_COMMITTED_LOCAL_SSD_TOTAL_GB                                                                                    = src.Quota_COMMITTED_LOCAL_SSD_TOTAL_GB
	Quota_COMMITTED_M3_CPUS                                                                                               = src.Quota_COMMITTED_M3_CPUS
	Quota_COMMITTED_MEMORY_OPTIMIZED_CPUS                                                                                 = src.Quota_COMMITTED_MEMORY_OPTIMIZED_CPUS
	Quota_COMMITTED_N2A_CPUS                                                                                              = src.Quota_COMMITTED_N2A_CPUS
	Quota_COMMITTED_N2D_CPUS                                                                                              = src.Quota_COMMITTED_N2D_CPUS
	Quota_COMMITTED_N2_CPUS                                                                                               = src.Quota_COMMITTED_N2_CPUS
	Quota_COMMITTED_NVIDIA_A100_80GB_GPUS                                                                                 = src.Quota_COMMITTED_NVIDIA_A100_80GB_GPUS
	Quota_COMMITTED_NVIDIA_A100_GPUS                                                                                      = src.Quota_COMMITTED_NVIDIA_A100_GPUS
	Quota_COMMITTED_NVIDIA_H100_GPUS                                                                                      = src.Quota_COMMITTED_NVIDIA_H100_GPUS
	Quota_COMMITTED_NVIDIA_K80_GPUS                                                                                       = src.Quota_COMMITTED_NVIDIA_K80_GPUS
	Quota_COMMITTED_NVIDIA_L4_GPUS                                                                                        = src.Quota_COMMITTED_NVIDIA_L4_GPUS
	Quota_COMMITTED_NVIDIA_P100_GPUS                                                                                      = src.Quota_COMMITTED_NVIDIA_P100_GPUS
	Quota_COMMITTED_NVIDIA_P4_GPUS                                                                                        = src.Quota_COMMITTED_NVIDIA_P4_GPUS
	Quota_COMMITTED_NVIDIA_T4_GPUS                                                                                        = src.Quota_COMMITTED_NVIDIA_T4_GPUS
	Quota_COMMITTED_NVIDIA_V100_GPUS                                                                                      = src.Quota_COMMITTED_NVIDIA_V100_GPUS
	Quota_COMMITTED_T2A_CPUS                                                                                              = src.Quota_COMMITTED_T2A_CPUS
	Quota_COMMITTED_T2D_CPUS                                                                                              = src.Quota_COMMITTED_T2D_CPUS
	Quota_COMMITTED_Z3_CPUS                                                                                               = src.Quota_COMMITTED_Z3_CPUS
	Quota_CPUS                                                                                                            = src.Quota_CPUS
	Quota_CPUS_ALL_REGIONS                                                                                                = src.Quota_CPUS_ALL_REGIONS
	Quota_DISKS_TOTAL_GB                                                                                                  = src.Quota_DISKS_TOTAL_GB
	Quota_E2_CPUS                                                                                                         = src.Quota_E2_CPUS
	Quota_EXTERNAL_MANAGED_FORWARDING_RULES                                                                               = src.Quota_EXTERNAL_MANAGED_FORWARDING_RULES
	Quota_EXTERNAL_NETWORK_LB_FORWARDING_RULES                                                                            = src.Quota_EXTERNAL_NETWORK_LB_FORWARDING_RULES
	Quota_EXTERNAL_PROTOCOL_FORWARDING_RULES                                                                              = src.Quota_EXTERNAL_PROTOCOL_FORWARDING_RULES
	Quota_EXTERNAL_VPN_GATEWAYS                                                                                           = src.Quota_EXTERNAL_VPN_GATEWAYS
	Quota_FIREWALLS                                                                                                       = src.Quota_FIREWALLS
	Quota_FORWARDING_RULES                                                                                                = src.Quota_FORWARDING_RULES
	Quota_GLOBAL_EXTERNAL_MANAGED_BACKEND_SERVICES                                                                        = src.Quota_GLOBAL_EXTERNAL_MANAGED_BACKEND_SERVICES
	Quota_GLOBAL_EXTERNAL_MANAGED_FORWARDING_RULES                                                                        = src.Quota_GLOBAL_EXTERNAL_MANAGED_FORWARDING_RULES
	Quota_GLOBAL_EXTERNAL_PROXY_LB_BACKEND_SERVICES                                                                       = src.Quota_GLOBAL_EXTERNAL_PROXY_LB_BACKEND_SERVICES
	Quota_GLOBAL_INTERNAL_ADDRESSES                                                                                       = src.Quota_GLOBAL_INTERNAL_ADDRESSES
	Quota_GLOBAL_INTERNAL_MANAGED_BACKEND_SERVICES                                                                        = src.Quota_GLOBAL_INTERNAL_MANAGED_BACKEND_SERVICES
	Quota_GLOBAL_INTERNAL_TRAFFIC_DIRECTOR_BACKEND_SERVICES                                                               = src.Quota_GLOBAL_INTERNAL_TRAFFIC_DIRECTOR_BACKEND_SERVICES
	Quota_GPUS_ALL_REGIONS                                                                                                = src.Quota_GPUS_ALL_REGIONS
	Quota_HDB_TOTAL_GB                                                                                                    = src.Quota_HDB_TOTAL_GB
	Quota_HDB_TOTAL_IOPS                                                                                                  = src.Quota_HDB_TOTAL_IOPS
	Quota_HDB_TOTAL_THROUGHPUT                                                                                            = src.Quota_HDB_TOTAL_THROUGHPUT
	Quota_HEALTH_CHECKS                                                                                                   = src.Quota_HEALTH_CHECKS
	Quota_IMAGES                                                                                                          = src.Quota_IMAGES
	Quota_INSTANCES                                                                                                       = src.Quota_INSTANCES
	Quota_INSTANCE_GROUPS                                                                                                 = src.Quota_INSTANCE_GROUPS
	Quota_INSTANCE_GROUP_MANAGERS                                                                                         = src.Quota_INSTANCE_GROUP_MANAGERS
	Quota_INSTANCE_TEMPLATES                                                                                              = src.Quota_INSTANCE_TEMPLATES
	Quota_INTERCONNECTS                                                                                                   = src.Quota_INTERCONNECTS
	Quota_INTERCONNECT_ATTACHMENTS_PER_REGION                                                                             = src.Quota_INTERCONNECT_ATTACHMENTS_PER_REGION
	Quota_INTERCONNECT_ATTACHMENTS_TOTAL_MBPS                                                                             = src.Quota_INTERCONNECT_ATTACHMENTS_TOTAL_MBPS
	Quota_INTERCONNECT_TOTAL_GBPS                                                                                         = src.Quota_INTERCONNECT_TOTAL_GBPS
	Quota_INTERNAL_ADDRESSES                                                                                              = src.Quota_INTERNAL_ADDRESSES
	Quota_INTERNAL_TRAFFIC_DIRECTOR_FORWARDING_RULES                                                                      = src.Quota_INTERNAL_TRAFFIC_DIRECTOR_FORWARDING_RULES
	Quota_IN_PLACE_SNAPSHOTS                                                                                              = src.Quota_IN_PLACE_SNAPSHOTS
	Quota_IN_USE_ADDRESSES                                                                                                = src.Quota_IN_USE_ADDRESSES
	Quota_IN_USE_BACKUP_SCHEDULES                                                                                         = src.Quota_IN_USE_BACKUP_SCHEDULES
	Quota_IN_USE_SNAPSHOT_SCHEDULES                                                                                       = src.Quota_IN_USE_SNAPSHOT_SCHEDULES
	Quota_LOCAL_SSD_TOTAL_GB                                                                                              = src.Quota_LOCAL_SSD_TOTAL_GB
	Quota_M1_CPUS                                                                                                         = src.Quota_M1_CPUS
	Quota_M2_CPUS                                                                                                         = src.Quota_M2_CPUS
	Quota_M3_CPUS                                                                                                         = src.Quota_M3_CPUS
	Quota_MACHINE_IMAGES                                                                                                  = src.Quota_MACHINE_IMAGES
	Quota_N2A_CPUS                                                                                                        = src.Quota_N2A_CPUS
	Quota_N2D_CPUS                                                                                                        = src.Quota_N2D_CPUS
	Quota_N2_CPUS                                                                                                         = src.Quota_N2_CPUS
	Quota_NETWORKS                                                                                                        = src.Quota_NETWORKS
	Quota_NETWORK_ATTACHMENTS                                                                                             = src.Quota_NETWORK_ATTACHMENTS
	Quota_NETWORK_ENDPOINT_GROUPS                                                                                         = src.Quota_NETWORK_ENDPOINT_GROUPS
	Quota_NETWORK_FIREWALL_POLICIES                                                                                       = src.Quota_NETWORK_FIREWALL_POLICIES
	Quota_NET_LB_SECURITY_POLICIES_PER_REGION                                                                             = src.Quota_NET_LB_SECURITY_POLICIES_PER_REGION
	Quota_NET_LB_SECURITY_POLICY_RULES_PER_REGION                                                                         = src.Quota_NET_LB_SECURITY_POLICY_RULES_PER_REGION
	Quota_NET_LB_SECURITY_POLICY_RULE_ATTRIBUTES_PER_REGION                                                               = src.Quota_NET_LB_SECURITY_POLICY_RULE_ATTRIBUTES_PER_REGION
	Quota_NODE_GROUPS                                                                                                     = src.Quota_NODE_GROUPS
	Quota_NODE_TEMPLATES                                                                                                  = src.Quota_NODE_TEMPLATES
	Quota_NVIDIA_A100_80GB_GPUS                                                                                           = src.Quota_NVIDIA_A100_80GB_GPUS
	Quota_NVIDIA_A100_GPUS                                                                                                = src.Quota_NVIDIA_A100_GPUS
	Quota_NVIDIA_K80_GPUS                                                                                                 = src.Quota_NVIDIA_K80_GPUS
	Quota_NVIDIA_L4_GPUS                                                                                                  = src.Quota_NVIDIA_L4_GPUS
	Quota_NVIDIA_P100_GPUS                                                                                                = src.Quota_NVIDIA_P100_GPUS
	Quota_NVIDIA_P100_VWS_GPUS                                                                                            = src.Quota_NVIDIA_P100_VWS_GPUS
	Quota_NVIDIA_P4_GPUS                                                                                                  = src.Quota_NVIDIA_P4_GPUS
	Quota_NVIDIA_P4_VWS_GPUS                                                                                              = src.Quota_NVIDIA_P4_VWS_GPUS
	Quota_NVIDIA_T4_GPUS                                                                                                  = src.Quota_NVIDIA_T4_GPUS
	Quota_NVIDIA_T4_VWS_GPUS                                                                                              = src.Quota_NVIDIA_T4_VWS_GPUS
	Quota_NVIDIA_V100_GPUS                                                                                                = src.Quota_NVIDIA_V100_GPUS
	Quota_PACKET_MIRRORINGS                                                                                               = src.Quota_PACKET_MIRRORINGS
	Quota_PD_EXTREME_TOTAL_PROVISIONED_IOPS                                                                               = src.Quota_PD_EXTREME_TOTAL_PROVISIONED_IOPS
	Quota_PREEMPTIBLE_CPUS                                                                                                = src.Quota_PREEMPTIBLE_CPUS
	Quota_PREEMPTIBLE_LOCAL_SSD_GB                                                                                        = src.Quota_PREEMPTIBLE_LOCAL_SSD_GB
	Quota_PREEMPTIBLE_NVIDIA_A100_80GB_GPUS                                                                               = src.Quota_PREEMPTIBLE_NVIDIA_A100_80GB_GPUS
	Quota_PREEMPTIBLE_NVIDIA_A100_GPUS                                                                                    = src.Quota_PREEMPTIBLE_NVIDIA_A100_GPUS
	Quota_PREEMPTIBLE_NVIDIA_H100_GPUS                                                                                    = src.Quota_PREEMPTIBLE_NVIDIA_H100_GPUS
	Quota_PREEMPTIBLE_NVIDIA_K80_GPUS                                                                                     = src.Quota_PREEMPTIBLE_NVIDIA_K80_GPUS
	Quota_PREEMPTIBLE_NVIDIA_L4_GPUS                                                                                      = src.Quota_PREEMPTIBLE_NVIDIA_L4_GPUS
	Quota_PREEMPTIBLE_NVIDIA_P100_GPUS                                                                                    = src.Quota_PREEMPTIBLE_NVIDIA_P100_GPUS
	Quota_PREEMPTIBLE_NVIDIA_P100_VWS_GPUS                                                                                = src.Quota_PREEMPTIBLE_NVIDIA_P100_VWS_GPUS
	Quota_PREEMPTIBLE_NVIDIA_P4_GPUS                                                                                      = src.Quota_PREEMPTIBLE_NVIDIA_P4_GPUS
	Quota_PREEMPTIBLE_NVIDIA_P4_VWS_GPUS                                                                                  = src.Quota_PREEMPTIBLE_NVIDIA_P4_VWS_GPUS
	Quota_PREEMPTIBLE_NVIDIA_T4_GPUS                                                                                      = src.Quota_PREEMPTIBLE_NVIDIA_T4_GPUS
	Quota_PREEMPTIBLE_NVIDIA_T4_VWS_GPUS                                                                                  = src.Quota_PREEMPTIBLE_NVIDIA_T4_VWS_GPUS
	Quota_PREEMPTIBLE_NVIDIA_V100_GPUS                                                                                    = src.Quota_PREEMPTIBLE_NVIDIA_V100_GPUS
	Quota_PREEMPTIBLE_TPU_LITE_DEVICE_V5                                                                                  = src.Quota_PREEMPTIBLE_TPU_LITE_DEVICE_V5
	Quota_PREEMPTIBLE_TPU_LITE_PODSLICE_V5                                                                                = src.Quota_PREEMPTIBLE_TPU_LITE_PODSLICE_V5
	Quota_PREEMPTIBLE_TPU_PODSLICE_V4                                                                                     = src.Quota_PREEMPTIBLE_TPU_PODSLICE_V4
	Quota_PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK                                                          = src.Quota_PSC_ILB_CONSUMER_FORWARDING_RULES_PER_PRODUCER_NETWORK
	Quota_PSC_INTERNAL_LB_FORWARDING_RULES                                                                                = src.Quota_PSC_INTERNAL_LB_FORWARDING_RULES
	Quota_PUBLIC_ADVERTISED_PREFIXES                                                                                      = src.Quota_PUBLIC_ADVERTISED_PREFIXES
	Quota_PUBLIC_DELEGATED_PREFIXES                                                                                       = src.Quota_PUBLIC_DELEGATED_PREFIXES
	Quota_REGIONAL_AUTOSCALERS                                                                                            = src.Quota_REGIONAL_AUTOSCALERS
	Quota_REGIONAL_EXTERNAL_MANAGED_BACKEND_SERVICES                                                                      = src.Quota_REGIONAL_EXTERNAL_MANAGED_BACKEND_SERVICES
	Quota_REGIONAL_EXTERNAL_NETWORK_LB_BACKEND_SERVICES                                                                   = src.Quota_REGIONAL_EXTERNAL_NETWORK_LB_BACKEND_SERVICES
	Quota_REGIONAL_INSTANCE_GROUP_MANAGERS                                                                                = src.Quota_REGIONAL_INSTANCE_GROUP_MANAGERS
	Quota_REGIONAL_INTERNAL_LB_BACKEND_SERVICES                                                                           = src.Quota_REGIONAL_INTERNAL_LB_BACKEND_SERVICES
	Quota_REGIONAL_INTERNAL_MANAGED_BACKEND_SERVICES                                                                      = src.Quota_REGIONAL_INTERNAL_MANAGED_BACKEND_SERVICES
	Quota_REGIONAL_INTERNAL_TRAFFIC_DIRECTOR_BACKEND_SERVICES                                                             = src.Quota_REGIONAL_INTERNAL_TRAFFIC_DIRECTOR_BACKEND_SERVICES
	Quota_RESERVATIONS                                                                                                    = src.Quota_RESERVATIONS
	Quota_RESOURCE_POLICIES                                                                                               = src.Quota_RESOURCE_POLICIES
	Quota_ROUTERS                                                                                                         = src.Quota_ROUTERS
	Quota_ROUTES                                                                                                          = src.Quota_ROUTES
	Quota_SECURITY_POLICIES                                                                                               = src.Quota_SECURITY_POLICIES
	Quota_SECURITY_POLICIES_PER_REGION                                                                                    = src.Quota_SECURITY_POLICIES_PER_REGION
	Quota_SECURITY_POLICY_ADVANCED_RULES_PER_REGION                                                                       = src.Quota_SECURITY_POLICY_ADVANCED_RULES_PER_REGION
	Quota_SECURITY_POLICY_CEVAL_RULES                                                                                     = src.Quota_SECURITY_POLICY_CEVAL_RULES
	Quota_SECURITY_POLICY_RULES                                                                                           = src.Quota_SECURITY_POLICY_RULES
	Quota_SECURITY_POLICY_RULES_PER_REGION                                                                                = src.Quota_SECURITY_POLICY_RULES_PER_REGION
	Quota_SERVICE_ATTACHMENTS                                                                                             = src.Quota_SERVICE_ATTACHMENTS
	Quota_SNAPSHOTS                                                                                                       = src.Quota_SNAPSHOTS
	Quota_SSD_TOTAL_GB                                                                                                    = src.Quota_SSD_TOTAL_GB
	Quota_SSL_CERTIFICATES                                                                                                = src.Quota_SSL_CERTIFICATES
	Quota_SSL_POLICIES                                                                                                    = src.Quota_SSL_POLICIES
	Quota_STATIC_ADDRESSES                                                                                                = src.Quota_STATIC_ADDRESSES
	Quota_STATIC_BYOIP_ADDRESSES                                                                                          = src.Quota_STATIC_BYOIP_ADDRESSES
	Quota_STATIC_EXTERNAL_IPV6_ADDRESS_RANGES                                                                             = src.Quota_STATIC_EXTERNAL_IPV6_ADDRESS_RANGES
	Quota_SUBNETWORKS                                                                                                     = src.Quota_SUBNETWORKS
	Quota_T2A_CPUS                                                                                                        = src.Quota_T2A_CPUS
	Quota_T2D_CPUS                                                                                                        = src.Quota_T2D_CPUS
	Quota_TARGET_HTTPS_PROXIES                                                                                            = src.Quota_TARGET_HTTPS_PROXIES
	Quota_TARGET_HTTP_PROXIES                                                                                             = src.Quota_TARGET_HTTP_PROXIES
	Quota_TARGET_INSTANCES                                                                                                = src.Quota_TARGET_INSTANCES
	Quota_TARGET_POOLS                                                                                                    = src.Quota_TARGET_POOLS
	Quota_TARGET_SSL_PROXIES                                                                                              = src.Quota_TARGET_SSL_PROXIES
	Quota_TARGET_TCP_PROXIES                                                                                              = src.Quota_TARGET_TCP_PROXIES
	Quota_TARGET_VPN_GATEWAYS                                                                                             = src.Quota_TARGET_VPN_GATEWAYS
	Quota_TPU_LITE_DEVICE_V5                                                                                              = src.Quota_TPU_LITE_DEVICE_V5
	Quota_TPU_LITE_PODSLICE_V5                                                                                            = src.Quota_TPU_LITE_PODSLICE_V5
	Quota_TPU_PODSLICE_V4                                                                                                 = src.Quota_TPU_PODSLICE_V4
	Quota_UNDEFINED_METRIC                                                                                                = src.Quota_UNDEFINED_METRIC
	Quota_URL_MAPS                                                                                                        = src.Quota_URL_MAPS
	Quota_VARIABLE_IPV6_PUBLIC_DELEGATED_PREFIXES                                                                         = src.Quota_VARIABLE_IPV6_PUBLIC_DELEGATED_PREFIXES
	Quota_VPN_GATEWAYS                                                                                                    = src.Quota_VPN_GATEWAYS
	Quota_VPN_TUNNELS                                                                                                     = src.Quota_VPN_TUNNELS
	Quota_XPN_SERVICE_PROJECTS                                                                                            = src.Quota_XPN_SERVICE_PROJECTS
	RawDisk_TAR                                                                                                           = src.RawDisk_TAR
	RawDisk_UNDEFINED_CONTAINER_TYPE                                                                                      = src.RawDisk_UNDEFINED_CONTAINER_TYPE
	RegionInstanceGroupManagersApplyUpdatesRequest_UNDEFINED_MINIMAL_ACTION                                               = src.RegionInstanceGroupManagersApplyUpdatesRequest_UNDEFINED_MINIMAL_ACTION
	RegionInstanceGroupManagersApplyUpdatesRequest_UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION                               = src.RegionInstanceGroupManagersApplyUpdatesRequest_UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION
	RegionInstanceGroupsListInstancesRequest_ALL                                                                          = src.RegionInstanceGroupsListInstancesRequest_ALL
	RegionInstanceGroupsListInstancesRequest_RUNNING                                                                      = src.RegionInstanceGroupsListInstancesRequest_RUNNING
	RegionInstanceGroupsListInstancesRequest_UNDEFINED_INSTANCE_STATE                                                     = src.RegionInstanceGroupsListInstancesRequest_UNDEFINED_INSTANCE_STATE
	RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_HIERARCHY                           = src.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_HIERARCHY
	RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_NETWORK                             = src.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_NETWORK
	RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_NETWORK_REGIONAL                    = src.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_NETWORK_REGIONAL
	RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNDEFINED_TYPE                      = src.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNDEFINED_TYPE
	RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNSPECIFIED                         = src.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_UNSPECIFIED
	Region_DOWN                                                                                                           = src.Region_DOWN
	Region_UNDEFINED_STATUS                                                                                               = src.Region_UNDEFINED_STATUS
	Region_UP                                                                                                             = src.Region_UP
	ReservationAffinity_ANY_RESERVATION                                                                                   = src.ReservationAffinity_ANY_RESERVATION
	ReservationAffinity_NO_RESERVATION                                                                                    = src.ReservationAffinity_NO_RESERVATION
	ReservationAffinity_SPECIFIC_RESERVATION                                                                              = src.ReservationAffinity_SPECIFIC_RESERVATION
	ReservationAffinity_UNDEFINED_CONSUME_RESERVATION_TYPE                                                                = src.ReservationAffinity_UNDEFINED_CONSUME_RESERVATION_TYPE
	ReservationAffinity_UNSPECIFIED                                                                                       = src.ReservationAffinity_UNSPECIFIED
	Reservation_CREATING                                                                                                  = src.Reservation_CREATING
	Reservation_DELETING                                                                                                  = src.Reservation_DELETING
	Reservation_INVALID                                                                                                   = src.Reservation_INVALID
	Reservation_READY                                                                                                     = src.Reservation_READY
	Reservation_UNDEFINED_STATUS                                                                                          = src.Reservation_UNDEFINED_STATUS
	Reservation_UPDATING                                                                                                  = src.Reservation_UPDATING
	ResourceCommitment_ACCELERATOR                                                                                        = src.ResourceCommitment_ACCELERATOR
	ResourceCommitment_LOCAL_SSD                                                                                          = src.ResourceCommitment_LOCAL_SSD
	ResourceCommitment_MEMORY                                                                                             = src.ResourceCommitment_MEMORY
	ResourceCommitment_UNDEFINED_TYPE                                                                                     = src.ResourceCommitment_UNDEFINED_TYPE
	ResourceCommitment_UNSPECIFIED                                                                                        = src.ResourceCommitment_UNSPECIFIED
	ResourceCommitment_VCPU                                                                                               = src.ResourceCommitment_VCPU
	ResourcePolicyGroupPlacementPolicy_COLLOCATED                                                                         = src.ResourcePolicyGroupPlacementPolicy_COLLOCATED
	ResourcePolicyGroupPlacementPolicy_UNDEFINED_COLLOCATION                                                              = src.ResourcePolicyGroupPlacementPolicy_UNDEFINED_COLLOCATION
	ResourcePolicyGroupPlacementPolicy_UNSPECIFIED_COLLOCATION                                                            = src.ResourcePolicyGroupPlacementPolicy_UNSPECIFIED_COLLOCATION
	ResourcePolicySnapshotSchedulePolicyRetentionPolicy_APPLY_RETENTION_POLICY                                            = src.ResourcePolicySnapshotSchedulePolicyRetentionPolicy_APPLY_RETENTION_POLICY
	ResourcePolicySnapshotSchedulePolicyRetentionPolicy_KEEP_AUTO_SNAPSHOTS                                               = src.ResourcePolicySnapshotSchedulePolicyRetentionPolicy_KEEP_AUTO_SNAPSHOTS
	ResourcePolicySnapshotSchedulePolicyRetentionPolicy_UNDEFINED_ON_SOURCE_DISK_DELETE                                   = src.ResourcePolicySnapshotSchedulePolicyRetentionPolicy_UNDEFINED_ON_SOURCE_DISK_DELETE
	ResourcePolicySnapshotSchedulePolicyRetentionPolicy_UNSPECIFIED_ON_SOURCE_DISK_DELETE                                 = src.ResourcePolicySnapshotSchedulePolicyRetentionPolicy_UNSPECIFIED_ON_SOURCE_DISK_DELETE
	ResourcePolicyWeeklyCycleDayOfWeek_FRIDAY                                                                             = src.ResourcePolicyWeeklyCycleDayOfWeek_FRIDAY
	ResourcePolicyWeeklyCycleDayOfWeek_INVALID                                                                            = src.ResourcePolicyWeeklyCycleDayOfWeek_INVALID
	ResourcePolicyWeeklyCycleDayOfWeek_MONDAY                                                                             = src.ResourcePolicyWeeklyCycleDayOfWeek_MONDAY
	ResourcePolicyWeeklyCycleDayOfWeek_SATURDAY                                                                           = src.ResourcePolicyWeeklyCycleDayOfWeek_SATURDAY
	ResourcePolicyWeeklyCycleDayOfWeek_SUNDAY                                                                             = src.ResourcePolicyWeeklyCycleDayOfWeek_SUNDAY
	ResourcePolicyWeeklyCycleDayOfWeek_THURSDAY                                                                           = src.ResourcePolicyWeeklyCycleDayOfWeek_THURSDAY
	ResourcePolicyWeeklyCycleDayOfWeek_TUESDAY                                                                            = src.ResourcePolicyWeeklyCycleDayOfWeek_TUESDAY
	ResourcePolicyWeeklyCycleDayOfWeek_UNDEFINED_DAY                                                                      = src.ResourcePolicyWeeklyCycleDayOfWeek_UNDEFINED_DAY
	ResourcePolicyWeeklyCycleDayOfWeek_WEDNESDAY                                                                          = src.ResourcePolicyWeeklyCycleDayOfWeek_WEDNESDAY
	ResourcePolicy_CREATING                                                                                               = src.ResourcePolicy_CREATING
	ResourcePolicy_DELETING                                                                                               = src.ResourcePolicy_DELETING
	ResourcePolicy_EXPIRED                                                                                                = src.ResourcePolicy_EXPIRED
	ResourcePolicy_INVALID                                                                                                = src.ResourcePolicy_INVALID
	ResourcePolicy_READY                                                                                                  = src.ResourcePolicy_READY
	ResourcePolicy_UNDEFINED_STATUS                                                                                       = src.ResourcePolicy_UNDEFINED_STATUS
	RouteAsPath_AS_CONFED_SEQUENCE                                                                                        = src.RouteAsPath_AS_CONFED_SEQUENCE
	RouteAsPath_AS_CONFED_SET                                                                                             = src.RouteAsPath_AS_CONFED_SET
	RouteAsPath_AS_SEQUENCE                                                                                               = src.RouteAsPath_AS_SEQUENCE
	RouteAsPath_AS_SET                                                                                                    = src.RouteAsPath_AS_SET
	RouteAsPath_UNDEFINED_PATH_SEGMENT_TYPE                                                                               = src.RouteAsPath_UNDEFINED_PATH_SEGMENT_TYPE
	Route_ACTIVE                                                                                                          = src.Route_ACTIVE
	Route_BGP                                                                                                             = src.Route_BGP
	Route_DROPPED                                                                                                         = src.Route_DROPPED
	Route_INACTIVE                                                                                                        = src.Route_INACTIVE
	Route_PENDING                                                                                                         = src.Route_PENDING
	Route_STATIC                                                                                                          = src.Route_STATIC
	Route_SUBNET                                                                                                          = src.Route_SUBNET
	Route_TRANSIT                                                                                                         = src.Route_TRANSIT
	Route_UNDEFINED_ROUTE_STATUS                                                                                          = src.Route_UNDEFINED_ROUTE_STATUS
	Route_UNDEFINED_ROUTE_TYPE                                                                                            = src.Route_UNDEFINED_ROUTE_TYPE
	RouterBgpPeerBfd_ACTIVE                                                                                               = src.RouterBgpPeerBfd_ACTIVE
	RouterBgpPeerBfd_DISABLED                                                                                             = src.RouterBgpPeerBfd_DISABLED
	RouterBgpPeerBfd_PASSIVE                                                                                              = src.RouterBgpPeerBfd_PASSIVE
	RouterBgpPeerBfd_UNDEFINED_SESSION_INITIALIZATION_MODE                                                                = src.RouterBgpPeerBfd_UNDEFINED_SESSION_INITIALIZATION_MODE
	RouterBgpPeer_ALL_SUBNETS                                                                                             = src.RouterBgpPeer_ALL_SUBNETS
	RouterBgpPeer_CUSTOM                                                                                                  = src.RouterBgpPeer_CUSTOM
	RouterBgpPeer_DEFAULT                                                                                                 = src.RouterBgpPeer_DEFAULT
	RouterBgpPeer_FALSE                                                                                                   = src.RouterBgpPeer_FALSE
	RouterBgpPeer_MANAGED_BY_ATTACHMENT                                                                                   = src.RouterBgpPeer_MANAGED_BY_ATTACHMENT
	RouterBgpPeer_MANAGED_BY_USER                                                                                         = src.RouterBgpPeer_MANAGED_BY_USER
	RouterBgpPeer_TRUE                                                                                                    = src.RouterBgpPeer_TRUE
	RouterBgpPeer_UNDEFINED_ADVERTISED_GROUPS                                                                             = src.RouterBgpPeer_UNDEFINED_ADVERTISED_GROUPS
	RouterBgpPeer_UNDEFINED_ADVERTISE_MODE                                                                                = src.RouterBgpPeer_UNDEFINED_ADVERTISE_MODE
	RouterBgpPeer_UNDEFINED_ENABLE                                                                                        = src.RouterBgpPeer_UNDEFINED_ENABLE
	RouterBgpPeer_UNDEFINED_MANAGEMENT_TYPE                                                                               = src.RouterBgpPeer_UNDEFINED_MANAGEMENT_TYPE
	RouterBgp_ALL_SUBNETS                                                                                                 = src.RouterBgp_ALL_SUBNETS
	RouterBgp_CUSTOM                                                                                                      = src.RouterBgp_CUSTOM
	RouterBgp_DEFAULT                                                                                                     = src.RouterBgp_DEFAULT
	RouterBgp_UNDEFINED_ADVERTISED_GROUPS                                                                                 = src.RouterBgp_UNDEFINED_ADVERTISED_GROUPS
	RouterBgp_UNDEFINED_ADVERTISE_MODE                                                                                    = src.RouterBgp_UNDEFINED_ADVERTISE_MODE
	RouterInterface_IPV4                                                                                                  = src.RouterInterface_IPV4
	RouterInterface_IPV6                                                                                                  = src.RouterInterface_IPV6
	RouterInterface_MANAGED_BY_ATTACHMENT                                                                                 = src.RouterInterface_MANAGED_BY_ATTACHMENT
	RouterInterface_MANAGED_BY_USER                                                                                       = src.RouterInterface_MANAGED_BY_USER
	RouterInterface_UNDEFINED_IP_VERSION                                                                                  = src.RouterInterface_UNDEFINED_IP_VERSION
	RouterInterface_UNDEFINED_MANAGEMENT_TYPE                                                                             = src.RouterInterface_UNDEFINED_MANAGEMENT_TYPE
	RouterNatLogConfig_ALL                                                                                                = src.RouterNatLogConfig_ALL
	RouterNatLogConfig_ERRORS_ONLY                                                                                        = src.RouterNatLogConfig_ERRORS_ONLY
	RouterNatLogConfig_TRANSLATIONS_ONLY                                                                                  = src.RouterNatLogConfig_TRANSLATIONS_ONLY
	RouterNatLogConfig_UNDEFINED_FILTER                                                                                   = src.RouterNatLogConfig_UNDEFINED_FILTER
	RouterNatSubnetworkToNat_ALL_IP_RANGES                                                                                = src.RouterNatSubnetworkToNat_ALL_IP_RANGES
	RouterNatSubnetworkToNat_LIST_OF_SECONDARY_IP_RANGES                                                                  = src.RouterNatSubnetworkToNat_LIST_OF_SECONDARY_IP_RANGES
	RouterNatSubnetworkToNat_PRIMARY_IP_RANGE                                                                             = src.RouterNatSubnetworkToNat_PRIMARY_IP_RANGE
	RouterNatSubnetworkToNat_UNDEFINED_SOURCE_IP_RANGES_TO_NAT                                                            = src.RouterNatSubnetworkToNat_UNDEFINED_SOURCE_IP_RANGES_TO_NAT
	RouterNat_ALL_SUBNETWORKS_ALL_IP_RANGES                                                                               = src.RouterNat_ALL_SUBNETWORKS_ALL_IP_RANGES
	RouterNat_ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES                                                                       = src.RouterNat_ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES
	RouterNat_AUTO_ONLY                                                                                                   = src.RouterNat_AUTO_ONLY
	RouterNat_ENDPOINT_TYPE_MANAGED_PROXY_LB                                                                              = src.RouterNat_ENDPOINT_TYPE_MANAGED_PROXY_LB
	RouterNat_ENDPOINT_TYPE_SWG                                                                                           = src.RouterNat_ENDPOINT_TYPE_SWG
	RouterNat_ENDPOINT_TYPE_VM                                                                                            = src.RouterNat_ENDPOINT_TYPE_VM
	RouterNat_FIXED_STANDARD                                                                                              = src.RouterNat_FIXED_STANDARD
	RouterNat_LIST_OF_SUBNETWORKS                                                                                         = src.RouterNat_LIST_OF_SUBNETWORKS
	RouterNat_MANUAL_ONLY                                                                                                 = src.RouterNat_MANUAL_ONLY
	RouterNat_PREMIUM                                                                                                     = src.RouterNat_PREMIUM
	RouterNat_PRIVATE                                                                                                     = src.RouterNat_PRIVATE
	RouterNat_PUBLIC                                                                                                      = src.RouterNat_PUBLIC
	RouterNat_STANDARD                                                                                                    = src.RouterNat_STANDARD
	RouterNat_STANDARD_OVERRIDES_FIXED_STANDARD                                                                           = src.RouterNat_STANDARD_OVERRIDES_FIXED_STANDARD
	RouterNat_UNDEFINED_AUTO_NETWORK_TIER                                                                                 = src.RouterNat_UNDEFINED_AUTO_NETWORK_TIER
	RouterNat_UNDEFINED_ENDPOINT_TYPES                                                                                    = src.RouterNat_UNDEFINED_ENDPOINT_TYPES
	RouterNat_UNDEFINED_NAT_IP_ALLOCATE_OPTION                                                                            = src.RouterNat_UNDEFINED_NAT_IP_ALLOCATE_OPTION
	RouterNat_UNDEFINED_SOURCE_SUBNETWORK_IP_RANGES_TO_NAT                                                                = src.RouterNat_UNDEFINED_SOURCE_SUBNETWORK_IP_RANGES_TO_NAT
	RouterNat_UNDEFINED_TYPE                                                                                              = src.RouterNat_UNDEFINED_TYPE
	RouterStatusBgpPeerStatus_DOWN                                                                                        = src.RouterStatusBgpPeerStatus_DOWN
	RouterStatusBgpPeerStatus_IPV4_PEER_ON_IPV6_ONLY_CONNECTION                                                           = src.RouterStatusBgpPeerStatus_IPV4_PEER_ON_IPV6_ONLY_CONNECTION
	RouterStatusBgpPeerStatus_IPV6_PEER_ON_IPV4_ONLY_CONNECTION                                                           = src.RouterStatusBgpPeerStatus_IPV6_PEER_ON_IPV4_ONLY_CONNECTION
	RouterStatusBgpPeerStatus_MD5_AUTH_INTERNAL_PROBLEM                                                                   = src.RouterStatusBgpPeerStatus_MD5_AUTH_INTERNAL_PROBLEM
	RouterStatusBgpPeerStatus_STATUS_REASON_UNSPECIFIED                                                                   = src.RouterStatusBgpPeerStatus_STATUS_REASON_UNSPECIFIED
	RouterStatusBgpPeerStatus_UNDEFINED_STATUS                                                                            = src.RouterStatusBgpPeerStatus_UNDEFINED_STATUS
	RouterStatusBgpPeerStatus_UNDEFINED_STATUS_REASON                                                                     = src.RouterStatusBgpPeerStatus_UNDEFINED_STATUS_REASON
	RouterStatusBgpPeerStatus_UNKNOWN                                                                                     = src.RouterStatusBgpPeerStatus_UNKNOWN
	RouterStatusBgpPeerStatus_UP                                                                                          = src.RouterStatusBgpPeerStatus_UP
	SSLHealthCheck_NONE                                                                                                   = src.SSLHealthCheck_NONE
	SSLHealthCheck_PROXY_V1                                                                                               = src.SSLHealthCheck_PROXY_V1
	SSLHealthCheck_UNDEFINED_PORT_SPECIFICATION                                                                           = src.SSLHealthCheck_UNDEFINED_PORT_SPECIFICATION
	SSLHealthCheck_UNDEFINED_PROXY_HEADER                                                                                 = src.SSLHealthCheck_UNDEFINED_PROXY_HEADER
	SSLHealthCheck_USE_FIXED_PORT                                                                                         = src.SSLHealthCheck_USE_FIXED_PORT
	SSLHealthCheck_USE_NAMED_PORT                                                                                         = src.SSLHealthCheck_USE_NAMED_PORT
	SSLHealthCheck_USE_SERVING_PORT                                                                                       = src.SSLHealthCheck_USE_SERVING_PORT
	SavedAttachedDisk_NVME                                                                                                = src.SavedAttachedDisk_NVME
	SavedAttachedDisk_PERSISTENT                                                                                          = src.SavedAttachedDisk_PERSISTENT
	SavedAttachedDisk_READ_ONLY                                                                                           = src.SavedAttachedDisk_READ_ONLY
	SavedAttachedDisk_READ_WRITE                                                                                          = src.SavedAttachedDisk_READ_WRITE
	SavedAttachedDisk_SCRATCH                                                                                             = src.SavedAttachedDisk_SCRATCH
	SavedAttachedDisk_SCSI                                                                                                = src.SavedAttachedDisk_SCSI
	SavedAttachedDisk_UNDEFINED_INTERFACE                                                                                 = src.SavedAttachedDisk_UNDEFINED_INTERFACE
	SavedAttachedDisk_UNDEFINED_MODE                                                                                      = src.SavedAttachedDisk_UNDEFINED_MODE
	SavedAttachedDisk_UNDEFINED_STORAGE_BYTES_STATUS                                                                      = src.SavedAttachedDisk_UNDEFINED_STORAGE_BYTES_STATUS
	SavedAttachedDisk_UNDEFINED_TYPE                                                                                      = src.SavedAttachedDisk_UNDEFINED_TYPE
	SavedAttachedDisk_UPDATING                                                                                            = src.SavedAttachedDisk_UPDATING
	SavedAttachedDisk_UP_TO_DATE                                                                                          = src.SavedAttachedDisk_UP_TO_DATE
	SavedDisk_ARCHITECTURE_UNSPECIFIED                                                                                    = src.SavedDisk_ARCHITECTURE_UNSPECIFIED
	SavedDisk_ARM64                                                                                                       = src.SavedDisk_ARM64
	SavedDisk_UNDEFINED_ARCHITECTURE                                                                                      = src.SavedDisk_UNDEFINED_ARCHITECTURE
	SavedDisk_UNDEFINED_STORAGE_BYTES_STATUS                                                                              = src.SavedDisk_UNDEFINED_STORAGE_BYTES_STATUS
	SavedDisk_UPDATING                                                                                                    = src.SavedDisk_UPDATING
	SavedDisk_UP_TO_DATE                                                                                                  = src.SavedDisk_UP_TO_DATE
	SavedDisk_X86_64                                                                                                      = src.SavedDisk_X86_64
	ScalingScheduleStatus_ACTIVE                                                                                          = src.ScalingScheduleStatus_ACTIVE
	ScalingScheduleStatus_DISABLED                                                                                        = src.ScalingScheduleStatus_DISABLED
	ScalingScheduleStatus_OBSOLETE                                                                                        = src.ScalingScheduleStatus_OBSOLETE
	ScalingScheduleStatus_READY                                                                                           = src.ScalingScheduleStatus_READY
	ScalingScheduleStatus_UNDEFINED_STATE                                                                                 = src.ScalingScheduleStatus_UNDEFINED_STATE
	SchedulingNodeAffinity_IN                                                                                             = src.SchedulingNodeAffinity_IN
	SchedulingNodeAffinity_NOT_IN                                                                                         = src.SchedulingNodeAffinity_NOT_IN
	SchedulingNodeAffinity_OPERATOR_UNSPECIFIED                                                                           = src.SchedulingNodeAffinity_OPERATOR_UNSPECIFIED
	SchedulingNodeAffinity_UNDEFINED_OPERATOR                                                                             = src.SchedulingNodeAffinity_UNDEFINED_OPERATOR
	Scheduling_DELETE                                                                                                     = src.Scheduling_DELETE
	Scheduling_INSTANCE_TERMINATION_ACTION_UNSPECIFIED                                                                    = src.Scheduling_INSTANCE_TERMINATION_ACTION_UNSPECIFIED
	Scheduling_MIGRATE                                                                                                    = src.Scheduling_MIGRATE
	Scheduling_SPOT                                                                                                       = src.Scheduling_SPOT
	Scheduling_STANDARD                                                                                                   = src.Scheduling_STANDARD
	Scheduling_STOP                                                                                                       = src.Scheduling_STOP
	Scheduling_TERMINATE                                                                                                  = src.Scheduling_TERMINATE
	Scheduling_UNDEFINED_INSTANCE_TERMINATION_ACTION                                                                      = src.Scheduling_UNDEFINED_INSTANCE_TERMINATION_ACTION
	Scheduling_UNDEFINED_ON_HOST_MAINTENANCE                                                                              = src.Scheduling_UNDEFINED_ON_HOST_MAINTENANCE
	Scheduling_UNDEFINED_PROVISIONING_MODEL                                                                               = src.Scheduling_UNDEFINED_PROVISIONING_MODEL
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_HTTP_HEADER_HOST = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_HTTP_HEADER_HOST
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_HTTP_PATH        = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_HTTP_PATH
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_UNDEFINED_TYPE   = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_UNDEFINED_TYPE
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_UNSPECIFIED_TYPE = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_UNSPECIFIED_TYPE
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_PREMIUM                                                 = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_PREMIUM
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_STANDARD                                                = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_STANDARD
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_UNDEFINED_RULE_VISIBILITY                               = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_UNDEFINED_RULE_VISIBILITY
	SecurityPolicyAdvancedOptionsConfig_DISABLED                                                                          = src.SecurityPolicyAdvancedOptionsConfig_DISABLED
	SecurityPolicyAdvancedOptionsConfig_NORMAL                                                                            = src.SecurityPolicyAdvancedOptionsConfig_NORMAL
	SecurityPolicyAdvancedOptionsConfig_STANDARD                                                                          = src.SecurityPolicyAdvancedOptionsConfig_STANDARD
	SecurityPolicyAdvancedOptionsConfig_STANDARD_WITH_GRAPHQL                                                             = src.SecurityPolicyAdvancedOptionsConfig_STANDARD_WITH_GRAPHQL
	SecurityPolicyAdvancedOptionsConfig_UNDEFINED_JSON_PARSING                                                            = src.SecurityPolicyAdvancedOptionsConfig_UNDEFINED_JSON_PARSING
	SecurityPolicyAdvancedOptionsConfig_UNDEFINED_LOG_LEVEL                                                               = src.SecurityPolicyAdvancedOptionsConfig_UNDEFINED_LOG_LEVEL
	SecurityPolicyAdvancedOptionsConfig_VERBOSE                                                                           = src.SecurityPolicyAdvancedOptionsConfig_VERBOSE
	SecurityPolicyDdosProtectionConfig_ADVANCED                                                                           = src.SecurityPolicyDdosProtectionConfig_ADVANCED
	SecurityPolicyDdosProtectionConfig_STANDARD                                                                           = src.SecurityPolicyDdosProtectionConfig_STANDARD
	SecurityPolicyDdosProtectionConfig_UNDEFINED_DDOS_PROTECTION                                                          = src.SecurityPolicyDdosProtectionConfig_UNDEFINED_DDOS_PROTECTION
	SecurityPolicyRuleMatcher_SRC_IPS_V1                                                                                  = src.SecurityPolicyRuleMatcher_SRC_IPS_V1
	SecurityPolicyRuleMatcher_UNDEFINED_VERSIONED_EXPR                                                                    = src.SecurityPolicyRuleMatcher_UNDEFINED_VERSIONED_EXPR
	SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_CONTAINS                                                 = src.SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_CONTAINS
	SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_ENDS_WITH                                                = src.SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_ENDS_WITH
	SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_EQUALS                                                   = src.SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_EQUALS
	SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_EQUALS_ANY                                               = src.SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_EQUALS_ANY
	SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_STARTS_WITH                                              = src.SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_STARTS_WITH
	SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_UNDEFINED_OP                                             = src.SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_UNDEFINED_OP
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_ALL                                                              = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_ALL
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_HTTP_COOKIE                                                      = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_HTTP_COOKIE
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_HTTP_HEADER                                                      = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_HTTP_HEADER
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_HTTP_PATH                                                        = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_HTTP_PATH
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_IP                                                               = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_IP
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_REGION_CODE                                                      = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_REGION_CODE
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_SNI                                                              = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_SNI
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_TLS_JA3_FINGERPRINT                                              = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_TLS_JA3_FINGERPRINT
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_UNDEFINED_ENFORCE_ON_KEY_TYPE                                    = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_UNDEFINED_ENFORCE_ON_KEY_TYPE
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_USER_IP                                                          = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_USER_IP
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_XFF_IP                                                           = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_XFF_IP
	SecurityPolicyRuleRateLimitOptions_ALL                                                                                = src.SecurityPolicyRuleRateLimitOptions_ALL
	SecurityPolicyRuleRateLimitOptions_HTTP_COOKIE                                                                        = src.SecurityPolicyRuleRateLimitOptions_HTTP_COOKIE
	SecurityPolicyRuleRateLimitOptions_HTTP_HEADER                                                                        = src.SecurityPolicyRuleRateLimitOptions_HTTP_HEADER
	SecurityPolicyRuleRateLimitOptions_HTTP_PATH                                                                          = src.SecurityPolicyRuleRateLimitOptions_HTTP_PATH
	SecurityPolicyRuleRateLimitOptions_IP                                                                                 = src.SecurityPolicyRuleRateLimitOptions_IP
	SecurityPolicyRuleRateLimitOptions_REGION_CODE                                                                        = src.SecurityPolicyRuleRateLimitOptions_REGION_CODE
	SecurityPolicyRuleRateLimitOptions_SNI                                                                                = src.SecurityPolicyRuleRateLimitOptions_SNI
	SecurityPolicyRuleRateLimitOptions_TLS_JA3_FINGERPRINT                                                                = src.SecurityPolicyRuleRateLimitOptions_TLS_JA3_FINGERPRINT
	SecurityPolicyRuleRateLimitOptions_UNDEFINED_ENFORCE_ON_KEY                                                           = src.SecurityPolicyRuleRateLimitOptions_UNDEFINED_ENFORCE_ON_KEY
	SecurityPolicyRuleRateLimitOptions_USER_IP                                                                            = src.SecurityPolicyRuleRateLimitOptions_USER_IP
	SecurityPolicyRuleRateLimitOptions_XFF_IP                                                                             = src.SecurityPolicyRuleRateLimitOptions_XFF_IP
	SecurityPolicyRuleRedirectOptions_EXTERNAL_302                                                                        = src.SecurityPolicyRuleRedirectOptions_EXTERNAL_302
	SecurityPolicyRuleRedirectOptions_GOOGLE_RECAPTCHA                                                                    = src.SecurityPolicyRuleRedirectOptions_GOOGLE_RECAPTCHA
	SecurityPolicyRuleRedirectOptions_UNDEFINED_TYPE                                                                      = src.SecurityPolicyRuleRedirectOptions_UNDEFINED_TYPE
	SecurityPolicyUserDefinedField_IPV4                                                                                   = src.SecurityPolicyUserDefinedField_IPV4
	SecurityPolicyUserDefinedField_IPV6                                                                                   = src.SecurityPolicyUserDefinedField_IPV6
	SecurityPolicyUserDefinedField_TCP                                                                                    = src.SecurityPolicyUserDefinedField_TCP
	SecurityPolicyUserDefinedField_UDP                                                                                    = src.SecurityPolicyUserDefinedField_UDP
	SecurityPolicyUserDefinedField_UNDEFINED_BASE                                                                         = src.SecurityPolicyUserDefinedField_UNDEFINED_BASE
	SecurityPolicy_CLOUD_ARMOR                                                                                            = src.SecurityPolicy_CLOUD_ARMOR
	SecurityPolicy_CLOUD_ARMOR_EDGE                                                                                       = src.SecurityPolicy_CLOUD_ARMOR_EDGE
	SecurityPolicy_CLOUD_ARMOR_NETWORK                                                                                    = src.SecurityPolicy_CLOUD_ARMOR_NETWORK
	SecurityPolicy_UNDEFINED_TYPE                                                                                         = src.SecurityPolicy_UNDEFINED_TYPE
	ServerBinding_RESTART_NODE_ON_ANY_SERVER                                                                              = src.ServerBinding_RESTART_NODE_ON_ANY_SERVER
	ServerBinding_RESTART_NODE_ON_MINIMAL_SERVERS                                                                         = src.ServerBinding_RESTART_NODE_ON_MINIMAL_SERVERS
	ServerBinding_SERVER_BINDING_TYPE_UNSPECIFIED                                                                         = src.ServerBinding_SERVER_BINDING_TYPE_UNSPECIFIED
	ServerBinding_UNDEFINED_TYPE                                                                                          = src.ServerBinding_UNDEFINED_TYPE
	ServiceAttachmentConnectedEndpoint_ACCEPTED                                                                           = src.ServiceAttachmentConnectedEndpoint_ACCEPTED
	ServiceAttachmentConnectedEndpoint_CLOSED                                                                             = src.ServiceAttachmentConnectedEndpoint_CLOSED
	ServiceAttachmentConnectedEndpoint_NEEDS_ATTENTION                                                                    = src.ServiceAttachmentConnectedEndpoint_NEEDS_ATTENTION
	ServiceAttachmentConnectedEndpoint_PENDING                                                                            = src.ServiceAttachmentConnectedEndpoint_PENDING
	ServiceAttachmentConnectedEndpoint_REJECTED                                                                           = src.ServiceAttachmentConnectedEndpoint_REJECTED
	ServiceAttachmentConnectedEndpoint_STATUS_UNSPECIFIED                                                                 = src.ServiceAttachmentConnectedEndpoint_STATUS_UNSPECIFIED
	ServiceAttachmentConnectedEndpoint_UNDEFINED_STATUS                                                                   = src.ServiceAttachmentConnectedEndpoint_UNDEFINED_STATUS
	ServiceAttachment_ACCEPT_AUTOMATIC                                                                                    = src.ServiceAttachment_ACCEPT_AUTOMATIC
	ServiceAttachment_ACCEPT_MANUAL                                                                                       = src.ServiceAttachment_ACCEPT_MANUAL
	ServiceAttachment_CONNECTION_PREFERENCE_UNSPECIFIED                                                                   = src.ServiceAttachment_CONNECTION_PREFERENCE_UNSPECIFIED
	ServiceAttachment_UNDEFINED_CONNECTION_PREFERENCE                                                                     = src.ServiceAttachment_UNDEFINED_CONNECTION_PREFERENCE
	SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_ABANDONED                                          = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_ABANDONED
	SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_DONE                                               = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_DONE
	SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_FAILED                                             = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_FAILED
	SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_PROPAGATED                                         = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_PROPAGATED
	SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_PROPAGATING                                        = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_PROPAGATING
	SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_UNDEFINED_STATE                                    = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_UNDEFINED_STATE
	SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_UNSPECIFIED                                        = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_UNSPECIFIED
	ShareSettings_LOCAL                                                                                                   = src.ShareSettings_LOCAL
	ShareSettings_ORGANIZATION                                                                                            = src.ShareSettings_ORGANIZATION
	ShareSettings_SHARE_TYPE_UNSPECIFIED                                                                                  = src.ShareSettings_SHARE_TYPE_UNSPECIFIED
	ShareSettings_SPECIFIC_PROJECTS                                                                                       = src.ShareSettings_SPECIFIC_PROJECTS
	ShareSettings_UNDEFINED_SHARE_TYPE                                                                                    = src.ShareSettings_UNDEFINED_SHARE_TYPE
	SnapshotSettingsStorageLocationSettings_LOCAL_REGION                                                                  = src.SnapshotSettingsStorageLocationSettings_LOCAL_REGION
	SnapshotSettingsStorageLocationSettings_NEAREST_MULTI_REGION                                                          = src.SnapshotSettingsStorageLocationSettings_NEAREST_MULTI_REGION
	SnapshotSettingsStorageLocationSettings_SPECIFIC_LOCATIONS                                                            = src.SnapshotSettingsStorageLocationSettings_SPECIFIC_LOCATIONS
	SnapshotSettingsStorageLocationSettings_STORAGE_LOCATION_POLICY_UNSPECIFIED                                           = src.SnapshotSettingsStorageLocationSettings_STORAGE_LOCATION_POLICY_UNSPECIFIED
	SnapshotSettingsStorageLocationSettings_UNDEFINED_POLICY                                                              = src.SnapshotSettingsStorageLocationSettings_UNDEFINED_POLICY
	Snapshot_ARCHITECTURE_UNSPECIFIED                                                                                     = src.Snapshot_ARCHITECTURE_UNSPECIFIED
	Snapshot_ARCHIVE                                                                                                      = src.Snapshot_ARCHIVE
	Snapshot_ARM64                                                                                                        = src.Snapshot_ARM64
	Snapshot_CREATING                                                                                                     = src.Snapshot_CREATING
	Snapshot_DELETING                                                                                                     = src.Snapshot_DELETING
	Snapshot_FAILED                                                                                                       = src.Snapshot_FAILED
	Snapshot_READY                                                                                                        = src.Snapshot_READY
	Snapshot_STANDARD                                                                                                     = src.Snapshot_STANDARD
	Snapshot_UNDEFINED_ARCHITECTURE                                                                                       = src.Snapshot_UNDEFINED_ARCHITECTURE
	Snapshot_UNDEFINED_SNAPSHOT_TYPE                                                                                      = src.Snapshot_UNDEFINED_SNAPSHOT_TYPE
	Snapshot_UNDEFINED_STATUS                                                                                             = src.Snapshot_UNDEFINED_STATUS
	Snapshot_UNDEFINED_STORAGE_BYTES_STATUS                                                                               = src.Snapshot_UNDEFINED_STORAGE_BYTES_STATUS
	Snapshot_UPDATING                                                                                                     = src.Snapshot_UPDATING
	Snapshot_UPLOADING                                                                                                    = src.Snapshot_UPLOADING
	Snapshot_UP_TO_DATE                                                                                                   = src.Snapshot_UP_TO_DATE
	Snapshot_X86_64                                                                                                       = src.Snapshot_X86_64
	SourceInstanceProperties_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED                                                       = src.SourceInstanceProperties_KEY_REVOCATION_ACTION_TYPE_UNSPECIFIED
	SourceInstanceProperties_NONE                                                                                         = src.SourceInstanceProperties_NONE
	SourceInstanceProperties_STOP                                                                                         = src.SourceInstanceProperties_STOP
	SourceInstanceProperties_UNDEFINED_KEY_REVOCATION_ACTION_TYPE                                                         = src.SourceInstanceProperties_UNDEFINED_KEY_REVOCATION_ACTION_TYPE
	SslCertificateManagedSslCertificate_ACTIVE                                                                            = src.SslCertificateManagedSslCertificate_ACTIVE
	SslCertificateManagedSslCertificate_MANAGED_CERTIFICATE_STATUS_UNSPECIFIED                                            = src.SslCertificateManagedSslCertificate_MANAGED_CERTIFICATE_STATUS_UNSPECIFIED
	SslCertificateManagedSslCertificate_PROVISIONING                                                                      = src.SslCertificateManagedSslCertificate_PROVISIONING
	SslCertificateManagedSslCertificate_PROVISIONING_FAILED                                                               = src.SslCertificateManagedSslCertificate_PROVISIONING_FAILED
	SslCertificateManagedSslCertificate_PROVISIONING_FAILED_PERMANENTLY                                                   = src.SslCertificateManagedSslCertificate_PROVISIONING_FAILED_PERMANENTLY
	SslCertificateManagedSslCertificate_RENEWAL_FAILED                                                                    = src.SslCertificateManagedSslCertificate_RENEWAL_FAILED
	SslCertificateManagedSslCertificate_UNDEFINED_STATUS                                                                  = src.SslCertificateManagedSslCertificate_UNDEFINED_STATUS
	SslCertificate_MANAGED                                                                                                = src.SslCertificate_MANAGED
	SslCertificate_SELF_MANAGED                                                                                           = src.SslCertificate_SELF_MANAGED
	SslCertificate_TYPE_UNSPECIFIED                                                                                       = src.SslCertificate_TYPE_UNSPECIFIED
	SslCertificate_UNDEFINED_TYPE                                                                                         = src.SslCertificate_UNDEFINED_TYPE
	SslPolicy_COMPATIBLE                                                                                                  = src.SslPolicy_COMPATIBLE
	SslPolicy_CUSTOM                                                                                                      = src.SslPolicy_CUSTOM
	SslPolicy_MODERN                                                                                                      = src.SslPolicy_MODERN
	SslPolicy_RESTRICTED                                                                                                  = src.SslPolicy_RESTRICTED
	SslPolicy_TLS_1_0                                                                                                     = src.SslPolicy_TLS_1_0
	SslPolicy_TLS_1_1                                                                                                     = src.SslPolicy_TLS_1_1
	SslPolicy_TLS_1_2                                                                                                     = src.SslPolicy_TLS_1_2
	SslPolicy_UNDEFINED_MIN_TLS_VERSION                                                                                   = src.SslPolicy_UNDEFINED_MIN_TLS_VERSION
	SslPolicy_UNDEFINED_PROFILE                                                                                           = src.SslPolicy_UNDEFINED_PROFILE
	StatefulPolicyPreservedStateDiskDevice_NEVER                                                                          = src.StatefulPolicyPreservedStateDiskDevice_NEVER
	StatefulPolicyPreservedStateDiskDevice_ON_PERMANENT_INSTANCE_DELETION                                                 = src.StatefulPolicyPreservedStateDiskDevice_ON_PERMANENT_INSTANCE_DELETION
	StatefulPolicyPreservedStateDiskDevice_UNDEFINED_AUTO_DELETE                                                          = src.StatefulPolicyPreservedStateDiskDevice_UNDEFINED_AUTO_DELETE
	StatefulPolicyPreservedStateNetworkIp_NEVER                                                                           = src.StatefulPolicyPreservedStateNetworkIp_NEVER
	StatefulPolicyPreservedStateNetworkIp_ON_PERMANENT_INSTANCE_DELETION                                                  = src.StatefulPolicyPreservedStateNetworkIp_ON_PERMANENT_INSTANCE_DELETION
	StatefulPolicyPreservedStateNetworkIp_UNDEFINED_AUTO_DELETE                                                           = src.StatefulPolicyPreservedStateNetworkIp_UNDEFINED_AUTO_DELETE
	StoragePoolDisk_CREATING                                                                                              = src.StoragePoolDisk_CREATING
	StoragePoolDisk_DELETING                                                                                              = src.StoragePoolDisk_DELETING
	StoragePoolDisk_FAILED                                                                                                = src.StoragePoolDisk_FAILED
	StoragePoolDisk_READY                                                                                                 = src.StoragePoolDisk_READY
	StoragePoolDisk_RESTORING                                                                                             = src.StoragePoolDisk_RESTORING
	StoragePoolDisk_UNAVAILABLE                                                                                           = src.StoragePoolDisk_UNAVAILABLE
	StoragePoolDisk_UNDEFINED_STATUS                                                                                      = src.StoragePoolDisk_UNDEFINED_STATUS
	StoragePool_CREATING                                                                                                  = src.StoragePool_CREATING
	StoragePool_DELETING                                                                                                  = src.StoragePool_DELETING
	StoragePool_FAILED                                                                                                    = src.StoragePool_FAILED
	StoragePool_READY                                                                                                     = src.StoragePool_READY
	StoragePool_UNDEFINED_CAPACITY_PROVISIONING_TYPE                                                                      = src.StoragePool_UNDEFINED_CAPACITY_PROVISIONING_TYPE
	StoragePool_UNDEFINED_PERFORMANCE_PROVISIONING_TYPE                                                                   = src.StoragePool_UNDEFINED_PERFORMANCE_PROVISIONING_TYPE
	StoragePool_UNDEFINED_STATE                                                                                           = src.StoragePool_UNDEFINED_STATE
	SubnetworkLogConfig_CUSTOM_METADATA                                                                                   = src.SubnetworkLogConfig_CUSTOM_METADATA
	SubnetworkLogConfig_EXCLUDE_ALL_METADATA                                                                              = src.SubnetworkLogConfig_EXCLUDE_ALL_METADATA
	SubnetworkLogConfig_INCLUDE_ALL_METADATA                                                                              = src.SubnetworkLogConfig_INCLUDE_ALL_METADATA
	SubnetworkLogConfig_INTERVAL_10_MIN                                                                                   = src.SubnetworkLogConfig_INTERVAL_10_MIN
	SubnetworkLogConfig_INTERVAL_15_MIN                                                                                   = src.SubnetworkLogConfig_INTERVAL_15_MIN
	SubnetworkLogConfig_INTERVAL_1_MIN                                                                                    = src.SubnetworkLogConfig_INTERVAL_1_MIN
	SubnetworkLogConfig_INTERVAL_30_SEC                                                                                   = src.SubnetworkLogConfig_INTERVAL_30_SEC
	SubnetworkLogConfig_INTERVAL_5_MIN                                                                                    = src.SubnetworkLogConfig_INTERVAL_5_MIN
	SubnetworkLogConfig_INTERVAL_5_SEC                                                                                    = src.SubnetworkLogConfig_INTERVAL_5_SEC
	SubnetworkLogConfig_UNDEFINED_AGGREGATION_INTERVAL                                                                    = src.SubnetworkLogConfig_UNDEFINED_AGGREGATION_INTERVAL
	SubnetworkLogConfig_UNDEFINED_METADATA                                                                                = src.SubnetworkLogConfig_UNDEFINED_METADATA
	Subnetwork_ACTIVE                                                                                                     = src.Subnetwork_ACTIVE
	Subnetwork_BACKUP                                                                                                     = src.Subnetwork_BACKUP
	Subnetwork_DISABLE_GOOGLE_ACCESS                                                                                      = src.Subnetwork_DISABLE_GOOGLE_ACCESS
	Subnetwork_DRAINING                                                                                                   = src.Subnetwork_DRAINING
	Subnetwork_ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE                                                                      = src.Subnetwork_ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE
	Subnetwork_ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE                                                                        = src.Subnetwork_ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE
	Subnetwork_EXTERNAL                                                                                                   = src.Subnetwork_EXTERNAL
	Subnetwork_GLOBAL_MANAGED_PROXY                                                                                       = src.Subnetwork_GLOBAL_MANAGED_PROXY
	Subnetwork_INTERNAL                                                                                                   = src.Subnetwork_INTERNAL
	Subnetwork_INTERNAL_HTTPS_LOAD_BALANCER                                                                               = src.Subnetwork_INTERNAL_HTTPS_LOAD_BALANCER
	Subnetwork_IPV4_IPV6                                                                                                  = src.Subnetwork_IPV4_IPV6
	Subnetwork_IPV4_ONLY                                                                                                  = src.Subnetwork_IPV4_ONLY
	Subnetwork_IPV6_ONLY                                                                                                  = src.Subnetwork_IPV6_ONLY
	Subnetwork_PRIVATE                                                                                                    = src.Subnetwork_PRIVATE
	Subnetwork_PRIVATE_NAT                                                                                                = src.Subnetwork_PRIVATE_NAT
	Subnetwork_PRIVATE_RFC_1918                                                                                           = src.Subnetwork_PRIVATE_RFC_1918
	Subnetwork_PRIVATE_SERVICE_CONNECT                                                                                    = src.Subnetwork_PRIVATE_SERVICE_CONNECT
	Subnetwork_READY                                                                                                      = src.Subnetwork_READY
	Subnetwork_REGIONAL_MANAGED_PROXY                                                                                     = src.Subnetwork_REGIONAL_MANAGED_PROXY
	Subnetwork_UNDEFINED_IPV6_ACCESS_TYPE                                                                                 = src.Subnetwork_UNDEFINED_IPV6_ACCESS_TYPE
	Subnetwork_UNDEFINED_PRIVATE_IPV6_GOOGLE_ACCESS                                                                       = src.Subnetwork_UNDEFINED_PRIVATE_IPV6_GOOGLE_ACCESS
	Subnetwork_UNDEFINED_PURPOSE                                                                                          = src.Subnetwork_UNDEFINED_PURPOSE
	Subnetwork_UNDEFINED_ROLE                                                                                             = src.Subnetwork_UNDEFINED_ROLE
	Subnetwork_UNDEFINED_STACK_TYPE                                                                                       = src.Subnetwork_UNDEFINED_STACK_TYPE
	Subnetwork_UNDEFINED_STATE                                                                                            = src.Subnetwork_UNDEFINED_STATE
	Subnetwork_UNSPECIFIED_IPV6_ACCESS_TYPE                                                                               = src.Subnetwork_UNSPECIFIED_IPV6_ACCESS_TYPE
	Subnetwork_UNSPECIFIED_STACK_TYPE                                                                                     = src.Subnetwork_UNSPECIFIED_STACK_TYPE
	Subsetting_CONSISTENT_HASH_SUBSETTING                                                                                 = src.Subsetting_CONSISTENT_HASH_SUBSETTING
	Subsetting_NONE                                                                                                       = src.Subsetting_NONE
	Subsetting_UNDEFINED_POLICY                                                                                           = src.Subsetting_UNDEFINED_POLICY
	TCPHealthCheck_NONE                                                                                                   = src.TCPHealthCheck_NONE
	TCPHealthCheck_PROXY_V1                                                                                               = src.TCPHealthCheck_PROXY_V1
	TCPHealthCheck_UNDEFINED_PORT_SPECIFICATION                                                                           = src.TCPHealthCheck_UNDEFINED_PORT_SPECIFICATION
	TCPHealthCheck_UNDEFINED_PROXY_HEADER                                                                                 = src.TCPHealthCheck_UNDEFINED_PROXY_HEADER
	TCPHealthCheck_USE_FIXED_PORT                                                                                         = src.TCPHealthCheck_USE_FIXED_PORT
	TCPHealthCheck_USE_NAMED_PORT                                                                                         = src.TCPHealthCheck_USE_NAMED_PORT
	TCPHealthCheck_USE_SERVING_PORT                                                                                       = src.TCPHealthCheck_USE_SERVING_PORT
	TargetHttpsProxiesSetQuicOverrideRequest_DISABLE                                                                      = src.TargetHttpsProxiesSetQuicOverrideRequest_DISABLE
	TargetHttpsProxiesSetQuicOverrideRequest_ENABLE                                                                       = src.TargetHttpsProxiesSetQuicOverrideRequest_ENABLE
	TargetHttpsProxiesSetQuicOverrideRequest_NONE                                                                         = src.TargetHttpsProxiesSetQuicOverrideRequest_NONE
	TargetHttpsProxiesSetQuicOverrideRequest_UNDEFINED_QUIC_OVERRIDE                                                      = src.TargetHttpsProxiesSetQuicOverrideRequest_UNDEFINED_QUIC_OVERRIDE
	TargetHttpsProxy_DISABLE                                                                                              = src.TargetHttpsProxy_DISABLE
	TargetHttpsProxy_DISABLED                                                                                             = src.TargetHttpsProxy_DISABLED
	TargetHttpsProxy_ENABLE                                                                                               = src.TargetHttpsProxy_ENABLE
	TargetHttpsProxy_NONE                                                                                                 = src.TargetHttpsProxy_NONE
	TargetHttpsProxy_PERMISSIVE                                                                                           = src.TargetHttpsProxy_PERMISSIVE
	TargetHttpsProxy_STRICT                                                                                               = src.TargetHttpsProxy_STRICT
	TargetHttpsProxy_UNDEFINED_QUIC_OVERRIDE                                                                              = src.TargetHttpsProxy_UNDEFINED_QUIC_OVERRIDE
	TargetHttpsProxy_UNDEFINED_TLS_EARLY_DATA                                                                             = src.TargetHttpsProxy_UNDEFINED_TLS_EARLY_DATA
	TargetInstance_NO_NAT                                                                                                 = src.TargetInstance_NO_NAT
	TargetInstance_UNDEFINED_NAT_POLICY                                                                                   = src.TargetInstance_UNDEFINED_NAT_POLICY
	TargetPool_CLIENT_IP                                                                                                  = src.TargetPool_CLIENT_IP
	TargetPool_CLIENT_IP_NO_DESTINATION                                                                                   = src.TargetPool_CLIENT_IP_NO_DESTINATION
	TargetPool_CLIENT_IP_PORT_PROTO                                                                                       = src.TargetPool_CLIENT_IP_PORT_PROTO
	TargetPool_CLIENT_IP_PROTO                                                                                            = src.TargetPool_CLIENT_IP_PROTO
	TargetPool_GENERATED_COOKIE                                                                                           = src.TargetPool_GENERATED_COOKIE
	TargetPool_HEADER_FIELD                                                                                               = src.TargetPool_HEADER_FIELD
	TargetPool_HTTP_COOKIE                                                                                                = src.TargetPool_HTTP_COOKIE
	TargetPool_NONE                                                                                                       = src.TargetPool_NONE
	TargetPool_STRONG_COOKIE_AFFINITY                                                                                     = src.TargetPool_STRONG_COOKIE_AFFINITY
	TargetPool_UNDEFINED_SESSION_AFFINITY                                                                                 = src.TargetPool_UNDEFINED_SESSION_AFFINITY
	TargetSslProxiesSetProxyHeaderRequest_NONE                                                                            = src.TargetSslProxiesSetProxyHeaderRequest_NONE
	TargetSslProxiesSetProxyHeaderRequest_PROXY_V1                                                                        = src.TargetSslProxiesSetProxyHeaderRequest_PROXY_V1
	TargetSslProxiesSetProxyHeaderRequest_UNDEFINED_PROXY_HEADER                                                          = src.TargetSslProxiesSetProxyHeaderRequest_UNDEFINED_PROXY_HEADER
	TargetSslProxy_NONE                                                                                                   = src.TargetSslProxy_NONE
	TargetSslProxy_PROXY_V1                                                                                               = src.TargetSslProxy_PROXY_V1
	TargetSslProxy_UNDEFINED_PROXY_HEADER                                                                                 = src.TargetSslProxy_UNDEFINED_PROXY_HEADER
	TargetTcpProxiesSetProxyHeaderRequest_NONE                                                                            = src.TargetTcpProxiesSetProxyHeaderRequest_NONE
	TargetTcpProxiesSetProxyHeaderRequest_PROXY_V1                                                                        = src.TargetTcpProxiesSetProxyHeaderRequest_PROXY_V1
	TargetTcpProxiesSetProxyHeaderRequest_UNDEFINED_PROXY_HEADER                                                          = src.TargetTcpProxiesSetProxyHeaderRequest_UNDEFINED_PROXY_HEADER
	TargetTcpProxy_NONE                                                                                                   = src.TargetTcpProxy_NONE
	TargetTcpProxy_PROXY_V1                                                                                               = src.TargetTcpProxy_PROXY_V1
	TargetTcpProxy_UNDEFINED_PROXY_HEADER                                                                                 = src.TargetTcpProxy_UNDEFINED_PROXY_HEADER
	TargetVpnGateway_CREATING                                                                                             = src.TargetVpnGateway_CREATING
	TargetVpnGateway_DELETING                                                                                             = src.TargetVpnGateway_DELETING
	TargetVpnGateway_FAILED                                                                                               = src.TargetVpnGateway_FAILED
	TargetVpnGateway_READY                                                                                                = src.TargetVpnGateway_READY
	TargetVpnGateway_UNDEFINED_STATUS                                                                                     = src.TargetVpnGateway_UNDEFINED_STATUS
	UpcomingMaintenance_ONGOING                                                                                           = src.UpcomingMaintenance_ONGOING
	UpcomingMaintenance_PENDING                                                                                           = src.UpcomingMaintenance_PENDING
	UpcomingMaintenance_SCHEDULED                                                                                         = src.UpcomingMaintenance_SCHEDULED
	UpcomingMaintenance_UNDEFINED_MAINTENANCE_STATUS                                                                      = src.UpcomingMaintenance_UNDEFINED_MAINTENANCE_STATUS
	UpcomingMaintenance_UNDEFINED_TYPE                                                                                    = src.UpcomingMaintenance_UNDEFINED_TYPE
	UpcomingMaintenance_UNKNOWN                                                                                           = src.UpcomingMaintenance_UNKNOWN
	UpcomingMaintenance_UNKNOWN_TYPE                                                                                      = src.UpcomingMaintenance_UNKNOWN_TYPE
	UpcomingMaintenance_UNSCHEDULED                                                                                       = src.UpcomingMaintenance_UNSCHEDULED
	UpdateInstanceRequest_UNDEFINED_MINIMAL_ACTION                                                                        = src.UpdateInstanceRequest_UNDEFINED_MINIMAL_ACTION
	UpdateInstanceRequest_UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION                                                        = src.UpdateInstanceRequest_UNDEFINED_MOST_DISRUPTIVE_ALLOWED_ACTION
	UrlMapsValidateRequest_EXTERNAL                                                                                       = src.UrlMapsValidateRequest_EXTERNAL
	UrlMapsValidateRequest_EXTERNAL_MANAGED                                                                               = src.UrlMapsValidateRequest_EXTERNAL_MANAGED
	UrlMapsValidateRequest_LOAD_BALANCING_SCHEME_UNSPECIFIED                                                              = src.UrlMapsValidateRequest_LOAD_BALANCING_SCHEME_UNSPECIFIED
	UrlMapsValidateRequest_UNDEFINED_LOAD_BALANCING_SCHEMES                                                               = src.UrlMapsValidateRequest_UNDEFINED_LOAD_BALANCING_SCHEMES
	UsableSubnetwork_ACTIVE                                                                                               = src.UsableSubnetwork_ACTIVE
	UsableSubnetwork_BACKUP                                                                                               = src.UsableSubnetwork_BACKUP
	UsableSubnetwork_EXTERNAL                                                                                             = src.UsableSubnetwork_EXTERNAL
	UsableSubnetwork_GLOBAL_MANAGED_PROXY                                                                                 = src.UsableSubnetwork_GLOBAL_MANAGED_PROXY
	UsableSubnetwork_INTERNAL                                                                                             = src.UsableSubnetwork_INTERNAL
	UsableSubnetwork_INTERNAL_HTTPS_LOAD_BALANCER                                                                         = src.UsableSubnetwork_INTERNAL_HTTPS_LOAD_BALANCER
	UsableSubnetwork_IPV4_IPV6                                                                                            = src.UsableSubnetwork_IPV4_IPV6
	UsableSubnetwork_IPV4_ONLY                                                                                            = src.UsableSubnetwork_IPV4_ONLY
	UsableSubnetwork_IPV6_ONLY                                                                                            = src.UsableSubnetwork_IPV6_ONLY
	UsableSubnetwork_PRIVATE                                                                                              = src.UsableSubnetwork_PRIVATE
	UsableSubnetwork_PRIVATE_NAT                                                                                          = src.UsableSubnetwork_PRIVATE_NAT
	UsableSubnetwork_PRIVATE_RFC_1918                                                                                     = src.UsableSubnetwork_PRIVATE_RFC_1918
	UsableSubnetwork_PRIVATE_SERVICE_CONNECT                                                                              = src.UsableSubnetwork_PRIVATE_SERVICE_CONNECT
	UsableSubnetwork_REGIONAL_MANAGED_PROXY                                                                               = src.UsableSubnetwork_REGIONAL_MANAGED_PROXY
	UsableSubnetwork_UNDEFINED_IPV6_ACCESS_TYPE                                                                           = src.UsableSubnetwork_UNDEFINED_IPV6_ACCESS_TYPE
	UsableSubnetwork_UNDEFINED_PURPOSE                                                                                    = src.UsableSubnetwork_UNDEFINED_PURPOSE
	UsableSubnetwork_UNDEFINED_ROLE                                                                                       = src.UsableSubnetwork_UNDEFINED_ROLE
	UsableSubnetwork_UNDEFINED_STACK_TYPE                                                                                 = src.UsableSubnetwork_UNDEFINED_STACK_TYPE
	VpnGatewayStatusHighAvailabilityRequirementState_CONNECTION_REDUNDANCY_MET                                            = src.VpnGatewayStatusHighAvailabilityRequirementState_CONNECTION_REDUNDANCY_MET
	VpnGatewayStatusHighAvailabilityRequirementState_CONNECTION_REDUNDANCY_NOT_MET                                        = src.VpnGatewayStatusHighAvailabilityRequirementState_CONNECTION_REDUNDANCY_NOT_MET
	VpnGatewayStatusHighAvailabilityRequirementState_INCOMPLETE_TUNNELS_COVERAGE                                          = src.VpnGatewayStatusHighAvailabilityRequirementState_INCOMPLETE_TUNNELS_COVERAGE
	VpnGatewayStatusHighAvailabilityRequirementState_UNDEFINED_STATE                                                      = src.VpnGatewayStatusHighAvailabilityRequirementState_UNDEFINED_STATE
	VpnGatewayStatusHighAvailabilityRequirementState_UNDEFINED_UNSATISFIED_REASON                                         = src.VpnGatewayStatusHighAvailabilityRequirementState_UNDEFINED_UNSATISFIED_REASON
	VpnGateway_IPV4                                                                                                       = src.VpnGateway_IPV4
	VpnGateway_IPV4_IPV6                                                                                                  = src.VpnGateway_IPV4_IPV6
	VpnGateway_IPV4_ONLY                                                                                                  = src.VpnGateway_IPV4_ONLY
	VpnGateway_IPV6                                                                                                       = src.VpnGateway_IPV6
	VpnGateway_IPV6_ONLY                                                                                                  = src.VpnGateway_IPV6_ONLY
	VpnGateway_UNDEFINED_GATEWAY_IP_VERSION                                                                               = src.VpnGateway_UNDEFINED_GATEWAY_IP_VERSION
	VpnGateway_UNDEFINED_STACK_TYPE                                                                                       = src.VpnGateway_UNDEFINED_STACK_TYPE
	VpnTunnel_ALLOCATING_RESOURCES                                                                                        = src.VpnTunnel_ALLOCATING_RESOURCES
	VpnTunnel_AUTHORIZATION_ERROR                                                                                         = src.VpnTunnel_AUTHORIZATION_ERROR
	VpnTunnel_DEPROVISIONING                                                                                              = src.VpnTunnel_DEPROVISIONING
	VpnTunnel_ESTABLISHED                                                                                                 = src.VpnTunnel_ESTABLISHED
	VpnTunnel_FAILED                                                                                                      = src.VpnTunnel_FAILED
	VpnTunnel_FIRST_HANDSHAKE                                                                                             = src.VpnTunnel_FIRST_HANDSHAKE
	VpnTunnel_NEGOTIATION_FAILURE                                                                                         = src.VpnTunnel_NEGOTIATION_FAILURE
	VpnTunnel_NETWORK_ERROR                                                                                               = src.VpnTunnel_NETWORK_ERROR
	VpnTunnel_NO_INCOMING_PACKETS                                                                                         = src.VpnTunnel_NO_INCOMING_PACKETS
	VpnTunnel_PROVISIONING                                                                                                = src.VpnTunnel_PROVISIONING
	VpnTunnel_REJECTED                                                                                                    = src.VpnTunnel_REJECTED
	VpnTunnel_STOPPED                                                                                                     = src.VpnTunnel_STOPPED
	VpnTunnel_UNDEFINED_STATUS                                                                                            = src.VpnTunnel_UNDEFINED_STATUS
	VpnTunnel_WAITING_FOR_FULL_CONFIG                                                                                     = src.VpnTunnel_WAITING_FOR_FULL_CONFIG
	Warning_CLEANUP_FAILED                                                                                                = src.Warning_CLEANUP_FAILED
	Warning_DEPRECATED_RESOURCE_USED                                                                                      = src.Warning_DEPRECATED_RESOURCE_USED
	Warning_DEPRECATED_TYPE_USED                                                                                          = src.Warning_DEPRECATED_TYPE_USED
	Warning_DISK_SIZE_LARGER_THAN_IMAGE_SIZE                                                                              = src.Warning_DISK_SIZE_LARGER_THAN_IMAGE_SIZE
	Warning_EXPERIMENTAL_TYPE_USED                                                                                        = src.Warning_EXPERIMENTAL_TYPE_USED
	Warning_EXTERNAL_API_WARNING                                                                                          = src.Warning_EXTERNAL_API_WARNING
	Warning_FIELD_VALUE_OVERRIDEN                                                                                         = src.Warning_FIELD_VALUE_OVERRIDEN
	Warning_INJECTED_KERNELS_DEPRECATED                                                                                   = src.Warning_INJECTED_KERNELS_DEPRECATED
	Warning_INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB                                                                  = src.Warning_INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB
	Warning_LARGE_DEPLOYMENT_WARNING                                                                                      = src.Warning_LARGE_DEPLOYMENT_WARNING
	Warning_LIST_OVERHEAD_QUOTA_EXCEED                                                                                    = src.Warning_LIST_OVERHEAD_QUOTA_EXCEED
	Warning_MISSING_TYPE_DEPENDENCY                                                                                       = src.Warning_MISSING_TYPE_DEPENDENCY
	Warning_NEXT_HOP_ADDRESS_NOT_ASSIGNED                                                                                 = src.Warning_NEXT_HOP_ADDRESS_NOT_ASSIGNED
	Warning_NEXT_HOP_CANNOT_IP_FORWARD                                                                                    = src.Warning_NEXT_HOP_CANNOT_IP_FORWARD
	Warning_NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE                                                                       = src.Warning_NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE
	Warning_NEXT_HOP_INSTANCE_NOT_FOUND                                                                                   = src.Warning_NEXT_HOP_INSTANCE_NOT_FOUND
	Warning_NEXT_HOP_INSTANCE_NOT_ON_NETWORK                                                                              = src.Warning_NEXT_HOP_INSTANCE_NOT_ON_NETWORK
	Warning_NEXT_HOP_NOT_RUNNING                                                                                          = src.Warning_NEXT_HOP_NOT_RUNNING
	Warning_NOT_CRITICAL_ERROR                                                                                            = src.Warning_NOT_CRITICAL_ERROR
	Warning_NO_RESULTS_ON_PAGE                                                                                            = src.Warning_NO_RESULTS_ON_PAGE
	Warning_PARTIAL_SUCCESS                                                                                               = src.Warning_PARTIAL_SUCCESS
	Warning_REQUIRED_TOS_AGREEMENT                                                                                        = src.Warning_REQUIRED_TOS_AGREEMENT
	Warning_RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING                                                                     = src.Warning_RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING
	Warning_RESOURCE_NOT_DELETED                                                                                          = src.Warning_RESOURCE_NOT_DELETED
	Warning_SCHEMA_VALIDATION_IGNORED                                                                                     = src.Warning_SCHEMA_VALIDATION_IGNORED
	Warning_SINGLE_INSTANCE_PROPERTY_TEMPLATE                                                                             = src.Warning_SINGLE_INSTANCE_PROPERTY_TEMPLATE
	Warning_UNDECLARED_PROPERTIES                                                                                         = src.Warning_UNDECLARED_PROPERTIES
	Warning_UNDEFINED_CODE                                                                                                = src.Warning_UNDEFINED_CODE
	Warning_UNREACHABLE                                                                                                   = src.Warning_UNREACHABLE
	Warnings_CLEANUP_FAILED                                                                                               = src.Warnings_CLEANUP_FAILED
	Warnings_DEPRECATED_RESOURCE_USED                                                                                     = src.Warnings_DEPRECATED_RESOURCE_USED
	Warnings_DEPRECATED_TYPE_USED                                                                                         = src.Warnings_DEPRECATED_TYPE_USED
	Warnings_DISK_SIZE_LARGER_THAN_IMAGE_SIZE                                                                             = src.Warnings_DISK_SIZE_LARGER_THAN_IMAGE_SIZE
	Warnings_EXPERIMENTAL_TYPE_USED                                                                                       = src.Warnings_EXPERIMENTAL_TYPE_USED
	Warnings_EXTERNAL_API_WARNING                                                                                         = src.Warnings_EXTERNAL_API_WARNING
	Warnings_FIELD_VALUE_OVERRIDEN                                                                                        = src.Warnings_FIELD_VALUE_OVERRIDEN
	Warnings_INJECTED_KERNELS_DEPRECATED                                                                                  = src.Warnings_INJECTED_KERNELS_DEPRECATED
	Warnings_INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB                                                                 = src.Warnings_INVALID_HEALTH_CHECK_FOR_DYNAMIC_WIEGHTED_LB
	Warnings_LARGE_DEPLOYMENT_WARNING                                                                                     = src.Warnings_LARGE_DEPLOYMENT_WARNING
	Warnings_LIST_OVERHEAD_QUOTA_EXCEED                                                                                   = src.Warnings_LIST_OVERHEAD_QUOTA_EXCEED
	Warnings_MISSING_TYPE_DEPENDENCY                                                                                      = src.Warnings_MISSING_TYPE_DEPENDENCY
	Warnings_NEXT_HOP_ADDRESS_NOT_ASSIGNED                                                                                = src.Warnings_NEXT_HOP_ADDRESS_NOT_ASSIGNED
	Warnings_NEXT_HOP_CANNOT_IP_FORWARD                                                                                   = src.Warnings_NEXT_HOP_CANNOT_IP_FORWARD
	Warnings_NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE                                                                      = src.Warnings_NEXT_HOP_INSTANCE_HAS_NO_IPV6_INTERFACE
	Warnings_NEXT_HOP_INSTANCE_NOT_FOUND                                                                                  = src.Warnings_NEXT_HOP_INSTANCE_NOT_FOUND
	Warnings_NEXT_HOP_INSTANCE_NOT_ON_NETWORK                                                                             = src.Warnings_NEXT_HOP_INSTANCE_NOT_ON_NETWORK
	Warnings_NEXT_HOP_NOT_RUNNING                                                                                         = src.Warnings_NEXT_HOP_NOT_RUNNING
	Warnings_NOT_CRITICAL_ERROR                                                                                           = src.Warnings_NOT_CRITICAL_ERROR
	Warnings_NO_RESULTS_ON_PAGE                                                                                           = src.Warnings_NO_RESULTS_ON_PAGE
	Warnings_PARTIAL_SUCCESS                                                                                              = src.Warnings_PARTIAL_SUCCESS
	Warnings_REQUIRED_TOS_AGREEMENT                                                                                       = src.Warnings_REQUIRED_TOS_AGREEMENT
	Warnings_RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING                                                                    = src.Warnings_RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING
	Warnings_RESOURCE_NOT_DELETED                                                                                         = src.Warnings_RESOURCE_NOT_DELETED
	Warnings_SCHEMA_VALIDATION_IGNORED                                                                                    = src.Warnings_SCHEMA_VALIDATION_IGNORED
	Warnings_SINGLE_INSTANCE_PROPERTY_TEMPLATE                                                                            = src.Warnings_SINGLE_INSTANCE_PROPERTY_TEMPLATE
	Warnings_UNDECLARED_PROPERTIES                                                                                        = src.Warnings_UNDECLARED_PROPERTIES
	Warnings_UNDEFINED_CODE                                                                                               = src.Warnings_UNDEFINED_CODE
	Warnings_UNREACHABLE                                                                                                  = src.Warnings_UNREACHABLE
	XpnResourceId_PROJECT                                                                                                 = src.XpnResourceId_PROJECT
	XpnResourceId_UNDEFINED_TYPE                                                                                          = src.XpnResourceId_UNDEFINED_TYPE
	XpnResourceId_XPN_RESOURCE_TYPE_UNSPECIFIED                                                                           = src.XpnResourceId_XPN_RESOURCE_TYPE_UNSPECIFIED
	Zone_DOWN                                                                                                             = src.Zone_DOWN
	Zone_UNDEFINED_STATUS                                                                                                 = src.Zone_UNDEFINED_STATUS
	Zone_UP                                                                                                               = src.Zone_UP
)

// Deprecated: Please use vars in: cloud.google.com/go/compute/apiv1/computepb
var (
	AccessConfig_NetworkTier_name                                                                                   = src.AccessConfig_NetworkTier_name
	AccessConfig_NetworkTier_value                                                                                  = src.AccessConfig_NetworkTier_value
	AccessConfig_Type_name                                                                                          = src.AccessConfig_Type_name
	AccessConfig_Type_value                                                                                         = src.AccessConfig_Type_value
	Address_AddressType_name                                                                                        = src.Address_AddressType_name
	Address_AddressType_value                                                                                       = src.Address_AddressType_value
	Address_IpVersion_name                                                                                          = src.Address_IpVersion_name
	Address_IpVersion_value                                                                                         = src.Address_IpVersion_value
	Address_Ipv6EndpointType_name                                                                                   = src.Address_Ipv6EndpointType_name
	Address_Ipv6EndpointType_value                                                                                  = src.Address_Ipv6EndpointType_value
	Address_NetworkTier_name                                                                                        = src.Address_NetworkTier_name
	Address_NetworkTier_value                                                                                       = src.Address_NetworkTier_value
	Address_Purpose_name                                                                                            = src.Address_Purpose_name
	Address_Purpose_value                                                                                           = src.Address_Purpose_value
	Address_Status_name                                                                                             = src.Address_Status_name
	Address_Status_value                                                                                            = src.Address_Status_value
	AdvancedMachineFeatures_PerformanceMonitoringUnit_name                                                          = src.AdvancedMachineFeatures_PerformanceMonitoringUnit_name
	AdvancedMachineFeatures_PerformanceMonitoringUnit_value                                                         = src.AdvancedMachineFeatures_PerformanceMonitoringUnit_value
	AllocationAggregateReservation_VmFamily_name                                                                    = src.AllocationAggregateReservation_VmFamily_name
	AllocationAggregateReservation_VmFamily_value                                                                   = src.AllocationAggregateReservation_VmFamily_value
	AllocationAggregateReservation_WorkloadType_name                                                                = src.AllocationAggregateReservation_WorkloadType_name
	AllocationAggregateReservation_WorkloadType_value                                                               = src.AllocationAggregateReservation_WorkloadType_value
	AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_Interface_name                           = src.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_Interface_name
	AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_Interface_value                          = src.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_Interface_value
	AttachedDiskInitializeParams_Architecture_name                                                                  = src.AttachedDiskInitializeParams_Architecture_name
	AttachedDiskInitializeParams_Architecture_value                                                                 = src.AttachedDiskInitializeParams_Architecture_value
	AttachedDiskInitializeParams_OnUpdateAction_name                                                                = src.AttachedDiskInitializeParams_OnUpdateAction_name
	AttachedDiskInitializeParams_OnUpdateAction_value                                                               = src.AttachedDiskInitializeParams_OnUpdateAction_value
	AttachedDisk_Architecture_name                                                                                  = src.AttachedDisk_Architecture_name
	AttachedDisk_Architecture_value                                                                                 = src.AttachedDisk_Architecture_value
	AttachedDisk_Interface_name                                                                                     = src.AttachedDisk_Interface_name
	AttachedDisk_Interface_value                                                                                    = src.AttachedDisk_Interface_value
	AttachedDisk_Mode_name                                                                                          = src.AttachedDisk_Mode_name
	AttachedDisk_Mode_value                                                                                         = src.AttachedDisk_Mode_value
	AttachedDisk_SavedState_name                                                                                    = src.AttachedDisk_SavedState_name
	AttachedDisk_SavedState_value                                                                                   = src.AttachedDisk_SavedState_value
	AttachedDisk_Type_name                                                                                          = src.AttachedDisk_Type_name
	AttachedDisk_Type_value                                                                                         = src.AttachedDisk_Type_value
	AuditLogConfig_LogType_name                                                                                     = src.AuditLogConfig_LogType_name
	AuditLogConfig_LogType_value                                                                                    = src.AuditLogConfig_LogType_value
	AutoscalerStatusDetails_Type_name                                                                               = src.AutoscalerStatusDetails_Type_name
	AutoscalerStatusDetails_Type_value                                                                              = src.AutoscalerStatusDetails_Type_value
	Autoscaler_Status_name                                                                                          = src.Autoscaler_Status_name
	Autoscaler_Status_value                                                                                         = src.Autoscaler_Status_value
	AutoscalingPolicyCpuUtilization_PredictiveMethod_name                                                           = src.AutoscalingPolicyCpuUtilization_PredictiveMethod_name
	AutoscalingPolicyCpuUtilization_PredictiveMethod_value                                                          = src.AutoscalingPolicyCpuUtilization_PredictiveMethod_value
	AutoscalingPolicyCustomMetricUtilization_UtilizationTargetType_name                                             = src.AutoscalingPolicyCustomMetricUtilization_UtilizationTargetType_name
	AutoscalingPolicyCustomMetricUtilization_UtilizationTargetType_value                                            = src.AutoscalingPolicyCustomMetricUtilization_UtilizationTargetType_value
	AutoscalingPolicy_Mode_name                                                                                     = src.AutoscalingPolicy_Mode_name
	AutoscalingPolicy_Mode_value                                                                                    = src.AutoscalingPolicy_Mode_value
	BackendBucketCdnPolicy_CacheMode_name                                                                           = src.BackendBucketCdnPolicy_CacheMode_name
	BackendBucketCdnPolicy_CacheMode_value                                                                          = src.BackendBucketCdnPolicy_CacheMode_value
	BackendBucket_CompressionMode_name                                                                              = src.BackendBucket_CompressionMode_name
	BackendBucket_CompressionMode_value                                                                             = src.BackendBucket_CompressionMode_value
	BackendServiceCdnPolicy_CacheMode_name                                                                          = src.BackendServiceCdnPolicy_CacheMode_name
	BackendServiceCdnPolicy_CacheMode_value                                                                         = src.BackendServiceCdnPolicy_CacheMode_value
	BackendServiceConnectionTrackingPolicy_ConnectionPersistenceOnUnhealthyBackends_name                            = src.BackendServiceConnectionTrackingPolicy_ConnectionPersistenceOnUnhealthyBackends_name
	BackendServiceConnectionTrackingPolicy_ConnectionPersistenceOnUnhealthyBackends_value                           = src.BackendServiceConnectionTrackingPolicy_ConnectionPersistenceOnUnhealthyBackends_value
	BackendServiceConnectionTrackingPolicy_TrackingMode_name                                                        = src.BackendServiceConnectionTrackingPolicy_TrackingMode_name
	BackendServiceConnectionTrackingPolicy_TrackingMode_value                                                       = src.BackendServiceConnectionTrackingPolicy_TrackingMode_value
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name_name                                                 = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name_name
	BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name_value                                                = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name_value
	BackendServiceLogConfig_OptionalMode_name                                                                       = src.BackendServiceLogConfig_OptionalMode_name
	BackendServiceLogConfig_OptionalMode_value                                                                      = src.BackendServiceLogConfig_OptionalMode_value
	BackendService_CompressionMode_name                                                                             = src.BackendService_CompressionMode_name
	BackendService_CompressionMode_value                                                                            = src.BackendService_CompressionMode_value
	BackendService_IpAddressSelectionPolicy_name                                                                    = src.BackendService_IpAddressSelectionPolicy_name
	BackendService_IpAddressSelectionPolicy_value                                                                   = src.BackendService_IpAddressSelectionPolicy_value
	BackendService_LoadBalancingScheme_name                                                                         = src.BackendService_LoadBalancingScheme_name
	BackendService_LoadBalancingScheme_value                                                                        = src.BackendService_LoadBalancingScheme_value
	BackendService_LocalityLbPolicy_name                                                                            = src.BackendService_LocalityLbPolicy_name
	BackendService_LocalityLbPolicy_value                                                                           = src.BackendService_LocalityLbPolicy_value
	BackendService_Protocol_name                                                                                    = src.BackendService_Protocol_name
	BackendService_Protocol_value                                                                                   = src.BackendService_Protocol_value
	BackendService_SessionAffinity_name                                                                             = src.BackendService_SessionAffinity_name
	BackendService_SessionAffinity_value                                                                            = src.BackendService_SessionAffinity_value
	Backend_BalancingMode_name                                                                                      = src.Backend_BalancingMode_name
	Backend_BalancingMode_value                                                                                     = src.Backend_BalancingMode_value
	Backend_Preference_name                                                                                         = src.Backend_Preference_name
	Backend_Preference_value                                                                                        = src.Backend_Preference_value
	BfdPacket_Diagnostic_name                                                                                       = src.BfdPacket_Diagnostic_name
	BfdPacket_Diagnostic_value                                                                                      = src.BfdPacket_Diagnostic_value
	BfdPacket_State_name                                                                                            = src.BfdPacket_State_name
	BfdPacket_State_value                                                                                           = src.BfdPacket_State_value
	BfdStatus_BfdSessionInitializationMode_name                                                                     = src.BfdStatus_BfdSessionInitializationMode_name
	BfdStatus_BfdSessionInitializationMode_value                                                                    = src.BfdStatus_BfdSessionInitializationMode_value
	BfdStatus_LocalDiagnostic_name                                                                                  = src.BfdStatus_LocalDiagnostic_name
	BfdStatus_LocalDiagnostic_value                                                                                 = src.BfdStatus_LocalDiagnostic_value
	BfdStatus_LocalState_name                                                                                       = src.BfdStatus_LocalState_name
	BfdStatus_LocalState_value                                                                                      = src.BfdStatus_LocalState_value
	BulkInsertOperationStatus_Status_name                                                                           = src.BulkInsertOperationStatus_Status_name
	BulkInsertOperationStatus_Status_value                                                                          = src.BulkInsertOperationStatus_Status_value
	Commitment_Category_name                                                                                        = src.Commitment_Category_name
	Commitment_Category_value                                                                                       = src.Commitment_Category_value
	Commitment_Plan_name                                                                                            = src.Commitment_Plan_name
	Commitment_Plan_value                                                                                           = src.Commitment_Plan_value
	Commitment_Status_name                                                                                          = src.Commitment_Status_name
	Commitment_Status_value                                                                                         = src.Commitment_Status_value
	Commitment_Type_name                                                                                            = src.Commitment_Type_name
	Commitment_Type_value                                                                                           = src.Commitment_Type_value
	ConfidentialInstanceConfig_ConfidentialInstanceType_name                                                        = src.ConfidentialInstanceConfig_ConfidentialInstanceType_name
	ConfidentialInstanceConfig_ConfidentialInstanceType_value                                                       = src.ConfidentialInstanceConfig_ConfidentialInstanceType_value
	DeprecationStatus_State_name                                                                                    = src.DeprecationStatus_State_name
	DeprecationStatus_State_value                                                                                   = src.DeprecationStatus_State_value
	DiskInstantiationConfig_InstantiateFrom_name                                                                    = src.DiskInstantiationConfig_InstantiateFrom_name
	DiskInstantiationConfig_InstantiateFrom_value                                                                   = src.DiskInstantiationConfig_InstantiateFrom_value
	DiskResourceStatusAsyncReplicationStatus_State_name                                                             = src.DiskResourceStatusAsyncReplicationStatus_State_name
	DiskResourceStatusAsyncReplicationStatus_State_value                                                            = src.DiskResourceStatusAsyncReplicationStatus_State_value
	Disk_AccessMode_name                                                                                            = src.Disk_AccessMode_name
	Disk_AccessMode_value                                                                                           = src.Disk_AccessMode_value
	Disk_Architecture_name                                                                                          = src.Disk_Architecture_name
	Disk_Architecture_value                                                                                         = src.Disk_Architecture_value
	Disk_Status_name                                                                                                = src.Disk_Status_name
	Disk_Status_value                                                                                               = src.Disk_Status_value
	DistributionPolicy_TargetShape_name                                                                             = src.DistributionPolicy_TargetShape_name
	DistributionPolicy_TargetShape_value                                                                            = src.DistributionPolicy_TargetShape_value
	ExchangedPeeringRoute_Type_name                                                                                 = src.ExchangedPeeringRoute_Type_name
	ExchangedPeeringRoute_Type_value                                                                                = src.ExchangedPeeringRoute_Type_value
	ExternalVpnGateway_RedundancyType_name                                                                          = src.ExternalVpnGateway_RedundancyType_name
	ExternalVpnGateway_RedundancyType_value                                                                         = src.ExternalVpnGateway_RedundancyType_value
	FileContentBuffer_FileType_name                                                                                 = src.FileContentBuffer_FileType_name
	FileContentBuffer_FileType_value                                                                                = src.FileContentBuffer_FileType_value
	File_google_cloud_compute_v1_compute_proto                                                                      = src.File_google_cloud_compute_v1_compute_proto
	FirewallLogConfig_Metadata_name                                                                                 = src.FirewallLogConfig_Metadata_name
	FirewallLogConfig_Metadata_value                                                                                = src.FirewallLogConfig_Metadata_value
	FirewallPolicyRuleSecureTag_State_name                                                                          = src.FirewallPolicyRuleSecureTag_State_name
	FirewallPolicyRuleSecureTag_State_value                                                                         = src.FirewallPolicyRuleSecureTag_State_value
	FirewallPolicyRule_Direction_name                                                                               = src.FirewallPolicyRule_Direction_name
	FirewallPolicyRule_Direction_value                                                                              = src.FirewallPolicyRule_Direction_value
	Firewall_Direction_name                                                                                         = src.Firewall_Direction_name
	Firewall_Direction_value                                                                                        = src.Firewall_Direction_value
	ForwardingRule_IPProtocolEnum_name                                                                              = src.ForwardingRule_IPProtocolEnum_name
	ForwardingRule_IPProtocolEnum_value                                                                             = src.ForwardingRule_IPProtocolEnum_value
	ForwardingRule_IpVersion_name                                                                                   = src.ForwardingRule_IpVersion_name
	ForwardingRule_IpVersion_value                                                                                  = src.ForwardingRule_IpVersion_value
	ForwardingRule_LoadBalancingScheme_name                                                                         = src.ForwardingRule_LoadBalancingScheme_name
	ForwardingRule_LoadBalancingScheme_value                                                                        = src.ForwardingRule_LoadBalancingScheme_value
	ForwardingRule_NetworkTier_name                                                                                 = src.ForwardingRule_NetworkTier_name
	ForwardingRule_NetworkTier_value                                                                                = src.ForwardingRule_NetworkTier_value
	ForwardingRule_PscConnectionStatus_name                                                                         = src.ForwardingRule_PscConnectionStatus_name
	ForwardingRule_PscConnectionStatus_value                                                                        = src.ForwardingRule_PscConnectionStatus_value
	GRPCHealthCheck_PortSpecification_name                                                                          = src.GRPCHealthCheck_PortSpecification_name
	GRPCHealthCheck_PortSpecification_value                                                                         = src.GRPCHealthCheck_PortSpecification_value
	GuestOsFeature_Type_name                                                                                        = src.GuestOsFeature_Type_name
	GuestOsFeature_Type_value                                                                                       = src.GuestOsFeature_Type_value
	HTTP2HealthCheck_PortSpecification_name                                                                         = src.HTTP2HealthCheck_PortSpecification_name
	HTTP2HealthCheck_PortSpecification_value                                                                        = src.HTTP2HealthCheck_PortSpecification_value
	HTTP2HealthCheck_ProxyHeader_name                                                                               = src.HTTP2HealthCheck_ProxyHeader_name
	HTTP2HealthCheck_ProxyHeader_value                                                                              = src.HTTP2HealthCheck_ProxyHeader_value
	HTTPHealthCheck_PortSpecification_name                                                                          = src.HTTPHealthCheck_PortSpecification_name
	HTTPHealthCheck_PortSpecification_value                                                                         = src.HTTPHealthCheck_PortSpecification_value
	HTTPHealthCheck_ProxyHeader_name                                                                                = src.HTTPHealthCheck_ProxyHeader_name
	HTTPHealthCheck_ProxyHeader_value                                                                               = src.HTTPHealthCheck_ProxyHeader_value
	HTTPSHealthCheck_PortSpecification_name                                                                         = src.HTTPSHealthCheck_PortSpecification_name
	HTTPSHealthCheck_PortSpecification_value                                                                        = src.HTTPSHealthCheck_PortSpecification_value
	HTTPSHealthCheck_ProxyHeader_name                                                                               = src.HTTPSHealthCheck_ProxyHeader_name
	HTTPSHealthCheck_ProxyHeader_value                                                                              = src.HTTPSHealthCheck_ProxyHeader_value
	HealthCheckService_HealthStatusAggregationPolicy_name                                                           = src.HealthCheckService_HealthStatusAggregationPolicy_name
	HealthCheckService_HealthStatusAggregationPolicy_value                                                          = src.HealthCheckService_HealthStatusAggregationPolicy_value
	HealthCheck_Type_name                                                                                           = src.HealthCheck_Type_name
	HealthCheck_Type_value                                                                                          = src.HealthCheck_Type_value
	HealthStatusForNetworkEndpoint_HealthState_name                                                                 = src.HealthStatusForNetworkEndpoint_HealthState_name
	HealthStatusForNetworkEndpoint_HealthState_value                                                                = src.HealthStatusForNetworkEndpoint_HealthState_value
	HealthStatusForNetworkEndpoint_Ipv6HealthState_name                                                             = src.HealthStatusForNetworkEndpoint_Ipv6HealthState_name
	HealthStatusForNetworkEndpoint_Ipv6HealthState_value                                                            = src.HealthStatusForNetworkEndpoint_Ipv6HealthState_value
	HealthStatus_HealthState_name                                                                                   = src.HealthStatus_HealthState_name
	HealthStatus_HealthState_value                                                                                  = src.HealthStatus_HealthState_value
	HealthStatus_Ipv6HealthState_name                                                                               = src.HealthStatus_Ipv6HealthState_name
	HealthStatus_Ipv6HealthState_value                                                                              = src.HealthStatus_Ipv6HealthState_value
	HealthStatus_WeightError_name                                                                                   = src.HealthStatus_WeightError_name
	HealthStatus_WeightError_value                                                                                  = src.HealthStatus_WeightError_value
	HttpRedirectAction_RedirectResponseCode_name                                                                    = src.HttpRedirectAction_RedirectResponseCode_name
	HttpRedirectAction_RedirectResponseCode_value                                                                   = src.HttpRedirectAction_RedirectResponseCode_value
	Image_Architecture_name                                                                                         = src.Image_Architecture_name
	Image_Architecture_value                                                                                        = src.Image_Architecture_value
	Image_SourceType_name                                                                                           = src.Image_SourceType_name
	Image_SourceType_value                                                                                          = src.Image_SourceType_value
	Image_Status_name                                                                                               = src.Image_Status_name
	Image_Status_value                                                                                              = src.Image_Status_value
	InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure_name                                         = src.InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure_name
	InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure_value                                        = src.InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure_value
	InstanceGroupManagerInstanceLifecyclePolicy_ForceUpdateOnRepair_name                                            = src.InstanceGroupManagerInstanceLifecyclePolicy_ForceUpdateOnRepair_name
	InstanceGroupManagerInstanceLifecyclePolicy_ForceUpdateOnRepair_value                                           = src.InstanceGroupManagerInstanceLifecyclePolicy_ForceUpdateOnRepair_value
	InstanceGroupManagerResizeRequest_State_name                                                                    = src.InstanceGroupManagerResizeRequest_State_name
	InstanceGroupManagerResizeRequest_State_value                                                                   = src.InstanceGroupManagerResizeRequest_State_value
	InstanceGroupManagerUpdatePolicy_InstanceRedistributionType_name                                                = src.InstanceGroupManagerUpdatePolicy_InstanceRedistributionType_name
	InstanceGroupManagerUpdatePolicy_InstanceRedistributionType_value                                               = src.InstanceGroupManagerUpdatePolicy_InstanceRedistributionType_value
	InstanceGroupManagerUpdatePolicy_MinimalAction_name                                                             = src.InstanceGroupManagerUpdatePolicy_MinimalAction_name
	InstanceGroupManagerUpdatePolicy_MinimalAction_value                                                            = src.InstanceGroupManagerUpdatePolicy_MinimalAction_value
	InstanceGroupManagerUpdatePolicy_MostDisruptiveAllowedAction_name                                               = src.InstanceGroupManagerUpdatePolicy_MostDisruptiveAllowedAction_name
	InstanceGroupManagerUpdatePolicy_MostDisruptiveAllowedAction_value                                              = src.InstanceGroupManagerUpdatePolicy_MostDisruptiveAllowedAction_value
	InstanceGroupManagerUpdatePolicy_ReplacementMethod_name                                                         = src.InstanceGroupManagerUpdatePolicy_ReplacementMethod_name
	InstanceGroupManagerUpdatePolicy_ReplacementMethod_value                                                        = src.InstanceGroupManagerUpdatePolicy_ReplacementMethod_value
	InstanceGroupManagerUpdatePolicy_Type_name                                                                      = src.InstanceGroupManagerUpdatePolicy_Type_name
	InstanceGroupManagerUpdatePolicy_Type_value                                                                     = src.InstanceGroupManagerUpdatePolicy_Type_value
	InstanceGroupManager_ListManagedInstancesResults_name                                                           = src.InstanceGroupManager_ListManagedInstancesResults_name
	InstanceGroupManager_ListManagedInstancesResults_value                                                          = src.InstanceGroupManager_ListManagedInstancesResults_value
	InstanceGroupManagersApplyUpdatesRequest_MinimalAction_name                                                     = src.InstanceGroupManagersApplyUpdatesRequest_MinimalAction_name
	InstanceGroupManagersApplyUpdatesRequest_MinimalAction_value                                                    = src.InstanceGroupManagersApplyUpdatesRequest_MinimalAction_value
	InstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction_name                                       = src.InstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction_name
	InstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction_value                                      = src.InstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction_value
	InstanceGroupsListInstancesRequest_InstanceState_name                                                           = src.InstanceGroupsListInstancesRequest_InstanceState_name
	InstanceGroupsListInstancesRequest_InstanceState_value                                                          = src.InstanceGroupsListInstancesRequest_InstanceState_value
	InstanceManagedByIgmErrorInstanceActionDetails_Action_name                                                      = src.InstanceManagedByIgmErrorInstanceActionDetails_Action_name
	InstanceManagedByIgmErrorInstanceActionDetails_Action_value                                                     = src.InstanceManagedByIgmErrorInstanceActionDetails_Action_value
	InstanceProperties_KeyRevocationActionType_name                                                                 = src.InstanceProperties_KeyRevocationActionType_name
	InstanceProperties_KeyRevocationActionType_value                                                                = src.InstanceProperties_KeyRevocationActionType_value
	InstanceProperties_PrivateIpv6GoogleAccess_name                                                                 = src.InstanceProperties_PrivateIpv6GoogleAccess_name
	InstanceProperties_PrivateIpv6GoogleAccess_value                                                                = src.InstanceProperties_PrivateIpv6GoogleAccess_value
	InstanceWithNamedPorts_Status_name                                                                              = src.InstanceWithNamedPorts_Status_name
	InstanceWithNamedPorts_Status_value                                                                             = src.InstanceWithNamedPorts_Status_value
	Instance_KeyRevocationActionType_name                                                                           = src.Instance_KeyRevocationActionType_name
	Instance_KeyRevocationActionType_value                                                                          = src.Instance_KeyRevocationActionType_value
	Instance_PrivateIpv6GoogleAccess_name                                                                           = src.Instance_PrivateIpv6GoogleAccess_name
	Instance_PrivateIpv6GoogleAccess_value                                                                          = src.Instance_PrivateIpv6GoogleAccess_value
	Instance_Status_name                                                                                            = src.Instance_Status_name
	Instance_Status_value                                                                                           = src.Instance_Status_value
	InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_name                                         = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_name
	InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_value                                        = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_value
	InstantSnapshot_Architecture_name                                                                               = src.InstantSnapshot_Architecture_name
	InstantSnapshot_Architecture_value                                                                              = src.InstantSnapshot_Architecture_value
	InstantSnapshot_Status_name                                                                                     = src.InstantSnapshot_Status_name
	InstantSnapshot_Status_value                                                                                    = src.InstantSnapshot_Status_value
	InterconnectAttachmentConfigurationConstraints_BgpMd5_name                                                      = src.InterconnectAttachmentConfigurationConstraints_BgpMd5_name
	InterconnectAttachmentConfigurationConstraints_BgpMd5_value                                                     = src.InterconnectAttachmentConfigurationConstraints_BgpMd5_value
	InterconnectAttachment_Bandwidth_name                                                                           = src.InterconnectAttachment_Bandwidth_name
	InterconnectAttachment_Bandwidth_value                                                                          = src.InterconnectAttachment_Bandwidth_value
	InterconnectAttachment_EdgeAvailabilityDomain_name                                                              = src.InterconnectAttachment_EdgeAvailabilityDomain_name
	InterconnectAttachment_EdgeAvailabilityDomain_value                                                             = src.InterconnectAttachment_EdgeAvailabilityDomain_value
	InterconnectAttachment_Encryption_name                                                                          = src.InterconnectAttachment_Encryption_name
	InterconnectAttachment_Encryption_value                                                                         = src.InterconnectAttachment_Encryption_value
	InterconnectAttachment_OperationalStatus_name                                                                   = src.InterconnectAttachment_OperationalStatus_name
	InterconnectAttachment_OperationalStatus_value                                                                  = src.InterconnectAttachment_OperationalStatus_value
	InterconnectAttachment_StackType_name                                                                           = src.InterconnectAttachment_StackType_name
	InterconnectAttachment_StackType_value                                                                          = src.InterconnectAttachment_StackType_value
	InterconnectAttachment_State_name                                                                               = src.InterconnectAttachment_State_name
	InterconnectAttachment_State_value                                                                              = src.InterconnectAttachment_State_value
	InterconnectAttachment_Type_name                                                                                = src.InterconnectAttachment_Type_name
	InterconnectAttachment_Type_value                                                                               = src.InterconnectAttachment_Type_value
	InterconnectDiagnosticsLinkLACPStatus_State_name                                                                = src.InterconnectDiagnosticsLinkLACPStatus_State_name
	InterconnectDiagnosticsLinkLACPStatus_State_value                                                               = src.InterconnectDiagnosticsLinkLACPStatus_State_value
	InterconnectDiagnosticsLinkOpticalPower_State_name                                                              = src.InterconnectDiagnosticsLinkOpticalPower_State_name
	InterconnectDiagnosticsLinkOpticalPower_State_value                                                             = src.InterconnectDiagnosticsLinkOpticalPower_State_value
	InterconnectDiagnosticsLinkStatus_OperationalStatus_name                                                        = src.InterconnectDiagnosticsLinkStatus_OperationalStatus_name
	InterconnectDiagnosticsLinkStatus_OperationalStatus_value                                                       = src.InterconnectDiagnosticsLinkStatus_OperationalStatus_value
	InterconnectDiagnostics_BundleAggregationType_name                                                              = src.InterconnectDiagnostics_BundleAggregationType_name
	InterconnectDiagnostics_BundleAggregationType_value                                                             = src.InterconnectDiagnostics_BundleAggregationType_value
	InterconnectDiagnostics_BundleOperationalStatus_name                                                            = src.InterconnectDiagnostics_BundleOperationalStatus_name
	InterconnectDiagnostics_BundleOperationalStatus_value                                                           = src.InterconnectDiagnostics_BundleOperationalStatus_value
	InterconnectLocationRegionInfo_LocationPresence_name                                                            = src.InterconnectLocationRegionInfo_LocationPresence_name
	InterconnectLocationRegionInfo_LocationPresence_value                                                           = src.InterconnectLocationRegionInfo_LocationPresence_value
	InterconnectLocation_AvailableFeatures_name                                                                     = src.InterconnectLocation_AvailableFeatures_name
	InterconnectLocation_AvailableFeatures_value                                                                    = src.InterconnectLocation_AvailableFeatures_value
	InterconnectLocation_AvailableLinkTypes_name                                                                    = src.InterconnectLocation_AvailableLinkTypes_name
	InterconnectLocation_AvailableLinkTypes_value                                                                   = src.InterconnectLocation_AvailableLinkTypes_value
	InterconnectLocation_Continent_name                                                                             = src.InterconnectLocation_Continent_name
	InterconnectLocation_Continent_value                                                                            = src.InterconnectLocation_Continent_value
	InterconnectLocation_Status_name                                                                                = src.InterconnectLocation_Status_name
	InterconnectLocation_Status_value                                                                               = src.InterconnectLocation_Status_value
	InterconnectOutageNotification_IssueType_name                                                                   = src.InterconnectOutageNotification_IssueType_name
	InterconnectOutageNotification_IssueType_value                                                                  = src.InterconnectOutageNotification_IssueType_value
	InterconnectOutageNotification_Source_name                                                                      = src.InterconnectOutageNotification_Source_name
	InterconnectOutageNotification_Source_value                                                                     = src.InterconnectOutageNotification_Source_value
	InterconnectOutageNotification_State_name                                                                       = src.InterconnectOutageNotification_State_name
	InterconnectOutageNotification_State_value                                                                      = src.InterconnectOutageNotification_State_value
	InterconnectRemoteLocationConstraints_PortPairRemoteLocation_name                                               = src.InterconnectRemoteLocationConstraints_PortPairRemoteLocation_name
	InterconnectRemoteLocationConstraints_PortPairRemoteLocation_value                                              = src.InterconnectRemoteLocationConstraints_PortPairRemoteLocation_value
	InterconnectRemoteLocationConstraints_PortPairVlan_name                                                         = src.InterconnectRemoteLocationConstraints_PortPairVlan_name
	InterconnectRemoteLocationConstraints_PortPairVlan_value                                                        = src.InterconnectRemoteLocationConstraints_PortPairVlan_value
	InterconnectRemoteLocation_Continent_name                                                                       = src.InterconnectRemoteLocation_Continent_name
	InterconnectRemoteLocation_Continent_value                                                                      = src.InterconnectRemoteLocation_Continent_value
	InterconnectRemoteLocation_Lacp_name                                                                            = src.InterconnectRemoteLocation_Lacp_name
	InterconnectRemoteLocation_Lacp_value                                                                           = src.InterconnectRemoteLocation_Lacp_value
	InterconnectRemoteLocation_Status_name                                                                          = src.InterconnectRemoteLocation_Status_name
	InterconnectRemoteLocation_Status_value                                                                         = src.InterconnectRemoteLocation_Status_value
	Interconnect_AvailableFeatures_name                                                                             = src.Interconnect_AvailableFeatures_name
	Interconnect_AvailableFeatures_value                                                                            = src.Interconnect_AvailableFeatures_value
	Interconnect_InterconnectType_name                                                                              = src.Interconnect_InterconnectType_name
	Interconnect_InterconnectType_value                                                                             = src.Interconnect_InterconnectType_value
	Interconnect_LinkType_name                                                                                      = src.Interconnect_LinkType_name
	Interconnect_LinkType_value                                                                                     = src.Interconnect_LinkType_value
	Interconnect_OperationalStatus_name                                                                             = src.Interconnect_OperationalStatus_name
	Interconnect_OperationalStatus_value                                                                            = src.Interconnect_OperationalStatus_value
	Interconnect_RequestedFeatures_name                                                                             = src.Interconnect_RequestedFeatures_name
	Interconnect_RequestedFeatures_value                                                                            = src.Interconnect_RequestedFeatures_value
	Interconnect_State_name                                                                                         = src.Interconnect_State_name
	Interconnect_State_value                                                                                        = src.Interconnect_State_value
	LicenseCode_State_name                                                                                          = src.LicenseCode_State_name
	LicenseCode_State_value                                                                                         = src.LicenseCode_State_value
	ListPeeringRoutesNetworksRequest_Direction_name                                                                 = src.ListPeeringRoutesNetworksRequest_Direction_name
	ListPeeringRoutesNetworksRequest_Direction_value                                                                = src.ListPeeringRoutesNetworksRequest_Direction_value
	LocationPolicyLocation_Preference_name                                                                          = src.LocationPolicyLocation_Preference_name
	LocationPolicyLocation_Preference_value                                                                         = src.LocationPolicyLocation_Preference_value
	LocationPolicy_TargetShape_name                                                                                 = src.LocationPolicy_TargetShape_name
	LocationPolicy_TargetShape_value                                                                                = src.LocationPolicy_TargetShape_value
	MachineImage_Status_name                                                                                        = src.MachineImage_Status_name
	MachineImage_Status_value                                                                                       = src.MachineImage_Status_value
	MachineType_Architecture_name                                                                                   = src.MachineType_Architecture_name
	MachineType_Architecture_value                                                                                  = src.MachineType_Architecture_value
	ManagedInstanceInstanceHealth_DetailedHealthState_name                                                          = src.ManagedInstanceInstanceHealth_DetailedHealthState_name
	ManagedInstanceInstanceHealth_DetailedHealthState_value                                                         = src.ManagedInstanceInstanceHealth_DetailedHealthState_value
	ManagedInstance_CurrentAction_name                                                                              = src.ManagedInstance_CurrentAction_name
	ManagedInstance_CurrentAction_value                                                                             = src.ManagedInstance_CurrentAction_value
	ManagedInstance_InstanceStatus_name                                                                             = src.ManagedInstance_InstanceStatus_name
	ManagedInstance_InstanceStatus_value                                                                            = src.ManagedInstance_InstanceStatus_value
	MetadataFilter_FilterMatchCriteria_name                                                                         = src.MetadataFilter_FilterMatchCriteria_name
	MetadataFilter_FilterMatchCriteria_value                                                                        = src.MetadataFilter_FilterMatchCriteria_value
	NatIpInfoNatIpInfoMapping_Mode_name                                                                             = src.NatIpInfoNatIpInfoMapping_Mode_name
	NatIpInfoNatIpInfoMapping_Mode_value                                                                            = src.NatIpInfoNatIpInfoMapping_Mode_value
	NatIpInfoNatIpInfoMapping_Usage_name                                                                            = src.NatIpInfoNatIpInfoMapping_Usage_name
	NatIpInfoNatIpInfoMapping_Usage_value                                                                           = src.NatIpInfoNatIpInfoMapping_Usage_value
	NetworkAttachmentConnectedEndpoint_Status_name                                                                  = src.NetworkAttachmentConnectedEndpoint_Status_name
	NetworkAttachmentConnectedEndpoint_Status_value                                                                 = src.NetworkAttachmentConnectedEndpoint_Status_value
	NetworkAttachment_ConnectionPreference_name                                                                     = src.NetworkAttachment_ConnectionPreference_name
	NetworkAttachment_ConnectionPreference_value                                                                    = src.NetworkAttachment_ConnectionPreference_value
	NetworkEndpointGroupPscData_PscConnectionStatus_name                                                            = src.NetworkEndpointGroupPscData_PscConnectionStatus_name
	NetworkEndpointGroupPscData_PscConnectionStatus_value                                                           = src.NetworkEndpointGroupPscData_PscConnectionStatus_value
	NetworkEndpointGroup_NetworkEndpointType_name                                                                   = src.NetworkEndpointGroup_NetworkEndpointType_name
	NetworkEndpointGroup_NetworkEndpointType_value                                                                  = src.NetworkEndpointGroup_NetworkEndpointType_value
	NetworkEndpointGroupsListEndpointsRequest_HealthStatus_name                                                     = src.NetworkEndpointGroupsListEndpointsRequest_HealthStatus_name
	NetworkEndpointGroupsListEndpointsRequest_HealthStatus_value                                                    = src.NetworkEndpointGroupsListEndpointsRequest_HealthStatus_value
	NetworkInterface_Ipv6AccessType_name                                                                            = src.NetworkInterface_Ipv6AccessType_name
	NetworkInterface_Ipv6AccessType_value                                                                           = src.NetworkInterface_Ipv6AccessType_value
	NetworkInterface_NicType_name                                                                                   = src.NetworkInterface_NicType_name
	NetworkInterface_NicType_value                                                                                  = src.NetworkInterface_NicType_value
	NetworkInterface_StackType_name                                                                                 = src.NetworkInterface_StackType_name
	NetworkInterface_StackType_value                                                                                = src.NetworkInterface_StackType_value
	NetworkPeering_StackType_name                                                                                   = src.NetworkPeering_StackType_name
	NetworkPeering_StackType_value                                                                                  = src.NetworkPeering_StackType_value
	NetworkPeering_State_name                                                                                       = src.NetworkPeering_State_name
	NetworkPeering_State_value                                                                                      = src.NetworkPeering_State_value
	NetworkPerformanceConfig_TotalEgressBandwidthTier_name                                                          = src.NetworkPerformanceConfig_TotalEgressBandwidthTier_name
	NetworkPerformanceConfig_TotalEgressBandwidthTier_value                                                         = src.NetworkPerformanceConfig_TotalEgressBandwidthTier_value
	NetworkRoutingConfig_RoutingMode_name                                                                           = src.NetworkRoutingConfig_RoutingMode_name
	NetworkRoutingConfig_RoutingMode_value                                                                          = src.NetworkRoutingConfig_RoutingMode_value
	Network_NetworkFirewallPolicyEnforcementOrder_name                                                              = src.Network_NetworkFirewallPolicyEnforcementOrder_name
	Network_NetworkFirewallPolicyEnforcementOrder_value                                                             = src.Network_NetworkFirewallPolicyEnforcementOrder_value
	NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_name                                          = src.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_name
	NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_value                                         = src.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_value
	NodeGroupAutoscalingPolicy_Mode_name                                                                            = src.NodeGroupAutoscalingPolicy_Mode_name
	NodeGroupAutoscalingPolicy_Mode_value                                                                           = src.NodeGroupAutoscalingPolicy_Mode_value
	NodeGroupNode_CpuOvercommitType_name                                                                            = src.NodeGroupNode_CpuOvercommitType_name
	NodeGroupNode_CpuOvercommitType_value                                                                           = src.NodeGroupNode_CpuOvercommitType_value
	NodeGroupNode_Status_name                                                                                       = src.NodeGroupNode_Status_name
	NodeGroupNode_Status_value                                                                                      = src.NodeGroupNode_Status_value
	NodeGroup_MaintenanceInterval_name                                                                              = src.NodeGroup_MaintenanceInterval_name
	NodeGroup_MaintenanceInterval_value                                                                             = src.NodeGroup_MaintenanceInterval_value
	NodeGroup_MaintenancePolicy_name                                                                                = src.NodeGroup_MaintenancePolicy_name
	NodeGroup_MaintenancePolicy_value                                                                               = src.NodeGroup_MaintenancePolicy_value
	NodeGroup_Status_name                                                                                           = src.NodeGroup_Status_name
	NodeGroup_Status_value                                                                                          = src.NodeGroup_Status_value
	NodeTemplate_CpuOvercommitType_name                                                                             = src.NodeTemplate_CpuOvercommitType_name
	NodeTemplate_CpuOvercommitType_value                                                                            = src.NodeTemplate_CpuOvercommitType_value
	NodeTemplate_Status_name                                                                                        = src.NodeTemplate_Status_name
	NodeTemplate_Status_value                                                                                       = src.NodeTemplate_Status_value
	Operation_Status_name                                                                                           = src.Operation_Status_name
	Operation_Status_value                                                                                          = src.Operation_Status_value
	PacketIntervals_Duration_name                                                                                   = src.PacketIntervals_Duration_name
	PacketIntervals_Duration_value                                                                                  = src.PacketIntervals_Duration_value
	PacketIntervals_Type_name                                                                                       = src.PacketIntervals_Type_name
	PacketIntervals_Type_value                                                                                      = src.PacketIntervals_Type_value
	PacketMirroringFilter_Direction_name                                                                            = src.PacketMirroringFilter_Direction_name
	PacketMirroringFilter_Direction_value                                                                           = src.PacketMirroringFilter_Direction_value
	PacketMirroring_Enable_name                                                                                     = src.PacketMirroring_Enable_name
	PacketMirroring_Enable_value                                                                                    = src.PacketMirroring_Enable_value
	PerInstanceConfig_Status_name                                                                                   = src.PerInstanceConfig_Status_name
	PerInstanceConfig_Status_value                                                                                  = src.PerInstanceConfig_Status_value
	PreservedStatePreservedDisk_AutoDelete_name                                                                     = src.PreservedStatePreservedDisk_AutoDelete_name
	PreservedStatePreservedDisk_AutoDelete_value                                                                    = src.PreservedStatePreservedDisk_AutoDelete_value
	PreservedStatePreservedDisk_Mode_name                                                                           = src.PreservedStatePreservedDisk_Mode_name
	PreservedStatePreservedDisk_Mode_value                                                                          = src.PreservedStatePreservedDisk_Mode_value
	PreservedStatePreservedNetworkIp_AutoDelete_name                                                                = src.PreservedStatePreservedNetworkIp_AutoDelete_name
	PreservedStatePreservedNetworkIp_AutoDelete_value                                                               = src.PreservedStatePreservedNetworkIp_AutoDelete_value
	Project_CloudArmorTier_name                                                                                     = src.Project_CloudArmorTier_name
	Project_CloudArmorTier_value                                                                                    = src.Project_CloudArmorTier_value
	Project_DefaultNetworkTier_name                                                                                 = src.Project_DefaultNetworkTier_name
	Project_DefaultNetworkTier_value                                                                                = src.Project_DefaultNetworkTier_value
	Project_VmDnsSetting_name                                                                                       = src.Project_VmDnsSetting_name
	Project_VmDnsSetting_value                                                                                      = src.Project_VmDnsSetting_value
	Project_XpnProjectStatus_name                                                                                   = src.Project_XpnProjectStatus_name
	Project_XpnProjectStatus_value                                                                                  = src.Project_XpnProjectStatus_value
	ProjectsSetCloudArmorTierRequest_CloudArmorTier_name                                                            = src.ProjectsSetCloudArmorTierRequest_CloudArmorTier_name
	ProjectsSetCloudArmorTierRequest_CloudArmorTier_value                                                           = src.ProjectsSetCloudArmorTierRequest_CloudArmorTier_value
	ProjectsSetDefaultNetworkTierRequest_NetworkTier_name                                                           = src.ProjectsSetDefaultNetworkTierRequest_NetworkTier_name
	ProjectsSetDefaultNetworkTierRequest_NetworkTier_value                                                          = src.ProjectsSetDefaultNetworkTierRequest_NetworkTier_value
	PublicAdvertisedPrefix_ByoipApiVersion_name                                                                     = src.PublicAdvertisedPrefix_ByoipApiVersion_name
	PublicAdvertisedPrefix_ByoipApiVersion_value                                                                    = src.PublicAdvertisedPrefix_ByoipApiVersion_value
	PublicAdvertisedPrefix_PdpScope_name                                                                            = src.PublicAdvertisedPrefix_PdpScope_name
	PublicAdvertisedPrefix_PdpScope_value                                                                           = src.PublicAdvertisedPrefix_PdpScope_value
	PublicAdvertisedPrefix_Status_name                                                                              = src.PublicAdvertisedPrefix_Status_name
	PublicAdvertisedPrefix_Status_value                                                                             = src.PublicAdvertisedPrefix_Status_value
	PublicDelegatedPrefixPublicDelegatedSubPrefix_Mode_name                                                         = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_Mode_name
	PublicDelegatedPrefixPublicDelegatedSubPrefix_Mode_value                                                        = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_Mode_value
	PublicDelegatedPrefixPublicDelegatedSubPrefix_Status_name                                                       = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_Status_name
	PublicDelegatedPrefixPublicDelegatedSubPrefix_Status_value                                                      = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_Status_value
	PublicDelegatedPrefix_ByoipApiVersion_name                                                                      = src.PublicDelegatedPrefix_ByoipApiVersion_name
	PublicDelegatedPrefix_ByoipApiVersion_value                                                                     = src.PublicDelegatedPrefix_ByoipApiVersion_value
	PublicDelegatedPrefix_Mode_name                                                                                 = src.PublicDelegatedPrefix_Mode_name
	PublicDelegatedPrefix_Mode_value                                                                                = src.PublicDelegatedPrefix_Mode_value
	PublicDelegatedPrefix_Status_name                                                                               = src.PublicDelegatedPrefix_Status_name
	PublicDelegatedPrefix_Status_value                                                                              = src.PublicDelegatedPrefix_Status_value
	QuotaExceededInfo_RolloutStatus_name                                                                            = src.QuotaExceededInfo_RolloutStatus_name
	QuotaExceededInfo_RolloutStatus_value                                                                           = src.QuotaExceededInfo_RolloutStatus_value
	QuotaStatusWarning_Code_name                                                                                    = src.QuotaStatusWarning_Code_name
	QuotaStatusWarning_Code_value                                                                                   = src.QuotaStatusWarning_Code_value
	Quota_Metric_name                                                                                               = src.Quota_Metric_name
	Quota_Metric_value                                                                                              = src.Quota_Metric_value
	RawDisk_ContainerType_name                                                                                      = src.RawDisk_ContainerType_name
	RawDisk_ContainerType_value                                                                                     = src.RawDisk_ContainerType_value
	RegionInstanceGroupManagersApplyUpdatesRequest_MinimalAction_name                                               = src.RegionInstanceGroupManagersApplyUpdatesRequest_MinimalAction_name
	RegionInstanceGroupManagersApplyUpdatesRequest_MinimalAction_value                                              = src.RegionInstanceGroupManagersApplyUpdatesRequest_MinimalAction_value
	RegionInstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction_name                                 = src.RegionInstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction_name
	RegionInstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction_value                                = src.RegionInstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction_value
	RegionInstanceGroupsListInstancesRequest_InstanceState_name                                                     = src.RegionInstanceGroupsListInstancesRequest_InstanceState_name
	RegionInstanceGroupsListInstancesRequest_InstanceState_value                                                    = src.RegionInstanceGroupsListInstancesRequest_InstanceState_value
	RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_name                     = src.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_name
	RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_value                    = src.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type_value
	Region_Status_name                                                                                              = src.Region_Status_name
	Region_Status_value                                                                                             = src.Region_Status_value
	ReservationAffinity_ConsumeReservationType_name                                                                 = src.ReservationAffinity_ConsumeReservationType_name
	ReservationAffinity_ConsumeReservationType_value                                                                = src.ReservationAffinity_ConsumeReservationType_value
	Reservation_Status_name                                                                                         = src.Reservation_Status_name
	Reservation_Status_value                                                                                        = src.Reservation_Status_value
	ResourceCommitment_Type_name                                                                                    = src.ResourceCommitment_Type_name
	ResourceCommitment_Type_value                                                                                   = src.ResourceCommitment_Type_value
	ResourcePolicyGroupPlacementPolicy_Collocation_name                                                             = src.ResourcePolicyGroupPlacementPolicy_Collocation_name
	ResourcePolicyGroupPlacementPolicy_Collocation_value                                                            = src.ResourcePolicyGroupPlacementPolicy_Collocation_value
	ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete_name                                     = src.ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete_name
	ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete_value                                    = src.ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete_value
	ResourcePolicyWeeklyCycleDayOfWeek_Day_name                                                                     = src.ResourcePolicyWeeklyCycleDayOfWeek_Day_name
	ResourcePolicyWeeklyCycleDayOfWeek_Day_value                                                                    = src.ResourcePolicyWeeklyCycleDayOfWeek_Day_value
	ResourcePolicy_Status_name                                                                                      = src.ResourcePolicy_Status_name
	ResourcePolicy_Status_value                                                                                     = src.ResourcePolicy_Status_value
	RouteAsPath_PathSegmentType_name                                                                                = src.RouteAsPath_PathSegmentType_name
	RouteAsPath_PathSegmentType_value                                                                               = src.RouteAsPath_PathSegmentType_value
	Route_RouteStatus_name                                                                                          = src.Route_RouteStatus_name
	Route_RouteStatus_value                                                                                         = src.Route_RouteStatus_value
	Route_RouteType_name                                                                                            = src.Route_RouteType_name
	Route_RouteType_value                                                                                           = src.Route_RouteType_value
	RouterBgpPeerBfd_SessionInitializationMode_name                                                                 = src.RouterBgpPeerBfd_SessionInitializationMode_name
	RouterBgpPeerBfd_SessionInitializationMode_value                                                                = src.RouterBgpPeerBfd_SessionInitializationMode_value
	RouterBgpPeer_AdvertiseMode_name                                                                                = src.RouterBgpPeer_AdvertiseMode_name
	RouterBgpPeer_AdvertiseMode_value                                                                               = src.RouterBgpPeer_AdvertiseMode_value
	RouterBgpPeer_AdvertisedGroups_name                                                                             = src.RouterBgpPeer_AdvertisedGroups_name
	RouterBgpPeer_AdvertisedGroups_value                                                                            = src.RouterBgpPeer_AdvertisedGroups_value
	RouterBgpPeer_Enable_name                                                                                       = src.RouterBgpPeer_Enable_name
	RouterBgpPeer_Enable_value                                                                                      = src.RouterBgpPeer_Enable_value
	RouterBgpPeer_ManagementType_name                                                                               = src.RouterBgpPeer_ManagementType_name
	RouterBgpPeer_ManagementType_value                                                                              = src.RouterBgpPeer_ManagementType_value
	RouterBgp_AdvertiseMode_name                                                                                    = src.RouterBgp_AdvertiseMode_name
	RouterBgp_AdvertiseMode_value                                                                                   = src.RouterBgp_AdvertiseMode_value
	RouterBgp_AdvertisedGroups_name                                                                                 = src.RouterBgp_AdvertisedGroups_name
	RouterBgp_AdvertisedGroups_value                                                                                = src.RouterBgp_AdvertisedGroups_value
	RouterInterface_IpVersion_name                                                                                  = src.RouterInterface_IpVersion_name
	RouterInterface_IpVersion_value                                                                                 = src.RouterInterface_IpVersion_value
	RouterInterface_ManagementType_name                                                                             = src.RouterInterface_ManagementType_name
	RouterInterface_ManagementType_value                                                                            = src.RouterInterface_ManagementType_value
	RouterNatLogConfig_Filter_name                                                                                  = src.RouterNatLogConfig_Filter_name
	RouterNatLogConfig_Filter_value                                                                                 = src.RouterNatLogConfig_Filter_value
	RouterNatSubnetworkToNat_SourceIpRangesToNat_name                                                               = src.RouterNatSubnetworkToNat_SourceIpRangesToNat_name
	RouterNatSubnetworkToNat_SourceIpRangesToNat_value                                                              = src.RouterNatSubnetworkToNat_SourceIpRangesToNat_value
	RouterNat_AutoNetworkTier_name                                                                                  = src.RouterNat_AutoNetworkTier_name
	RouterNat_AutoNetworkTier_value                                                                                 = src.RouterNat_AutoNetworkTier_value
	RouterNat_EndpointTypes_name                                                                                    = src.RouterNat_EndpointTypes_name
	RouterNat_EndpointTypes_value                                                                                   = src.RouterNat_EndpointTypes_value
	RouterNat_NatIpAllocateOption_name                                                                              = src.RouterNat_NatIpAllocateOption_name
	RouterNat_NatIpAllocateOption_value                                                                             = src.RouterNat_NatIpAllocateOption_value
	RouterNat_SourceSubnetworkIpRangesToNat_name                                                                    = src.RouterNat_SourceSubnetworkIpRangesToNat_name
	RouterNat_SourceSubnetworkIpRangesToNat_value                                                                   = src.RouterNat_SourceSubnetworkIpRangesToNat_value
	RouterNat_Type_name                                                                                             = src.RouterNat_Type_name
	RouterNat_Type_value                                                                                            = src.RouterNat_Type_value
	RouterStatusBgpPeerStatus_StatusReason_name                                                                     = src.RouterStatusBgpPeerStatus_StatusReason_name
	RouterStatusBgpPeerStatus_StatusReason_value                                                                    = src.RouterStatusBgpPeerStatus_StatusReason_value
	RouterStatusBgpPeerStatus_Status_name                                                                           = src.RouterStatusBgpPeerStatus_Status_name
	RouterStatusBgpPeerStatus_Status_value                                                                          = src.RouterStatusBgpPeerStatus_Status_value
	SSLHealthCheck_PortSpecification_name                                                                           = src.SSLHealthCheck_PortSpecification_name
	SSLHealthCheck_PortSpecification_value                                                                          = src.SSLHealthCheck_PortSpecification_value
	SSLHealthCheck_ProxyHeader_name                                                                                 = src.SSLHealthCheck_ProxyHeader_name
	SSLHealthCheck_ProxyHeader_value                                                                                = src.SSLHealthCheck_ProxyHeader_value
	SavedAttachedDisk_Interface_name                                                                                = src.SavedAttachedDisk_Interface_name
	SavedAttachedDisk_Interface_value                                                                               = src.SavedAttachedDisk_Interface_value
	SavedAttachedDisk_Mode_name                                                                                     = src.SavedAttachedDisk_Mode_name
	SavedAttachedDisk_Mode_value                                                                                    = src.SavedAttachedDisk_Mode_value
	SavedAttachedDisk_StorageBytesStatus_name                                                                       = src.SavedAttachedDisk_StorageBytesStatus_name
	SavedAttachedDisk_StorageBytesStatus_value                                                                      = src.SavedAttachedDisk_StorageBytesStatus_value
	SavedAttachedDisk_Type_name                                                                                     = src.SavedAttachedDisk_Type_name
	SavedAttachedDisk_Type_value                                                                                    = src.SavedAttachedDisk_Type_value
	SavedDisk_Architecture_name                                                                                     = src.SavedDisk_Architecture_name
	SavedDisk_Architecture_value                                                                                    = src.SavedDisk_Architecture_value
	SavedDisk_StorageBytesStatus_name                                                                               = src.SavedDisk_StorageBytesStatus_name
	SavedDisk_StorageBytesStatus_value                                                                              = src.SavedDisk_StorageBytesStatus_value
	ScalingScheduleStatus_State_name                                                                                = src.ScalingScheduleStatus_State_name
	ScalingScheduleStatus_State_value                                                                               = src.ScalingScheduleStatus_State_value
	SchedulingNodeAffinity_Operator_name                                                                            = src.SchedulingNodeAffinity_Operator_name
	SchedulingNodeAffinity_Operator_value                                                                           = src.SchedulingNodeAffinity_Operator_value
	Scheduling_InstanceTerminationAction_name                                                                       = src.Scheduling_InstanceTerminationAction_name
	Scheduling_InstanceTerminationAction_value                                                                      = src.Scheduling_InstanceTerminationAction_value
	Scheduling_OnHostMaintenance_name                                                                               = src.Scheduling_OnHostMaintenance_name
	Scheduling_OnHostMaintenance_value                                                                              = src.Scheduling_OnHostMaintenance_value
	Scheduling_ProvisioningModel_name                                                                               = src.Scheduling_ProvisioningModel_name
	Scheduling_ProvisioningModel_value                                                                              = src.Scheduling_ProvisioningModel_value
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_Type_name  = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_Type_name
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_Type_value = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_Type_value
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_RuleVisibility_name                               = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_RuleVisibility_name
	SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_RuleVisibility_value                              = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_RuleVisibility_value
	SecurityPolicyAdvancedOptionsConfig_JsonParsing_name                                                            = src.SecurityPolicyAdvancedOptionsConfig_JsonParsing_name
	SecurityPolicyAdvancedOptionsConfig_JsonParsing_value                                                           = src.SecurityPolicyAdvancedOptionsConfig_JsonParsing_value
	SecurityPolicyAdvancedOptionsConfig_LogLevel_name                                                               = src.SecurityPolicyAdvancedOptionsConfig_LogLevel_name
	SecurityPolicyAdvancedOptionsConfig_LogLevel_value                                                              = src.SecurityPolicyAdvancedOptionsConfig_LogLevel_value
	SecurityPolicyDdosProtectionConfig_DdosProtection_name                                                          = src.SecurityPolicyDdosProtectionConfig_DdosProtection_name
	SecurityPolicyDdosProtectionConfig_DdosProtection_value                                                         = src.SecurityPolicyDdosProtectionConfig_DdosProtection_value
	SecurityPolicyRuleMatcher_VersionedExpr_name                                                                    = src.SecurityPolicyRuleMatcher_VersionedExpr_name
	SecurityPolicyRuleMatcher_VersionedExpr_value                                                                   = src.SecurityPolicyRuleMatcher_VersionedExpr_value
	SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op_name                                            = src.SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op_name
	SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op_value                                           = src.SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op_value
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_EnforceOnKeyType_name                                      = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_EnforceOnKeyType_name
	SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_EnforceOnKeyType_value                                     = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_EnforceOnKeyType_value
	SecurityPolicyRuleRateLimitOptions_EnforceOnKey_name                                                            = src.SecurityPolicyRuleRateLimitOptions_EnforceOnKey_name
	SecurityPolicyRuleRateLimitOptions_EnforceOnKey_value                                                           = src.SecurityPolicyRuleRateLimitOptions_EnforceOnKey_value
	SecurityPolicyRuleRedirectOptions_Type_name                                                                     = src.SecurityPolicyRuleRedirectOptions_Type_name
	SecurityPolicyRuleRedirectOptions_Type_value                                                                    = src.SecurityPolicyRuleRedirectOptions_Type_value
	SecurityPolicyUserDefinedField_Base_name                                                                        = src.SecurityPolicyUserDefinedField_Base_name
	SecurityPolicyUserDefinedField_Base_value                                                                       = src.SecurityPolicyUserDefinedField_Base_value
	SecurityPolicy_Type_name                                                                                        = src.SecurityPolicy_Type_name
	SecurityPolicy_Type_value                                                                                       = src.SecurityPolicy_Type_value
	ServerBinding_Type_name                                                                                         = src.ServerBinding_Type_name
	ServerBinding_Type_value                                                                                        = src.ServerBinding_Type_value
	ServiceAttachmentConnectedEndpoint_Status_name                                                                  = src.ServiceAttachmentConnectedEndpoint_Status_name
	ServiceAttachmentConnectedEndpoint_Status_value                                                                 = src.ServiceAttachmentConnectedEndpoint_Status_value
	ServiceAttachment_ConnectionPreference_name                                                                     = src.ServiceAttachment_ConnectionPreference_name
	ServiceAttachment_ConnectionPreference_value                                                                    = src.ServiceAttachment_ConnectionPreference_value
	SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State_name                                   = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State_name
	SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State_value                                  = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State_value
	ShareSettings_ShareType_name                                                                                    = src.ShareSettings_ShareType_name
	ShareSettings_ShareType_value                                                                                   = src.ShareSettings_ShareType_value
	SnapshotSettingsStorageLocationSettings_Policy_name                                                             = src.SnapshotSettingsStorageLocationSettings_Policy_name
	SnapshotSettingsStorageLocationSettings_Policy_value                                                            = src.SnapshotSettingsStorageLocationSettings_Policy_value
	Snapshot_Architecture_name                                                                                      = src.Snapshot_Architecture_name
	Snapshot_Architecture_value                                                                                     = src.Snapshot_Architecture_value
	Snapshot_SnapshotType_name                                                                                      = src.Snapshot_SnapshotType_name
	Snapshot_SnapshotType_value                                                                                     = src.Snapshot_SnapshotType_value
	Snapshot_Status_name                                                                                            = src.Snapshot_Status_name
	Snapshot_Status_value                                                                                           = src.Snapshot_Status_value
	Snapshot_StorageBytesStatus_name                                                                                = src.Snapshot_StorageBytesStatus_name
	Snapshot_StorageBytesStatus_value                                                                               = src.Snapshot_StorageBytesStatus_value
	SourceInstanceProperties_KeyRevocationActionType_name                                                           = src.SourceInstanceProperties_KeyRevocationActionType_name
	SourceInstanceProperties_KeyRevocationActionType_value                                                          = src.SourceInstanceProperties_KeyRevocationActionType_value
	SslCertificateManagedSslCertificate_Status_name                                                                 = src.SslCertificateManagedSslCertificate_Status_name
	SslCertificateManagedSslCertificate_Status_value                                                                = src.SslCertificateManagedSslCertificate_Status_value
	SslCertificate_Type_name                                                                                        = src.SslCertificate_Type_name
	SslCertificate_Type_value                                                                                       = src.SslCertificate_Type_value
	SslPolicy_MinTlsVersion_name                                                                                    = src.SslPolicy_MinTlsVersion_name
	SslPolicy_MinTlsVersion_value                                                                                   = src.SslPolicy_MinTlsVersion_value
	SslPolicy_Profile_name                                                                                          = src.SslPolicy_Profile_name
	SslPolicy_Profile_value                                                                                         = src.SslPolicy_Profile_value
	StatefulPolicyPreservedStateDiskDevice_AutoDelete_name                                                          = src.StatefulPolicyPreservedStateDiskDevice_AutoDelete_name
	StatefulPolicyPreservedStateDiskDevice_AutoDelete_value                                                         = src.StatefulPolicyPreservedStateDiskDevice_AutoDelete_value
	StatefulPolicyPreservedStateNetworkIp_AutoDelete_name                                                           = src.StatefulPolicyPreservedStateNetworkIp_AutoDelete_name
	StatefulPolicyPreservedStateNetworkIp_AutoDelete_value                                                          = src.StatefulPolicyPreservedStateNetworkIp_AutoDelete_value
	StoragePoolDisk_Status_name                                                                                     = src.StoragePoolDisk_Status_name
	StoragePoolDisk_Status_value                                                                                    = src.StoragePoolDisk_Status_value
	StoragePool_CapacityProvisioningType_name                                                                       = src.StoragePool_CapacityProvisioningType_name
	StoragePool_CapacityProvisioningType_value                                                                      = src.StoragePool_CapacityProvisioningType_value
	StoragePool_PerformanceProvisioningType_name                                                                    = src.StoragePool_PerformanceProvisioningType_name
	StoragePool_PerformanceProvisioningType_value                                                                   = src.StoragePool_PerformanceProvisioningType_value
	StoragePool_State_name                                                                                          = src.StoragePool_State_name
	StoragePool_State_value                                                                                         = src.StoragePool_State_value
	SubnetworkLogConfig_AggregationInterval_name                                                                    = src.SubnetworkLogConfig_AggregationInterval_name
	SubnetworkLogConfig_AggregationInterval_value                                                                   = src.SubnetworkLogConfig_AggregationInterval_value
	SubnetworkLogConfig_Metadata_name                                                                               = src.SubnetworkLogConfig_Metadata_name
	SubnetworkLogConfig_Metadata_value                                                                              = src.SubnetworkLogConfig_Metadata_value
	Subnetwork_Ipv6AccessType_name                                                                                  = src.Subnetwork_Ipv6AccessType_name
	Subnetwork_Ipv6AccessType_value                                                                                 = src.Subnetwork_Ipv6AccessType_value
	Subnetwork_PrivateIpv6GoogleAccess_name                                                                         = src.Subnetwork_PrivateIpv6GoogleAccess_name
	Subnetwork_PrivateIpv6GoogleAccess_value                                                                        = src.Subnetwork_PrivateIpv6GoogleAccess_value
	Subnetwork_Purpose_name                                                                                         = src.Subnetwork_Purpose_name
	Subnetwork_Purpose_value                                                                                        = src.Subnetwork_Purpose_value
	Subnetwork_Role_name                                                                                            = src.Subnetwork_Role_name
	Subnetwork_Role_value                                                                                           = src.Subnetwork_Role_value
	Subnetwork_StackType_name                                                                                       = src.Subnetwork_StackType_name
	Subnetwork_StackType_value                                                                                      = src.Subnetwork_StackType_value
	Subnetwork_State_name                                                                                           = src.Subnetwork_State_name
	Subnetwork_State_value                                                                                          = src.Subnetwork_State_value
	Subsetting_Policy_name                                                                                          = src.Subsetting_Policy_name
	Subsetting_Policy_value                                                                                         = src.Subsetting_Policy_value
	TCPHealthCheck_PortSpecification_name                                                                           = src.TCPHealthCheck_PortSpecification_name
	TCPHealthCheck_PortSpecification_value                                                                          = src.TCPHealthCheck_PortSpecification_value
	TCPHealthCheck_ProxyHeader_name                                                                                 = src.TCPHealthCheck_ProxyHeader_name
	TCPHealthCheck_ProxyHeader_value                                                                                = src.TCPHealthCheck_ProxyHeader_value
	TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride_name                                                      = src.TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride_name
	TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride_value                                                     = src.TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride_value
	TargetHttpsProxy_QuicOverride_name                                                                              = src.TargetHttpsProxy_QuicOverride_name
	TargetHttpsProxy_QuicOverride_value                                                                             = src.TargetHttpsProxy_QuicOverride_value
	TargetHttpsProxy_TlsEarlyData_name                                                                              = src.TargetHttpsProxy_TlsEarlyData_name
	TargetHttpsProxy_TlsEarlyData_value                                                                             = src.TargetHttpsProxy_TlsEarlyData_value
	TargetInstance_NatPolicy_name                                                                                   = src.TargetInstance_NatPolicy_name
	TargetInstance_NatPolicy_value                                                                                  = src.TargetInstance_NatPolicy_value
	TargetPool_SessionAffinity_name                                                                                 = src.TargetPool_SessionAffinity_name
	TargetPool_SessionAffinity_value                                                                                = src.TargetPool_SessionAffinity_value
	TargetSslProxiesSetProxyHeaderRequest_ProxyHeader_name                                                          = src.TargetSslProxiesSetProxyHeaderRequest_ProxyHeader_name
	TargetSslProxiesSetProxyHeaderRequest_ProxyHeader_value                                                         = src.TargetSslProxiesSetProxyHeaderRequest_ProxyHeader_value
	TargetSslProxy_ProxyHeader_name                                                                                 = src.TargetSslProxy_ProxyHeader_name
	TargetSslProxy_ProxyHeader_value                                                                                = src.TargetSslProxy_ProxyHeader_value
	TargetTcpProxiesSetProxyHeaderRequest_ProxyHeader_name                                                          = src.TargetTcpProxiesSetProxyHeaderRequest_ProxyHeader_name
	TargetTcpProxiesSetProxyHeaderRequest_ProxyHeader_value                                                         = src.TargetTcpProxiesSetProxyHeaderRequest_ProxyHeader_value
	TargetTcpProxy_ProxyHeader_name                                                                                 = src.TargetTcpProxy_ProxyHeader_name
	TargetTcpProxy_ProxyHeader_value                                                                                = src.TargetTcpProxy_ProxyHeader_value
	TargetVpnGateway_Status_name                                                                                    = src.TargetVpnGateway_Status_name
	TargetVpnGateway_Status_value                                                                                   = src.TargetVpnGateway_Status_value
	UpcomingMaintenance_MaintenanceStatus_name                                                                      = src.UpcomingMaintenance_MaintenanceStatus_name
	UpcomingMaintenance_MaintenanceStatus_value                                                                     = src.UpcomingMaintenance_MaintenanceStatus_value
	UpcomingMaintenance_Type_name                                                                                   = src.UpcomingMaintenance_Type_name
	UpcomingMaintenance_Type_value                                                                                  = src.UpcomingMaintenance_Type_value
	UpdateInstanceRequest_MinimalAction_name                                                                        = src.UpdateInstanceRequest_MinimalAction_name
	UpdateInstanceRequest_MinimalAction_value                                                                       = src.UpdateInstanceRequest_MinimalAction_value
	UpdateInstanceRequest_MostDisruptiveAllowedAction_name                                                          = src.UpdateInstanceRequest_MostDisruptiveAllowedAction_name
	UpdateInstanceRequest_MostDisruptiveAllowedAction_value                                                         = src.UpdateInstanceRequest_MostDisruptiveAllowedAction_value
	UrlMapsValidateRequest_LoadBalancingSchemes_name                                                                = src.UrlMapsValidateRequest_LoadBalancingSchemes_name
	UrlMapsValidateRequest_LoadBalancingSchemes_value                                                               = src.UrlMapsValidateRequest_LoadBalancingSchemes_value
	UsableSubnetwork_Ipv6AccessType_name                                                                            = src.UsableSubnetwork_Ipv6AccessType_name
	UsableSubnetwork_Ipv6AccessType_value                                                                           = src.UsableSubnetwork_Ipv6AccessType_value
	UsableSubnetwork_Purpose_name                                                                                   = src.UsableSubnetwork_Purpose_name
	UsableSubnetwork_Purpose_value                                                                                  = src.UsableSubnetwork_Purpose_value
	UsableSubnetwork_Role_name                                                                                      = src.UsableSubnetwork_Role_name
	UsableSubnetwork_Role_value                                                                                     = src.UsableSubnetwork_Role_value
	UsableSubnetwork_StackType_name                                                                                 = src.UsableSubnetwork_StackType_name
	UsableSubnetwork_StackType_value                                                                                = src.UsableSubnetwork_StackType_value
	VpnGatewayStatusHighAvailabilityRequirementState_State_name                                                     = src.VpnGatewayStatusHighAvailabilityRequirementState_State_name
	VpnGatewayStatusHighAvailabilityRequirementState_State_value                                                    = src.VpnGatewayStatusHighAvailabilityRequirementState_State_value
	VpnGatewayStatusHighAvailabilityRequirementState_UnsatisfiedReason_name                                         = src.VpnGatewayStatusHighAvailabilityRequirementState_UnsatisfiedReason_name
	VpnGatewayStatusHighAvailabilityRequirementState_UnsatisfiedReason_value                                        = src.VpnGatewayStatusHighAvailabilityRequirementState_UnsatisfiedReason_value
	VpnGateway_GatewayIpVersion_name                                                                                = src.VpnGateway_GatewayIpVersion_name
	VpnGateway_GatewayIpVersion_value                                                                               = src.VpnGateway_GatewayIpVersion_value
	VpnGateway_StackType_name                                                                                       = src.VpnGateway_StackType_name
	VpnGateway_StackType_value                                                                                      = src.VpnGateway_StackType_value
	VpnTunnel_Status_name                                                                                           = src.VpnTunnel_Status_name
	VpnTunnel_Status_value                                                                                          = src.VpnTunnel_Status_value
	Warning_Code_name                                                                                               = src.Warning_Code_name
	Warning_Code_value                                                                                              = src.Warning_Code_value
	Warnings_Code_name                                                                                              = src.Warnings_Code_name
	Warnings_Code_value                                                                                             = src.Warnings_Code_value
	XpnResourceId_Type_name                                                                                         = src.XpnResourceId_Type_name
	XpnResourceId_Type_value                                                                                        = src.XpnResourceId_Type_value
	Zone_Status_name                                                                                                = src.Zone_Status_name
	Zone_Status_value                                                                                               = src.Zone_Status_value
)

// Messages Contains the configurations necessary to generate a signature for
// access to private storage buckets that support Signature Version 4 for
// authentication. The service name for generating the authentication header
// will always default to 's3'.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AWSV4Signature = src.AWSV4Signature

// A request message for InstanceGroupManagers.AbandonInstances. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AbandonInstancesInstanceGroupManagerRequest = src.AbandonInstancesInstanceGroupManagerRequest

// A request message for RegionInstanceGroupManagers.AbandonInstances. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AbandonInstancesRegionInstanceGroupManagerRequest = src.AbandonInstancesRegionInstanceGroupManagerRequest

// A specification of the type and number of accelerator cards attached to the
// instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AcceleratorConfig = src.AcceleratorConfig

// Represents an Accelerator Type resource. Google Cloud Platform provides
// graphics processing units (accelerators) that you can add to VM instances to
// improve or accelerate performance when working with intensive workloads. For
// more information, read GPUs on Compute Engine.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AcceleratorType = src.AcceleratorType
type AcceleratorTypeAggregatedList = src.AcceleratorTypeAggregatedList

// Contains a list of accelerator types.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AcceleratorTypeList = src.AcceleratorTypeList
type AcceleratorTypesScopedList = src.AcceleratorTypesScopedList
type Accelerators = src.Accelerators

// An access configuration attached to an instance's network interface. Only
// one access config per instance is supported.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AccessConfig = src.AccessConfig

// This signifies the networking tier used for configuring this access
// configuration and can only take the following values: PREMIUM, STANDARD. If
// an AccessConfig is specified without a valid external IP address, an
// ephemeral IP will be created with this networkTier. If an AccessConfig with
// a valid external IP address is specified, it must match that of the
// networkTier associated with the Address resource owning that IP.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AccessConfig_NetworkTier = src.AccessConfig_NetworkTier

// The type of configuration. In accessConfigs (IPv4), the default and only
// option is ONE_TO_ONE_NAT. In ipv6AccessConfigs, the default and only option
// is DIRECT_IPV6.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AccessConfig_Type = src.AccessConfig_Type

// A request message for Instances.AddAccessConfig. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddAccessConfigInstanceRequest = src.AddAccessConfigInstanceRequest

// A request message for FirewallPolicies.AddAssociation. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddAssociationFirewallPolicyRequest = src.AddAssociationFirewallPolicyRequest

// A request message for NetworkFirewallPolicies.AddAssociation. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddAssociationNetworkFirewallPolicyRequest = src.AddAssociationNetworkFirewallPolicyRequest

// A request message for RegionNetworkFirewallPolicies.AddAssociation. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddAssociationRegionNetworkFirewallPolicyRequest = src.AddAssociationRegionNetworkFirewallPolicyRequest

// A request message for TargetPools.AddHealthCheck. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddHealthCheckTargetPoolRequest = src.AddHealthCheckTargetPoolRequest

// A request message for TargetPools.AddInstance. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddInstanceTargetPoolRequest = src.AddInstanceTargetPoolRequest

// A request message for InstanceGroups.AddInstances. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddInstancesInstanceGroupRequest = src.AddInstancesInstanceGroupRequest

// A request message for NodeGroups.AddNodes. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddNodesNodeGroupRequest = src.AddNodesNodeGroupRequest

// A request message for Networks.AddPeering. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddPeeringNetworkRequest = src.AddPeeringNetworkRequest

// A request message for Disks.AddResourcePolicies. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddResourcePoliciesDiskRequest = src.AddResourcePoliciesDiskRequest

// A request message for Instances.AddResourcePolicies. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddResourcePoliciesInstanceRequest = src.AddResourcePoliciesInstanceRequest

// A request message for RegionDisks.AddResourcePolicies. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddResourcePoliciesRegionDiskRequest = src.AddResourcePoliciesRegionDiskRequest

// A request message for FirewallPolicies.AddRule. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddRuleFirewallPolicyRequest = src.AddRuleFirewallPolicyRequest

// A request message for NetworkFirewallPolicies.AddRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddRuleNetworkFirewallPolicyRequest = src.AddRuleNetworkFirewallPolicyRequest

// A request message for RegionNetworkFirewallPolicies.AddRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddRuleRegionNetworkFirewallPolicyRequest = src.AddRuleRegionNetworkFirewallPolicyRequest

// A request message for RegionSecurityPolicies.AddRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddRuleRegionSecurityPolicyRequest = src.AddRuleRegionSecurityPolicyRequest

// A request message for SecurityPolicies.AddRule. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddRuleSecurityPolicyRequest = src.AddRuleSecurityPolicyRequest

// A request message for BackendBuckets.AddSignedUrlKey. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddSignedUrlKeyBackendBucketRequest = src.AddSignedUrlKeyBackendBucketRequest

// A request message for BackendServices.AddSignedUrlKey. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddSignedUrlKeyBackendServiceRequest = src.AddSignedUrlKeyBackendServiceRequest

// Represents an IP Address resource. Google Compute Engine has two IP Address
// resources: * [Global (external and
// internal)](https://cloud.google.com/compute/docs/reference/rest/v1/globalAddresses)
// * [Regional (external and
// internal)](https://cloud.google.com/compute/docs/reference/rest/v1/addresses)
// For more information, see Reserving a static external IP address.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Address = src.Address
type AddressAggregatedList = src.AddressAggregatedList

// Contains a list of addresses.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AddressList = src.AddressList

// The type of address to reserve, either INTERNAL or EXTERNAL. If
// unspecified, defaults to EXTERNAL.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Address_AddressType = src.Address_AddressType

// The IP version that will be used by this address. Valid options are IPV4 or
// IPV6.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Address_IpVersion = src.Address_IpVersion

// The endpoint type of this address, which should be VM or NETLB. This is
// used for deciding which type of endpoint this address can be used after the
// external IPv6 address reservation.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Address_Ipv6EndpointType = src.Address_Ipv6EndpointType

// This signifies the networking tier used for configuring this address and
// can only take the following values: PREMIUM or STANDARD. Internal IP
// addresses are always Premium Tier; global external IP addresses are always
// Premium Tier; regional external IP addresses can be either Standard or
// Premium Tier. If this field is not specified, it is assumed to be PREMIUM.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Address_NetworkTier = src.Address_NetworkTier

// The purpose of this resource, which can be one of the following values: -
// GCE_ENDPOINT for addresses that are used by VM instances, alias IP ranges,
// load balancers, and similar resources. - DNS_RESOLVER for a DNS resolver
// address in a subnetwork for a Cloud DNS inbound forwarder IP addresses
// (regional internal IP address in a subnet of a VPC network) - VPC_PEERING
// for global internal IP addresses used for private services access allocated
// ranges. - NAT_AUTO for the regional external IP addresses used by Cloud NAT
// when allocating addresses using automatic NAT IP address allocation. -
// IPSEC_INTERCONNECT for addresses created from a private IP range that are
// reserved for a VLAN attachment in an *HA VPN over Cloud Interconnect*
// configuration. These addresses are regional resources. -
// `SHARED_LOADBALANCER_VIP` for an internal IP address that is assigned to
// multiple internal forwarding rules. - `PRIVATE_SERVICE_CONNECT` for a
// private network address that is used to configure Private Service Connect.
// Only global internal addresses can use this purpose.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Address_Purpose = src.Address_Purpose

// [Output Only] The status of the address, which can be one of RESERVING,
// RESERVED, or IN_USE. An address that is RESERVING is currently in the
// process of being reserved. A RESERVED address is currently reserved and
// available to use. An IN_USE address is currently being used by another
// resource and is not available.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Address_Status = src.Address_Status
type AddressesScopedList = src.AddressesScopedList

// Specifies options for controlling advanced machine features. Options that
// would traditionally be configured in a BIOS belong here. Features that
// require operating system support may have corresponding entries in the
// GuestOsFeatures of an Image (e.g., whether or not the OS in the Image
// supports nested virtualization being enabled or disabled).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AdvancedMachineFeatures = src.AdvancedMachineFeatures

// Type of Performance Monitoring Unit requested on instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AdvancedMachineFeatures_PerformanceMonitoringUnit = src.AdvancedMachineFeatures_PerformanceMonitoringUnit

// A request message for AcceleratorTypes.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListAcceleratorTypesRequest = src.AggregatedListAcceleratorTypesRequest

// A request message for Addresses.AggregatedList. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListAddressesRequest = src.AggregatedListAddressesRequest

// A request message for Autoscalers.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListAutoscalersRequest = src.AggregatedListAutoscalersRequest

// A request message for BackendServices.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListBackendServicesRequest = src.AggregatedListBackendServicesRequest

// A request message for DiskTypes.AggregatedList. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListDiskTypesRequest = src.AggregatedListDiskTypesRequest

// A request message for Disks.AggregatedList. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListDisksRequest = src.AggregatedListDisksRequest

// A request message for ForwardingRules.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListForwardingRulesRequest = src.AggregatedListForwardingRulesRequest

// A request message for GlobalOperations.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListGlobalOperationsRequest = src.AggregatedListGlobalOperationsRequest

// A request message for HealthChecks.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListHealthChecksRequest = src.AggregatedListHealthChecksRequest

// A request message for InstanceGroupManagers.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListInstanceGroupManagersRequest = src.AggregatedListInstanceGroupManagersRequest

// A request message for InstanceGroups.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListInstanceGroupsRequest = src.AggregatedListInstanceGroupsRequest

// A request message for InstanceTemplates.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListInstanceTemplatesRequest = src.AggregatedListInstanceTemplatesRequest

// A request message for Instances.AggregatedList. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListInstancesRequest = src.AggregatedListInstancesRequest

// A request message for InstantSnapshots.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListInstantSnapshotsRequest = src.AggregatedListInstantSnapshotsRequest

// A request message for InterconnectAttachments.AggregatedList. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListInterconnectAttachmentsRequest = src.AggregatedListInterconnectAttachmentsRequest

// A request message for MachineTypes.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListMachineTypesRequest = src.AggregatedListMachineTypesRequest

// A request message for NetworkAttachments.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListNetworkAttachmentsRequest = src.AggregatedListNetworkAttachmentsRequest

// A request message for NetworkEdgeSecurityServices.AggregatedList. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListNetworkEdgeSecurityServicesRequest = src.AggregatedListNetworkEdgeSecurityServicesRequest

// A request message for NetworkEndpointGroups.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListNetworkEndpointGroupsRequest = src.AggregatedListNetworkEndpointGroupsRequest

// A request message for NodeGroups.AggregatedList. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListNodeGroupsRequest = src.AggregatedListNodeGroupsRequest

// A request message for NodeTemplates.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListNodeTemplatesRequest = src.AggregatedListNodeTemplatesRequest

// A request message for NodeTypes.AggregatedList. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListNodeTypesRequest = src.AggregatedListNodeTypesRequest

// A request message for PacketMirrorings.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListPacketMirroringsRequest = src.AggregatedListPacketMirroringsRequest

// A request message for PublicDelegatedPrefixes.AggregatedList. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListPublicDelegatedPrefixesRequest = src.AggregatedListPublicDelegatedPrefixesRequest

// A request message for RegionCommitments.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListRegionCommitmentsRequest = src.AggregatedListRegionCommitmentsRequest

// A request message for Reservations.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListReservationsRequest = src.AggregatedListReservationsRequest

// A request message for ResourcePolicies.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListResourcePoliciesRequest = src.AggregatedListResourcePoliciesRequest

// A request message for Routers.AggregatedList. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListRoutersRequest = src.AggregatedListRoutersRequest

// A request message for SecurityPolicies.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListSecurityPoliciesRequest = src.AggregatedListSecurityPoliciesRequest

// A request message for ServiceAttachments.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListServiceAttachmentsRequest = src.AggregatedListServiceAttachmentsRequest

// A request message for SslCertificates.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListSslCertificatesRequest = src.AggregatedListSslCertificatesRequest

// A request message for SslPolicies.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListSslPoliciesRequest = src.AggregatedListSslPoliciesRequest

// A request message for StoragePoolTypes.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListStoragePoolTypesRequest = src.AggregatedListStoragePoolTypesRequest

// A request message for StoragePools.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListStoragePoolsRequest = src.AggregatedListStoragePoolsRequest

// A request message for Subnetworks.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListSubnetworksRequest = src.AggregatedListSubnetworksRequest

// A request message for TargetHttpProxies.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListTargetHttpProxiesRequest = src.AggregatedListTargetHttpProxiesRequest

// A request message for TargetHttpsProxies.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListTargetHttpsProxiesRequest = src.AggregatedListTargetHttpsProxiesRequest

// A request message for TargetInstances.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListTargetInstancesRequest = src.AggregatedListTargetInstancesRequest

// A request message for TargetPools.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListTargetPoolsRequest = src.AggregatedListTargetPoolsRequest

// A request message for TargetTcpProxies.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListTargetTcpProxiesRequest = src.AggregatedListTargetTcpProxiesRequest

// A request message for TargetVpnGateways.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListTargetVpnGatewaysRequest = src.AggregatedListTargetVpnGatewaysRequest

// A request message for UrlMaps.AggregatedList. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListUrlMapsRequest = src.AggregatedListUrlMapsRequest

// A request message for VpnGateways.AggregatedList. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListVpnGatewaysRequest = src.AggregatedListVpnGatewaysRequest

// A request message for VpnTunnels.AggregatedList. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AggregatedListVpnTunnelsRequest = src.AggregatedListVpnTunnelsRequest

// An alias IP range attached to an instance's network interface.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AliasIpRange = src.AliasIpRange

// This reservation type is specified by total resource amounts (e.g. total
// count of CPUs) and can account for multiple instance SKUs. In other words,
// one can create instances of varying shapes against this reservation.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AllocationAggregateReservation = src.AllocationAggregateReservation
type AllocationAggregateReservationReservedResourceInfo = src.AllocationAggregateReservationReservedResourceInfo
type AllocationAggregateReservationReservedResourceInfoAccelerator = src.AllocationAggregateReservationReservedResourceInfoAccelerator

// The VM family that all instances scheduled against this reservation must
// belong to.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AllocationAggregateReservation_VmFamily = src.AllocationAggregateReservation_VmFamily

// The workload type of the instances that will target this reservation.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AllocationAggregateReservation_WorkloadType = src.AllocationAggregateReservation_WorkloadType

// [Output Only] Contains output only fields.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AllocationResourceStatus = src.AllocationResourceStatus

// Contains Properties set for the reservation.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AllocationResourceStatusSpecificSKUAllocation = src.AllocationResourceStatusSpecificSKUAllocation
type AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk = src.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk

// Specifies the disk interface to use for attaching this disk, which is
// either SCSI or NVME. The default is SCSI. For performance characteristics of
// SCSI over NVMe, see Local SSD performance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_Interface = src.AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk_Interface

// Properties of the SKU instances being reserved. Next ID: 9
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AllocationSpecificSKUAllocationReservedInstanceProperties = src.AllocationSpecificSKUAllocationReservedInstanceProperties

// This reservation type allows to pre allocate specific instance
// configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AllocationSpecificSKUReservation = src.AllocationSpecificSKUReservation
type Allowed = src.Allowed

// A request message for PublicAdvertisedPrefixes.Announce. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AnnouncePublicAdvertisedPrefixeRequest = src.AnnouncePublicAdvertisedPrefixeRequest

// A request message for PublicDelegatedPrefixes.Announce. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AnnouncePublicDelegatedPrefixeRequest = src.AnnouncePublicDelegatedPrefixeRequest

// A request message for InstanceGroupManagers.ApplyUpdatesToInstances. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ApplyUpdatesToInstancesInstanceGroupManagerRequest = src.ApplyUpdatesToInstancesInstanceGroupManagerRequest

// A request message for RegionInstanceGroupManagers.ApplyUpdatesToInstances.
// See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest = src.ApplyUpdatesToInstancesRegionInstanceGroupManagerRequest

// A request message for Instances.AttachDisk. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachDiskInstanceRequest = src.AttachDiskInstanceRequest

// A request message for GlobalNetworkEndpointGroups.AttachNetworkEndpoints.
// See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest = src.AttachNetworkEndpointsGlobalNetworkEndpointGroupRequest

// A request message for NetworkEndpointGroups.AttachNetworkEndpoints. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachNetworkEndpointsNetworkEndpointGroupRequest = src.AttachNetworkEndpointsNetworkEndpointGroupRequest

// A request message for RegionNetworkEndpointGroups.AttachNetworkEndpoints.
// See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachNetworkEndpointsRegionNetworkEndpointGroupRequest = src.AttachNetworkEndpointsRegionNetworkEndpointGroupRequest

// An instance-attached disk resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachedDisk = src.AttachedDisk

// [Input Only] Specifies the parameters for a new disk that will be created
// alongside the new instance. Use initialization parameters to create boot
// disks or local SSDs attached to the new instance. This field is persisted
// and returned for instanceTemplate and not returned in the context of
// instance. This property is mutually exclusive with the source property; you
// can only define one or the other, but not both.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachedDiskInitializeParams = src.AttachedDiskInitializeParams

// The architecture of the attached disk. Valid values are arm64 or x86_64.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachedDiskInitializeParams_Architecture = src.AttachedDiskInitializeParams_Architecture

// Specifies which action to take on instance update with this disk. Default
// is to use the existing disk.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachedDiskInitializeParams_OnUpdateAction = src.AttachedDiskInitializeParams_OnUpdateAction

// [Output Only] The architecture of the attached disk. Valid values are ARM64
// or X86_64.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachedDisk_Architecture = src.AttachedDisk_Architecture

// Specifies the disk interface to use for attaching this disk, which is
// either SCSI or NVME. For most machine types, the default is SCSI. Local SSDs
// can use either NVME or SCSI. In certain configurations, persistent disks can
// use NVMe. For more information, see About persistent disks.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachedDisk_Interface = src.AttachedDisk_Interface

// The mode in which to attach this disk, either READ_WRITE or READ_ONLY. If
// not specified, the default is to attach the disk in READ_WRITE mode.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachedDisk_Mode = src.AttachedDisk_Mode

// For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this
// field is set to PRESERVED if the LocalSSD data has been saved to a
// persistent location by customer request. (see the discard_local_ssd option
// on Stop/Suspend). Read-only in the api.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachedDisk_SavedState = src.AttachedDisk_SavedState

// Specifies the type of the disk, either SCRATCH or PERSISTENT. If not
// specified, the default is PERSISTENT.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AttachedDisk_Type = src.AttachedDisk_Type

// Specifies the audit configuration for a service. The configuration
// determines which permission types are logged, and what identities, if any,
// are exempted from logging. An AuditConfig must have one or more
// AuditLogConfigs. If there are AuditConfigs for both `allServices` and a
// specific service, the union of the two AuditConfigs is used for that
// service: the log_types specified in each AuditConfig are enabled, and the
// exempted_members in each AuditLogConfig are exempted. Example Policy with
// multiple AuditConfigs: { "audit_configs": [ { "service": "allServices",
// "audit_log_configs": [ { "log_type": "DATA_READ", "exempted_members": [
// "user:jose@example.com" ] }, { "log_type": "DATA_WRITE" }, { "log_type":
// "ADMIN_READ" } ] }, { "service": "sampleservice.googleapis.com",
// "audit_log_configs": [ { "log_type": "DATA_READ" }, { "log_type":
// "DATA_WRITE", "exempted_members": [ "user:aliya@example.com" ] } ] } ] } For
// sampleservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ
// logging. It also exempts `jose@example.com` from DATA_READ logging, and
// `aliya@example.com` from DATA_WRITE logging.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AuditConfig = src.AuditConfig

// Provides the configuration for logging a type of permissions. Example: {
// "audit_log_configs": [ { "log_type": "DATA_READ", "exempted_members": [
// "user:jose@example.com" ] }, { "log_type": "DATA_WRITE" } ] } This enables
// 'DATA_READ' and 'DATA_WRITE' logging, while exempting jose@example.com from
// DATA_READ logging.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AuditLogConfig = src.AuditLogConfig

// The log type that this config enables.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AuditLogConfig_LogType = src.AuditLogConfig_LogType

// Represents an Autoscaler resource. Google Compute Engine has two Autoscaler
// resources: * [Zonal](/compute/docs/reference/rest/v1/autoscalers) *
// [Regional](/compute/docs/reference/rest/v1/regionAutoscalers) Use
// autoscalers to automatically add or delete instances from a managed instance
// group according to your defined autoscaling policy. For more information,
// read Autoscaling Groups of Instances. For zonal managed instance groups
// resource, use the autoscaler resource. For regional managed instance groups,
// use the regionAutoscalers resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Autoscaler = src.Autoscaler
type AutoscalerAggregatedList = src.AutoscalerAggregatedList

// Contains a list of Autoscaler resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalerList = src.AutoscalerList
type AutoscalerStatusDetails = src.AutoscalerStatusDetails

// The type of error, warning, or notice returned. Current set of possible
// values: - ALL_INSTANCES_UNHEALTHY (WARNING): All instances in the instance
// group are unhealthy (not in RUNNING state). - BACKEND_SERVICE_DOES_NOT_EXIST
// (ERROR): There is no backend service attached to the instance group. -
// CAPPED_AT_MAX_NUM_REPLICAS (WARNING): Autoscaler recommends a size greater
// than maxNumReplicas. - CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The
// custom metric samples are not exported often enough to be a credible base
// for autoscaling. - CUSTOM_METRIC_INVALID (ERROR): The custom metric that was
// specified does not exist or does not have the necessary labels. -
// MIN_EQUALS_MAX (WARNING): The minNumReplicas is equal to maxNumReplicas.
// This means the autoscaler cannot add or remove instances from the instance
// group. - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The autoscaler did not
// receive any data from the custom metric configured for autoscaling. -
// MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The autoscaler is configured
// to scale based on a load balancing signal but the instance group has not
// received any requests from the load balancer. - MODE_OFF (WARNING):
// Autoscaling is turned off. The number of instances in the group won't change
// automatically. The autoscaling configuration is preserved. - MODE_ONLY_UP
// (WARNING): Autoscaling is in the "Autoscale only out" mode. The autoscaler
// can add instances but not remove any. - MORE_THAN_ONE_BACKEND_SERVICE
// (ERROR): The instance group cannot be autoscaled because it has more than
// one backend service attached to it. - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR):
// There is insufficient quota for the necessary resources, such as CPU or
// number of instances. - REGION_RESOURCE_STOCKOUT (ERROR): Shown only for
// regional autoscalers: there is a resource stockout in the chosen region. -
// SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not
// exist. - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR):
// Autoscaling does not work with an HTTP/S load balancer that has been
// configured for maxRate. - ZONE_RESOURCE_STOCKOUT (ERROR): For zonal
// autoscalers: there is a resource stockout in the chosen zone. For regional
// autoscalers: in at least one of the zones you're using there is a resource
// stockout. New values might be added in the future. Some of the values might
// not be available in all API versions.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalerStatusDetails_Type = src.AutoscalerStatusDetails_Type

// [Output Only] The status of the autoscaler configuration. Current set of
// possible values: - PENDING: Autoscaler backend hasn't read new/updated
// configuration. - DELETING: Configuration is being deleted. - ACTIVE:
// Configuration is acknowledged to be effective. Some warnings might be
// present in the statusDetails field. - ERROR: Configuration has errors.
// Actionable for users. Details are present in the statusDetails field. New
// values might be added in the future.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Autoscaler_Status = src.Autoscaler_Status
type AutoscalersScopedList = src.AutoscalersScopedList

// Cloud Autoscaler policy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalingPolicy = src.AutoscalingPolicy

// CPU utilization policy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalingPolicyCpuUtilization = src.AutoscalingPolicyCpuUtilization

// Indicates whether predictive autoscaling based on CPU metric is enabled.
// Valid values are: * NONE (default). No predictive method is used. The
// autoscaler scales the group to meet current demand based on real-time
// metrics. * OPTIMIZE_AVAILABILITY. Predictive autoscaling improves
// availability by monitoring daily and weekly load patterns and scaling out
// ahead of anticipated demand.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalingPolicyCpuUtilization_PredictiveMethod = src.AutoscalingPolicyCpuUtilization_PredictiveMethod

// Custom utilization metric policy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalingPolicyCustomMetricUtilization = src.AutoscalingPolicyCustomMetricUtilization

// Defines how target utilization value is expressed for a Stackdriver
// Monitoring metric. Either GAUGE, DELTA_PER_SECOND, or DELTA_PER_MINUTE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalingPolicyCustomMetricUtilization_UtilizationTargetType = src.AutoscalingPolicyCustomMetricUtilization_UtilizationTargetType

// Configuration parameters of autoscaling based on load balancing.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalingPolicyLoadBalancingUtilization = src.AutoscalingPolicyLoadBalancingUtilization

// Configuration that allows for slower scale in so that even if Autoscaler
// recommends an abrupt scale in of a MIG, it will be throttled as specified by
// the parameters below.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalingPolicyScaleInControl = src.AutoscalingPolicyScaleInControl

// Scaling based on user-defined schedule. The message describes a single
// scaling schedule. A scaling schedule changes the minimum number of VM
// instances an autoscaler can recommend, which can trigger scaling out.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalingPolicyScalingSchedule = src.AutoscalingPolicyScalingSchedule

// Defines the operating mode for this policy. The following modes are
// available: - OFF: Disables the autoscaler but maintains its configuration. -
// ONLY_SCALE_OUT: Restricts the autoscaler to add VM instances only. - ON:
// Enables all autoscaler activities according to its policy. For more
// information, see "Turning off or restricting an autoscaler"
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type AutoscalingPolicy_Mode = src.AutoscalingPolicy_Mode

// Message containing information of one individual backend.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Backend = src.Backend

// Represents a Cloud Storage Bucket resource. This Cloud Storage bucket
// resource is referenced by a URL map of a load balancer. For more
// information, read Backend Buckets.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendBucket = src.BackendBucket

// Message containing Cloud CDN configuration for a backend bucket.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendBucketCdnPolicy = src.BackendBucketCdnPolicy

// Bypass the cache when the specified request headers are present, e.g.
// Pragma or Authorization headers. Values are case insensitive. The presence
// of such a header overrides the cache_mode setting.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendBucketCdnPolicyBypassCacheOnRequestHeader = src.BackendBucketCdnPolicyBypassCacheOnRequestHeader

// Message containing what to include in the cache key for a request for Cloud
// CDN.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendBucketCdnPolicyCacheKeyPolicy = src.BackendBucketCdnPolicyCacheKeyPolicy

// Specify CDN TTLs for response error codes.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendBucketCdnPolicyNegativeCachingPolicy = src.BackendBucketCdnPolicyNegativeCachingPolicy

// Specifies the cache setting for all responses from this backend. The
// possible values are: USE_ORIGIN_HEADERS Requires the origin to set valid
// caching headers to cache content. Responses without these headers will not
// be cached at Google's edge, and will require a full trip to the origin on
// every request, potentially impacting performance and increasing load on the
// origin server. FORCE_CACHE_ALL Cache all content, ignoring any "private",
// "no-store" or "no-cache" directives in Cache-Control response headers.
// Warning: this may result in Cloud CDN caching private, per-user (user
// identifiable) content. CACHE_ALL_STATIC Automatically cache static content,
// including common image formats, media (video and audio), and web assets
// (JavaScript and CSS). Requests and responses that are marked as uncacheable,
// as well as dynamic content (including HTML), will not be cached.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendBucketCdnPolicy_CacheMode = src.BackendBucketCdnPolicy_CacheMode

// Contains a list of BackendBucket resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendBucketList = src.BackendBucketList
type BackendBucketUsedBy = src.BackendBucketUsedBy

// Compress text responses using Brotli or gzip compression, based on the
// client's Accept-Encoding header.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendBucket_CompressionMode = src.BackendBucket_CompressionMode

// Represents a Backend Service resource. A backend service defines how Google
// Cloud load balancers distribute traffic. The backend service configuration
// contains a set of values, such as the protocol used to connect to backends,
// various distribution and session settings, health checks, and timeouts.
// These settings provide fine-grained control over how your load balancer
// behaves. Most of the settings have default values that allow for easy
// configuration if you need to get started quickly. Backend services in Google
// Compute Engine can be either regionally or globally scoped. *
// [Global](https://cloud.google.com/compute/docs/reference/rest/v1/backendServices)
// *
// [Regional](https://cloud.google.com/compute/docs/reference/rest/v1/regionBackendServices)
// For more information, see Backend Services.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendService = src.BackendService

// Contains a list of BackendServicesScopedList.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceAggregatedList = src.BackendServiceAggregatedList

// Message containing Cloud CDN configuration for a backend service.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceCdnPolicy = src.BackendServiceCdnPolicy

// Bypass the cache when the specified request headers are present, e.g.
// Pragma or Authorization headers. Values are case insensitive. The presence
// of such a header overrides the cache_mode setting.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceCdnPolicyBypassCacheOnRequestHeader = src.BackendServiceCdnPolicyBypassCacheOnRequestHeader

// Specify CDN TTLs for response error codes.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceCdnPolicyNegativeCachingPolicy = src.BackendServiceCdnPolicyNegativeCachingPolicy

// Specifies the cache setting for all responses from this backend. The
// possible values are: USE_ORIGIN_HEADERS Requires the origin to set valid
// caching headers to cache content. Responses without these headers will not
// be cached at Google's edge, and will require a full trip to the origin on
// every request, potentially impacting performance and increasing load on the
// origin server. FORCE_CACHE_ALL Cache all content, ignoring any "private",
// "no-store" or "no-cache" directives in Cache-Control response headers.
// Warning: this may result in Cloud CDN caching private, per-user (user
// identifiable) content. CACHE_ALL_STATIC Automatically cache static content,
// including common image formats, media (video and audio), and web assets
// (JavaScript and CSS). Requests and responses that are marked as uncacheable,
// as well as dynamic content (including HTML), will not be cached.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceCdnPolicy_CacheMode = src.BackendServiceCdnPolicy_CacheMode

// Connection Tracking configuration for this BackendService.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceConnectionTrackingPolicy = src.BackendServiceConnectionTrackingPolicy

// Specifies connection persistence when backends are unhealthy. The default
// value is DEFAULT_FOR_PROTOCOL. If set to DEFAULT_FOR_PROTOCOL, the existing
// connections persist on unhealthy backends only for connection-oriented
// protocols (TCP and SCTP) and only if the Tracking Mode is PER_CONNECTION
// (default tracking mode) or the Session Affinity is configured for 5-tuple.
// They do not persist for UDP. If set to NEVER_PERSIST, after a backend
// becomes unhealthy, the existing connections on the unhealthy backend are
// never persisted on the unhealthy backend. They are always diverted to newly
// selected healthy backends (unless all backends are unhealthy). If set to
// ALWAYS_PERSIST, existing connections always persist on unhealthy backends
// regardless of protocol and session affinity. It is generally not recommended
// to use this mode overriding the default. For more details, see [Connection
// Persistence for Network Load
// Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#connection-persistence)
// and [Connection Persistence for Internal TCP/UDP Load
// Balancing](https://cloud.google.com/load-balancing/docs/internal#connection-persistence).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceConnectionTrackingPolicy_ConnectionPersistenceOnUnhealthyBackends = src.BackendServiceConnectionTrackingPolicy_ConnectionPersistenceOnUnhealthyBackends

// Specifies the key used for connection tracking. There are two options: -
// PER_CONNECTION: This is the default mode. The Connection Tracking is
// performed as per the Connection Key (default Hash Method) for the specific
// protocol. - PER_SESSION: The Connection Tracking is performed as per the
// configured Session Affinity. It matches the configured Session Affinity. For
// more details, see [Tracking Mode for Network Load
// Balancing](https://cloud.google.com/load-balancing/docs/network/networklb-backend-service#tracking-mode)
// and [Tracking Mode for Internal TCP/UDP Load
// Balancing](https://cloud.google.com/load-balancing/docs/internal#tracking-mode).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceConnectionTrackingPolicy_TrackingMode = src.BackendServiceConnectionTrackingPolicy_TrackingMode

// For load balancers that have configurable failover: [Internal passthrough
// Network Load
// Balancers](https://cloud.google.com/load-balancing/docs/internal/failover-overview)
// and [external passthrough Network Load
// Balancers](https://cloud.google.com/load-balancing/docs/network/networklb-failover-overview).
// On failover or failback, this field indicates whether connection draining
// will be honored. Google Cloud has a fixed connection draining timeout of 10
// minutes. A setting of true terminates existing TCP connections to the active
// pool during failover and failback, immediately draining traffic. A setting
// of false allows existing TCP connections to persist, even on VMs no longer
// in the active pool, for up to the duration of the connection draining
// timeout (10 minutes).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceFailoverPolicy = src.BackendServiceFailoverPolicy
type BackendServiceGroupHealth = src.BackendServiceGroupHealth

// The HTTP cookie used for stateful session affinity.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceHttpCookie = src.BackendServiceHttpCookie

// Identity-Aware Proxy
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceIAP = src.BackendServiceIAP

// Contains a list of BackendService resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceList = src.BackendServiceList

// Contains a list of usable BackendService resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceListUsable = src.BackendServiceListUsable

// Container for either a built-in LB policy supported by gRPC or Envoy or a
// custom one implemented by the end user.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceLocalityLoadBalancingPolicyConfig = src.BackendServiceLocalityLoadBalancingPolicyConfig

// The configuration for a custom policy implemented by the user and deployed
// with the client.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy = src.BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy

// The configuration for a built-in load balancing policy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceLocalityLoadBalancingPolicyConfigPolicy = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy

// The name of a locality load-balancing policy. Valid values include
// ROUND_ROBIN and, for Java clients, LEAST_REQUEST. For information about
// these values, see the description of localityLbPolicy. Do not specify the
// same policy more than once for a backend. If you do, the configuration is
// rejected.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name = src.BackendServiceLocalityLoadBalancingPolicyConfigPolicy_Name

// The available logging options for the load balancer traffic served by this
// backend service.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceLogConfig = src.BackendServiceLogConfig

// This field can only be specified if logging is enabled for this backend
// service. Configures whether all, none or a subset of optional fields should
// be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL,
// EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendServiceLogConfig_OptionalMode = src.BackendServiceLogConfig_OptionalMode
type BackendServiceReference = src.BackendServiceReference
type BackendServiceUsedBy = src.BackendServiceUsedBy

// Compress text responses using Brotli or gzip compression, based on the
// client's Accept-Encoding header.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendService_CompressionMode = src.BackendService_CompressionMode

// Specifies a preference for traffic sent from the proxy to the backend (or
// from the client to the backend for proxyless gRPC). The possible values are:
// - IPV4_ONLY: Only send IPv4 traffic to the backends of the backend service
// (Instance Group, Managed Instance Group, Network Endpoint Group), regardless
// of traffic from the client to the proxy. Only IPv4 health checks are used to
// check the health of the backends. This is the default setting. -
// PREFER_IPV6: Prioritize the connection to the endpoint's IPv6 address over
// its IPv4 address (provided there is a healthy IPv6 address). - IPV6_ONLY:
// Only send IPv6 traffic to the backends of the backend service (Instance
// Group, Managed Instance Group, Network Endpoint Group), regardless of
// traffic from the client to the proxy. Only IPv6 health checks are used to
// check the health of the backends. This field is applicable to either: -
// Advanced global external Application Load Balancer (load balancing scheme
// EXTERNAL_MANAGED), - Regional external Application Load Balancer, - Internal
// proxy Network Load Balancer (load balancing scheme INTERNAL_MANAGED), -
// Regional internal Application Load Balancer (load balancing scheme
// INTERNAL_MANAGED), - Traffic Director with Envoy proxies and proxyless gRPC
// (load balancing scheme INTERNAL_SELF_MANAGED).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendService_IpAddressSelectionPolicy = src.BackendService_IpAddressSelectionPolicy

// Specifies the load balancer type. A backend service created for one type of
// load balancer cannot be used with another. For more information, refer to
// Choosing a load balancer.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendService_LoadBalancingScheme = src.BackendService_LoadBalancingScheme

// The load balancing algorithm used within the scope of the locality. The
// possible values are: - ROUND_ROBIN: This is a simple policy in which each
// healthy backend is selected in round robin order. This is the default. -
// LEAST_REQUEST: An O(1) algorithm which selects two random healthy hosts and
// picks the host which has fewer active requests. - RING_HASH: The ring/modulo
// hash load balancer implements consistent hashing to backends. The algorithm
// has the property that the addition/removal of a host from a set of N hosts
// only affects 1/N of the requests. - RANDOM: The load balancer selects a
// random healthy host. - ORIGINAL_DESTINATION: Backend host is selected based
// on the client connection metadata, i.e., connections are opened to the same
// address as the destination address of the incoming connection before the
// connection was redirected to the load balancer. - MAGLEV: used as a drop in
// replacement for the ring hash load balancer. Maglev is not as stable as ring
// hash but has faster table lookup build times and host selection times. For
// more information about Maglev, see https://ai.google/research/pubs/pub44824
// This field is applicable to either: - A regional backend service with the
// service_protocol set to HTTP, HTTPS, or HTTP2, and load_balancing_scheme set
// to INTERNAL_MANAGED. - A global backend service with the
// load_balancing_scheme set to INTERNAL_SELF_MANAGED, INTERNAL_MANAGED, or
// EXTERNAL_MANAGED. If sessionAffinity is not configured—that is, if session
// affinity remains at the default value of NONE—then the default value for
// localityLbPolicy is ROUND_ROBIN. If session affinity is set to a value other
// than NONE, then the default value for localityLbPolicy is MAGLEV. Only
// ROUND_ROBIN and RING_HASH are supported when the backend service is
// referenced by a URL map that is bound to target gRPC proxy that has
// validateForProxyless field set to true.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendService_LocalityLbPolicy = src.BackendService_LocalityLbPolicy

// The protocol this BackendService uses to communicate with backends.
// Possible values are HTTP, HTTPS, HTTP2, TCP, SSL, UDP or GRPC. depending on
// the chosen load balancer or Traffic Director configuration. Refer to the
// documentation for the load balancers or for Traffic Director for more
// information. Must be set to GRPC when the backend service is referenced by a
// URL map that is bound to target gRPC proxy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendService_Protocol = src.BackendService_Protocol

// Type of session affinity to use. The default is NONE. Only NONE and
// HEADER_FIELD are supported when the backend service is referenced by a URL
// map that is bound to target gRPC proxy that has validateForProxyless field
// set to true. For more details, see: [Session
// Affinity](https://cloud.google.com/load-balancing/docs/backend-service#session_affinity).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BackendService_SessionAffinity = src.BackendService_SessionAffinity
type BackendServicesScopedList = src.BackendServicesScopedList

// Specifies how to determine whether the backend of a load balancer can
// handle additional traffic or is fully loaded. For usage guidelines, see
// Connection balancing mode. Backends must use compatible balancing modes. For
// more information, see Supported balancing modes and target capacity settings
// and Restrictions and guidance for instance groups. Note: Currently, if you
// use the API to configure incompatible balancing modes, the configuration
// might be accepted even though it has no impact and is ignored. Specifically,
// Backend.maxUtilization is ignored when Backend.balancingMode is RATE. In the
// future, this incompatible combination will be rejected.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Backend_BalancingMode = src.Backend_BalancingMode

// This field indicates whether this backend should be fully utilized before
// sending traffic to backends with default preference. The possible values
// are: - PREFERRED: Backends with this preference level will be filled up to
// their capacity limits first, based on RTT. - DEFAULT: If preferred backends
// don't have enough capacity, backends in this layer would be used and traffic
// would be assigned based on the load balancing algorithm you use. This is the
// default
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Backend_Preference = src.Backend_Preference
type BfdPacket = src.BfdPacket

// The diagnostic code specifies the local system's reason for the last change
// in session state. This allows remote systems to determine the reason that
// the previous session failed, for example. These diagnostic codes are
// specified in section 4.1 of RFC5880
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BfdPacket_Diagnostic = src.BfdPacket_Diagnostic

// The current BFD session state as seen by the transmitting system. These
// states are specified in section 4.1 of RFC5880
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BfdPacket_State = src.BfdPacket_State

// Next free: 15
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BfdStatus = src.BfdStatus
type BfdStatusPacketCounts = src.BfdStatusPacketCounts

// The BFD session initialization mode for this BGP peer. If set to ACTIVE,
// the Cloud Router will initiate the BFD session for this BGP peer. If set to
// PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD
// session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP
// peer.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BfdStatus_BfdSessionInitializationMode = src.BfdStatus_BfdSessionInitializationMode

// The diagnostic code specifies the local system's reason for the last change
// in session state. This allows remote systems to determine the reason that
// the previous session failed, for example. These diagnostic codes are
// specified in section 4.1 of RFC5880
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BfdStatus_LocalDiagnostic = src.BfdStatus_LocalDiagnostic

// The current BFD session state as seen by the transmitting system. These
// states are specified in section 4.1 of RFC5880
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BfdStatus_LocalState = src.BfdStatus_LocalState

// Associates `members`, or principals, with a `role`.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Binding = src.Binding

// A request message for Disks.BulkInsert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BulkInsertDiskRequest = src.BulkInsertDiskRequest

// A transient resource used in compute.disks.bulkInsert and
// compute.regionDisks.bulkInsert. It is only used to process requests and is
// not persisted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BulkInsertDiskResource = src.BulkInsertDiskResource

// A request message for Instances.BulkInsert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BulkInsertInstanceRequest = src.BulkInsertInstanceRequest

// A transient resource used in compute.instances.bulkInsert and
// compute.regionInstances.bulkInsert . This resource is not persisted
// anywhere, it is used only for processing the requests.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BulkInsertInstanceResource = src.BulkInsertInstanceResource

// Per-instance properties to be set on individual instances. To be extended
// in the future.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BulkInsertInstanceResourcePerInstanceProperties = src.BulkInsertInstanceResourcePerInstanceProperties
type BulkInsertOperationStatus = src.BulkInsertOperationStatus

// [Output Only] Creation status of BulkInsert operation - information if the
// flow is rolling forward or rolling back.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BulkInsertOperationStatus_Status = src.BulkInsertOperationStatus_Status

// A request message for RegionDisks.BulkInsert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BulkInsertRegionDiskRequest = src.BulkInsertRegionDiskRequest

// A request message for RegionInstances.BulkInsert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type BulkInsertRegionInstanceRequest = src.BulkInsertRegionInstanceRequest
type CacheInvalidationRule = src.CacheInvalidationRule

// Message containing what to include in the cache key for a request for Cloud
// CDN.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CacheKeyPolicy = src.CacheKeyPolicy

// A request message for InstanceGroupManagerResizeRequests.Cancel. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CancelInstanceGroupManagerResizeRequestRequest = src.CancelInstanceGroupManagerResizeRequestRequest

// Settings controlling the volume of requests, connections and retries to
// this backend service.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CircuitBreakers = src.CircuitBreakers

// A request message for FirewallPolicies.CloneRules. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CloneRulesFirewallPolicyRequest = src.CloneRulesFirewallPolicyRequest

// A request message for NetworkFirewallPolicies.CloneRules. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CloneRulesNetworkFirewallPolicyRequest = src.CloneRulesNetworkFirewallPolicyRequest

// A request message for RegionNetworkFirewallPolicies.CloneRules. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CloneRulesRegionNetworkFirewallPolicyRequest = src.CloneRulesRegionNetworkFirewallPolicyRequest

// Represents a regional Commitment resource. Creating a commitment resource
// means that you are purchasing a committed use contract with an explicit
// start and end time. You can create commitments based on vCPUs and memory
// usage and receive discounted rates. For full details, read Signing Up for
// Committed Use Discounts.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Commitment = src.Commitment
type CommitmentAggregatedList = src.CommitmentAggregatedList

// Contains a list of Commitment resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CommitmentList = src.CommitmentList

// [Output Only] Contains output only fields.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CommitmentResourceStatus = src.CommitmentResourceStatus

// The category of the commitment. Category MACHINE specifies commitments
// composed of machine resources such as VCPU or MEMORY, listed in resources.
// Category LICENSE specifies commitments composed of software licenses, listed
// in licenseResources. Note that only MACHINE commitments should have a Type
// specified.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Commitment_Category = src.Commitment_Category

// The plan for this commitment, which determines duration and discount rate.
// The currently supported plans are TWELVE_MONTH (1 year), and
// THIRTY_SIX_MONTH (3 years).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Commitment_Plan = src.Commitment_Plan

// [Output Only] Status of the commitment with regards to eventual expiration
// (each commitment has an end date defined). One of the following values:
// NOT_YET_ACTIVE, ACTIVE, EXPIRED.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Commitment_Status = src.Commitment_Status

// The type of commitment, which affects the discount rate and the eligible
// resources. Type MEMORY_OPTIMIZED specifies a commitment that will only apply
// to memory optimized machines. Type ACCELERATOR_OPTIMIZED specifies a
// commitment that will only apply to accelerator optimized machines.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Commitment_Type = src.Commitment_Type
type CommitmentsScopedList = src.CommitmentsScopedList

// A set of Confidential Instance options.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ConfidentialInstanceConfig = src.ConfidentialInstanceConfig

// Defines the type of technology used by the confidential instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ConfidentialInstanceConfig_ConfidentialInstanceType = src.ConfidentialInstanceConfig_ConfidentialInstanceType

// Message containing connection draining configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ConnectionDraining = src.ConnectionDraining

// This message defines settings for a consistent hash style load balancer.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ConsistentHashLoadBalancerSettings = src.ConsistentHashLoadBalancerSettings

// The information about the HTTP Cookie on which the hash function is based
// for load balancing policies that use a consistent hash.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ConsistentHashLoadBalancerSettingsHttpCookie = src.ConsistentHashLoadBalancerSettingsHttpCookie

// The specification for allowing client-side cross-origin requests. For more
// information about the W3C recommendation for cross-origin resource sharing
// (CORS), see Fetch API Living Standard.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CorsPolicy = src.CorsPolicy

// A request message for InstanceGroupManagers.CreateInstances. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CreateInstancesInstanceGroupManagerRequest = src.CreateInstancesInstanceGroupManagerRequest

// A request message for RegionInstanceGroupManagers.CreateInstances. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CreateInstancesRegionInstanceGroupManagerRequest = src.CreateInstancesRegionInstanceGroupManagerRequest

// A request message for Disks.CreateSnapshot. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CreateSnapshotDiskRequest = src.CreateSnapshotDiskRequest

// A request message for RegionDisks.CreateSnapshot. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CreateSnapshotRegionDiskRequest = src.CreateSnapshotRegionDiskRequest

// Specifies the custom error response policy that must be applied when the
// backend service or backend bucket responds with an error.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CustomErrorResponsePolicy = src.CustomErrorResponsePolicy

// Specifies the mapping between the response code that will be returned along
// with the custom error content and the response code returned by the backend
// service.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type CustomErrorResponsePolicyCustomErrorResponseRule = src.CustomErrorResponsePolicyCustomErrorResponseRule
type CustomerEncryptionKey = src.CustomerEncryptionKey
type CustomerEncryptionKeyProtectedDisk = src.CustomerEncryptionKeyProtectedDisk
type Data = src.Data

// A request message for Instances.DeleteAccessConfig. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteAccessConfigInstanceRequest = src.DeleteAccessConfigInstanceRequest

// A request message for Addresses.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteAddressRequest = src.DeleteAddressRequest

// A request message for Autoscalers.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteAutoscalerRequest = src.DeleteAutoscalerRequest

// A request message for BackendBuckets.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteBackendBucketRequest = src.DeleteBackendBucketRequest

// A request message for BackendServices.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteBackendServiceRequest = src.DeleteBackendServiceRequest

// A request message for Disks.Delete. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteDiskRequest = src.DeleteDiskRequest

// A request message for ExternalVpnGateways.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteExternalVpnGatewayRequest = src.DeleteExternalVpnGatewayRequest

// A request message for FirewallPolicies.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteFirewallPolicyRequest = src.DeleteFirewallPolicyRequest

// A request message for Firewalls.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteFirewallRequest = src.DeleteFirewallRequest

// A request message for ForwardingRules.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteForwardingRuleRequest = src.DeleteForwardingRuleRequest

// A request message for GlobalAddresses.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteGlobalAddressRequest = src.DeleteGlobalAddressRequest

// A request message for GlobalForwardingRules.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteGlobalForwardingRuleRequest = src.DeleteGlobalForwardingRuleRequest

// A request message for GlobalNetworkEndpointGroups.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteGlobalNetworkEndpointGroupRequest = src.DeleteGlobalNetworkEndpointGroupRequest

// A request message for GlobalOperations.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteGlobalOperationRequest = src.DeleteGlobalOperationRequest

// A response message for GlobalOperations.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteGlobalOperationResponse = src.DeleteGlobalOperationResponse

// A request message for GlobalOrganizationOperations.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteGlobalOrganizationOperationRequest = src.DeleteGlobalOrganizationOperationRequest

// A response message for GlobalOrganizationOperations.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteGlobalOrganizationOperationResponse = src.DeleteGlobalOrganizationOperationResponse

// A request message for GlobalPublicDelegatedPrefixes.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteGlobalPublicDelegatedPrefixeRequest = src.DeleteGlobalPublicDelegatedPrefixeRequest

// A request message for HealthChecks.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteHealthCheckRequest = src.DeleteHealthCheckRequest

// A request message for Images.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteImageRequest = src.DeleteImageRequest

// A request message for InstanceGroupManagers.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteInstanceGroupManagerRequest = src.DeleteInstanceGroupManagerRequest

// A request message for InstanceGroupManagerResizeRequests.Delete. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteInstanceGroupManagerResizeRequestRequest = src.DeleteInstanceGroupManagerResizeRequestRequest

// A request message for InstanceGroups.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteInstanceGroupRequest = src.DeleteInstanceGroupRequest

// A request message for Instances.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteInstanceRequest = src.DeleteInstanceRequest

// A request message for InstanceTemplates.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteInstanceTemplateRequest = src.DeleteInstanceTemplateRequest

// A request message for InstanceGroupManagers.DeleteInstances. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteInstancesInstanceGroupManagerRequest = src.DeleteInstancesInstanceGroupManagerRequest

// A request message for RegionInstanceGroupManagers.DeleteInstances. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteInstancesRegionInstanceGroupManagerRequest = src.DeleteInstancesRegionInstanceGroupManagerRequest

// A request message for InstantSnapshots.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteInstantSnapshotRequest = src.DeleteInstantSnapshotRequest

// A request message for InterconnectAttachments.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteInterconnectAttachmentRequest = src.DeleteInterconnectAttachmentRequest

// A request message for Interconnects.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteInterconnectRequest = src.DeleteInterconnectRequest

// A request message for Licenses.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteLicenseRequest = src.DeleteLicenseRequest

// A request message for MachineImages.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteMachineImageRequest = src.DeleteMachineImageRequest

// A request message for NetworkAttachments.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteNetworkAttachmentRequest = src.DeleteNetworkAttachmentRequest

// A request message for NetworkEdgeSecurityServices.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteNetworkEdgeSecurityServiceRequest = src.DeleteNetworkEdgeSecurityServiceRequest

// A request message for NetworkEndpointGroups.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteNetworkEndpointGroupRequest = src.DeleteNetworkEndpointGroupRequest

// A request message for NetworkFirewallPolicies.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteNetworkFirewallPolicyRequest = src.DeleteNetworkFirewallPolicyRequest

// A request message for Networks.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteNetworkRequest = src.DeleteNetworkRequest

// A request message for NodeGroups.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteNodeGroupRequest = src.DeleteNodeGroupRequest

// A request message for NodeTemplates.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteNodeTemplateRequest = src.DeleteNodeTemplateRequest

// A request message for NodeGroups.DeleteNodes. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteNodesNodeGroupRequest = src.DeleteNodesNodeGroupRequest

// A request message for PacketMirrorings.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeletePacketMirroringRequest = src.DeletePacketMirroringRequest

// A request message for InstanceGroupManagers.DeletePerInstanceConfigs. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeletePerInstanceConfigsInstanceGroupManagerRequest = src.DeletePerInstanceConfigsInstanceGroupManagerRequest

// A request message for RegionInstanceGroupManagers.DeletePerInstanceConfigs.
// See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeletePerInstanceConfigsRegionInstanceGroupManagerRequest = src.DeletePerInstanceConfigsRegionInstanceGroupManagerRequest

// A request message for PublicAdvertisedPrefixes.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeletePublicAdvertisedPrefixeRequest = src.DeletePublicAdvertisedPrefixeRequest

// A request message for PublicDelegatedPrefixes.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeletePublicDelegatedPrefixeRequest = src.DeletePublicDelegatedPrefixeRequest

// A request message for RegionAutoscalers.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionAutoscalerRequest = src.DeleteRegionAutoscalerRequest

// A request message for RegionBackendServices.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionBackendServiceRequest = src.DeleteRegionBackendServiceRequest

// A request message for RegionDisks.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionDiskRequest = src.DeleteRegionDiskRequest

// A request message for RegionHealthChecks.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionHealthCheckRequest = src.DeleteRegionHealthCheckRequest

// A request message for RegionHealthCheckServices.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionHealthCheckServiceRequest = src.DeleteRegionHealthCheckServiceRequest

// A request message for RegionInstanceGroupManagers.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionInstanceGroupManagerRequest = src.DeleteRegionInstanceGroupManagerRequest

// A request message for RegionInstanceTemplates.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionInstanceTemplateRequest = src.DeleteRegionInstanceTemplateRequest

// A request message for RegionInstantSnapshots.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionInstantSnapshotRequest = src.DeleteRegionInstantSnapshotRequest

// A request message for RegionNetworkEndpointGroups.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionNetworkEndpointGroupRequest = src.DeleteRegionNetworkEndpointGroupRequest

// A request message for RegionNetworkFirewallPolicies.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionNetworkFirewallPolicyRequest = src.DeleteRegionNetworkFirewallPolicyRequest

// A request message for RegionNotificationEndpoints.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionNotificationEndpointRequest = src.DeleteRegionNotificationEndpointRequest

// A request message for RegionOperations.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionOperationRequest = src.DeleteRegionOperationRequest

// A response message for RegionOperations.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionOperationResponse = src.DeleteRegionOperationResponse

// A request message for RegionSecurityPolicies.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionSecurityPolicyRequest = src.DeleteRegionSecurityPolicyRequest

// A request message for RegionSslCertificates.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionSslCertificateRequest = src.DeleteRegionSslCertificateRequest

// A request message for RegionSslPolicies.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionSslPolicyRequest = src.DeleteRegionSslPolicyRequest

// A request message for RegionTargetHttpProxies.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionTargetHttpProxyRequest = src.DeleteRegionTargetHttpProxyRequest

// A request message for RegionTargetHttpsProxies.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionTargetHttpsProxyRequest = src.DeleteRegionTargetHttpsProxyRequest

// A request message for RegionTargetTcpProxies.Delete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionTargetTcpProxyRequest = src.DeleteRegionTargetTcpProxyRequest

// A request message for RegionUrlMaps.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRegionUrlMapRequest = src.DeleteRegionUrlMapRequest

// A request message for Reservations.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteReservationRequest = src.DeleteReservationRequest

// A request message for ResourcePolicies.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteResourcePolicyRequest = src.DeleteResourcePolicyRequest

// A request message for Routes.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRouteRequest = src.DeleteRouteRequest

// A request message for Routers.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteRouterRequest = src.DeleteRouterRequest

// A request message for SecurityPolicies.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteSecurityPolicyRequest = src.DeleteSecurityPolicyRequest

// A request message for ServiceAttachments.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteServiceAttachmentRequest = src.DeleteServiceAttachmentRequest

// A request message for BackendBuckets.DeleteSignedUrlKey. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteSignedUrlKeyBackendBucketRequest = src.DeleteSignedUrlKeyBackendBucketRequest

// A request message for BackendServices.DeleteSignedUrlKey. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteSignedUrlKeyBackendServiceRequest = src.DeleteSignedUrlKeyBackendServiceRequest

// A request message for Snapshots.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteSnapshotRequest = src.DeleteSnapshotRequest

// A request message for SslCertificates.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteSslCertificateRequest = src.DeleteSslCertificateRequest

// A request message for SslPolicies.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteSslPolicyRequest = src.DeleteSslPolicyRequest

// A request message for StoragePools.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteStoragePoolRequest = src.DeleteStoragePoolRequest

// A request message for Subnetworks.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteSubnetworkRequest = src.DeleteSubnetworkRequest

// A request message for TargetGrpcProxies.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteTargetGrpcProxyRequest = src.DeleteTargetGrpcProxyRequest

// A request message for TargetHttpProxies.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteTargetHttpProxyRequest = src.DeleteTargetHttpProxyRequest

// A request message for TargetHttpsProxies.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteTargetHttpsProxyRequest = src.DeleteTargetHttpsProxyRequest

// A request message for TargetInstances.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteTargetInstanceRequest = src.DeleteTargetInstanceRequest

// A request message for TargetPools.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteTargetPoolRequest = src.DeleteTargetPoolRequest

// A request message for TargetSslProxies.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteTargetSslProxyRequest = src.DeleteTargetSslProxyRequest

// A request message for TargetTcpProxies.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteTargetTcpProxyRequest = src.DeleteTargetTcpProxyRequest

// A request message for TargetVpnGateways.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteTargetVpnGatewayRequest = src.DeleteTargetVpnGatewayRequest

// A request message for UrlMaps.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteUrlMapRequest = src.DeleteUrlMapRequest

// A request message for VpnGateways.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteVpnGatewayRequest = src.DeleteVpnGatewayRequest

// A request message for VpnTunnels.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteVpnTunnelRequest = src.DeleteVpnTunnelRequest

// A request message for ZoneOperations.Delete. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteZoneOperationRequest = src.DeleteZoneOperationRequest

// A response message for ZoneOperations.Delete. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeleteZoneOperationResponse = src.DeleteZoneOperationResponse
type Denied = src.Denied

// A request message for Images.Deprecate. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeprecateImageRequest = src.DeprecateImageRequest

// Deprecation status for a public resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeprecationStatus = src.DeprecationStatus

// The deprecation state of this resource. This can be ACTIVE, DEPRECATED,
// OBSOLETE, or DELETED. Operations which communicate the end of life date for
// an image, can use ACTIVE. Operations which create a new resource using a
// DEPRECATED resource will return successfully, but with a warning indicating
// the deprecated resource and recommending its replacement. Operations which
// use OBSOLETE or DELETED resources will be rejected and result in an error.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DeprecationStatus_State = src.DeprecationStatus_State

// A request message for Instances.DetachDisk. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DetachDiskInstanceRequest = src.DetachDiskInstanceRequest

// A request message for GlobalNetworkEndpointGroups.DetachNetworkEndpoints.
// See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest = src.DetachNetworkEndpointsGlobalNetworkEndpointGroupRequest

// A request message for NetworkEndpointGroups.DetachNetworkEndpoints. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DetachNetworkEndpointsNetworkEndpointGroupRequest = src.DetachNetworkEndpointsNetworkEndpointGroupRequest

// A request message for RegionNetworkEndpointGroups.DetachNetworkEndpoints.
// See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DetachNetworkEndpointsRegionNetworkEndpointGroupRequest = src.DetachNetworkEndpointsRegionNetworkEndpointGroupRequest

// A request message for Projects.DisableXpnHost. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DisableXpnHostProjectRequest = src.DisableXpnHostProjectRequest

// A request message for Projects.DisableXpnResource. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DisableXpnResourceProjectRequest = src.DisableXpnResourceProjectRequest

// Represents a Persistent Disk resource. Google Compute Engine has two Disk
// resources: * [Zonal](/compute/docs/reference/rest/v1/disks) *
// [Regional](/compute/docs/reference/rest/v1/regionDisks) Persistent disks are
// required for running your VM instances. Create both boot and non-boot (data)
// persistent disks. For more information, read Persistent Disks. For more
// storage options, read Storage options. The disks resource represents a zonal
// persistent disk. For more information, read Zonal persistent disks. The
// regionDisks resource represents a regional persistent disk. For more
// information, read Regional resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Disk = src.Disk
type DiskAggregatedList = src.DiskAggregatedList
type DiskAsyncReplication = src.DiskAsyncReplication
type DiskAsyncReplicationList = src.DiskAsyncReplicationList

// A specification of the desired way to instantiate a disk in the instance
// template when its created from a source instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DiskInstantiationConfig = src.DiskInstantiationConfig

// Specifies whether to include the disk and what image to use. Possible
// values are: - source-image: to use the same image that was used to create
// the source instance's corresponding disk. Applicable to the boot disk and
// additional read-write disks. - source-image-family: to use the same image
// family that was used to create the source instance's corresponding disk.
// Applicable to the boot disk and additional read-write disks. - custom-image:
// to use a user-provided image url for disk creation. Applicable to the boot
// disk and additional read-write disks. - attach-read-only: to attach a
// read-only disk. Applicable to read-only disks. - do-not-include: to exclude
// a disk from the template. Applicable to additional read-write disks, local
// SSDs, and read-only disks.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DiskInstantiationConfig_InstantiateFrom = src.DiskInstantiationConfig_InstantiateFrom

// A list of Disk resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DiskList = src.DiskList
type DiskMoveRequest = src.DiskMoveRequest

// Additional disk params.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DiskParams = src.DiskParams
type DiskResourceStatus = src.DiskResourceStatus
type DiskResourceStatusAsyncReplicationStatus = src.DiskResourceStatusAsyncReplicationStatus
type DiskResourceStatusAsyncReplicationStatus_State = src.DiskResourceStatusAsyncReplicationStatus_State

// Represents a Disk Type resource. Google Compute Engine has two Disk Type
// resources: * [Regional](/compute/docs/reference/rest/v1/regionDiskTypes) *
// [Zonal](/compute/docs/reference/rest/v1/diskTypes) You can choose from a
// variety of disk types based on your needs. For more information, read
// Storage options. The diskTypes resource represents disk types for a zonal
// persistent disk. For more information, read Zonal persistent disks. The
// regionDiskTypes resource represents disk types for a regional persistent
// disk. For more information, read Regional persistent disks.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DiskType = src.DiskType
type DiskTypeAggregatedList = src.DiskTypeAggregatedList

// Contains a list of disk types.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DiskTypeList = src.DiskTypeList
type DiskTypesScopedList = src.DiskTypesScopedList

// The access mode of the disk. - READ_WRITE_SINGLE: The default AccessMode,
// means the disk can be attached to single instance in RW mode. -
// READ_WRITE_MANY: The AccessMode means the disk can be attached to multiple
// instances in RW mode. - READ_ONLY_MANY: The AccessMode means the disk can be
// attached to multiple instances in RO mode. The AccessMode is only valid for
// Hyperdisk disk types.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Disk_AccessMode = src.Disk_AccessMode

// The architecture of the disk. Valid values are ARM64 or X86_64.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Disk_Architecture = src.Disk_Architecture

// [Output Only] The status of disk creation. - CREATING: Disk is
// provisioning. - RESTORING: Source data is being copied into the disk. -
// FAILED: Disk creation failed. - READY: Disk is ready for use. - DELETING:
// Disk is deleting.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Disk_Status = src.Disk_Status
type DisksAddResourcePoliciesRequest = src.DisksAddResourcePoliciesRequest
type DisksRemoveResourcePoliciesRequest = src.DisksRemoveResourcePoliciesRequest
type DisksResizeRequest = src.DisksResizeRequest
type DisksScopedList = src.DisksScopedList
type DisksStartAsyncReplicationRequest = src.DisksStartAsyncReplicationRequest

// A transient resource used in compute.disks.stopGroupAsyncReplication and
// compute.regionDisks.stopGroupAsyncReplication. It is only used to process
// requests and is not persisted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DisksStopGroupAsyncReplicationResource = src.DisksStopGroupAsyncReplicationResource

// A set of Display Device options
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DisplayDevice = src.DisplayDevice
type DistributionPolicy = src.DistributionPolicy
type DistributionPolicyZoneConfiguration = src.DistributionPolicyZoneConfiguration

// The distribution shape to which the group converges either proactively or
// on resize events (depending on the value set in
// updatePolicy.instanceRedistributionType).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type DistributionPolicy_TargetShape = src.DistributionPolicy_TargetShape

// A Duration represents a fixed-length span of time represented as a count of
// seconds and fractions of seconds at nanosecond resolution. It is independent
// of any calendar and concepts like "day" or "month". Range is approximately
// 10,000 years.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Duration = src.Duration

// A request message for Projects.EnableXpnHost. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type EnableXpnHostProjectRequest = src.EnableXpnHostProjectRequest

// A request message for Projects.EnableXpnResource. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type EnableXpnResourceProjectRequest = src.EnableXpnResourceProjectRequest

// Errors that prevented the ResizeRequest to be fulfilled.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Error = src.Error
type ErrorDetails = src.ErrorDetails

// Describes the cause of the error with structured details. Example of an
// error when contacting the "pubsub.googleapis.com" API when it is not
// enabled: { "reason": "API_DISABLED" "domain": "googleapis.com" "metadata": {
// "resource": "projects/123", "service": "pubsub.googleapis.com" } } This
// response indicates that the pubsub.googleapis.com API is not enabled.
// Example of an error that is returned when attempting to create a Spanner
// instance in a region that is out of stock: { "reason": "STOCKOUT" "domain":
// "spanner.googleapis.com", "metadata": { "availableRegions":
// "us-central1,us-east2" } }
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ErrorInfo = src.ErrorInfo
type Errors = src.Errors
type ExchangedPeeringRoute = src.ExchangedPeeringRoute

// The type of the peering route.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ExchangedPeeringRoute_Type = src.ExchangedPeeringRoute_Type
type ExchangedPeeringRoutesList = src.ExchangedPeeringRoutesList

// A request message for Subnetworks.ExpandIpCidrRange. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ExpandIpCidrRangeSubnetworkRequest = src.ExpandIpCidrRangeSubnetworkRequest

// Represents a textual expression in the Common Expression Language (CEL)
// syntax. CEL is a C-like expression language. The syntax and semantics of CEL
// are documented at https://github.com/google/cel-spec. Example (Comparison):
// title: "Summary size limit" description: "Determines if a summary is less
// than 100 chars" expression: "document.summary.size() < 100" Example
// (Equality): title: "Requestor is owner" description: "Determines if
// requestor is the document owner" expression: "document.owner ==
// request.auth.claims.email" Example (Logic): title: "Public documents"
// description: "Determine whether the document should be publicly visible"
// expression: "document.type != 'private' && document.type != 'internal'"
// Example (Data Manipulation): title: "Notification string" description:
// "Create a notification string with a timestamp." expression: "'New message
// received at ' + string(document.create_time)" The exact variables and
// functions that may be referenced within an expression are determined by the
// service that evaluates it. See the service documentation for additional
// information.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Expr = src.Expr

// Represents an external VPN gateway. External VPN gateway is the on-premises
// VPN gateway(s) or another cloud provider's VPN gateway that connects to your
// Google Cloud VPN gateway. To create a highly available VPN from Google Cloud
// Platform to your VPN gateway or another cloud provider's VPN gateway, you
// must create a external VPN gateway resource with information about the other
// gateway. For more information about using external VPN gateways, see
// Creating an HA VPN gateway and tunnel pair to a peer VPN.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ExternalVpnGateway = src.ExternalVpnGateway

// The interface for the external VPN gateway.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ExternalVpnGatewayInterface = src.ExternalVpnGatewayInterface

// Response to the list request, and contains a list of externalVpnGateways.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ExternalVpnGatewayList = src.ExternalVpnGatewayList

// Indicates the user-supplied redundancy type of this external VPN gateway.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ExternalVpnGateway_RedundancyType = src.ExternalVpnGateway_RedundancyType
type FileContentBuffer = src.FileContentBuffer

// The file type of source file.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type FileContentBuffer_FileType = src.FileContentBuffer_FileType

// Represents a Firewall Rule resource. Firewall rules allow or deny ingress
// traffic to, and egress traffic from your instances. For more information,
// read Firewall rules.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Firewall = src.Firewall

// Contains a list of firewalls.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type FirewallList = src.FirewallList

// The available logging options for a firewall rule.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type FirewallLogConfig = src.FirewallLogConfig

// This field can only be specified for a particular firewall rule if logging
// is enabled for that rule. This field denotes whether to include or exclude
// metadata for firewall logs.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type FirewallLogConfig_Metadata = src.FirewallLogConfig_Metadata
type FirewallPoliciesListAssociationsResponse = src.FirewallPoliciesListAssociationsResponse

// Represents a Firewall Policy resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type FirewallPolicy = src.FirewallPolicy
type FirewallPolicyAssociation = src.FirewallPolicyAssociation
type FirewallPolicyList = src.FirewallPolicyList

// Represents a rule that describes one or more match conditions along with
// the action to be taken when traffic matches this condition (allow or deny).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type FirewallPolicyRule = src.FirewallPolicyRule

// Represents a match condition that incoming traffic is evaluated against.
// Exactly one field must be specified.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type FirewallPolicyRuleMatcher = src.FirewallPolicyRuleMatcher
type FirewallPolicyRuleMatcherLayer4Config = src.FirewallPolicyRuleMatcherLayer4Config
type FirewallPolicyRuleSecureTag = src.FirewallPolicyRuleSecureTag

// [Output Only] State of the secure tag, either `EFFECTIVE` or `INEFFECTIVE`.
// A secure tag is `INEFFECTIVE` when it is deleted or its network is deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type FirewallPolicyRuleSecureTag_State = src.FirewallPolicyRuleSecureTag_State

// The direction in which this rule applies.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type FirewallPolicyRule_Direction = src.FirewallPolicyRule_Direction

// Direction of traffic to which this firewall applies, either `INGRESS` or
// `EGRESS`. The default is `INGRESS`. For `EGRESS` traffic, you cannot specify
// the sourceTags fields.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Firewall_Direction = src.Firewall_Direction

// Encapsulates numeric value that can be either absolute or relative.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type FixedOrPercent = src.FixedOrPercent

// Represents a Forwarding Rule resource. Forwarding rule resources in Google
// Cloud can be either regional or global in scope: *
// [Global](https://cloud.google.com/compute/docs/reference/rest/v1/globalForwardingRules)
// *
// [Regional](https://cloud.google.com/compute/docs/reference/rest/v1/forwardingRules)
// A forwarding rule and its corresponding IP address represent the frontend
// configuration of a Google Cloud load balancer. Forwarding rules can also
// reference target instances and Cloud VPN Classic gateways
// (targetVpnGateway). For more information, read Forwarding rule concepts and
// Using protocol forwarding.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ForwardingRule = src.ForwardingRule
type ForwardingRuleAggregatedList = src.ForwardingRuleAggregatedList

// Contains a list of ForwardingRule resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ForwardingRuleList = src.ForwardingRuleList
type ForwardingRuleReference = src.ForwardingRuleReference

// Describes the auto-registration of the forwarding rule to Service
// Directory. The region and project of the Service Directory resource
// generated from this registration will be the same as this forwarding rule.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ForwardingRuleServiceDirectoryRegistration = src.ForwardingRuleServiceDirectoryRegistration

// The IP protocol to which this rule applies. For protocol forwarding, valid
// options are TCP, UDP, ESP, AH, SCTP, ICMP and L3_DEFAULT. The valid IP
// protocols are different for different load balancing products as described
// in [Load balancing
// features](https://cloud.google.com/load-balancing/docs/features#protocols_from_the_load_balancer_to_the_backends).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ForwardingRule_IPProtocolEnum = src.ForwardingRule_IPProtocolEnum

// The IP Version that will be used by this forwarding rule. Valid options are
// IPV4 or IPV6.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ForwardingRule_IpVersion = src.ForwardingRule_IpVersion

// Specifies the forwarding rule type. For more information about forwarding
// rules, refer to Forwarding rule concepts.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ForwardingRule_LoadBalancingScheme = src.ForwardingRule_LoadBalancingScheme

// This signifies the networking tier used for configuring this load balancer
// and can only take the following values: PREMIUM, STANDARD. For regional
// ForwardingRule, the valid values are PREMIUM and STANDARD. For
// GlobalForwardingRule, the valid value is PREMIUM. If this field is not
// specified, it is assumed to be PREMIUM. If IPAddress is specified, this
// value must be equal to the networkTier of the Address.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ForwardingRule_NetworkTier = src.ForwardingRule_NetworkTier
type ForwardingRule_PscConnectionStatus = src.ForwardingRule_PscConnectionStatus
type ForwardingRulesScopedList = src.ForwardingRulesScopedList
type GRPCHealthCheck = src.GRPCHealthCheck

// Specifies how a port is selected for health checking. Can be one of the
// following values: USE_FIXED_PORT: Specifies a port number explicitly using
// the port field in the health check. Supported by backend services for
// passthrough load balancers and backend services for proxy load balancers.
// Not supported by target pools. The health check supports all backends
// supported by the backend service provided the backend can be health checked.
// For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network
// endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported.
// USE_SERVING_PORT: Provides an indirect method of specifying the health check
// port by referring to the backend service. Only supported by backend services
// for proxy load balancers. Not supported by target pools. Not supported by
// backend services for passthrough load balancers. Supports all backends that
// can be health checked; for example, GCE_VM_IP_PORT network endpoint groups
// and instance group backends. For GCE_VM_IP_PORT network endpoint group
// backends, the health check uses the port number specified for each endpoint
// in the network endpoint group. For instance group backends, the health check
// uses the port number determined by looking up the backend service's named
// port in the instance group's list of named ports.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GRPCHealthCheck_PortSpecification = src.GRPCHealthCheck_PortSpecification

// A request message for AcceleratorTypes.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetAcceleratorTypeRequest = src.GetAcceleratorTypeRequest

// A request message for Addresses.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetAddressRequest = src.GetAddressRequest

// A request message for FirewallPolicies.GetAssociation. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetAssociationFirewallPolicyRequest = src.GetAssociationFirewallPolicyRequest

// A request message for NetworkFirewallPolicies.GetAssociation. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetAssociationNetworkFirewallPolicyRequest = src.GetAssociationNetworkFirewallPolicyRequest

// A request message for RegionNetworkFirewallPolicies.GetAssociation. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetAssociationRegionNetworkFirewallPolicyRequest = src.GetAssociationRegionNetworkFirewallPolicyRequest

// A request message for Autoscalers.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetAutoscalerRequest = src.GetAutoscalerRequest

// A request message for BackendBuckets.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetBackendBucketRequest = src.GetBackendBucketRequest

// A request message for BackendServices.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetBackendServiceRequest = src.GetBackendServiceRequest

// A request message for Interconnects.GetDiagnostics. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetDiagnosticsInterconnectRequest = src.GetDiagnosticsInterconnectRequest

// A request message for Disks.Get. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetDiskRequest = src.GetDiskRequest

// A request message for DiskTypes.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetDiskTypeRequest = src.GetDiskTypeRequest

// A request message for Instances.GetEffectiveFirewalls. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetEffectiveFirewallsInstanceRequest = src.GetEffectiveFirewallsInstanceRequest

// A request message for Networks.GetEffectiveFirewalls. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetEffectiveFirewallsNetworkRequest = src.GetEffectiveFirewallsNetworkRequest

// A request message for RegionNetworkFirewallPolicies.GetEffectiveFirewalls.
// See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest = src.GetEffectiveFirewallsRegionNetworkFirewallPolicyRequest

// A request message for ExternalVpnGateways.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetExternalVpnGatewayRequest = src.GetExternalVpnGatewayRequest

// A request message for FirewallPolicies.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetFirewallPolicyRequest = src.GetFirewallPolicyRequest

// A request message for Firewalls.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetFirewallRequest = src.GetFirewallRequest

// A request message for ForwardingRules.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetForwardingRuleRequest = src.GetForwardingRuleRequest

// A request message for Images.GetFromFamily. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetFromFamilyImageRequest = src.GetFromFamilyImageRequest

// A request message for GlobalAddresses.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetGlobalAddressRequest = src.GetGlobalAddressRequest

// A request message for GlobalForwardingRules.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetGlobalForwardingRuleRequest = src.GetGlobalForwardingRuleRequest

// A request message for GlobalNetworkEndpointGroups.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetGlobalNetworkEndpointGroupRequest = src.GetGlobalNetworkEndpointGroupRequest

// A request message for GlobalOperations.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetGlobalOperationRequest = src.GetGlobalOperationRequest

// A request message for GlobalOrganizationOperations.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetGlobalOrganizationOperationRequest = src.GetGlobalOrganizationOperationRequest

// A request message for GlobalPublicDelegatedPrefixes.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetGlobalPublicDelegatedPrefixeRequest = src.GetGlobalPublicDelegatedPrefixeRequest

// A request message for Instances.GetGuestAttributes. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetGuestAttributesInstanceRequest = src.GetGuestAttributesInstanceRequest

// A request message for BackendServices.GetHealth. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetHealthBackendServiceRequest = src.GetHealthBackendServiceRequest

// A request message for HealthChecks.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetHealthCheckRequest = src.GetHealthCheckRequest

// A request message for RegionBackendServices.GetHealth. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetHealthRegionBackendServiceRequest = src.GetHealthRegionBackendServiceRequest

// A request message for TargetPools.GetHealth. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetHealthTargetPoolRequest = src.GetHealthTargetPoolRequest

// A request message for BackendBuckets.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyBackendBucketRequest = src.GetIamPolicyBackendBucketRequest

// A request message for BackendServices.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyBackendServiceRequest = src.GetIamPolicyBackendServiceRequest

// A request message for Disks.GetIamPolicy. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyDiskRequest = src.GetIamPolicyDiskRequest

// A request message for FirewallPolicies.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyFirewallPolicyRequest = src.GetIamPolicyFirewallPolicyRequest

// A request message for Images.GetIamPolicy. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyImageRequest = src.GetIamPolicyImageRequest

// A request message for Instances.GetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyInstanceRequest = src.GetIamPolicyInstanceRequest

// A request message for InstanceTemplates.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyInstanceTemplateRequest = src.GetIamPolicyInstanceTemplateRequest

// A request message for InstantSnapshots.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyInstantSnapshotRequest = src.GetIamPolicyInstantSnapshotRequest

// A request message for Licenses.GetIamPolicy. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyLicenseRequest = src.GetIamPolicyLicenseRequest

// A request message for MachineImages.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyMachineImageRequest = src.GetIamPolicyMachineImageRequest

// A request message for NetworkAttachments.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyNetworkAttachmentRequest = src.GetIamPolicyNetworkAttachmentRequest

// A request message for NetworkFirewallPolicies.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyNetworkFirewallPolicyRequest = src.GetIamPolicyNetworkFirewallPolicyRequest

// A request message for NodeGroups.GetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyNodeGroupRequest = src.GetIamPolicyNodeGroupRequest

// A request message for NodeTemplates.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyNodeTemplateRequest = src.GetIamPolicyNodeTemplateRequest

// A request message for RegionBackendServices.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyRegionBackendServiceRequest = src.GetIamPolicyRegionBackendServiceRequest

// A request message for RegionDisks.GetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyRegionDiskRequest = src.GetIamPolicyRegionDiskRequest

// A request message for RegionInstantSnapshots.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyRegionInstantSnapshotRequest = src.GetIamPolicyRegionInstantSnapshotRequest

// A request message for RegionNetworkFirewallPolicies.GetIamPolicy. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyRegionNetworkFirewallPolicyRequest = src.GetIamPolicyRegionNetworkFirewallPolicyRequest

// A request message for Reservations.GetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyReservationRequest = src.GetIamPolicyReservationRequest

// A request message for ResourcePolicies.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyResourcePolicyRequest = src.GetIamPolicyResourcePolicyRequest

// A request message for ServiceAttachments.GetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyServiceAttachmentRequest = src.GetIamPolicyServiceAttachmentRequest

// A request message for Snapshots.GetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicySnapshotRequest = src.GetIamPolicySnapshotRequest

// A request message for StoragePools.GetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicyStoragePoolRequest = src.GetIamPolicyStoragePoolRequest

// A request message for Subnetworks.GetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetIamPolicySubnetworkRequest = src.GetIamPolicySubnetworkRequest

// A request message for ImageFamilyViews.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetImageFamilyViewRequest = src.GetImageFamilyViewRequest

// A request message for Images.Get. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetImageRequest = src.GetImageRequest

// A request message for InstanceGroupManagers.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInstanceGroupManagerRequest = src.GetInstanceGroupManagerRequest

// A request message for InstanceGroupManagerResizeRequests.Get. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInstanceGroupManagerResizeRequestRequest = src.GetInstanceGroupManagerResizeRequestRequest

// A request message for InstanceGroups.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInstanceGroupRequest = src.GetInstanceGroupRequest

// A request message for Instances.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInstanceRequest = src.GetInstanceRequest

// A request message for InstanceSettingsService.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInstanceSettingRequest = src.GetInstanceSettingRequest

// A request message for InstanceTemplates.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInstanceTemplateRequest = src.GetInstanceTemplateRequest

// A request message for InstantSnapshots.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInstantSnapshotRequest = src.GetInstantSnapshotRequest

// A request message for InterconnectAttachments.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInterconnectAttachmentRequest = src.GetInterconnectAttachmentRequest

// A request message for InterconnectLocations.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInterconnectLocationRequest = src.GetInterconnectLocationRequest

// A request message for InterconnectRemoteLocations.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInterconnectRemoteLocationRequest = src.GetInterconnectRemoteLocationRequest

// A request message for Interconnects.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetInterconnectRequest = src.GetInterconnectRequest

// A request message for LicenseCodes.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetLicenseCodeRequest = src.GetLicenseCodeRequest

// A request message for Licenses.Get. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetLicenseRequest = src.GetLicenseRequest

// A request message for MachineImages.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetMachineImageRequest = src.GetMachineImageRequest

// A request message for MachineTypes.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetMachineTypeRequest = src.GetMachineTypeRequest

// A request message for Interconnects.GetMacsecConfig. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetMacsecConfigInterconnectRequest = src.GetMacsecConfigInterconnectRequest

// A request message for Routers.GetNatIpInfo. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetNatIpInfoRouterRequest = src.GetNatIpInfoRouterRequest

// A request message for Routers.GetNatMappingInfo. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetNatMappingInfoRoutersRequest = src.GetNatMappingInfoRoutersRequest

// A request message for NetworkAttachments.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetNetworkAttachmentRequest = src.GetNetworkAttachmentRequest

// A request message for NetworkEdgeSecurityServices.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetNetworkEdgeSecurityServiceRequest = src.GetNetworkEdgeSecurityServiceRequest

// A request message for NetworkEndpointGroups.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetNetworkEndpointGroupRequest = src.GetNetworkEndpointGroupRequest

// A request message for NetworkFirewallPolicies.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetNetworkFirewallPolicyRequest = src.GetNetworkFirewallPolicyRequest

// A request message for Networks.Get. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetNetworkRequest = src.GetNetworkRequest

// A request message for NodeGroups.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetNodeGroupRequest = src.GetNodeGroupRequest

// A request message for NodeTemplates.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetNodeTemplateRequest = src.GetNodeTemplateRequest

// A request message for NodeTypes.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetNodeTypeRequest = src.GetNodeTypeRequest

// A request message for PacketMirrorings.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetPacketMirroringRequest = src.GetPacketMirroringRequest

// A request message for Projects.Get. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetProjectRequest = src.GetProjectRequest

// A request message for PublicAdvertisedPrefixes.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetPublicAdvertisedPrefixeRequest = src.GetPublicAdvertisedPrefixeRequest

// A request message for PublicDelegatedPrefixes.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetPublicDelegatedPrefixeRequest = src.GetPublicDelegatedPrefixeRequest

// A request message for RegionAutoscalers.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionAutoscalerRequest = src.GetRegionAutoscalerRequest

// A request message for RegionBackendServices.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionBackendServiceRequest = src.GetRegionBackendServiceRequest

// A request message for RegionCommitments.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionCommitmentRequest = src.GetRegionCommitmentRequest

// A request message for RegionDisks.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionDiskRequest = src.GetRegionDiskRequest

// A request message for RegionDiskTypes.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionDiskTypeRequest = src.GetRegionDiskTypeRequest

// A request message for RegionHealthChecks.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionHealthCheckRequest = src.GetRegionHealthCheckRequest

// A request message for RegionHealthCheckServices.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionHealthCheckServiceRequest = src.GetRegionHealthCheckServiceRequest

// A request message for RegionInstanceGroupManagers.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionInstanceGroupManagerRequest = src.GetRegionInstanceGroupManagerRequest

// A request message for RegionInstanceGroups.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionInstanceGroupRequest = src.GetRegionInstanceGroupRequest

// A request message for RegionInstanceTemplates.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionInstanceTemplateRequest = src.GetRegionInstanceTemplateRequest

// A request message for RegionInstantSnapshots.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionInstantSnapshotRequest = src.GetRegionInstantSnapshotRequest

// A request message for RegionNetworkEndpointGroups.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionNetworkEndpointGroupRequest = src.GetRegionNetworkEndpointGroupRequest

// A request message for RegionNetworkFirewallPolicies.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionNetworkFirewallPolicyRequest = src.GetRegionNetworkFirewallPolicyRequest

// A request message for RegionNotificationEndpoints.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionNotificationEndpointRequest = src.GetRegionNotificationEndpointRequest

// A request message for RegionOperations.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionOperationRequest = src.GetRegionOperationRequest

// A request message for Regions.Get. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionRequest = src.GetRegionRequest

// A request message for RegionSecurityPolicies.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionSecurityPolicyRequest = src.GetRegionSecurityPolicyRequest

// A request message for RegionSslCertificates.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionSslCertificateRequest = src.GetRegionSslCertificateRequest

// A request message for RegionSslPolicies.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionSslPolicyRequest = src.GetRegionSslPolicyRequest

// A request message for RegionTargetHttpProxies.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionTargetHttpProxyRequest = src.GetRegionTargetHttpProxyRequest

// A request message for RegionTargetHttpsProxies.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionTargetHttpsProxyRequest = src.GetRegionTargetHttpsProxyRequest

// A request message for RegionTargetTcpProxies.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionTargetTcpProxyRequest = src.GetRegionTargetTcpProxyRequest

// A request message for RegionUrlMaps.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRegionUrlMapRequest = src.GetRegionUrlMapRequest

// A request message for Reservations.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetReservationRequest = src.GetReservationRequest

// A request message for ResourcePolicies.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetResourcePolicyRequest = src.GetResourcePolicyRequest

// A request message for Routes.Get. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRouteRequest = src.GetRouteRequest

// A request message for Routers.Get. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRouterRequest = src.GetRouterRequest

// A request message for Routers.GetRouterStatus. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRouterStatusRouterRequest = src.GetRouterStatusRouterRequest

// A request message for FirewallPolicies.GetRule. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRuleFirewallPolicyRequest = src.GetRuleFirewallPolicyRequest

// A request message for NetworkFirewallPolicies.GetRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRuleNetworkFirewallPolicyRequest = src.GetRuleNetworkFirewallPolicyRequest

// A request message for RegionNetworkFirewallPolicies.GetRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRuleRegionNetworkFirewallPolicyRequest = src.GetRuleRegionNetworkFirewallPolicyRequest

// A request message for RegionSecurityPolicies.GetRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRuleRegionSecurityPolicyRequest = src.GetRuleRegionSecurityPolicyRequest

// A request message for SecurityPolicies.GetRule. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetRuleSecurityPolicyRequest = src.GetRuleSecurityPolicyRequest

// A request message for Instances.GetScreenshot. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetScreenshotInstanceRequest = src.GetScreenshotInstanceRequest

// A request message for SecurityPolicies.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetSecurityPolicyRequest = src.GetSecurityPolicyRequest

// A request message for Instances.GetSerialPortOutput. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetSerialPortOutputInstanceRequest = src.GetSerialPortOutputInstanceRequest

// A request message for ServiceAttachments.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetServiceAttachmentRequest = src.GetServiceAttachmentRequest

// A request message for Instances.GetShieldedInstanceIdentity. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetShieldedInstanceIdentityInstanceRequest = src.GetShieldedInstanceIdentityInstanceRequest

// A request message for Snapshots.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetSnapshotRequest = src.GetSnapshotRequest

// A request message for SnapshotSettingsService.Get. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetSnapshotSettingRequest = src.GetSnapshotSettingRequest

// A request message for SslCertificates.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetSslCertificateRequest = src.GetSslCertificateRequest

// A request message for SslPolicies.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetSslPolicyRequest = src.GetSslPolicyRequest

// A request message for VpnGateways.GetStatus. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetStatusVpnGatewayRequest = src.GetStatusVpnGatewayRequest

// A request message for StoragePools.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetStoragePoolRequest = src.GetStoragePoolRequest

// A request message for StoragePoolTypes.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetStoragePoolTypeRequest = src.GetStoragePoolTypeRequest

// A request message for Subnetworks.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetSubnetworkRequest = src.GetSubnetworkRequest

// A request message for TargetGrpcProxies.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetTargetGrpcProxyRequest = src.GetTargetGrpcProxyRequest

// A request message for TargetHttpProxies.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetTargetHttpProxyRequest = src.GetTargetHttpProxyRequest

// A request message for TargetHttpsProxies.Get. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetTargetHttpsProxyRequest = src.GetTargetHttpsProxyRequest

// A request message for TargetInstances.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetTargetInstanceRequest = src.GetTargetInstanceRequest

// A request message for TargetPools.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetTargetPoolRequest = src.GetTargetPoolRequest

// A request message for TargetSslProxies.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetTargetSslProxyRequest = src.GetTargetSslProxyRequest

// A request message for TargetTcpProxies.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetTargetTcpProxyRequest = src.GetTargetTcpProxyRequest

// A request message for TargetVpnGateways.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetTargetVpnGatewayRequest = src.GetTargetVpnGatewayRequest

// A request message for UrlMaps.Get. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetUrlMapRequest = src.GetUrlMapRequest

// A request message for VpnGateways.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetVpnGatewayRequest = src.GetVpnGatewayRequest

// A request message for VpnTunnels.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetVpnTunnelRequest = src.GetVpnTunnelRequest

// A request message for Projects.GetXpnHost. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetXpnHostProjectRequest = src.GetXpnHostProjectRequest

// A request message for Projects.GetXpnResources. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetXpnResourcesProjectsRequest = src.GetXpnResourcesProjectsRequest

// A request message for ZoneOperations.Get. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetZoneOperationRequest = src.GetZoneOperationRequest

// A request message for Zones.Get. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GetZoneRequest = src.GetZoneRequest
type GlobalAddressesMoveRequest = src.GlobalAddressesMoveRequest
type GlobalNetworkEndpointGroupsAttachEndpointsRequest = src.GlobalNetworkEndpointGroupsAttachEndpointsRequest
type GlobalNetworkEndpointGroupsDetachEndpointsRequest = src.GlobalNetworkEndpointGroupsDetachEndpointsRequest
type GlobalOrganizationSetPolicyRequest = src.GlobalOrganizationSetPolicyRequest
type GlobalSetLabelsRequest = src.GlobalSetLabelsRequest
type GlobalSetPolicyRequest = src.GlobalSetPolicyRequest

// A guest attributes entry.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GuestAttributes = src.GuestAttributes

// A guest attributes namespace/key/value entry.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GuestAttributesEntry = src.GuestAttributesEntry

// Array of guest attribute namespace/key/value tuples.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GuestAttributesValue = src.GuestAttributesValue

// Guest OS features.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GuestOsFeature = src.GuestOsFeature

// The ID of a supported feature. To add multiple values, use commas to
// separate values. Set to one or more of the following values: -
// VIRTIO_SCSI_MULTIQUEUE - WINDOWS - MULTI_IP_SUBNET - UEFI_COMPATIBLE - GVNIC
// - SEV_CAPABLE - SUSPEND_RESUME_COMPATIBLE - SEV_LIVE_MIGRATABLE_V2 -
// SEV_SNP_CAPABLE - TDX_CAPABLE - IDPF For more information, see Enabling
// guest operating system features.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type GuestOsFeature_Type = src.GuestOsFeature_Type
type HTTP2HealthCheck = src.HTTP2HealthCheck

// Specifies how a port is selected for health checking. Can be one of the
// following values: USE_FIXED_PORT: Specifies a port number explicitly using
// the port field in the health check. Supported by backend services for
// passthrough load balancers and backend services for proxy load balancers.
// Not supported by target pools. The health check supports all backends
// supported by the backend service provided the backend can be health checked.
// For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network
// endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported.
// USE_SERVING_PORT: Provides an indirect method of specifying the health check
// port by referring to the backend service. Only supported by backend services
// for proxy load balancers. Not supported by target pools. Not supported by
// backend services for passthrough load balancers. Supports all backends that
// can be health checked; for example, GCE_VM_IP_PORT network endpoint groups
// and instance group backends. For GCE_VM_IP_PORT network endpoint group
// backends, the health check uses the port number specified for each endpoint
// in the network endpoint group. For instance group backends, the health check
// uses the port number determined by looking up the backend service's named
// port in the instance group's list of named ports.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HTTP2HealthCheck_PortSpecification = src.HTTP2HealthCheck_PortSpecification

// Specifies the type of proxy header to append before sending data to the
// backend, either NONE or PROXY_V1. The default is NONE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HTTP2HealthCheck_ProxyHeader = src.HTTP2HealthCheck_ProxyHeader
type HTTPHealthCheck = src.HTTPHealthCheck

// Specifies how a port is selected for health checking. Can be one of the
// following values: USE_FIXED_PORT: Specifies a port number explicitly using
// the port field in the health check. Supported by backend services for
// passthrough load balancers and backend services for proxy load balancers.
// Also supported in legacy HTTP health checks for target pools. The health
// check supports all backends supported by the backend service provided the
// backend can be health checked. For example, GCE_VM_IP network endpoint
// groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends.
// USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method
// of specifying the health check port by referring to the backend service.
// Only supported by backend services for proxy load balancers. Not supported
// by target pools. Not supported by backend services for pass-through load
// balancers. Supports all backends that can be health checked; for example,
// GCE_VM_IP_PORT network endpoint groups and instance group backends. For
// GCE_VM_IP_PORT network endpoint group backends, the health check uses the
// port number specified for each endpoint in the network endpoint group. For
// instance group backends, the health check uses the port number determined by
// looking up the backend service's named port in the instance group's list of
// named ports.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HTTPHealthCheck_PortSpecification = src.HTTPHealthCheck_PortSpecification

// Specifies the type of proxy header to append before sending data to the
// backend, either NONE or PROXY_V1. The default is NONE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HTTPHealthCheck_ProxyHeader = src.HTTPHealthCheck_ProxyHeader
type HTTPSHealthCheck = src.HTTPSHealthCheck

// Specifies how a port is selected for health checking. Can be one of the
// following values: USE_FIXED_PORT: Specifies a port number explicitly using
// the port field in the health check. Supported by backend services for
// passthrough load balancers and backend services for proxy load balancers.
// Not supported by target pools. The health check supports all backends
// supported by the backend service provided the backend can be health checked.
// For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network
// endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported.
// USE_SERVING_PORT: Provides an indirect method of specifying the health check
// port by referring to the backend service. Only supported by backend services
// for proxy load balancers. Not supported by target pools. Not supported by
// backend services for passthrough load balancers. Supports all backends that
// can be health checked; for example, GCE_VM_IP_PORT network endpoint groups
// and instance group backends. For GCE_VM_IP_PORT network endpoint group
// backends, the health check uses the port number specified for each endpoint
// in the network endpoint group. For instance group backends, the health check
// uses the port number determined by looking up the backend service's named
// port in the instance group's list of named ports.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HTTPSHealthCheck_PortSpecification = src.HTTPSHealthCheck_PortSpecification

// Specifies the type of proxy header to append before sending data to the
// backend, either NONE or PROXY_V1. The default is NONE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HTTPSHealthCheck_ProxyHeader = src.HTTPSHealthCheck_ProxyHeader

// Represents a health check resource. Google Compute Engine has two health
// check resources: *
// [Regional](/compute/docs/reference/rest/v1/regionHealthChecks) *
// [Global](/compute/docs/reference/rest/v1/healthChecks) These health check
// resources can be used for load balancing and for autohealing VMs in a
// managed instance group (MIG). **Load balancing** Health check requirements
// vary depending on the type of load balancer. For details about the type of
// health check supported for each load balancer and corresponding backend
// type, see Health checks overview: Load balancer guide. **Autohealing in
// MIGs** The health checks that you use for autohealing VMs in a MIG can be
// either regional or global. For more information, see Set up an application
// health check and autohealing. For more information, see Health checks
// overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthCheck = src.HealthCheck

// Contains a list of HealthCheck resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthCheckList = src.HealthCheckList

// Configuration of logging on a health check. If logging is enabled, logs
// will be exported to Stackdriver.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthCheckLogConfig = src.HealthCheckLogConfig

// A full or valid partial URL to a health check. For example, the following
// are valid URLs: -
// https://www.googleapis.com/compute/beta/projects/project-id/global/httpHealthChecks/health-check
// - projects/project-id/global/httpHealthChecks/health-check -
// global/httpHealthChecks/health-check
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthCheckReference = src.HealthCheckReference

// Represents a Health-Check as a Service resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthCheckService = src.HealthCheckService

// A full or valid partial URL to a health check service. For example, the
// following are valid URLs: -
// https://www.googleapis.com/compute/beta/projects/project-id/regions/us-west1/healthCheckServices/health-check-service
// -
// projects/project-id/regions/us-west1/healthCheckServices/health-check-service
// - regions/us-west1/healthCheckServices/health-check-service
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthCheckServiceReference = src.HealthCheckServiceReference

// Optional. Policy for how the results from multiple health checks for the
// same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified. -
// NO_AGGREGATION. An EndpointHealth message is returned for each pair in the
// health check service. - AND. If any health check of an endpoint reports
// UNHEALTHY, then UNHEALTHY is the HealthState of the endpoint. If all health
// checks report HEALTHY, the HealthState of the endpoint is HEALTHY. . This is
// only allowed with regional HealthCheckService.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthCheckService_HealthStatusAggregationPolicy = src.HealthCheckService_HealthStatusAggregationPolicy
type HealthCheckServicesList = src.HealthCheckServicesList

// Specifies the type of the healthCheck, either TCP, SSL, HTTP, HTTPS, HTTP2
// or GRPC. Exactly one of the protocol-specific health check fields must be
// specified, which must match type field.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthCheck_Type = src.HealthCheck_Type
type HealthChecksAggregatedList = src.HealthChecksAggregatedList
type HealthChecksScopedList = src.HealthChecksScopedList
type HealthStatus = src.HealthStatus
type HealthStatusForNetworkEndpoint = src.HealthStatusForNetworkEndpoint

// Health state of the network endpoint determined based on the health checks
// configured. Additional supported values which may be not listed in the enum
// directly due to technical reasons: DRAINING HEALTHY UNHEALTHY UNKNOWN
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthStatusForNetworkEndpoint_HealthState = src.HealthStatusForNetworkEndpoint_HealthState

// Health state of the ipv6 network endpoint determined based on the health
// checks configured. Additional supported values which may be not listed in
// the enum directly due to technical reasons: DRAINING HEALTHY UNHEALTHY
// UNKNOWN
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthStatusForNetworkEndpoint_Ipv6HealthState = src.HealthStatusForNetworkEndpoint_Ipv6HealthState

// Health state of the IPv4 address of the instance. Additional supported
// values which may be not listed in the enum directly due to technical
// reasons: HEALTHY UNHEALTHY
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthStatus_HealthState = src.HealthStatus_HealthState

// Health state of the IPv6 address of the instance. Additional supported
// values which may be not listed in the enum directly due to technical
// reasons: HEALTHY UNHEALTHY
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HealthStatus_Ipv6HealthState = src.HealthStatus_Ipv6HealthState
type HealthStatus_WeightError = src.HealthStatus_WeightError

// Provides links to documentation or for performing an out of band action.
// For example, if a quota check failed with an error indicating the calling
// project hasn't enabled the accessed service, this can contain a URL pointing
// directly to the right place in the developer console to flip the bit.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Help = src.Help

// Describes a URL link.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HelpLink = src.HelpLink

// UrlMaps A host-matching rule for a URL. If matched, will use the named
// PathMatcher to select the BackendService.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HostRule = src.HostRule

// Specification for how requests are aborted as part of fault injection.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpFaultAbort = src.HttpFaultAbort

// Specifies the delay introduced by the load balancer before forwarding the
// request to the backend service as part of fault injection.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpFaultDelay = src.HttpFaultDelay

// The specification for fault injection introduced into traffic to test the
// resiliency of clients to backend service failure. As part of fault
// injection, when clients send requests to a backend service, delays can be
// introduced by the load balancer on a percentage of requests before sending
// those request to the backend service. Similarly requests from clients can be
// aborted by the load balancer for a percentage of requests.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpFaultInjection = src.HttpFaultInjection

// The request and response header transformations that take effect before the
// request is passed along to the selected backendService.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpHeaderAction = src.HttpHeaderAction

// matchRule criteria for request header matches.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpHeaderMatch = src.HttpHeaderMatch

// Specification determining how headers are added to requests or responses.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpHeaderOption = src.HttpHeaderOption

// HttpRouteRuleMatch criteria for a request's query parameter.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpQueryParameterMatch = src.HttpQueryParameterMatch

// Specifies settings for an HTTP redirect.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpRedirectAction = src.HttpRedirectAction

// The HTTP Status code to use for this RedirectAction. Supported values are:
// - MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds to
// 301. - FOUND, which corresponds to 302. - SEE_OTHER which corresponds to
// 303. - TEMPORARY_REDIRECT, which corresponds to 307. In this case, the
// request method is retained. - PERMANENT_REDIRECT, which corresponds to 308.
// In this case, the request method is retained.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpRedirectAction_RedirectResponseCode = src.HttpRedirectAction_RedirectResponseCode

// The retry policy associates with HttpRouteRule
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpRetryPolicy = src.HttpRetryPolicy
type HttpRouteAction = src.HttpRouteAction

// The HttpRouteRule setting specifies how to match an HTTP request and the
// corresponding routing action that load balancing proxies perform.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpRouteRule = src.HttpRouteRule

// HttpRouteRuleMatch specifies a set of criteria for matching requests to an
// HttpRouteRule. All specified criteria must be satisfied for a match to
// occur.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type HttpRouteRuleMatch = src.HttpRouteRuleMatch

// Represents an Image resource. You can use images to create boot disks for
// your VM instances. For more information, read Images.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Image = src.Image
type ImageFamilyView = src.ImageFamilyView

// Contains a list of images.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ImageList = src.ImageList

// The architecture of the image. Valid values are ARM64 or X86_64.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Image_Architecture = src.Image_Architecture

// The type of the image used to create this disk. The default and only valid
// value is RAW.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Image_SourceType = src.Image_SourceType

// [Output Only] The status of the image. An image can be used to create other
// resources, such as instances, only after the image has been successfully
// created and the status is set to READY. Possible values are FAILED, PENDING,
// or READY.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Image_Status = src.Image_Status

// Initial State for shielded instance, these are public keys which are safe
// to store in public
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InitialStateConfig = src.InitialStateConfig

// A request message for Addresses.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertAddressRequest = src.InsertAddressRequest

// A request message for Autoscalers.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertAutoscalerRequest = src.InsertAutoscalerRequest

// A request message for BackendBuckets.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertBackendBucketRequest = src.InsertBackendBucketRequest

// A request message for BackendServices.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertBackendServiceRequest = src.InsertBackendServiceRequest

// A request message for Disks.Insert. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertDiskRequest = src.InsertDiskRequest

// A request message for ExternalVpnGateways.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertExternalVpnGatewayRequest = src.InsertExternalVpnGatewayRequest

// A request message for FirewallPolicies.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertFirewallPolicyRequest = src.InsertFirewallPolicyRequest

// A request message for Firewalls.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertFirewallRequest = src.InsertFirewallRequest

// A request message for ForwardingRules.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertForwardingRuleRequest = src.InsertForwardingRuleRequest

// A request message for GlobalAddresses.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertGlobalAddressRequest = src.InsertGlobalAddressRequest

// A request message for GlobalForwardingRules.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertGlobalForwardingRuleRequest = src.InsertGlobalForwardingRuleRequest

// A request message for GlobalNetworkEndpointGroups.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertGlobalNetworkEndpointGroupRequest = src.InsertGlobalNetworkEndpointGroupRequest

// A request message for GlobalPublicDelegatedPrefixes.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertGlobalPublicDelegatedPrefixeRequest = src.InsertGlobalPublicDelegatedPrefixeRequest

// A request message for HealthChecks.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertHealthCheckRequest = src.InsertHealthCheckRequest

// A request message for Images.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertImageRequest = src.InsertImageRequest

// A request message for InstanceGroupManagers.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertInstanceGroupManagerRequest = src.InsertInstanceGroupManagerRequest

// A request message for InstanceGroupManagerResizeRequests.Insert. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertInstanceGroupManagerResizeRequestRequest = src.InsertInstanceGroupManagerResizeRequestRequest

// A request message for InstanceGroups.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertInstanceGroupRequest = src.InsertInstanceGroupRequest

// A request message for Instances.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertInstanceRequest = src.InsertInstanceRequest

// A request message for InstanceTemplates.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertInstanceTemplateRequest = src.InsertInstanceTemplateRequest

// A request message for InstantSnapshots.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertInstantSnapshotRequest = src.InsertInstantSnapshotRequest

// A request message for InterconnectAttachments.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertInterconnectAttachmentRequest = src.InsertInterconnectAttachmentRequest

// A request message for Interconnects.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertInterconnectRequest = src.InsertInterconnectRequest

// A request message for Licenses.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertLicenseRequest = src.InsertLicenseRequest

// A request message for MachineImages.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertMachineImageRequest = src.InsertMachineImageRequest

// A request message for NetworkAttachments.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertNetworkAttachmentRequest = src.InsertNetworkAttachmentRequest

// A request message for NetworkEdgeSecurityServices.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertNetworkEdgeSecurityServiceRequest = src.InsertNetworkEdgeSecurityServiceRequest

// A request message for NetworkEndpointGroups.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertNetworkEndpointGroupRequest = src.InsertNetworkEndpointGroupRequest

// A request message for NetworkFirewallPolicies.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertNetworkFirewallPolicyRequest = src.InsertNetworkFirewallPolicyRequest

// A request message for Networks.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertNetworkRequest = src.InsertNetworkRequest

// A request message for NodeGroups.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertNodeGroupRequest = src.InsertNodeGroupRequest

// A request message for NodeTemplates.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertNodeTemplateRequest = src.InsertNodeTemplateRequest

// A request message for PacketMirrorings.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertPacketMirroringRequest = src.InsertPacketMirroringRequest

// A request message for PublicAdvertisedPrefixes.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertPublicAdvertisedPrefixeRequest = src.InsertPublicAdvertisedPrefixeRequest

// A request message for PublicDelegatedPrefixes.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertPublicDelegatedPrefixeRequest = src.InsertPublicDelegatedPrefixeRequest

// A request message for RegionAutoscalers.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionAutoscalerRequest = src.InsertRegionAutoscalerRequest

// A request message for RegionBackendServices.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionBackendServiceRequest = src.InsertRegionBackendServiceRequest

// A request message for RegionCommitments.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionCommitmentRequest = src.InsertRegionCommitmentRequest

// A request message for RegionDisks.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionDiskRequest = src.InsertRegionDiskRequest

// A request message for RegionHealthChecks.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionHealthCheckRequest = src.InsertRegionHealthCheckRequest

// A request message for RegionHealthCheckServices.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionHealthCheckServiceRequest = src.InsertRegionHealthCheckServiceRequest

// A request message for RegionInstanceGroupManagers.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionInstanceGroupManagerRequest = src.InsertRegionInstanceGroupManagerRequest

// A request message for RegionInstanceTemplates.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionInstanceTemplateRequest = src.InsertRegionInstanceTemplateRequest

// A request message for RegionInstantSnapshots.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionInstantSnapshotRequest = src.InsertRegionInstantSnapshotRequest

// A request message for RegionNetworkEndpointGroups.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionNetworkEndpointGroupRequest = src.InsertRegionNetworkEndpointGroupRequest

// A request message for RegionNetworkFirewallPolicies.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionNetworkFirewallPolicyRequest = src.InsertRegionNetworkFirewallPolicyRequest

// A request message for RegionNotificationEndpoints.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionNotificationEndpointRequest = src.InsertRegionNotificationEndpointRequest

// A request message for RegionSecurityPolicies.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionSecurityPolicyRequest = src.InsertRegionSecurityPolicyRequest

// A request message for RegionSslCertificates.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionSslCertificateRequest = src.InsertRegionSslCertificateRequest

// A request message for RegionSslPolicies.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionSslPolicyRequest = src.InsertRegionSslPolicyRequest

// A request message for RegionTargetHttpProxies.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionTargetHttpProxyRequest = src.InsertRegionTargetHttpProxyRequest

// A request message for RegionTargetHttpsProxies.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionTargetHttpsProxyRequest = src.InsertRegionTargetHttpsProxyRequest

// A request message for RegionTargetTcpProxies.Insert. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionTargetTcpProxyRequest = src.InsertRegionTargetTcpProxyRequest

// A request message for RegionUrlMaps.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRegionUrlMapRequest = src.InsertRegionUrlMapRequest

// A request message for Reservations.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertReservationRequest = src.InsertReservationRequest

// A request message for ResourcePolicies.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertResourcePolicyRequest = src.InsertResourcePolicyRequest

// A request message for Routes.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRouteRequest = src.InsertRouteRequest

// A request message for Routers.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertRouterRequest = src.InsertRouterRequest

// A request message for SecurityPolicies.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertSecurityPolicyRequest = src.InsertSecurityPolicyRequest

// A request message for ServiceAttachments.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertServiceAttachmentRequest = src.InsertServiceAttachmentRequest

// A request message for Snapshots.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertSnapshotRequest = src.InsertSnapshotRequest

// A request message for SslCertificates.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertSslCertificateRequest = src.InsertSslCertificateRequest

// A request message for SslPolicies.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertSslPolicyRequest = src.InsertSslPolicyRequest

// A request message for StoragePools.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertStoragePoolRequest = src.InsertStoragePoolRequest

// A request message for Subnetworks.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertSubnetworkRequest = src.InsertSubnetworkRequest

// A request message for TargetGrpcProxies.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertTargetGrpcProxyRequest = src.InsertTargetGrpcProxyRequest

// A request message for TargetHttpProxies.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertTargetHttpProxyRequest = src.InsertTargetHttpProxyRequest

// A request message for TargetHttpsProxies.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertTargetHttpsProxyRequest = src.InsertTargetHttpsProxyRequest

// A request message for TargetInstances.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertTargetInstanceRequest = src.InsertTargetInstanceRequest

// A request message for TargetPools.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertTargetPoolRequest = src.InsertTargetPoolRequest

// A request message for TargetSslProxies.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertTargetSslProxyRequest = src.InsertTargetSslProxyRequest

// A request message for TargetTcpProxies.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertTargetTcpProxyRequest = src.InsertTargetTcpProxyRequest

// A request message for TargetVpnGateways.Insert. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertTargetVpnGatewayRequest = src.InsertTargetVpnGatewayRequest

// A request message for UrlMaps.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertUrlMapRequest = src.InsertUrlMapRequest

// A request message for VpnGateways.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertVpnGatewayRequest = src.InsertVpnGatewayRequest

// A request message for VpnTunnels.Insert. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InsertVpnTunnelRequest = src.InsertVpnTunnelRequest

// Represents an Instance resource. An instance is a virtual machine that is
// hosted on Google Cloud Platform. For more information, read Virtual Machine
// Instances.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Instance = src.Instance
type InstanceAggregatedList = src.InstanceAggregatedList
type InstanceConsumptionData = src.InstanceConsumptionData
type InstanceConsumptionInfo = src.InstanceConsumptionInfo

// Represents an Instance Group resource. Instance Groups can be used to
// configure a target for load balancing. Instance groups can either be managed
// or unmanaged. To create managed instance groups, use the
// instanceGroupManager or regionInstanceGroupManager resource instead. Use
// zonal unmanaged instance groups if you need to apply load balancing to
// groups of heterogeneous instances or if you need to manage the instances
// yourself. You cannot create regional unmanaged instance groups. For more
// information, read Instance groups.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroup = src.InstanceGroup
type InstanceGroupAggregatedList = src.InstanceGroupAggregatedList

// A list of InstanceGroup resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupList = src.InstanceGroupList

// Represents a Managed Instance Group resource. An instance group is a
// collection of VM instances that you can manage as a single entity. For more
// information, read Instance groups. For zonal Managed Instance Group, use the
// instanceGroupManagers resource. For regional Managed Instance Group, use the
// regionInstanceGroupManagers resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManager = src.InstanceGroupManager
type InstanceGroupManagerActionsSummary = src.InstanceGroupManagerActionsSummary
type InstanceGroupManagerAggregatedList = src.InstanceGroupManagerAggregatedList
type InstanceGroupManagerAllInstancesConfig = src.InstanceGroupManagerAllInstancesConfig
type InstanceGroupManagerAutoHealingPolicy = src.InstanceGroupManagerAutoHealingPolicy
type InstanceGroupManagerInstanceFlexibilityPolicy = src.InstanceGroupManagerInstanceFlexibilityPolicy
type InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection = src.InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
type InstanceGroupManagerInstanceLifecyclePolicy = src.InstanceGroupManagerInstanceLifecyclePolicy

// The action that a MIG performs on a failed or an unhealthy VM. A VM is
// marked as unhealthy when the application running on that VM fails a health
// check. Valid values are - REPAIR (default): MIG automatically repairs a
// failed or an unhealthy VM by recreating it. For more information, see About
// repairing VMs in a MIG. - DO_NOTHING: MIG does not repair a failed or an
// unhealthy VM.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure = src.InstanceGroupManagerInstanceLifecyclePolicy_DefaultActionOnFailure

// A bit indicating whether to forcefully apply the group's latest
// configuration when repairing a VM. Valid options are: - NO (default): If
// configuration updates are available, they are not forcefully applied during
// repair. Instead, configuration updates are applied according to the group's
// update policy. - YES: If configuration updates are available, they are
// applied during repair.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerInstanceLifecyclePolicy_ForceUpdateOnRepair = src.InstanceGroupManagerInstanceLifecyclePolicy_ForceUpdateOnRepair

// [Output Only] A list of managed instance groups.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerList = src.InstanceGroupManagerList

// InstanceGroupManagerResizeRequest represents a request to create a number
// of VMs: either immediately or by queuing the request for the specified time.
// This resize request is nested under InstanceGroupManager and the VMs created
// by this request are added to the owning InstanceGroupManager.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerResizeRequest = src.InstanceGroupManagerResizeRequest
type InstanceGroupManagerResizeRequestStatus = src.InstanceGroupManagerResizeRequestStatus
type InstanceGroupManagerResizeRequestStatusLastAttempt = src.InstanceGroupManagerResizeRequestStatusLastAttempt

// [Output only] Current state of the request.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerResizeRequest_State = src.InstanceGroupManagerResizeRequest_State

// [Output Only] A list of resize requests.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerResizeRequestsListResponse = src.InstanceGroupManagerResizeRequestsListResponse
type InstanceGroupManagerStatus = src.InstanceGroupManagerStatus
type InstanceGroupManagerStatusAllInstancesConfig = src.InstanceGroupManagerStatusAllInstancesConfig
type InstanceGroupManagerStatusStateful = src.InstanceGroupManagerStatusStateful
type InstanceGroupManagerStatusStatefulPerInstanceConfigs = src.InstanceGroupManagerStatusStatefulPerInstanceConfigs
type InstanceGroupManagerStatusVersionTarget = src.InstanceGroupManagerStatusVersionTarget
type InstanceGroupManagerUpdatePolicy = src.InstanceGroupManagerUpdatePolicy

// The instance redistribution policy for regional managed instance groups.
// Valid values are: - PROACTIVE (default): The group attempts to maintain an
// even distribution of VM instances across zones in the region. - NONE: For
// non-autoscaled groups, proactive redistribution is disabled. Additional
// supported values which may be not listed in the enum directly due to
// technical reasons: NONE PROACTIVE
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerUpdatePolicy_InstanceRedistributionType = src.InstanceGroupManagerUpdatePolicy_InstanceRedistributionType

// Minimal action to be taken on an instance. Use this option to minimize
// disruption as much as possible or to apply a more disruptive action than is
// necessary. - To limit disruption as much as possible, set the minimal action
// to REFRESH. If your update requires a more disruptive action, Compute Engine
// performs the necessary action to execute the update. - To apply a more
// disruptive action than is strictly necessary, set the minimal action to
// RESTART or REPLACE. For example, Compute Engine does not need to restart a
// VM to change its metadata. But if your application reads instance metadata
// only when a VM is restarted, you can set the minimal action to RESTART in
// order to pick up metadata changes. Additional supported values which may be
// not listed in the enum directly due to technical reasons: NONE REFRESH
// REPLACE RESTART
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerUpdatePolicy_MinimalAction = src.InstanceGroupManagerUpdatePolicy_MinimalAction

// Most disruptive action that is allowed to be taken on an instance. You can
// specify either NONE to forbid any actions, REFRESH to avoid restarting the
// VM and to limit disruption as much as possible. RESTART to allow actions
// that can be applied without instance replacing or REPLACE to allow all
// possible actions. If the Updater determines that the minimal update action
// needed is more disruptive than most disruptive allowed action you specify it
// will not perform the update at all. Additional supported values which may be
// not listed in the enum directly due to technical reasons: NONE REFRESH
// REPLACE RESTART
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerUpdatePolicy_MostDisruptiveAllowedAction = src.InstanceGroupManagerUpdatePolicy_MostDisruptiveAllowedAction

// What action should be used to replace instances. See minimal_action.REPLACE
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerUpdatePolicy_ReplacementMethod = src.InstanceGroupManagerUpdatePolicy_ReplacementMethod

// The type of update process. You can specify either PROACTIVE so that the
// MIG automatically updates VMs to the latest configurations or OPPORTUNISTIC
// so that you can select the VMs that you want to update. Additional supported
// values which may be not listed in the enum directly due to technical
// reasons: PROACTIVE
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagerUpdatePolicy_Type = src.InstanceGroupManagerUpdatePolicy_Type
type InstanceGroupManagerVersion = src.InstanceGroupManagerVersion

// Pagination behavior of the listManagedInstances API method for this managed
// instance group.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManager_ListManagedInstancesResults = src.InstanceGroupManager_ListManagedInstancesResults
type InstanceGroupManagersAbandonInstancesRequest = src.InstanceGroupManagersAbandonInstancesRequest

// InstanceGroupManagers.applyUpdatesToInstances
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagersApplyUpdatesRequest = src.InstanceGroupManagersApplyUpdatesRequest

// The minimal action that you want to perform on each instance during the
// update: - REPLACE: At minimum, delete the instance and create it again. -
// RESTART: Stop the instance and start it again. - REFRESH: Do not stop the
// instance and limit disruption as much as possible. - NONE: Do not disrupt
// the instance at all. By default, the minimum action is NONE. If your update
// requires a more disruptive action than you set with this flag, the necessary
// action is performed to execute the update. Additional supported values which
// may be not listed in the enum directly due to technical reasons: NONE
// REFRESH REPLACE RESTART
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagersApplyUpdatesRequest_MinimalAction = src.InstanceGroupManagersApplyUpdatesRequest_MinimalAction

// The most disruptive action that you want to perform on each instance during
// the update: - REPLACE: Delete the instance and create it again. - RESTART:
// Stop the instance and start it again. - REFRESH: Do not stop the instance
// and limit disruption as much as possible. - NONE: Do not disrupt the
// instance at all. By default, the most disruptive allowed action is REPLACE.
// If your update requires a more disruptive action than you set with this
// flag, the update request will fail. Additional supported values which may be
// not listed in the enum directly due to technical reasons: NONE REFRESH
// REPLACE RESTART
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction = src.InstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction

// InstanceGroupManagers.createInstances
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagersCreateInstancesRequest = src.InstanceGroupManagersCreateInstancesRequest
type InstanceGroupManagersDeleteInstancesRequest = src.InstanceGroupManagersDeleteInstancesRequest

// InstanceGroupManagers.deletePerInstanceConfigs
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagersDeletePerInstanceConfigsReq = src.InstanceGroupManagersDeletePerInstanceConfigsReq
type InstanceGroupManagersListErrorsResponse = src.InstanceGroupManagersListErrorsResponse
type InstanceGroupManagersListManagedInstancesResponse = src.InstanceGroupManagersListManagedInstancesResponse
type InstanceGroupManagersListPerInstanceConfigsResp = src.InstanceGroupManagersListPerInstanceConfigsResp

// InstanceGroupManagers.patchPerInstanceConfigs
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagersPatchPerInstanceConfigsReq = src.InstanceGroupManagersPatchPerInstanceConfigsReq
type InstanceGroupManagersRecreateInstancesRequest = src.InstanceGroupManagersRecreateInstancesRequest
type InstanceGroupManagersScopedList = src.InstanceGroupManagersScopedList
type InstanceGroupManagersSetInstanceTemplateRequest = src.InstanceGroupManagersSetInstanceTemplateRequest
type InstanceGroupManagersSetTargetPoolsRequest = src.InstanceGroupManagersSetTargetPoolsRequest

// InstanceGroupManagers.updatePerInstanceConfigs
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupManagersUpdatePerInstanceConfigsReq = src.InstanceGroupManagersUpdatePerInstanceConfigsReq
type InstanceGroupsAddInstancesRequest = src.InstanceGroupsAddInstancesRequest
type InstanceGroupsListInstances = src.InstanceGroupsListInstances
type InstanceGroupsListInstancesRequest = src.InstanceGroupsListInstancesRequest

// A filter for the state of the instances in the instance group. Valid
// options are ALL or RUNNING. If you do not specify this parameter the list
// includes all instances regardless of their state.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceGroupsListInstancesRequest_InstanceState = src.InstanceGroupsListInstancesRequest_InstanceState
type InstanceGroupsRemoveInstancesRequest = src.InstanceGroupsRemoveInstancesRequest
type InstanceGroupsScopedList = src.InstanceGroupsScopedList
type InstanceGroupsSetNamedPortsRequest = src.InstanceGroupsSetNamedPortsRequest

// Contains a list of instances.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceList = src.InstanceList

// Contains a list of instance referrers.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceListReferrers = src.InstanceListReferrers
type InstanceManagedByIgmError = src.InstanceManagedByIgmError
type InstanceManagedByIgmErrorInstanceActionDetails = src.InstanceManagedByIgmErrorInstanceActionDetails

// [Output Only] Action that managed instance group was executing on the
// instance when the error occurred. Possible values:
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceManagedByIgmErrorInstanceActionDetails_Action = src.InstanceManagedByIgmErrorInstanceActionDetails_Action
type InstanceManagedByIgmErrorManagedInstanceError = src.InstanceManagedByIgmErrorManagedInstanceError
type InstanceMoveRequest = src.InstanceMoveRequest

// Additional instance params.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceParams = src.InstanceParams
type InstanceProperties = src.InstanceProperties

// Represents the change that you want to make to the instance properties.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstancePropertiesPatch = src.InstancePropertiesPatch

// KeyRevocationActionType of the instance. Supported options are "STOP" and
// "NONE". The default value is "NONE" if it is not specified.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceProperties_KeyRevocationActionType = src.InstanceProperties_KeyRevocationActionType

// The private IPv6 google access type for VMs. If not specified, use
// INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not
// supported yet.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceProperties_PrivateIpv6GoogleAccess = src.InstanceProperties_PrivateIpv6GoogleAccess
type InstanceReference = src.InstanceReference

// Represents a Instance Settings resource. You can use instance settings to
// configure default settings for Compute Engine VM instances. For example, you
// can use it to configure default machine type of Compute Engine VM instances.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceSettings = src.InstanceSettings
type InstanceSettingsMetadata = src.InstanceSettingsMetadata

// Represents an Instance Template resource. Google Compute Engine has two
// Instance Template resources: *
// [Global](/compute/docs/reference/rest/v1/instanceTemplates) *
// [Regional](/compute/docs/reference/rest/v1/regionInstanceTemplates) You can
// reuse a global instance template in different regions whereas you can use a
// regional instance template in a specified region only. If you want to reduce
// cross-region dependency or achieve data residency, use a regional instance
// template. To create VMs, managed instance groups, and reservations, you can
// use either global or regional instance templates. For more information, read
// Instance Templates.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceTemplate = src.InstanceTemplate

// Contains a list of InstanceTemplatesScopedList.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceTemplateAggregatedList = src.InstanceTemplateAggregatedList

// A list of instance templates.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceTemplateList = src.InstanceTemplateList
type InstanceTemplatesScopedList = src.InstanceTemplatesScopedList
type InstanceWithNamedPorts = src.InstanceWithNamedPorts

// [Output Only] The status of the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstanceWithNamedPorts_Status = src.InstanceWithNamedPorts_Status

// KeyRevocationActionType of the instance. Supported options are "STOP" and
// "NONE". The default value is "NONE" if it is not specified.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Instance_KeyRevocationActionType = src.Instance_KeyRevocationActionType

// The private IPv6 google access type for the VM. If not specified, use
// INHERIT_FROM_SUBNETWORK as default.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Instance_PrivateIpv6GoogleAccess = src.Instance_PrivateIpv6GoogleAccess

// [Output Only] The status of the instance. One of the following values:
// PROVISIONING, STAGING, RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING,
// and TERMINATED. For more information about the status of the instance, see
// Instance life cycle.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Instance_Status = src.Instance_Status
type InstancesAddResourcePoliciesRequest = src.InstancesAddResourcePoliciesRequest
type InstancesBulkInsertOperationMetadata = src.InstancesBulkInsertOperationMetadata
type InstancesGetEffectiveFirewallsResponse = src.InstancesGetEffectiveFirewallsResponse
type InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

// [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
// NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type = src.InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type
type InstancesRemoveResourcePoliciesRequest = src.InstancesRemoveResourcePoliciesRequest
type InstancesScopedList = src.InstancesScopedList
type InstancesSetLabelsRequest = src.InstancesSetLabelsRequest
type InstancesSetMachineResourcesRequest = src.InstancesSetMachineResourcesRequest
type InstancesSetMachineTypeRequest = src.InstancesSetMachineTypeRequest
type InstancesSetMinCpuPlatformRequest = src.InstancesSetMinCpuPlatformRequest
type InstancesSetNameRequest = src.InstancesSetNameRequest
type InstancesSetSecurityPolicyRequest = src.InstancesSetSecurityPolicyRequest
type InstancesSetServiceAccountRequest = src.InstancesSetServiceAccountRequest
type InstancesStartWithEncryptionKeyRequest = src.InstancesStartWithEncryptionKeyRequest

// Represents a InstantSnapshot resource. You can use instant snapshots to
// create disk rollback points quickly..
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstantSnapshot = src.InstantSnapshot
type InstantSnapshotAggregatedList = src.InstantSnapshotAggregatedList

// Contains a list of InstantSnapshot resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstantSnapshotList = src.InstantSnapshotList
type InstantSnapshotResourceStatus = src.InstantSnapshotResourceStatus

// [Output Only] The architecture of the instant snapshot. Valid values are
// ARM64 or X86_64.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstantSnapshot_Architecture = src.InstantSnapshot_Architecture

// [Output Only] The status of the instantSnapshot. This can be CREATING,
// DELETING, FAILED, or READY.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InstantSnapshot_Status = src.InstantSnapshot_Status
type InstantSnapshotsScopedList = src.InstantSnapshotsScopedList

// HttpRouteRuleMatch criteria for field values that must stay within the
// specified integer range.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Int64RangeMatch = src.Int64RangeMatch

// Represents an Interconnect resource. An Interconnect resource is a
// dedicated connection between the Google Cloud network and your on-premises
// network. For more information, read the Dedicated Interconnect Overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Interconnect = src.Interconnect

// Represents an Interconnect Attachment (VLAN) resource. You can use
// Interconnect attachments (VLANS) to connect your Virtual Private Cloud
// networks to your on-premises networks through an Interconnect. For more
// information, read Creating VLAN Attachments.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachment = src.InterconnectAttachment
type InterconnectAttachmentAggregatedList = src.InterconnectAttachmentAggregatedList
type InterconnectAttachmentConfigurationConstraints = src.InterconnectAttachmentConfigurationConstraints
type InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange = src.InterconnectAttachmentConfigurationConstraintsBgpPeerASNRange

// [Output Only] Whether the attachment's BGP session
// requires/allows/disallows BGP MD5 authentication. This can take one of the
// following values: MD5_OPTIONAL, MD5_REQUIRED, MD5_UNSUPPORTED. For example,
// a Cross-Cloud Interconnect connection to a remote cloud provider that
// requires BGP MD5 authentication has the interconnectRemoteLocation
// attachment_configuration_constraints.bgp_md5 field set to MD5_REQUIRED, and
// that property is propagated to the attachment. Similarly, if BGP MD5 is
// MD5_UNSUPPORTED, an error is returned if MD5 is requested.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachmentConfigurationConstraints_BgpMd5 = src.InterconnectAttachmentConfigurationConstraints_BgpMd5

// Response to the list request, and contains a list of interconnect
// attachments.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachmentList = src.InterconnectAttachmentList

// Informational metadata about Partner attachments from Partners to display
// to customers. These fields are propagated from PARTNER_PROVIDER attachments
// to their corresponding PARTNER attachments.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachmentPartnerMetadata = src.InterconnectAttachmentPartnerMetadata

// Information for an interconnect attachment when this belongs to an
// interconnect of type DEDICATED.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachmentPrivateInfo = src.InterconnectAttachmentPrivateInfo

// Provisioned bandwidth capacity for the interconnect attachment. For
// attachments of type DEDICATED, the user can set the bandwidth. For
// attachments of type PARTNER, the Google Partner that is operating the
// interconnect must set the bandwidth. Output only for PARTNER type, mutable
// for PARTNER_PROVIDER and DEDICATED, and can take one of the following
// values: - BPS_50M: 50 Mbit/s - BPS_100M: 100 Mbit/s - BPS_200M: 200 Mbit/s -
// BPS_300M: 300 Mbit/s - BPS_400M: 400 Mbit/s - BPS_500M: 500 Mbit/s - BPS_1G:
// 1 Gbit/s - BPS_2G: 2 Gbit/s - BPS_5G: 5 Gbit/s - BPS_10G: 10 Gbit/s -
// BPS_20G: 20 Gbit/s - BPS_50G: 50 Gbit/s
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachment_Bandwidth = src.InterconnectAttachment_Bandwidth

// Desired availability domain for the attachment. Only available for type
// PARTNER, at creation time, and can take one of the following values: -
// AVAILABILITY_DOMAIN_ANY - AVAILABILITY_DOMAIN_1 - AVAILABILITY_DOMAIN_2 For
// improved reliability, customers should configure a pair of attachments, one
// per availability domain. The selected availability domain will be provided
// to the Partner via the pairing key, so that the provisioned circuit will lie
// in the specified domain. If not specified, the value will default to
// AVAILABILITY_DOMAIN_ANY.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachment_EdgeAvailabilityDomain = src.InterconnectAttachment_EdgeAvailabilityDomain

// Indicates the user-supplied encryption option of this VLAN attachment
// (interconnectAttachment). Can only be specified at attachment creation for
// PARTNER or DEDICATED attachments. Possible values are: - NONE - This is the
// default value, which means that the VLAN attachment carries unencrypted
// traffic. VMs are able to send traffic to, or receive traffic from, such a
// VLAN attachment. - IPSEC - The VLAN attachment carries only encrypted
// traffic that is encrypted by an IPsec device, such as an HA VPN gateway or
// third-party IPsec VPN. VMs cannot directly send traffic to, or receive
// traffic from, such a VLAN attachment. To use *HA VPN over Cloud
// Interconnect*, the VLAN attachment must be created with this option.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachment_Encryption = src.InterconnectAttachment_Encryption

// [Output Only] The current status of whether or not this interconnect
// attachment is functional, which can take one of the following values: -
// OS_ACTIVE: The attachment has been turned up and is ready to use. -
// OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup is
// not complete.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachment_OperationalStatus = src.InterconnectAttachment_OperationalStatus

// The stack type for this interconnect attachment to identify whether the
// IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used.
// This field can be both set at interconnect attachments creation and update
// interconnect attachment operations.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachment_StackType = src.InterconnectAttachment_StackType

// [Output Only] The current state of this attachment's functionality. Enum
// values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE, PARTNER,
// and PARTNER_PROVIDER interconnect attachments, while enum values
// PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for
// only PARTNER and PARTNER_PROVIDER interconnect attachments. This state can
// take one of the following values: - ACTIVE: The attachment has been turned
// up and is ready to use. - UNPROVISIONED: The attachment is not ready to use
// yet, because turnup is not complete. - PENDING_PARTNER: A newly-created
// PARTNER attachment that has not yet been configured on the Partner side. -
// PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of
// provisioning after a PARTNER_PROVIDER attachment was created that references
// it. - PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is
// waiting for a customer to activate it. - DEFUNCT: The attachment was deleted
// externally and is no longer functional. This could be because the associated
// Interconnect was removed, or because the other side of a Partner attachment
// was deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachment_State = src.InterconnectAttachment_State

// The type of interconnect attachment this is, which can take one of the
// following values: - DEDICATED: an attachment to a Dedicated Interconnect. -
// PARTNER: an attachment to a Partner Interconnect, created by the customer. -
// PARTNER_PROVIDER: an attachment to a Partner Interconnect, created by the
// partner.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectAttachment_Type = src.InterconnectAttachment_Type
type InterconnectAttachmentsScopedList = src.InterconnectAttachmentsScopedList

// Describes a single physical circuit between the Customer and Google.
// CircuitInfo objects are created by Google, so all fields are output only.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectCircuitInfo = src.InterconnectCircuitInfo

// Diagnostics information about the Interconnect connection, which contains
// detailed and current technical information about Google's side of the
// connection.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectDiagnostics = src.InterconnectDiagnostics

// Describing the ARP neighbor entries seen on this link
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectDiagnosticsARPEntry = src.InterconnectDiagnosticsARPEntry
type InterconnectDiagnosticsLinkLACPStatus = src.InterconnectDiagnosticsLinkLACPStatus

// The state of a LACP link, which can take one of the following values: -
// ACTIVE: The link is configured and active within the bundle. - DETACHED: The
// link is not configured within the bundle. This means that the rest of the
// object should be empty.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectDiagnosticsLinkLACPStatus_State = src.InterconnectDiagnosticsLinkLACPStatus_State
type InterconnectDiagnosticsLinkOpticalPower = src.InterconnectDiagnosticsLinkOpticalPower

// The status of the current value when compared to the warning and alarm
// levels for the receiving or transmitting transceiver. Possible states
// include: - OK: The value has not crossed a warning threshold. - LOW_WARNING:
// The value has crossed below the low warning threshold. - HIGH_WARNING: The
// value has crossed above the high warning threshold. - LOW_ALARM: The value
// has crossed below the low alarm threshold. - HIGH_ALARM: The value has
// crossed above the high alarm threshold.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectDiagnosticsLinkOpticalPower_State = src.InterconnectDiagnosticsLinkOpticalPower_State
type InterconnectDiagnosticsLinkStatus = src.InterconnectDiagnosticsLinkStatus

// The operational status of the link.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectDiagnosticsLinkStatus_OperationalStatus = src.InterconnectDiagnosticsLinkStatus_OperationalStatus

// Describes the status of MACsec encryption on the link.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectDiagnosticsMacsecStatus = src.InterconnectDiagnosticsMacsecStatus

// The aggregation type of the bundle interface.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectDiagnostics_BundleAggregationType = src.InterconnectDiagnostics_BundleAggregationType

// The operational status of the bundle interface.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectDiagnostics_BundleOperationalStatus = src.InterconnectDiagnostics_BundleOperationalStatus

// Response to the list request, and contains a list of interconnects.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectList = src.InterconnectList

// Represents an Interconnect Attachment (VLAN) Location resource. You can use
// this resource to find location details about an Interconnect attachment
// (VLAN). For more information about interconnect attachments, read Creating
// VLAN Attachments.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectLocation = src.InterconnectLocation

// Response to the list request, and contains a list of interconnect
// locations.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectLocationList = src.InterconnectLocationList

// Information about any potential InterconnectAttachments between an
// Interconnect at a specific InterconnectLocation, and a specific Cloud
// Region.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectLocationRegionInfo = src.InterconnectLocationRegionInfo

// Identifies the network presence of this location.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectLocationRegionInfo_LocationPresence = src.InterconnectLocationRegionInfo_LocationPresence
type InterconnectLocation_AvailableFeatures = src.InterconnectLocation_AvailableFeatures
type InterconnectLocation_AvailableLinkTypes = src.InterconnectLocation_AvailableLinkTypes

// [Output Only] Continent for this location, which can take one of the
// following values: - AFRICA - ASIA_PAC - EUROPE - NORTH_AMERICA -
// SOUTH_AMERICA
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectLocation_Continent = src.InterconnectLocation_Continent

// [Output Only] The status of this InterconnectLocation, which can take one
// of the following values: - CLOSED: The InterconnectLocation is closed and is
// unavailable for provisioning new Interconnects. - AVAILABLE: The
// InterconnectLocation is available for provisioning new Interconnects.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectLocation_Status = src.InterconnectLocation_Status

// Configuration information for enabling Media Access Control security
// (MACsec) on this Cloud Interconnect connection between Google and your
// on-premises router.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectMacsec = src.InterconnectMacsec

// MACsec configuration information for the Interconnect connection. Contains
// the generated Connectivity Association Key Name (CKN) and the key (CAK) for
// this Interconnect connection.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectMacsecConfig = src.InterconnectMacsecConfig

// Describes a pre-shared key used to setup MACsec in static connectivity
// association key (CAK) mode.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectMacsecConfigPreSharedKey = src.InterconnectMacsecConfigPreSharedKey

// Describes a pre-shared key used to setup MACsec in static connectivity
// association key (CAK) mode.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectMacsecPreSharedKey = src.InterconnectMacsecPreSharedKey

// Description of a planned outage on this Interconnect.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectOutageNotification = src.InterconnectOutageNotification

// Form this outage is expected to take, which can take one of the following
// values: - OUTAGE: The Interconnect may be completely out of service for some
// or all of the specified window. - PARTIAL_OUTAGE: Some circuits comprising
// the Interconnect as a whole should remain up, but with reduced bandwidth.
// Note that the versions of this enum prefixed with "IT_" have been deprecated
// in favor of the unprefixed values.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectOutageNotification_IssueType = src.InterconnectOutageNotification_IssueType

// The party that generated this notification, which can take the following
// value: - GOOGLE: this notification as generated by Google. Note that the
// value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectOutageNotification_Source = src.InterconnectOutageNotification_Source

// State of this notification, which can take one of the following values: -
// ACTIVE: This outage notification is active. The event could be in the past,
// present, or future. See start_time and end_time for scheduling. - CANCELLED:
// The outage associated with this notification was cancelled before the outage
// was due to start. - COMPLETED: The outage associated with this notification
// is complete. Note that the versions of this enum prefixed with "NS_" have
// been deprecated in favor of the unprefixed values.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectOutageNotification_State = src.InterconnectOutageNotification_State

// Represents a Cross-Cloud Interconnect Remote Location resource. You can use
// this resource to find remote location details about an Interconnect
// attachment (VLAN).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectRemoteLocation = src.InterconnectRemoteLocation
type InterconnectRemoteLocationConstraints = src.InterconnectRemoteLocationConstraints
type InterconnectRemoteLocationConstraintsSubnetLengthRange = src.InterconnectRemoteLocationConstraintsSubnetLengthRange

// [Output Only] Port pair remote location constraints, which can take one of
// the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
// PORT_PAIR_MATCHING_REMOTE_LOCATION. Google Cloud API refers only to
// individual ports, but the UI uses this field when ordering a pair of ports,
// to prevent users from accidentally ordering something that is incompatible
// with their cloud provider. Specifically, when ordering a redundant pair of
// Cross-Cloud Interconnect ports, and one of them uses a remote location with
// portPairMatchingRemoteLocation set to matching, the UI requires that both
// ports use the same remote location.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectRemoteLocationConstraints_PortPairRemoteLocation = src.InterconnectRemoteLocationConstraints_PortPairRemoteLocation

// [Output Only] Port pair VLAN constraints, which can take one of the
// following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectRemoteLocationConstraints_PortPairVlan = src.InterconnectRemoteLocationConstraints_PortPairVlan

// Response to the list request, and contains a list of interconnect remote
// locations.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectRemoteLocationList = src.InterconnectRemoteLocationList
type InterconnectRemoteLocationPermittedConnections = src.InterconnectRemoteLocationPermittedConnections

// [Output Only] Continent for this location, which can take one of the
// following values: - AFRICA - ASIA_PAC - EUROPE - NORTH_AMERICA -
// SOUTH_AMERICA
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectRemoteLocation_Continent = src.InterconnectRemoteLocation_Continent

// [Output Only] Link Aggregation Control Protocol (LACP) constraints, which
// can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectRemoteLocation_Lacp = src.InterconnectRemoteLocation_Lacp

// [Output Only] The status of this InterconnectRemoteLocation, which can take
// one of the following values: - CLOSED: The InterconnectRemoteLocation is
// closed and is unavailable for provisioning new Cross-Cloud Interconnects. -
// AVAILABLE: The InterconnectRemoteLocation is available for provisioning new
// Cross-Cloud Interconnects.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectRemoteLocation_Status = src.InterconnectRemoteLocation_Status

// Additional supported values which may be not listed in the enum directly
// due to technical reasons: IF_MACSEC
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Interconnect_AvailableFeatures = src.Interconnect_AvailableFeatures

// Type of interconnect, which can take one of the following values: -
// PARTNER: A partner-managed interconnection shared between customers though a
// partner. - DEDICATED: A dedicated physical interconnection with the
// customer. Note that a value IT_PRIVATE has been deprecated in favor of
// DEDICATED.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Interconnect_InterconnectType = src.Interconnect_InterconnectType

// Type of link requested, which can take one of the following values: -
// LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics -
// LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. Note that this
// field indicates the speed of each of the links in the bundle, not the speed
// of the entire bundle.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Interconnect_LinkType = src.Interconnect_LinkType

// [Output Only] The current status of this Interconnect's functionality,
// which can take one of the following values: - OS_ACTIVE: A valid
// Interconnect, which is turned up and is ready to use. Attachments may be
// provisioned on this Interconnect. - OS_UNPROVISIONED: An Interconnect that
// has not completed turnup. No attachments may be provisioned on this
// Interconnect. - OS_UNDER_MAINTENANCE: An Interconnect that is undergoing
// internal maintenance. No attachments may be provisioned or updated on this
// Interconnect.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Interconnect_OperationalStatus = src.Interconnect_OperationalStatus

// Additional supported values which may be not listed in the enum directly
// due to technical reasons: IF_MACSEC
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Interconnect_RequestedFeatures = src.Interconnect_RequestedFeatures

// [Output Only] The current state of Interconnect functionality, which can
// take one of the following values: - ACTIVE: The Interconnect is valid,
// turned up and ready to use. Attachments may be provisioned on this
// Interconnect. - UNPROVISIONED: The Interconnect has not completed turnup. No
// attachments may be provisioned on this Interconnect. - UNDER_MAINTENANCE:
// The Interconnect is undergoing internal maintenance. No attachments may be
// provisioned or updated on this Interconnect.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Interconnect_State = src.Interconnect_State

// Response for the InterconnectsGetDiagnosticsRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectsGetDiagnosticsResponse = src.InterconnectsGetDiagnosticsResponse

// Response for the InterconnectsGetMacsecConfigRequest.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InterconnectsGetMacsecConfigResponse = src.InterconnectsGetMacsecConfigResponse

// A request message for UrlMaps.InvalidateCache. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type InvalidateCacheUrlMapRequest = src.InvalidateCacheUrlMapRequest

// Metadata
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Items = src.Items

// Represents a License resource. A License represents billing and aggregate
// usage data for public and marketplace images. *Caution* This resource is
// intended for use only by third-party partners who are creating Cloud
// Marketplace images.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type License = src.License

// Represents a License Code resource. A License Code is a unique identifier
// used to represent a license resource. *Caution* This resource is intended
// for use only by third-party partners who are creating Cloud Marketplace
// images.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type LicenseCode = src.LicenseCode
type LicenseCodeLicenseAlias = src.LicenseCodeLicenseAlias

// [Output Only] Current state of this License Code.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type LicenseCode_State = src.LicenseCode_State

// Commitment for a particular license resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type LicenseResourceCommitment = src.LicenseResourceCommitment
type LicenseResourceRequirements = src.LicenseResourceRequirements
type LicensesListResponse = src.LicensesListResponse

// A request message for AcceleratorTypes.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListAcceleratorTypesRequest = src.ListAcceleratorTypesRequest

// A request message for Addresses.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListAddressesRequest = src.ListAddressesRequest

// A request message for FirewallPolicies.ListAssociations. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListAssociationsFirewallPolicyRequest = src.ListAssociationsFirewallPolicyRequest

// A request message for Autoscalers.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListAutoscalersRequest = src.ListAutoscalersRequest

// A request message for RegionSslPolicies.ListAvailableFeatures. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListAvailableFeaturesRegionSslPoliciesRequest = src.ListAvailableFeaturesRegionSslPoliciesRequest

// A request message for SslPolicies.ListAvailableFeatures. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListAvailableFeaturesSslPoliciesRequest = src.ListAvailableFeaturesSslPoliciesRequest

// A request message for BackendBuckets.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListBackendBucketsRequest = src.ListBackendBucketsRequest

// A request message for BackendServices.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListBackendServicesRequest = src.ListBackendServicesRequest

// A request message for DiskTypes.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListDiskTypesRequest = src.ListDiskTypesRequest

// A request message for Disks.List. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListDisksRequest = src.ListDisksRequest

// A request message for StoragePools.ListDisks. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListDisksStoragePoolsRequest = src.ListDisksStoragePoolsRequest

// A request message for InstanceGroupManagers.ListErrors. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListErrorsInstanceGroupManagersRequest = src.ListErrorsInstanceGroupManagersRequest

// A request message for RegionInstanceGroupManagers.ListErrors. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListErrorsRegionInstanceGroupManagersRequest = src.ListErrorsRegionInstanceGroupManagersRequest

// A request message for ExternalVpnGateways.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListExternalVpnGatewaysRequest = src.ListExternalVpnGatewaysRequest

// A request message for FirewallPolicies.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListFirewallPoliciesRequest = src.ListFirewallPoliciesRequest

// A request message for Firewalls.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListFirewallsRequest = src.ListFirewallsRequest

// A request message for ForwardingRules.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListForwardingRulesRequest = src.ListForwardingRulesRequest

// A request message for GlobalAddresses.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListGlobalAddressesRequest = src.ListGlobalAddressesRequest

// A request message for GlobalForwardingRules.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListGlobalForwardingRulesRequest = src.ListGlobalForwardingRulesRequest

// A request message for GlobalNetworkEndpointGroups.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListGlobalNetworkEndpointGroupsRequest = src.ListGlobalNetworkEndpointGroupsRequest

// A request message for GlobalOperations.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListGlobalOperationsRequest = src.ListGlobalOperationsRequest

// A request message for GlobalOrganizationOperations.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListGlobalOrganizationOperationsRequest = src.ListGlobalOrganizationOperationsRequest

// A request message for GlobalPublicDelegatedPrefixes.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListGlobalPublicDelegatedPrefixesRequest = src.ListGlobalPublicDelegatedPrefixesRequest

// A request message for HealthChecks.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListHealthChecksRequest = src.ListHealthChecksRequest

// A request message for Images.List. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListImagesRequest = src.ListImagesRequest

// A request message for InstanceGroupManagerResizeRequests.List. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInstanceGroupManagerResizeRequestsRequest = src.ListInstanceGroupManagerResizeRequestsRequest

// A request message for InstanceGroupManagers.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInstanceGroupManagersRequest = src.ListInstanceGroupManagersRequest

// A request message for InstanceGroups.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInstanceGroupsRequest = src.ListInstanceGroupsRequest

// A request message for InstanceTemplates.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInstanceTemplatesRequest = src.ListInstanceTemplatesRequest

// A request message for InstanceGroups.ListInstances. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInstancesInstanceGroupsRequest = src.ListInstancesInstanceGroupsRequest

// A request message for RegionInstanceGroups.ListInstances. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInstancesRegionInstanceGroupsRequest = src.ListInstancesRegionInstanceGroupsRequest

// A request message for Instances.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInstancesRequest = src.ListInstancesRequest

// A request message for InstantSnapshots.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInstantSnapshotsRequest = src.ListInstantSnapshotsRequest

// A request message for InterconnectAttachments.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInterconnectAttachmentsRequest = src.ListInterconnectAttachmentsRequest

// A request message for InterconnectLocations.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInterconnectLocationsRequest = src.ListInterconnectLocationsRequest

// A request message for InterconnectRemoteLocations.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInterconnectRemoteLocationsRequest = src.ListInterconnectRemoteLocationsRequest

// A request message for Interconnects.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListInterconnectsRequest = src.ListInterconnectsRequest

// A request message for Licenses.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListLicensesRequest = src.ListLicensesRequest

// A request message for MachineImages.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListMachineImagesRequest = src.ListMachineImagesRequest

// A request message for MachineTypes.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListMachineTypesRequest = src.ListMachineTypesRequest

// A request message for InstanceGroupManagers.ListManagedInstances. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListManagedInstancesInstanceGroupManagersRequest = src.ListManagedInstancesInstanceGroupManagersRequest

// A request message for RegionInstanceGroupManagers.ListManagedInstances. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListManagedInstancesRegionInstanceGroupManagersRequest = src.ListManagedInstancesRegionInstanceGroupManagersRequest

// A request message for NetworkAttachments.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNetworkAttachmentsRequest = src.ListNetworkAttachmentsRequest

// A request message for NetworkEndpointGroups.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNetworkEndpointGroupsRequest = src.ListNetworkEndpointGroupsRequest

// A request message for GlobalNetworkEndpointGroups.ListNetworkEndpoints. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest = src.ListNetworkEndpointsGlobalNetworkEndpointGroupsRequest

// A request message for NetworkEndpointGroups.ListNetworkEndpoints. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNetworkEndpointsNetworkEndpointGroupsRequest = src.ListNetworkEndpointsNetworkEndpointGroupsRequest

// A request message for RegionNetworkEndpointGroups.ListNetworkEndpoints. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNetworkEndpointsRegionNetworkEndpointGroupsRequest = src.ListNetworkEndpointsRegionNetworkEndpointGroupsRequest

// A request message for NetworkFirewallPolicies.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNetworkFirewallPoliciesRequest = src.ListNetworkFirewallPoliciesRequest

// A request message for Networks.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNetworksRequest = src.ListNetworksRequest

// A request message for NodeGroups.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNodeGroupsRequest = src.ListNodeGroupsRequest

// A request message for NodeTemplates.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNodeTemplatesRequest = src.ListNodeTemplatesRequest

// A request message for NodeTypes.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNodeTypesRequest = src.ListNodeTypesRequest

// A request message for NodeGroups.ListNodes. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListNodesNodeGroupsRequest = src.ListNodesNodeGroupsRequest

// A request message for PacketMirrorings.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListPacketMirroringsRequest = src.ListPacketMirroringsRequest

// A request message for Networks.ListPeeringRoutes. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListPeeringRoutesNetworksRequest = src.ListPeeringRoutesNetworksRequest

// The direction of the exchanged routes.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListPeeringRoutesNetworksRequest_Direction = src.ListPeeringRoutesNetworksRequest_Direction

// A request message for InstanceGroupManagers.ListPerInstanceConfigs. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListPerInstanceConfigsInstanceGroupManagersRequest = src.ListPerInstanceConfigsInstanceGroupManagersRequest

// A request message for RegionInstanceGroupManagers.ListPerInstanceConfigs.
// See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListPerInstanceConfigsRegionInstanceGroupManagersRequest = src.ListPerInstanceConfigsRegionInstanceGroupManagersRequest

// A request message for SecurityPolicies.ListPreconfiguredExpressionSets. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListPreconfiguredExpressionSetsSecurityPoliciesRequest = src.ListPreconfiguredExpressionSetsSecurityPoliciesRequest

// A request message for PublicAdvertisedPrefixes.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListPublicAdvertisedPrefixesRequest = src.ListPublicAdvertisedPrefixesRequest

// A request message for PublicDelegatedPrefixes.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListPublicDelegatedPrefixesRequest = src.ListPublicDelegatedPrefixesRequest

// A request message for Instances.ListReferrers. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListReferrersInstancesRequest = src.ListReferrersInstancesRequest

// A request message for RegionAutoscalers.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionAutoscalersRequest = src.ListRegionAutoscalersRequest

// A request message for RegionBackendServices.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionBackendServicesRequest = src.ListRegionBackendServicesRequest

// A request message for RegionCommitments.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionCommitmentsRequest = src.ListRegionCommitmentsRequest

// A request message for RegionDiskTypes.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionDiskTypesRequest = src.ListRegionDiskTypesRequest

// A request message for RegionDisks.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionDisksRequest = src.ListRegionDisksRequest

// A request message for RegionHealthCheckServices.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionHealthCheckServicesRequest = src.ListRegionHealthCheckServicesRequest

// A request message for RegionHealthChecks.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionHealthChecksRequest = src.ListRegionHealthChecksRequest

// A request message for RegionInstanceGroupManagers.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionInstanceGroupManagersRequest = src.ListRegionInstanceGroupManagersRequest

// A request message for RegionInstanceGroups.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionInstanceGroupsRequest = src.ListRegionInstanceGroupsRequest

// A request message for RegionInstanceTemplates.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionInstanceTemplatesRequest = src.ListRegionInstanceTemplatesRequest

// A request message for RegionInstantSnapshots.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionInstantSnapshotsRequest = src.ListRegionInstantSnapshotsRequest

// A request message for RegionNetworkEndpointGroups.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionNetworkEndpointGroupsRequest = src.ListRegionNetworkEndpointGroupsRequest

// A request message for RegionNetworkFirewallPolicies.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionNetworkFirewallPoliciesRequest = src.ListRegionNetworkFirewallPoliciesRequest

// A request message for RegionNotificationEndpoints.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionNotificationEndpointsRequest = src.ListRegionNotificationEndpointsRequest

// A request message for RegionOperations.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionOperationsRequest = src.ListRegionOperationsRequest

// A request message for RegionSecurityPolicies.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionSecurityPoliciesRequest = src.ListRegionSecurityPoliciesRequest

// A request message for RegionSslCertificates.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionSslCertificatesRequest = src.ListRegionSslCertificatesRequest

// A request message for RegionSslPolicies.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionSslPoliciesRequest = src.ListRegionSslPoliciesRequest

// A request message for RegionTargetHttpProxies.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionTargetHttpProxiesRequest = src.ListRegionTargetHttpProxiesRequest

// A request message for RegionTargetHttpsProxies.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionTargetHttpsProxiesRequest = src.ListRegionTargetHttpsProxiesRequest

// A request message for RegionTargetTcpProxies.List. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionTargetTcpProxiesRequest = src.ListRegionTargetTcpProxiesRequest

// A request message for RegionUrlMaps.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionUrlMapsRequest = src.ListRegionUrlMapsRequest

// A request message for RegionZones.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionZonesRequest = src.ListRegionZonesRequest

// A request message for Regions.List. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRegionsRequest = src.ListRegionsRequest

// A request message for Reservations.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListReservationsRequest = src.ListReservationsRequest

// A request message for ResourcePolicies.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListResourcePoliciesRequest = src.ListResourcePoliciesRequest

// A request message for Routers.List. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRoutersRequest = src.ListRoutersRequest

// A request message for Routes.List. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListRoutesRequest = src.ListRoutesRequest

// A request message for SecurityPolicies.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListSecurityPoliciesRequest = src.ListSecurityPoliciesRequest

// A request message for ServiceAttachments.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListServiceAttachmentsRequest = src.ListServiceAttachmentsRequest

// A request message for Snapshots.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListSnapshotsRequest = src.ListSnapshotsRequest

// A request message for SslCertificates.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListSslCertificatesRequest = src.ListSslCertificatesRequest

// A request message for SslPolicies.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListSslPoliciesRequest = src.ListSslPoliciesRequest

// A request message for StoragePoolTypes.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListStoragePoolTypesRequest = src.ListStoragePoolTypesRequest

// A request message for StoragePools.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListStoragePoolsRequest = src.ListStoragePoolsRequest

// A request message for Subnetworks.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListSubnetworksRequest = src.ListSubnetworksRequest

// A request message for TargetGrpcProxies.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListTargetGrpcProxiesRequest = src.ListTargetGrpcProxiesRequest

// A request message for TargetHttpProxies.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListTargetHttpProxiesRequest = src.ListTargetHttpProxiesRequest

// A request message for TargetHttpsProxies.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListTargetHttpsProxiesRequest = src.ListTargetHttpsProxiesRequest

// A request message for TargetInstances.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListTargetInstancesRequest = src.ListTargetInstancesRequest

// A request message for TargetPools.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListTargetPoolsRequest = src.ListTargetPoolsRequest

// A request message for TargetSslProxies.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListTargetSslProxiesRequest = src.ListTargetSslProxiesRequest

// A request message for TargetTcpProxies.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListTargetTcpProxiesRequest = src.ListTargetTcpProxiesRequest

// A request message for TargetVpnGateways.List. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListTargetVpnGatewaysRequest = src.ListTargetVpnGatewaysRequest

// A request message for UrlMaps.List. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListUrlMapsRequest = src.ListUrlMapsRequest

// A request message for BackendServices.ListUsable. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListUsableBackendServicesRequest = src.ListUsableBackendServicesRequest

// A request message for RegionBackendServices.ListUsable. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListUsableRegionBackendServicesRequest = src.ListUsableRegionBackendServicesRequest

// A request message for Subnetworks.ListUsable. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListUsableSubnetworksRequest = src.ListUsableSubnetworksRequest

// A request message for VpnGateways.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListVpnGatewaysRequest = src.ListVpnGatewaysRequest

// A request message for VpnTunnels.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListVpnTunnelsRequest = src.ListVpnTunnelsRequest

// A request message for Projects.ListXpnHosts. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListXpnHostsProjectsRequest = src.ListXpnHostsProjectsRequest

// A request message for ZoneOperations.List. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListZoneOperationsRequest = src.ListZoneOperationsRequest

// A request message for Zones.List. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ListZonesRequest = src.ListZonesRequest
type LocalDisk = src.LocalDisk

// Provides a localized error message that is safe to return to the user which
// can be attached to an RPC error.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type LocalizedMessage = src.LocalizedMessage

// Configuration for location policy among multiple possible locations (e.g.
// preferences for zone selection among zones in a single region).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type LocationPolicy = src.LocationPolicy
type LocationPolicyLocation = src.LocationPolicyLocation

// Per-zone constraints on location policy for this zone.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type LocationPolicyLocationConstraints = src.LocationPolicyLocationConstraints

// Preference for a given location. Set to either ALLOW or DENY.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type LocationPolicyLocation_Preference = src.LocationPolicyLocation_Preference

// Strategy for distributing VMs across zones in a region.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type LocationPolicy_TargetShape = src.LocationPolicy_TargetShape

// Represents a machine image resource. A machine image is a Compute Engine
// resource that stores all the configuration, metadata, permissions, and data
// from one or more disks required to create a Virtual machine (VM) instance.
// For more information, see Machine images.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MachineImage = src.MachineImage

// A list of machine images.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MachineImageList = src.MachineImageList

// [Output Only] The status of the machine image. One of the following values:
// INVALID, CREATING, READY, DELETING, and UPLOADING.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MachineImage_Status = src.MachineImage_Status

// Represents a Machine Type resource. You can use specific machine types for
// your VM instances based on performance and pricing requirements. For more
// information, read Machine Types.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MachineType = src.MachineType
type MachineTypeAggregatedList = src.MachineTypeAggregatedList

// Contains a list of machine types.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MachineTypeList = src.MachineTypeList

// [Output Only] The architecture of the machine type.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MachineType_Architecture = src.MachineType_Architecture
type MachineTypesScopedList = src.MachineTypesScopedList

// A Managed Instance resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ManagedInstance = src.ManagedInstance
type ManagedInstanceInstanceHealth = src.ManagedInstanceInstanceHealth

// [Output Only] The current detailed instance health state.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ManagedInstanceInstanceHealth_DetailedHealthState = src.ManagedInstanceInstanceHealth_DetailedHealthState
type ManagedInstanceLastAttempt = src.ManagedInstanceLastAttempt
type ManagedInstancePropertiesFromFlexibilityPolicy = src.ManagedInstancePropertiesFromFlexibilityPolicy
type ManagedInstanceVersion = src.ManagedInstanceVersion

// [Output Only] The current action that the managed instance group has
// scheduled for the instance. Possible values: - NONE The instance is running,
// and the managed instance group does not have any scheduled actions for this
// instance. - CREATING The managed instance group is creating this instance.
// If the group fails to create this instance, it will try again until it is
// successful. - CREATING_WITHOUT_RETRIES The managed instance group is
// attempting to create this instance only once. If the group fails to create
// this instance, it does not try again and the group's targetSize value is
// decreased instead. - RECREATING The managed instance group is recreating
// this instance. - DELETING The managed instance group is permanently deleting
// this instance. - ABANDONING The managed instance group is abandoning this
// instance. The instance will be removed from the instance group and from any
// target pools that are associated with this group. - RESTARTING The managed
// instance group is restarting the instance. - REFRESHING The managed instance
// group is applying configuration changes to the instance without stopping it.
// For example, the group can update the target pool list for an instance
// without stopping that instance. - VERIFYING The managed instance group has
// created the instance and it is in the process of being verified. Additional
// supported values which may be not listed in the enum directly due to
// technical reasons: STOPPING SUSPENDING
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ManagedInstance_CurrentAction = src.ManagedInstance_CurrentAction

// [Output Only] The status of the instance. This field is empty when the
// instance does not exist. Additional supported values which may be not listed
// in the enum directly due to technical reasons: STOPPING SUSPENDING
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ManagedInstance_InstanceStatus = src.ManagedInstance_InstanceStatus

// A metadata key/value entry.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Metadata = src.Metadata

// Opaque filter criteria used by load balancers to restrict routing
// configuration to a limited set of load balancing proxies. Proxies and
// sidecars involved in load balancing would typically present metadata to the
// load balancers that need to match criteria specified here. If a match takes
// place, the relevant configuration is made available to those proxies. For
// each metadataFilter in this list, if its filterMatchCriteria is set to
// MATCH_ANY, at least one of the filterLabels must match the corresponding
// label provided in the metadata. If its filterMatchCriteria is set to
// MATCH_ALL, then all of its filterLabels must match with corresponding labels
// provided in the metadata. An example for using metadataFilters would be: if
// load balancing involves Envoys, they receive routing configuration when
// values in metadataFilters match values supplied in of their XDS requests to
// loadbalancers.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MetadataFilter = src.MetadataFilter

// MetadataFilter label name value pairs that are expected to match
// corresponding labels presented as metadata to the load balancer.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MetadataFilterLabelMatch = src.MetadataFilterLabelMatch

// Specifies how individual filter label matches within the list of
// filterLabels and contributes toward the overall metadataFilter match.
// Supported values are: - MATCH_ANY: at least one of the filterLabels must
// have a matching label in the provided metadata. - MATCH_ALL: all
// filterLabels must have matching labels in the provided metadata.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MetadataFilter_FilterMatchCriteria = src.MetadataFilter_FilterMatchCriteria

// A request message for Addresses.Move. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MoveAddressRequest = src.MoveAddressRequest

// A request message for Projects.MoveDisk. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MoveDiskProjectRequest = src.MoveDiskProjectRequest

// A request message for FirewallPolicies.Move. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MoveFirewallPolicyRequest = src.MoveFirewallPolicyRequest

// A request message for GlobalAddresses.Move. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MoveGlobalAddressRequest = src.MoveGlobalAddressRequest

// A request message for Projects.MoveInstance. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type MoveInstanceProjectRequest = src.MoveInstanceProjectRequest

// The named port. For example: <"http", 80>.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NamedPort = src.NamedPort

// Contains NAT IP information of a NAT config (i.e. usage status, mode).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NatIpInfo = src.NatIpInfo

// Contains information of a NAT IP.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NatIpInfoNatIpInfoMapping = src.NatIpInfoNatIpInfoMapping

// Specifies whether NAT IP is auto or manual.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NatIpInfoNatIpInfoMapping_Mode = src.NatIpInfoNatIpInfoMapping_Mode

// Specifies whether NAT IP is currently serving at least one endpoint or not.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NatIpInfoNatIpInfoMapping_Usage = src.NatIpInfoNatIpInfoMapping_Usage
type NatIpInfoResponse = src.NatIpInfoResponse

// Represents a VPC Network resource. Networks connect resources to each other
// and to the internet. For more information, read Virtual Private Cloud (VPC)
// Network.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Network = src.Network

// NetworkAttachments A network attachment resource ...
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkAttachment = src.NetworkAttachment

// Contains a list of NetworkAttachmentsScopedList.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkAttachmentAggregatedList = src.NetworkAttachmentAggregatedList

// [Output Only] A connection connected to this network attachment.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkAttachmentConnectedEndpoint = src.NetworkAttachmentConnectedEndpoint

// The status of a connected endpoint to this network attachment.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkAttachmentConnectedEndpoint_Status = src.NetworkAttachmentConnectedEndpoint_Status
type NetworkAttachmentList = src.NetworkAttachmentList
type NetworkAttachment_ConnectionPreference = src.NetworkAttachment_ConnectionPreference
type NetworkAttachmentsScopedList = src.NetworkAttachmentsScopedList

// Represents a Google Cloud Armor network edge security service resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkEdgeSecurityService = src.NetworkEdgeSecurityService
type NetworkEdgeSecurityServiceAggregatedList = src.NetworkEdgeSecurityServiceAggregatedList
type NetworkEdgeSecurityServicesScopedList = src.NetworkEdgeSecurityServicesScopedList

// The network endpoint.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkEndpoint = src.NetworkEndpoint

// Represents a collection of network endpoints. A network endpoint group
// (NEG) defines how a set of endpoints should be reached, whether they are
// reachable, and where they are located. For more information about using NEGs
// for different use cases, see Network endpoint groups overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkEndpointGroup = src.NetworkEndpointGroup
type NetworkEndpointGroupAggregatedList = src.NetworkEndpointGroupAggregatedList

// Configuration for an App Engine network endpoint group (NEG). The service
// is optional, may be provided explicitly or in the URL mask. The version is
// optional and can only be provided explicitly or in the URL mask when service
// is present. Note: App Engine service must be in the same project and located
// in the same region as the Serverless NEG.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkEndpointGroupAppEngine = src.NetworkEndpointGroupAppEngine

// Configuration for a Cloud Function network endpoint group (NEG). The
// function must be provided explicitly or in the URL mask. Note: Cloud
// Function must be in the same project and located in the same region as the
// Serverless NEG.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkEndpointGroupCloudFunction = src.NetworkEndpointGroupCloudFunction

// Configuration for a Cloud Run network endpoint group (NEG). The service
// must be provided explicitly or in the URL mask. The tag is optional, may be
// provided explicitly or in the URL mask. Note: Cloud Run service must be in
// the same project and located in the same region as the Serverless NEG.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkEndpointGroupCloudRun = src.NetworkEndpointGroupCloudRun
type NetworkEndpointGroupList = src.NetworkEndpointGroupList

// All data that is specifically relevant to only network endpoint groups of
// type PRIVATE_SERVICE_CONNECT.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkEndpointGroupPscData = src.NetworkEndpointGroupPscData

// [Output Only] The connection status of the PSC Forwarding Rule.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkEndpointGroupPscData_PscConnectionStatus = src.NetworkEndpointGroupPscData_PscConnectionStatus

// Type of network endpoints in this network endpoint group. Can be one of
// GCE_VM_IP, GCE_VM_IP_PORT, NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,
// INTERNET_IP_PORT, SERVERLESS, PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkEndpointGroup_NetworkEndpointType = src.NetworkEndpointGroup_NetworkEndpointType
type NetworkEndpointGroupsAttachEndpointsRequest = src.NetworkEndpointGroupsAttachEndpointsRequest
type NetworkEndpointGroupsDetachEndpointsRequest = src.NetworkEndpointGroupsDetachEndpointsRequest
type NetworkEndpointGroupsListEndpointsRequest = src.NetworkEndpointGroupsListEndpointsRequest

// Optional query parameter for showing the health status of each network
// endpoint. Valid options are SKIP or SHOW. If you don't specify this
// parameter, the health status of network endpoints will not be provided.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkEndpointGroupsListEndpointsRequest_HealthStatus = src.NetworkEndpointGroupsListEndpointsRequest_HealthStatus
type NetworkEndpointGroupsListNetworkEndpoints = src.NetworkEndpointGroupsListNetworkEndpoints
type NetworkEndpointGroupsScopedList = src.NetworkEndpointGroupsScopedList
type NetworkEndpointWithHealthStatus = src.NetworkEndpointWithHealthStatus

// A network interface resource attached to an instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkInterface = src.NetworkInterface

// [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be
// accessed from the Internet. This field is always inherited from its
// subnetwork. Valid only if stackType is IPV4_IPV6.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkInterface_Ipv6AccessType = src.NetworkInterface_Ipv6AccessType

// The type of vNIC to be used on this interface. This may be gVNIC or
// VirtioNet.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkInterface_NicType = src.NetworkInterface_NicType

// The stack type for this network interface. To assign only IPv4 addresses,
// use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, use IPV4_IPV6. If not
// specified, IPV4_ONLY is used. This field can be both set at instance
// creation and update network interface operations.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkInterface_StackType = src.NetworkInterface_StackType

// Contains a list of networks.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkList = src.NetworkList

// A network peering attached to a network resource. The message includes the
// peering name, peer network, peering state, and a flag indicating whether
// Google Compute Engine should automatically create routes for the peering.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkPeering = src.NetworkPeering

// Which IP version(s) of traffic and routes are allowed to be imported or
// exported between peer networks. The default value is IPV4_ONLY.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkPeering_StackType = src.NetworkPeering_StackType

// [Output Only] State for the peering, either `ACTIVE` or `INACTIVE`. The
// peering is `ACTIVE` when there's a matching configuration in the peer
// network.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkPeering_State = src.NetworkPeering_State
type NetworkPerformanceConfig = src.NetworkPerformanceConfig
type NetworkPerformanceConfig_TotalEgressBandwidthTier = src.NetworkPerformanceConfig_TotalEgressBandwidthTier

// A routing configuration attached to a network resource. The message
// includes the list of routers associated with the network, and a flag
// indicating the type of routing behavior to enforce network-wide.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkRoutingConfig = src.NetworkRoutingConfig

// The network-wide routing mode to use. If set to REGIONAL, this network's
// Cloud Routers will only advertise routes with subnets of this network in the
// same region as the router. If set to GLOBAL, this network's Cloud Routers
// will advertise routes with all subnets of this network, across regions.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworkRoutingConfig_RoutingMode = src.NetworkRoutingConfig_RoutingMode

// The network firewall policy enforcement order. Can be either
// AFTER_CLASSIC_FIREWALL or BEFORE_CLASSIC_FIREWALL. Defaults to
// AFTER_CLASSIC_FIREWALL if the field is not specified.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Network_NetworkFirewallPolicyEnforcementOrder = src.Network_NetworkFirewallPolicyEnforcementOrder
type NetworksAddPeeringRequest = src.NetworksAddPeeringRequest
type NetworksGetEffectiveFirewallsResponse = src.NetworksGetEffectiveFirewallsResponse
type NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy = src.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy

// [Output Only] The type of the firewall policy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type = src.NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type
type NetworksRemovePeeringRequest = src.NetworksRemovePeeringRequest
type NetworksUpdatePeeringRequest = src.NetworksUpdatePeeringRequest

// Represents a sole-tenant Node Group resource. A sole-tenant node is a
// physical server that is dedicated to hosting VM instances only for your
// specific project. Use sole-tenant nodes to keep your instances physically
// separated from instances in other projects, or to group your instances
// together on the same host hardware. For more information, read Sole-tenant
// nodes.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeGroup = src.NodeGroup
type NodeGroupAggregatedList = src.NodeGroupAggregatedList
type NodeGroupAutoscalingPolicy = src.NodeGroupAutoscalingPolicy

// The autoscaling mode. Set to one of: ON, OFF, or ONLY_SCALE_OUT. For more
// information, see Autoscaler modes.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeGroupAutoscalingPolicy_Mode = src.NodeGroupAutoscalingPolicy_Mode

// Contains a list of nodeGroups.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeGroupList = src.NodeGroupList

// Time window specified for daily maintenance operations. GCE's internal
// maintenance will be performed within this window.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeGroupMaintenanceWindow = src.NodeGroupMaintenanceWindow
type NodeGroupNode = src.NodeGroupNode

// CPU overcommit.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeGroupNode_CpuOvercommitType = src.NodeGroupNode_CpuOvercommitType
type NodeGroupNode_Status = src.NodeGroupNode_Status

// Specifies the frequency of planned maintenance events. The accepted values
// are: `AS_NEEDED` and `RECURRENT`.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeGroup_MaintenanceInterval = src.NodeGroup_MaintenanceInterval

// Specifies how to handle instances when a node in the group undergoes
// maintenance. Set to one of: DEFAULT, RESTART_IN_PLACE, or
// MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more
// information, see Maintenance policies.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeGroup_MaintenancePolicy = src.NodeGroup_MaintenancePolicy
type NodeGroup_Status = src.NodeGroup_Status
type NodeGroupsAddNodesRequest = src.NodeGroupsAddNodesRequest
type NodeGroupsDeleteNodesRequest = src.NodeGroupsDeleteNodesRequest
type NodeGroupsListNodes = src.NodeGroupsListNodes
type NodeGroupsPerformMaintenanceRequest = src.NodeGroupsPerformMaintenanceRequest
type NodeGroupsScopedList = src.NodeGroupsScopedList
type NodeGroupsSetNodeTemplateRequest = src.NodeGroupsSetNodeTemplateRequest
type NodeGroupsSimulateMaintenanceEventRequest = src.NodeGroupsSimulateMaintenanceEventRequest

// Represent a sole-tenant Node Template resource. You can use a template to
// define properties for nodes in a node group. For more information, read
// Creating node groups and instances.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeTemplate = src.NodeTemplate
type NodeTemplateAggregatedList = src.NodeTemplateAggregatedList

// Contains a list of node templates.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeTemplateList = src.NodeTemplateList
type NodeTemplateNodeTypeFlexibility = src.NodeTemplateNodeTypeFlexibility

// CPU overcommit.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeTemplate_CpuOvercommitType = src.NodeTemplate_CpuOvercommitType

// [Output Only] The status of the node template. One of the following values:
// CREATING, READY, and DELETING.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeTemplate_Status = src.NodeTemplate_Status
type NodeTemplatesScopedList = src.NodeTemplatesScopedList

// Represent a sole-tenant Node Type resource. Each node within a node group
// must have a node type. A node type specifies the total amount of cores and
// memory for that node. Currently, the only available node type is
// n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available
// in multiple zones. For more information read Node types.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeType = src.NodeType
type NodeTypeAggregatedList = src.NodeTypeAggregatedList

// Contains a list of node types.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NodeTypeList = src.NodeTypeList
type NodeTypesScopedList = src.NodeTypesScopedList

// Represents a notification endpoint. A notification endpoint resource
// defines an endpoint to receive notifications when there are status changes
// detected by the associated health check service. For more information, see
// Health checks overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NotificationEndpoint = src.NotificationEndpoint

// Represents a gRPC setting that describes one gRPC notification endpoint and
// the retry duration attempting to send notification to this endpoint.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type NotificationEndpointGrpcSettings = src.NotificationEndpointGrpcSettings
type NotificationEndpointList = src.NotificationEndpointList

// Represents an Operation resource. Google Compute Engine has three Operation
// resources: * [Global](/compute/docs/reference/rest/v1/globalOperations) *
// [Regional](/compute/docs/reference/rest/v1/regionOperations) *
// [Zonal](/compute/docs/reference/rest/v1/zoneOperations) You can use an
// operation resource to manage asynchronous API requests. For more
// information, read Handling API responses. Operations can be global, regional
// or zonal. - For global operations, use the `globalOperations` resource. -
// For regional operations, use the `regionOperations` resource. - For zonal
// operations, use the `zoneOperations` resource. For more information, read
// Global, Regional, and Zonal Resources. Note that completed Operation
// resources have a limited retention period.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Operation = src.Operation
type OperationAggregatedList = src.OperationAggregatedList

// Contains a list of Operation resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type OperationList = src.OperationList

// [Output Only] The status of the operation, which can be one of the
// following: `PENDING`, `RUNNING`, or `DONE`.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Operation_Status = src.Operation_Status
type OperationsScopedList = src.OperationsScopedList

// Settings controlling the eviction of unhealthy hosts from the load
// balancing pool for the backend service.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type OutlierDetection = src.OutlierDetection

// Next free: 7
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PacketIntervals = src.PacketIntervals

// From how long ago in the past these intervals were observed.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PacketIntervals_Duration = src.PacketIntervals_Duration

// The type of packets for which inter-packet intervals were computed.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PacketIntervals_Type = src.PacketIntervals_Type

// Represents a Packet Mirroring resource. Packet Mirroring clones the traffic
// of specified instances in your Virtual Private Cloud (VPC) network and
// forwards it to a collector destination, such as an instance group of an
// internal TCP/UDP load balancer, for analysis or examination. For more
// information about setting up Packet Mirroring, see Using Packet Mirroring.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PacketMirroring = src.PacketMirroring

// Contains a list of packetMirrorings.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PacketMirroringAggregatedList = src.PacketMirroringAggregatedList
type PacketMirroringFilter = src.PacketMirroringFilter

// Direction of traffic to mirror, either INGRESS, EGRESS, or BOTH. The
// default is BOTH.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PacketMirroringFilter_Direction = src.PacketMirroringFilter_Direction
type PacketMirroringForwardingRuleInfo = src.PacketMirroringForwardingRuleInfo

// Contains a list of PacketMirroring resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PacketMirroringList = src.PacketMirroringList
type PacketMirroringMirroredResourceInfo = src.PacketMirroringMirroredResourceInfo
type PacketMirroringMirroredResourceInfoInstanceInfo = src.PacketMirroringMirroredResourceInfoInstanceInfo
type PacketMirroringMirroredResourceInfoSubnetInfo = src.PacketMirroringMirroredResourceInfoSubnetInfo
type PacketMirroringNetworkInfo = src.PacketMirroringNetworkInfo

// Indicates whether or not this packet mirroring takes effect. If set to
// FALSE, this packet mirroring policy will not be enforced on the network. The
// default is TRUE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PacketMirroring_Enable = src.PacketMirroring_Enable
type PacketMirroringsScopedList = src.PacketMirroringsScopedList

// A request message for Autoscalers.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchAutoscalerRequest = src.PatchAutoscalerRequest

// A request message for BackendBuckets.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchBackendBucketRequest = src.PatchBackendBucketRequest

// A request message for BackendServices.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchBackendServiceRequest = src.PatchBackendServiceRequest

// A request message for FirewallPolicies.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchFirewallPolicyRequest = src.PatchFirewallPolicyRequest

// A request message for Firewalls.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchFirewallRequest = src.PatchFirewallRequest

// A request message for ForwardingRules.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchForwardingRuleRequest = src.PatchForwardingRuleRequest

// A request message for GlobalForwardingRules.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchGlobalForwardingRuleRequest = src.PatchGlobalForwardingRuleRequest

// A request message for GlobalPublicDelegatedPrefixes.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchGlobalPublicDelegatedPrefixeRequest = src.PatchGlobalPublicDelegatedPrefixeRequest

// A request message for HealthChecks.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchHealthCheckRequest = src.PatchHealthCheckRequest

// A request message for Images.Patch. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchImageRequest = src.PatchImageRequest

// A request message for InstanceGroupManagers.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchInstanceGroupManagerRequest = src.PatchInstanceGroupManagerRequest

// A request message for InstanceSettingsService.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchInstanceSettingRequest = src.PatchInstanceSettingRequest

// A request message for InterconnectAttachments.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchInterconnectAttachmentRequest = src.PatchInterconnectAttachmentRequest

// A request message for Interconnects.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchInterconnectRequest = src.PatchInterconnectRequest

// A request message for NetworkAttachments.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchNetworkAttachmentRequest = src.PatchNetworkAttachmentRequest

// A request message for NetworkEdgeSecurityServices.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchNetworkEdgeSecurityServiceRequest = src.PatchNetworkEdgeSecurityServiceRequest

// A request message for NetworkFirewallPolicies.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchNetworkFirewallPolicyRequest = src.PatchNetworkFirewallPolicyRequest

// A request message for Networks.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchNetworkRequest = src.PatchNetworkRequest

// A request message for NodeGroups.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchNodeGroupRequest = src.PatchNodeGroupRequest

// A request message for PacketMirrorings.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchPacketMirroringRequest = src.PatchPacketMirroringRequest

// A request message for InstanceGroupManagers.PatchPerInstanceConfigs. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchPerInstanceConfigsInstanceGroupManagerRequest = src.PatchPerInstanceConfigsInstanceGroupManagerRequest

// A request message for RegionInstanceGroupManagers.PatchPerInstanceConfigs.
// See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchPerInstanceConfigsRegionInstanceGroupManagerRequest = src.PatchPerInstanceConfigsRegionInstanceGroupManagerRequest

// A request message for PublicAdvertisedPrefixes.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchPublicAdvertisedPrefixeRequest = src.PatchPublicAdvertisedPrefixeRequest

// A request message for PublicDelegatedPrefixes.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchPublicDelegatedPrefixeRequest = src.PatchPublicDelegatedPrefixeRequest

// A request message for RegionAutoscalers.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRegionAutoscalerRequest = src.PatchRegionAutoscalerRequest

// A request message for RegionBackendServices.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRegionBackendServiceRequest = src.PatchRegionBackendServiceRequest

// A request message for RegionHealthChecks.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRegionHealthCheckRequest = src.PatchRegionHealthCheckRequest

// A request message for RegionHealthCheckServices.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRegionHealthCheckServiceRequest = src.PatchRegionHealthCheckServiceRequest

// A request message for RegionInstanceGroupManagers.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRegionInstanceGroupManagerRequest = src.PatchRegionInstanceGroupManagerRequest

// A request message for RegionNetworkFirewallPolicies.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRegionNetworkFirewallPolicyRequest = src.PatchRegionNetworkFirewallPolicyRequest

// A request message for RegionSecurityPolicies.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRegionSecurityPolicyRequest = src.PatchRegionSecurityPolicyRequest

// A request message for RegionSslPolicies.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRegionSslPolicyRequest = src.PatchRegionSslPolicyRequest

// A request message for RegionTargetHttpsProxies.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRegionTargetHttpsProxyRequest = src.PatchRegionTargetHttpsProxyRequest

// A request message for RegionUrlMaps.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRegionUrlMapRequest = src.PatchRegionUrlMapRequest

// A request message for ResourcePolicies.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchResourcePolicyRequest = src.PatchResourcePolicyRequest

// A request message for Routers.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRouterRequest = src.PatchRouterRequest

// A request message for FirewallPolicies.PatchRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRuleFirewallPolicyRequest = src.PatchRuleFirewallPolicyRequest

// A request message for NetworkFirewallPolicies.PatchRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRuleNetworkFirewallPolicyRequest = src.PatchRuleNetworkFirewallPolicyRequest

// A request message for RegionNetworkFirewallPolicies.PatchRule. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRuleRegionNetworkFirewallPolicyRequest = src.PatchRuleRegionNetworkFirewallPolicyRequest

// A request message for RegionSecurityPolicies.PatchRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRuleRegionSecurityPolicyRequest = src.PatchRuleRegionSecurityPolicyRequest

// A request message for SecurityPolicies.PatchRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchRuleSecurityPolicyRequest = src.PatchRuleSecurityPolicyRequest

// A request message for SecurityPolicies.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchSecurityPolicyRequest = src.PatchSecurityPolicyRequest

// A request message for ServiceAttachments.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchServiceAttachmentRequest = src.PatchServiceAttachmentRequest

// A request message for SnapshotSettingsService.Patch. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchSnapshotSettingRequest = src.PatchSnapshotSettingRequest

// A request message for SslPolicies.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchSslPolicyRequest = src.PatchSslPolicyRequest

// A request message for Subnetworks.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchSubnetworkRequest = src.PatchSubnetworkRequest

// A request message for TargetGrpcProxies.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchTargetGrpcProxyRequest = src.PatchTargetGrpcProxyRequest

// A request message for TargetHttpProxies.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchTargetHttpProxyRequest = src.PatchTargetHttpProxyRequest

// A request message for TargetHttpsProxies.Patch. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchTargetHttpsProxyRequest = src.PatchTargetHttpsProxyRequest

// A request message for UrlMaps.Patch. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PatchUrlMapRequest = src.PatchUrlMapRequest

// A matcher for the path portion of the URL. The BackendService from the
// longest-matched rule will serve the URL. If no rule was matched, the default
// service is used.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PathMatcher = src.PathMatcher

// A path-matching rule for a URL. If matched, will use the specified
// BackendService to handle the traffic arriving at this URL.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PathRule = src.PathRule
type PerInstanceConfig = src.PerInstanceConfig

// The status of applying this per-instance configuration on the corresponding
// managed instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PerInstanceConfig_Status = src.PerInstanceConfig_Status

// A request message for Instances.PerformMaintenance. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PerformMaintenanceInstanceRequest = src.PerformMaintenanceInstanceRequest

// A request message for NodeGroups.PerformMaintenance. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PerformMaintenanceNodeGroupRequest = src.PerformMaintenanceNodeGroupRequest

// An Identity and Access Management (IAM) policy, which specifies access
// controls for Google Cloud resources. A `Policy` is a collection of
// `bindings`. A `binding` binds one or more `members`, or principals, to a
// single `role`. Principals can be user accounts, service accounts, Google
// groups, and domains (such as G Suite). A `role` is a named list of
// permissions; each `role` can be an IAM predefined role or a user-created
// custom role. For some types of Google Cloud resources, a `binding` can also
// specify a `condition`, which is a logical expression that allows access to a
// resource only if the expression evaluates to `true`. A condition can add
// constraints based on attributes of the request, the resource, or both. To
// learn which resources support conditions in their IAM policies, see the [IAM
// documentation](https://cloud.google.com/iam/help/conditions/resource-policies).
// **JSON example:** ``` { "bindings": [ { "role":
// "roles/resourcemanager.organizationAdmin", "members": [
// "user:mike@example.com", "group:admins@example.com", "domain:google.com",
// "serviceAccount:my-project-id@appspot.gserviceaccount.com" ] }, { "role":
// "roles/resourcemanager.organizationViewer", "members": [
// "user:eve@example.com" ], "condition": { "title": "expirable access",
// "description": "Does not grant access after Sep 2020", "expression":
// "request.time < timestamp('2020-10-01T00:00:00.000Z')", } } ], "etag":
// "BwWWja0YfJA=", "version": 3 } ``` **YAML example:** ``` bindings: -
// members: - user:mike@example.com - group:admins@example.com -
// domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com
// role: roles/resourcemanager.organizationAdmin - members: -
// user:eve@example.com role: roles/resourcemanager.organizationViewer
// condition: title: expirable access description: Does not grant access after
// Sep 2020 expression: request.time < timestamp('2020-10-01T00:00:00.000Z')
// etag: BwWWja0YfJA= version: 3 ``` For a description of IAM and its features,
// see the [IAM documentation](https://cloud.google.com/iam/docs/).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Policy = src.Policy
type PreconfiguredWafSet = src.PreconfiguredWafSet

// Preserved state for a given instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PreservedState = src.PreservedState
type PreservedStatePreservedDisk = src.PreservedStatePreservedDisk

// These stateful disks will never be deleted during autohealing, update,
// instance recreate operations. This flag is used to configure if the disk
// should be deleted after it is no longer used by the group, e.g. when the
// given instance or the whole MIG is deleted. Note: disks attached in
// READ_ONLY mode cannot be auto-deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PreservedStatePreservedDisk_AutoDelete = src.PreservedStatePreservedDisk_AutoDelete

// The mode in which to attach this disk, either READ_WRITE or READ_ONLY. If
// not specified, the default is to attach the disk in READ_WRITE mode.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PreservedStatePreservedDisk_Mode = src.PreservedStatePreservedDisk_Mode
type PreservedStatePreservedNetworkIp = src.PreservedStatePreservedNetworkIp
type PreservedStatePreservedNetworkIpIpAddress = src.PreservedStatePreservedNetworkIpIpAddress

// These stateful IPs will never be released during autohealing, update or VM
// instance recreate operations. This flag is used to configure if the IP
// reservation should be deleted after it is no longer used by the group, e.g.
// when the given instance or the whole group is deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PreservedStatePreservedNetworkIp_AutoDelete = src.PreservedStatePreservedNetworkIp_AutoDelete

// A request message for Routers.Preview. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PreviewRouterRequest = src.PreviewRouterRequest

// Represents a Project resource. A project is used to organize resources in a
// Google Cloud Platform environment. For more information, read about the
// Resource Hierarchy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Project = src.Project

// [Output Only] The Cloud Armor tier for this project. It can be one of the
// following values: CA_STANDARD, CA_ENTERPRISE_PAYGO. If this field is not
// specified, it is assumed to be CA_STANDARD.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Project_CloudArmorTier = src.Project_CloudArmorTier

// This signifies the default network tier used for configuring resources of
// the project and can only take the following values: PREMIUM, STANDARD.
// Initially the default network tier is PREMIUM.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Project_DefaultNetworkTier = src.Project_DefaultNetworkTier

// [Output Only] Default internal DNS setting used by VMs running in this
// project.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Project_VmDnsSetting = src.Project_VmDnsSetting

// [Output Only] The role this project has in a shared VPC configuration.
// Currently, only projects with the host role, which is specified by the value
// HOST, are differentiated.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Project_XpnProjectStatus = src.Project_XpnProjectStatus
type ProjectsDisableXpnResourceRequest = src.ProjectsDisableXpnResourceRequest
type ProjectsEnableXpnResourceRequest = src.ProjectsEnableXpnResourceRequest
type ProjectsGetXpnResources = src.ProjectsGetXpnResources
type ProjectsListXpnHostsRequest = src.ProjectsListXpnHostsRequest
type ProjectsSetCloudArmorTierRequest = src.ProjectsSetCloudArmorTierRequest

// Managed protection tier to be set.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ProjectsSetCloudArmorTierRequest_CloudArmorTier = src.ProjectsSetCloudArmorTierRequest_CloudArmorTier
type ProjectsSetDefaultNetworkTierRequest = src.ProjectsSetDefaultNetworkTierRequest

// Default network tier to be set.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ProjectsSetDefaultNetworkTierRequest_NetworkTier = src.ProjectsSetDefaultNetworkTierRequest_NetworkTier

// A public advertised prefix represents an aggregated IP prefix or netblock
// which customers bring to cloud. The IP prefix is a single unit of route
// advertisement and is announced globally to the internet.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicAdvertisedPrefix = src.PublicAdvertisedPrefix
type PublicAdvertisedPrefixList = src.PublicAdvertisedPrefixList

// Represents a CIDR range which can be used to assign addresses.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicAdvertisedPrefixPublicDelegatedPrefix = src.PublicAdvertisedPrefixPublicDelegatedPrefix

// [Output Only] The version of BYOIP API.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicAdvertisedPrefix_ByoipApiVersion = src.PublicAdvertisedPrefix_ByoipApiVersion

// Specifies how child public delegated prefix will be scoped. It could be one
// of following values: - `REGIONAL`: The public delegated prefix is regional
// only. The provisioning will take a few minutes. - `GLOBAL`: The public
// delegated prefix is global only. The provisioning will take ~4 weeks. -
// `GLOBAL_AND_REGIONAL` [output only]: The public delegated prefixes is BYOIP
// V1 legacy prefix. This is output only value and no longer supported in BYOIP
// V2.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicAdvertisedPrefix_PdpScope = src.PublicAdvertisedPrefix_PdpScope

// The status of the public advertised prefix. Possible values include: -
// `INITIAL`: RPKI validation is complete. - `PTR_CONFIGURED`: User has
// configured the PTR. - `VALIDATED`: Reverse DNS lookup is successful. -
// `REVERSE_DNS_LOOKUP_FAILED`: Reverse DNS lookup failed. -
// `PREFIX_CONFIGURATION_IN_PROGRESS`: The prefix is being configured. -
// `PREFIX_CONFIGURATION_COMPLETE`: The prefix is fully configured. -
// `PREFIX_REMOVAL_IN_PROGRESS`: The prefix is being removed.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicAdvertisedPrefix_Status = src.PublicAdvertisedPrefix_Status

// A PublicDelegatedPrefix resource represents an IP block within a
// PublicAdvertisedPrefix that is configured within a single cloud scope
// (global or region). IPs in the block can be allocated to resources within
// that scope. Public delegated prefixes may be further broken up into smaller
// IP blocks in the same scope as the parent block.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicDelegatedPrefix = src.PublicDelegatedPrefix
type PublicDelegatedPrefixAggregatedList = src.PublicDelegatedPrefixAggregatedList
type PublicDelegatedPrefixList = src.PublicDelegatedPrefixList

// Represents a sub PublicDelegatedPrefix.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicDelegatedPrefixPublicDelegatedSubPrefix = src.PublicDelegatedPrefixPublicDelegatedSubPrefix

// The PublicDelegatedSubPrefix mode for IPv6 only.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicDelegatedPrefixPublicDelegatedSubPrefix_Mode = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_Mode

// [Output Only] The status of the sub public delegated prefix.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicDelegatedPrefixPublicDelegatedSubPrefix_Status = src.PublicDelegatedPrefixPublicDelegatedSubPrefix_Status

// [Output Only] The version of BYOIP API.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicDelegatedPrefix_ByoipApiVersion = src.PublicDelegatedPrefix_ByoipApiVersion

// The public delegated prefix mode for IPv6 only.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicDelegatedPrefix_Mode = src.PublicDelegatedPrefix_Mode

// [Output Only] The status of the public delegated prefix, which can be one
// of following values: - `INITIALIZING` The public delegated prefix is being
// initialized and addresses cannot be created yet. - `READY_TO_ANNOUNCE` The
// public delegated prefix is a live migration prefix and is active. -
// `ANNOUNCED` The public delegated prefix is active. - `DELETING` The public
// delegated prefix is being deprovsioned.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type PublicDelegatedPrefix_Status = src.PublicDelegatedPrefix_Status
type PublicDelegatedPrefixesScopedList = src.PublicDelegatedPrefixesScopedList

// A quotas entry.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Quota = src.Quota

// Additional details for quota exceeded error for resource quota.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type QuotaExceededInfo = src.QuotaExceededInfo

// Rollout status of the future quota limit.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type QuotaExceededInfo_RolloutStatus = src.QuotaExceededInfo_RolloutStatus

// [Output Only] Warning of fetching the `quotas` field for this region. This
// field is populated only if fetching of the `quotas` field fails.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type QuotaStatusWarning = src.QuotaStatusWarning

// [Output Only] A warning code, if applicable. For example, Compute Engine
// returns NO_RESULTS_ON_PAGE if there are no results in the response.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type QuotaStatusWarning_Code = src.QuotaStatusWarning_Code

// [Output Only] Name of the quota metric.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Quota_Metric = src.Quota_Metric

// The parameters of the raw disk image.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RawDisk = src.RawDisk

// The format used to encode and transmit the block device, which should be
// TAR. This is just a container and transmission format and not a runtime
// format. Provided by the client when the disk image is created.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RawDisk_ContainerType = src.RawDisk_ContainerType

// A request message for InstanceGroupManagers.RecreateInstances. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RecreateInstancesInstanceGroupManagerRequest = src.RecreateInstancesInstanceGroupManagerRequest

// A request message for RegionInstanceGroupManagers.RecreateInstances. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RecreateInstancesRegionInstanceGroupManagerRequest = src.RecreateInstancesRegionInstanceGroupManagerRequest

// Represents a reference to a resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Reference = src.Reference

// Represents a Region resource. A region is a geographical area where a
// resource is located. For more information, read Regions and Zones.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Region = src.Region
type RegionAddressesMoveRequest = src.RegionAddressesMoveRequest

// Contains a list of autoscalers.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionAutoscalerList = src.RegionAutoscalerList
type RegionDiskTypeList = src.RegionDiskTypeList
type RegionDisksAddResourcePoliciesRequest = src.RegionDisksAddResourcePoliciesRequest
type RegionDisksRemoveResourcePoliciesRequest = src.RegionDisksRemoveResourcePoliciesRequest
type RegionDisksResizeRequest = src.RegionDisksResizeRequest
type RegionDisksStartAsyncReplicationRequest = src.RegionDisksStartAsyncReplicationRequest

// Contains a list of InstanceGroup resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionInstanceGroupList = src.RegionInstanceGroupList

// RegionInstanceGroupManagers.deletePerInstanceConfigs
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionInstanceGroupManagerDeleteInstanceConfigReq = src.RegionInstanceGroupManagerDeleteInstanceConfigReq

// Contains a list of managed instance groups.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionInstanceGroupManagerList = src.RegionInstanceGroupManagerList

// RegionInstanceGroupManagers.patchPerInstanceConfigs
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionInstanceGroupManagerPatchInstanceConfigReq = src.RegionInstanceGroupManagerPatchInstanceConfigReq

// RegionInstanceGroupManagers.updatePerInstanceConfigs
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionInstanceGroupManagerUpdateInstanceConfigReq = src.RegionInstanceGroupManagerUpdateInstanceConfigReq
type RegionInstanceGroupManagersAbandonInstancesRequest = src.RegionInstanceGroupManagersAbandonInstancesRequest

// RegionInstanceGroupManagers.applyUpdatesToInstances
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionInstanceGroupManagersApplyUpdatesRequest = src.RegionInstanceGroupManagersApplyUpdatesRequest

// The minimal action that you want to perform on each instance during the
// update: - REPLACE: At minimum, delete the instance and create it again. -
// RESTART: Stop the instance and start it again. - REFRESH: Do not stop the
// instance and limit disruption as much as possible. - NONE: Do not disrupt
// the instance at all. By default, the minimum action is NONE. If your update
// requires a more disruptive action than you set with this flag, the necessary
// action is performed to execute the update. Additional supported values which
// may be not listed in the enum directly due to technical reasons: NONE
// REFRESH REPLACE RESTART
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionInstanceGroupManagersApplyUpdatesRequest_MinimalAction = src.RegionInstanceGroupManagersApplyUpdatesRequest_MinimalAction

// The most disruptive action that you want to perform on each instance during
// the update: - REPLACE: Delete the instance and create it again. - RESTART:
// Stop the instance and start it again. - REFRESH: Do not stop the instance
// and limit disruption as much as possible. - NONE: Do not disrupt the
// instance at all. By default, the most disruptive allowed action is REPLACE.
// If your update requires a more disruptive action than you set with this
// flag, the update request will fail. Additional supported values which may be
// not listed in the enum directly due to technical reasons: NONE REFRESH
// REPLACE RESTART
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionInstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction = src.RegionInstanceGroupManagersApplyUpdatesRequest_MostDisruptiveAllowedAction

// RegionInstanceGroupManagers.createInstances
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionInstanceGroupManagersCreateInstancesRequest = src.RegionInstanceGroupManagersCreateInstancesRequest
type RegionInstanceGroupManagersDeleteInstancesRequest = src.RegionInstanceGroupManagersDeleteInstancesRequest
type RegionInstanceGroupManagersListErrorsResponse = src.RegionInstanceGroupManagersListErrorsResponse
type RegionInstanceGroupManagersListInstanceConfigsResp = src.RegionInstanceGroupManagersListInstanceConfigsResp
type RegionInstanceGroupManagersListInstancesResponse = src.RegionInstanceGroupManagersListInstancesResponse
type RegionInstanceGroupManagersRecreateRequest = src.RegionInstanceGroupManagersRecreateRequest
type RegionInstanceGroupManagersSetTargetPoolsRequest = src.RegionInstanceGroupManagersSetTargetPoolsRequest
type RegionInstanceGroupManagersSetTemplateRequest = src.RegionInstanceGroupManagersSetTemplateRequest
type RegionInstanceGroupsListInstances = src.RegionInstanceGroupsListInstances
type RegionInstanceGroupsListInstancesRequest = src.RegionInstanceGroupsListInstancesRequest

// Instances in which state should be returned. Valid options are: 'ALL',
// 'RUNNING'. By default, it lists all instances.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionInstanceGroupsListInstancesRequest_InstanceState = src.RegionInstanceGroupsListInstancesRequest_InstanceState
type RegionInstanceGroupsSetNamedPortsRequest = src.RegionInstanceGroupsSetNamedPortsRequest

// Contains a list of region resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionList = src.RegionList
type RegionNetworkEndpointGroupsAttachEndpointsRequest = src.RegionNetworkEndpointGroupsAttachEndpointsRequest
type RegionNetworkEndpointGroupsDetachEndpointsRequest = src.RegionNetworkEndpointGroupsDetachEndpointsRequest
type RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse = src.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse
type RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy = src.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

// [Output Only] The type of the firewall policy. Can be one of HIERARCHY,
// NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type = src.RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy_Type
type RegionSetLabelsRequest = src.RegionSetLabelsRequest
type RegionSetPolicyRequest = src.RegionSetPolicyRequest
type RegionTargetHttpsProxiesSetSslCertificatesRequest = src.RegionTargetHttpsProxiesSetSslCertificatesRequest
type RegionUrlMapsValidateRequest = src.RegionUrlMapsValidateRequest

// [Output Only] Status of the region, either UP or DOWN.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Region_Status = src.Region_Status

// A request message for FirewallPolicies.RemoveAssociation. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveAssociationFirewallPolicyRequest = src.RemoveAssociationFirewallPolicyRequest

// A request message for NetworkFirewallPolicies.RemoveAssociation. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveAssociationNetworkFirewallPolicyRequest = src.RemoveAssociationNetworkFirewallPolicyRequest

// A request message for RegionNetworkFirewallPolicies.RemoveAssociation. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveAssociationRegionNetworkFirewallPolicyRequest = src.RemoveAssociationRegionNetworkFirewallPolicyRequest

// A request message for TargetPools.RemoveHealthCheck. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveHealthCheckTargetPoolRequest = src.RemoveHealthCheckTargetPoolRequest

// A request message for TargetPools.RemoveInstance. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveInstanceTargetPoolRequest = src.RemoveInstanceTargetPoolRequest

// A request message for InstanceGroups.RemoveInstances. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveInstancesInstanceGroupRequest = src.RemoveInstancesInstanceGroupRequest

// A request message for Networks.RemovePeering. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemovePeeringNetworkRequest = src.RemovePeeringNetworkRequest

// A request message for Disks.RemoveResourcePolicies. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveResourcePoliciesDiskRequest = src.RemoveResourcePoliciesDiskRequest

// A request message for Instances.RemoveResourcePolicies. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveResourcePoliciesInstanceRequest = src.RemoveResourcePoliciesInstanceRequest

// A request message for RegionDisks.RemoveResourcePolicies. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveResourcePoliciesRegionDiskRequest = src.RemoveResourcePoliciesRegionDiskRequest

// A request message for FirewallPolicies.RemoveRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveRuleFirewallPolicyRequest = src.RemoveRuleFirewallPolicyRequest

// A request message for NetworkFirewallPolicies.RemoveRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveRuleNetworkFirewallPolicyRequest = src.RemoveRuleNetworkFirewallPolicyRequest

// A request message for RegionNetworkFirewallPolicies.RemoveRule. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveRuleRegionNetworkFirewallPolicyRequest = src.RemoveRuleRegionNetworkFirewallPolicyRequest

// A request message for RegionSecurityPolicies.RemoveRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveRuleRegionSecurityPolicyRequest = src.RemoveRuleRegionSecurityPolicyRequest

// A request message for SecurityPolicies.RemoveRule. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RemoveRuleSecurityPolicyRequest = src.RemoveRuleSecurityPolicyRequest

// A policy that specifies how requests intended for the route's backends are
// shadowed to a separate mirrored backend service. The load balancer doesn't
// wait for responses from the shadow service. Before sending traffic to the
// shadow service, the host or authority header is suffixed with -shadow.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RequestMirrorPolicy = src.RequestMirrorPolicy

// Represents a reservation resource. A reservation ensures that capacity is
// held in a specific zone even if the reserved VMs are not running. For more
// information, read Reserving zonal resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Reservation = src.Reservation

// Specifies the reservations that this instance can consume from.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ReservationAffinity = src.ReservationAffinity

// Specifies the type of reservation from which this instance can consume
// resources: ANY_RESERVATION (default), SPECIFIC_RESERVATION, or
// NO_RESERVATION. See Consuming reserved instances for examples.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ReservationAffinity_ConsumeReservationType = src.ReservationAffinity_ConsumeReservationType

// Contains a list of reservations.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ReservationAggregatedList = src.ReservationAggregatedList
type ReservationList = src.ReservationList

// [Output Only] The status of the reservation. - CREATING: Reservation
// resources are being allocated. - READY: Reservation resources have been
// allocated, and the reservation is ready for use. - DELETING: Reservation
// deletion is in progress. - UPDATING: Reservation update is in progress.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Reservation_Status = src.Reservation_Status
type ReservationsResizeRequest = src.ReservationsResizeRequest
type ReservationsScopedList = src.ReservationsScopedList

// A request message for Instances.Reset. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResetInstanceRequest = src.ResetInstanceRequest

// A request message for Disks.Resize. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResizeDiskRequest = src.ResizeDiskRequest

// A request message for InstanceGroupManagers.Resize. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResizeInstanceGroupManagerRequest = src.ResizeInstanceGroupManagerRequest

// A request message for RegionDisks.Resize. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResizeRegionDiskRequest = src.ResizeRegionDiskRequest

// A request message for RegionInstanceGroupManagers.Resize. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResizeRegionInstanceGroupManagerRequest = src.ResizeRegionInstanceGroupManagerRequest

// A request message for Reservations.Resize. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResizeReservationRequest = src.ResizeReservationRequest

// Commitment for a particular resource (a Commitment is composed of one or
// more of these).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourceCommitment = src.ResourceCommitment

// Type of resource for which this commitment applies. Possible values are
// VCPU, MEMORY, LOCAL_SSD, and ACCELERATOR.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourceCommitment_Type = src.ResourceCommitment_Type
type ResourceGroupReference = src.ResourceGroupReference
type ResourcePoliciesScopedList = src.ResourcePoliciesScopedList

// Represents a Resource Policy resource. You can use resource policies to
// schedule actions for some Compute Engine resources. For example, you can use
// them to schedule persistent disk snapshots.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicy = src.ResourcePolicy

// Contains a list of resourcePolicies.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyAggregatedList = src.ResourcePolicyAggregatedList

// Time window specified for daily operations.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyDailyCycle = src.ResourcePolicyDailyCycle

// Resource policy for disk consistency groups.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyDiskConsistencyGroupPolicy = src.ResourcePolicyDiskConsistencyGroupPolicy

// A GroupPlacementPolicy specifies resource placement configuration. It
// specifies the failure bucket separation
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyGroupPlacementPolicy = src.ResourcePolicyGroupPlacementPolicy

// Specifies network collocation
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyGroupPlacementPolicy_Collocation = src.ResourcePolicyGroupPlacementPolicy_Collocation

// Time window specified for hourly operations.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyHourlyCycle = src.ResourcePolicyHourlyCycle

// An InstanceSchedulePolicy specifies when and how frequent certain
// operations are performed on the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyInstanceSchedulePolicy = src.ResourcePolicyInstanceSchedulePolicy

// Schedule for an instance operation.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyInstanceSchedulePolicySchedule = src.ResourcePolicyInstanceSchedulePolicySchedule
type ResourcePolicyList = src.ResourcePolicyList

// Contains output only fields. Use this sub-message for all output fields set
// on ResourcePolicy. The internal structure of this "status" field should
// mimic the structure of ResourcePolicy proto specification.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyResourceStatus = src.ResourcePolicyResourceStatus
type ResourcePolicyResourceStatusInstanceSchedulePolicyStatus = src.ResourcePolicyResourceStatusInstanceSchedulePolicyStatus

// A snapshot schedule policy specifies when and how frequently snapshots are
// to be created for the target disk. Also specifies how many and how long
// these scheduled snapshots should be retained.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicySnapshotSchedulePolicy = src.ResourcePolicySnapshotSchedulePolicy

// Policy for retention of scheduled snapshots.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicySnapshotSchedulePolicyRetentionPolicy = src.ResourcePolicySnapshotSchedulePolicyRetentionPolicy

// Specifies the behavior to apply to scheduled snapshots when the source disk
// is deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete = src.ResourcePolicySnapshotSchedulePolicyRetentionPolicy_OnSourceDiskDelete

// A schedule for disks where the schedueled operations are performed.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicySnapshotSchedulePolicySchedule = src.ResourcePolicySnapshotSchedulePolicySchedule

// Specified snapshot properties for scheduled snapshots created by this
// policy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicySnapshotSchedulePolicySnapshotProperties = src.ResourcePolicySnapshotSchedulePolicySnapshotProperties

// Time window specified for weekly operations.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyWeeklyCycle = src.ResourcePolicyWeeklyCycle
type ResourcePolicyWeeklyCycleDayOfWeek = src.ResourcePolicyWeeklyCycleDayOfWeek

// Defines a schedule that runs on specific days of the week. Specify one or
// more days. The following options are available: MONDAY, TUESDAY, WEDNESDAY,
// THURSDAY, FRIDAY, SATURDAY, SUNDAY.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicyWeeklyCycleDayOfWeek_Day = src.ResourcePolicyWeeklyCycleDayOfWeek_Day

// [Output Only] The status of resource policy creation.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourcePolicy_Status = src.ResourcePolicy_Status

// Contains output only fields. Use this sub-message for actual values set on
// Instance attributes as compared to the value requested by the user (intent)
// in their instance CRUD calls.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResourceStatus = src.ResourceStatus
type ResourceStatusScheduling = src.ResourceStatusScheduling

// A request message for Instances.Resume. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ResumeInstanceRequest = src.ResumeInstanceRequest

// Represents a Route resource. A route defines a path from VM instances in
// the VPC network to a specific destination. This destination can be inside or
// outside the VPC network. For more information, read the Routes overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Route = src.Route
type RouteAsPath = src.RouteAsPath

// [Output Only] The type of the AS Path, which can be one of the following
// values: - 'AS_SET': unordered set of autonomous systems that the route in
// has traversed - 'AS_SEQUENCE': ordered set of autonomous systems that the
// route has traversed - 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous
// Systems in the local confederation that the route has traversed -
// 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local
// confederation that the route has traversed
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouteAsPath_PathSegmentType = src.RouteAsPath_PathSegmentType

// Contains a list of Route resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouteList = src.RouteList

// [Output only] The status of the route.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Route_RouteStatus = src.Route_RouteStatus

// [Output Only] The type of this route, which can be one of the following
// values: - 'TRANSIT' for a transit route that this router learned from
// another Cloud Router and will readvertise to one of its BGP peers - 'SUBNET'
// for a route from a subnet of the VPC - 'BGP' for a route learned from a BGP
// peer of this router - 'STATIC' for a static route
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Route_RouteType = src.Route_RouteType

// Represents a Cloud Router resource. For more information about Cloud
// Router, read the Cloud Router overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Router = src.Router

// Description-tagged IP ranges for the router to advertise.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterAdvertisedIpRange = src.RouterAdvertisedIpRange

// Contains a list of routers.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterAggregatedList = src.RouterAggregatedList
type RouterBgp = src.RouterBgp
type RouterBgpPeer = src.RouterBgpPeer
type RouterBgpPeerBfd = src.RouterBgpPeerBfd

// The BFD session initialization mode for this BGP peer. If set to ACTIVE,
// the Cloud Router will initiate the BFD session for this BGP peer. If set to
// PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD
// session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP
// peer. The default is DISABLED.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterBgpPeerBfd_SessionInitializationMode = src.RouterBgpPeerBfd_SessionInitializationMode
type RouterBgpPeerCustomLearnedIpRange = src.RouterBgpPeerCustomLearnedIpRange

// User-specified flag to indicate which mode to use for advertisement.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterBgpPeer_AdvertiseMode = src.RouterBgpPeer_AdvertiseMode
type RouterBgpPeer_AdvertisedGroups = src.RouterBgpPeer_AdvertisedGroups

// The status of the BGP peer connection. If set to FALSE, any active session
// with the peer is terminated and all associated routing information is
// removed. If set to TRUE, the peer connection can be established with routing
// information. The default is TRUE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterBgpPeer_Enable = src.RouterBgpPeer_Enable

// [Output Only] The resource that configures and manages this BGP peer. -
// MANAGED_BY_USER is the default value and can be managed by you or other
// users - MANAGED_BY_ATTACHMENT is a BGP peer that is configured and managed
// by Cloud Interconnect, specifically by an InterconnectAttachment of type
// PARTNER. Google automatically creates, updates, and deletes this type of BGP
// peer when the PARTNER InterconnectAttachment is created, updated, or
// deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterBgpPeer_ManagementType = src.RouterBgpPeer_ManagementType

// User-specified flag to indicate which mode to use for advertisement. The
// options are DEFAULT or CUSTOM.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterBgp_AdvertiseMode = src.RouterBgp_AdvertiseMode
type RouterBgp_AdvertisedGroups = src.RouterBgp_AdvertisedGroups
type RouterInterface = src.RouterInterface

// IP version of this interface.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterInterface_IpVersion = src.RouterInterface_IpVersion

// [Output Only] The resource that configures and manages this interface. -
// MANAGED_BY_USER is the default value and can be managed directly by users. -
// MANAGED_BY_ATTACHMENT is an interface that is configured and managed by
// Cloud Interconnect, specifically, by an InterconnectAttachment of type
// PARTNER. Google automatically creates, updates, and deletes this type of
// interface when the PARTNER InterconnectAttachment is created, updated, or
// deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterInterface_ManagementType = src.RouterInterface_ManagementType

// Contains a list of Router resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterList = src.RouterList
type RouterMd5AuthenticationKey = src.RouterMd5AuthenticationKey

// Represents a Nat resource. It enables the VMs within the specified
// subnetworks to access Internet without external IP addresses. It specifies a
// list of subnetworks (and the ranges within) that want to use NAT. Customers
// can also provide the external IPs that would be used for NAT. GCP would
// auto-allocate ephemeral IPs if no external IPs are provided.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterNat = src.RouterNat

// Configuration of logging on a NAT.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterNatLogConfig = src.RouterNatLogConfig

// Specify the desired filtering of logs on this NAT. If unspecified, logs are
// exported for all connections handled by this NAT. This option can take one
// of the following values: - ERRORS_ONLY: Export logs only for connection
// failures. - TRANSLATIONS_ONLY: Export logs only for successful connections.
// - ALL: Export logs for all connections, successful and unsuccessful.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterNatLogConfig_Filter = src.RouterNatLogConfig_Filter
type RouterNatRule = src.RouterNatRule
type RouterNatRuleAction = src.RouterNatRuleAction

// Defines the IP ranges that want to use NAT for a subnetwork.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterNatSubnetworkToNat = src.RouterNatSubnetworkToNat
type RouterNatSubnetworkToNat_SourceIpRangesToNat = src.RouterNatSubnetworkToNat_SourceIpRangesToNat

// The network tier to use when automatically reserving NAT IP addresses. Must
// be one of: PREMIUM, STANDARD. If not specified, then the current
// project-level default tier is used.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterNat_AutoNetworkTier = src.RouterNat_AutoNetworkTier
type RouterNat_EndpointTypes = src.RouterNat_EndpointTypes

// Specify the NatIpAllocateOption, which can take one of the following
// values: - MANUAL_ONLY: Uses only Nat IP addresses provided by customers.
// When there are not enough specified Nat IPs, the Nat service fails for new
// VMs. - AUTO_ONLY: Nat IPs are allocated by Google Cloud Platform; customers
// can't specify any Nat IPs. When choosing AUTO_ONLY, then nat_ip should be
// empty.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterNat_NatIpAllocateOption = src.RouterNat_NatIpAllocateOption

// Specify the Nat option, which can take one of the following values: -
// ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork are
// allowed to Nat. - ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary
// IP ranges in every Subnetwork are allowed to Nat. - LIST_OF_SUBNETWORKS: A
// list of Subnetworks are allowed to Nat (specified in the field subnetwork
// below) The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note
// that if this field contains ALL_SUBNETWORKS_ALL_IP_RANGES then there should
// not be any other Router.Nat section in any Router for this network in this
// region.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterNat_SourceSubnetworkIpRangesToNat = src.RouterNat_SourceSubnetworkIpRangesToNat

// Indicates whether this NAT is used for public or private IP translation. If
// unspecified, it defaults to PUBLIC.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterNat_Type = src.RouterNat_Type
type RouterStatus = src.RouterStatus
type RouterStatusBgpPeerStatus = src.RouterStatusBgpPeerStatus

// Status of the BGP peer: {UP, DOWN}
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterStatusBgpPeerStatus_Status = src.RouterStatusBgpPeerStatus_Status

// Indicates why particular status was returned.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterStatusBgpPeerStatus_StatusReason = src.RouterStatusBgpPeerStatus_StatusReason

// Status of a NAT contained in this router.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterStatusNatStatus = src.RouterStatusNatStatus

// Status of a NAT Rule contained in this NAT.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type RouterStatusNatStatusNatRuleStatus = src.RouterStatusNatStatusNatRuleStatus
type RouterStatusResponse = src.RouterStatusResponse
type RoutersPreviewResponse = src.RoutersPreviewResponse
type RoutersScopedList = src.RoutersScopedList
type SSLHealthCheck = src.SSLHealthCheck

// Specifies how a port is selected for health checking. Can be one of the
// following values: USE_FIXED_PORT: Specifies a port number explicitly using
// the port field in the health check. Supported by backend services for
// passthrough load balancers and backend services for proxy load balancers.
// Not supported by target pools. The health check supports all backends
// supported by the backend service provided the backend can be health checked.
// For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network
// endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported.
// USE_SERVING_PORT: Provides an indirect method of specifying the health check
// port by referring to the backend service. Only supported by backend services
// for proxy load balancers. Not supported by target pools. Not supported by
// backend services for passthrough load balancers. Supports all backends that
// can be health checked; for example, GCE_VM_IP_PORT network endpoint groups
// and instance group backends. For GCE_VM_IP_PORT network endpoint group
// backends, the health check uses the port number specified for each endpoint
// in the network endpoint group. For instance group backends, the health check
// uses the port number determined by looking up the backend service's named
// port in the instance group's list of named ports.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SSLHealthCheck_PortSpecification = src.SSLHealthCheck_PortSpecification

// Specifies the type of proxy header to append before sending data to the
// backend, either NONE or PROXY_V1. The default is NONE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SSLHealthCheck_ProxyHeader = src.SSLHealthCheck_ProxyHeader

// DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk
// resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SavedAttachedDisk = src.SavedAttachedDisk

// Specifies the disk interface to use for attaching this disk, which is
// either SCSI or NVME.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SavedAttachedDisk_Interface = src.SavedAttachedDisk_Interface

// The mode in which this disk is attached to the source instance, either
// READ_WRITE or READ_ONLY.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SavedAttachedDisk_Mode = src.SavedAttachedDisk_Mode

// [Output Only] An indicator whether storageBytes is in a stable state or it
// is being adjusted as a result of shared storage reallocation. This status
// can either be UPDATING, meaning the size of the snapshot is being updated,
// or UP_TO_DATE, meaning the size of the snapshot is up-to-date.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SavedAttachedDisk_StorageBytesStatus = src.SavedAttachedDisk_StorageBytesStatus

// Specifies the type of the attached disk, either SCRATCH or PERSISTENT.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SavedAttachedDisk_Type = src.SavedAttachedDisk_Type

// An instance-attached disk resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SavedDisk = src.SavedDisk

// [Output Only] The architecture of the attached disk.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SavedDisk_Architecture = src.SavedDisk_Architecture

// [Output Only] An indicator whether storageBytes is in a stable state or it
// is being adjusted as a result of shared storage reallocation. This status
// can either be UPDATING, meaning the size of the snapshot is being updated,
// or UP_TO_DATE, meaning the size of the snapshot is up-to-date.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SavedDisk_StorageBytesStatus = src.SavedDisk_StorageBytesStatus
type ScalingScheduleStatus = src.ScalingScheduleStatus

// [Output Only] The current state of a scaling schedule.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ScalingScheduleStatus_State = src.ScalingScheduleStatus_State

// Sets the scheduling options for an Instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Scheduling = src.Scheduling

// Node Affinity: the configuration of desired nodes onto which this Instance
// could be scheduled.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SchedulingNodeAffinity = src.SchedulingNodeAffinity

// Defines the operation of node selection. Valid operators are IN for
// affinity and NOT_IN for anti-affinity.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SchedulingNodeAffinity_Operator = src.SchedulingNodeAffinity_Operator

// Defines the behaviour for instances with the instance_termination_action
// STOP.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SchedulingOnInstanceStopAction = src.SchedulingOnInstanceStopAction

// Specifies the termination action for the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Scheduling_InstanceTerminationAction = src.Scheduling_InstanceTerminationAction

// Defines the maintenance behavior for this instance. For standard instances,
// the default behavior is MIGRATE. For preemptible instances, the default and
// only possible behavior is TERMINATE. For more information, see Set VM host
// maintenance policy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Scheduling_OnHostMaintenance = src.Scheduling_OnHostMaintenance

// Specifies the provisioning model of the instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Scheduling_ProvisioningModel = src.Scheduling_ProvisioningModel

// An instance's screenshot.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Screenshot = src.Screenshot
type SecurityPoliciesAggregatedList = src.SecurityPoliciesAggregatedList
type SecurityPoliciesListPreconfiguredExpressionSetsResponse = src.SecurityPoliciesListPreconfiguredExpressionSetsResponse
type SecurityPoliciesScopedList = src.SecurityPoliciesScopedList
type SecurityPoliciesWafConfig = src.SecurityPoliciesWafConfig

// Represents a Google Cloud Armor security policy resource. Only external
// backend services that use load balancers can reference a security policy.
// For more information, see Google Cloud Armor security policy overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicy = src.SecurityPolicy

// Configuration options for Cloud Armor Adaptive Protection (CAAP).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyAdaptiveProtectionConfig = src.SecurityPolicyAdaptiveProtectionConfig

// Configuration options for L7 DDoS detection. This field is only supported
// in Global Security Policies of type CLOUD_ARMOR.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
type SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

// Configurations to specifc granular traffic units processed by Adaptive
// Protection.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig

// Type of this configuration.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_Type = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig_Type

// Rule visibility can be one of the following: STANDARD - opaque rules.
// (default) PREMIUM - transparent rules. This field is only supported in
// Global Security Policies of type CLOUD_ARMOR.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_RuleVisibility = src.SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig_RuleVisibility
type SecurityPolicyAdvancedOptionsConfig = src.SecurityPolicyAdvancedOptionsConfig
type SecurityPolicyAdvancedOptionsConfigJsonCustomConfig = src.SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
type SecurityPolicyAdvancedOptionsConfig_JsonParsing = src.SecurityPolicyAdvancedOptionsConfig_JsonParsing
type SecurityPolicyAdvancedOptionsConfig_LogLevel = src.SecurityPolicyAdvancedOptionsConfig_LogLevel
type SecurityPolicyDdosProtectionConfig = src.SecurityPolicyDdosProtectionConfig
type SecurityPolicyDdosProtectionConfig_DdosProtection = src.SecurityPolicyDdosProtectionConfig_DdosProtection
type SecurityPolicyList = src.SecurityPolicyList
type SecurityPolicyRecaptchaOptionsConfig = src.SecurityPolicyRecaptchaOptionsConfig
type SecurityPolicyReference = src.SecurityPolicyReference

// Represents a rule that describes one or more match conditions along with
// the action to be taken when traffic matches this condition (allow or deny).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyRule = src.SecurityPolicyRule
type SecurityPolicyRuleHttpHeaderAction = src.SecurityPolicyRuleHttpHeaderAction
type SecurityPolicyRuleHttpHeaderActionHttpHeaderOption = src.SecurityPolicyRuleHttpHeaderActionHttpHeaderOption

// Represents a match condition that incoming traffic is evaluated against.
// Exactly one field must be specified.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyRuleMatcher = src.SecurityPolicyRuleMatcher
type SecurityPolicyRuleMatcherConfig = src.SecurityPolicyRuleMatcherConfig
type SecurityPolicyRuleMatcherExprOptions = src.SecurityPolicyRuleMatcherExprOptions
type SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions = src.SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions

// Preconfigured versioned expression. If this field is specified, config must
// also be specified. Available preconfigured expressions along with their
// requirements are: SRC_IPS_V1 - must specify the corresponding src_ip_range
// field in config.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyRuleMatcher_VersionedExpr = src.SecurityPolicyRuleMatcher_VersionedExpr

// Represents a match condition that incoming network traffic is evaluated
// against.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyRuleNetworkMatcher = src.SecurityPolicyRuleNetworkMatcher
type SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch = src.SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch
type SecurityPolicyRulePreconfiguredWafConfig = src.SecurityPolicyRulePreconfiguredWafConfig
type SecurityPolicyRulePreconfiguredWafConfigExclusion = src.SecurityPolicyRulePreconfiguredWafConfigExclusion
type SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams = src.SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams

// The match operator for the field.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op = src.SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams_Op
type SecurityPolicyRuleRateLimitOptions = src.SecurityPolicyRuleRateLimitOptions
type SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig

// Determines the key to enforce the rate_limit_threshold on. Possible values
// are: - ALL: A single rate limit threshold is applied to all the requests
// matching this rule. This is the default value if "enforceOnKeyConfigs" is
// not configured. - IP: The source IP address of the request is the key. Each
// IP has this limit enforced separately. - HTTP_HEADER: The value of the HTTP
// header whose name is configured under "enforceOnKeyName". The key value is
// truncated to the first 128 bytes of the header value. If no such header is
// present in the request, the key type defaults to ALL. - XFF_IP: The first IP
// address (i.e. the originating client IP address) specified in the list of
// IPs under X-Forwarded-For HTTP header. If no such header is present or the
// value is not a valid IP, the key defaults to the source IP address of the
// request i.e. key type IP. - HTTP_COOKIE: The value of the HTTP cookie whose
// name is configured under "enforceOnKeyName". The key value is truncated to
// the first 128 bytes of the cookie value. If no such cookie is present in the
// request, the key type defaults to ALL. - HTTP_PATH: The URL path of the HTTP
// request. The key value is truncated to the first 128 bytes. - SNI: Server
// name indication in the TLS session of the HTTPS request. The key value is
// truncated to the first 128 bytes. The key type defaults to ALL on a HTTP
// session. - REGION_CODE: The country/region from which the request
// originates. - TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client
// connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type
// defaults to ALL. - USER_IP: The IP address of the originating client, which
// is resolved based on "userIpRequestHeaders" configured with the security
// policy. If there is no "userIpRequestHeaders" configuration or an IP address
// cannot be resolved from it, the key type defaults to IP.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_EnforceOnKeyType = src.SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig_EnforceOnKeyType
type SecurityPolicyRuleRateLimitOptionsThreshold = src.SecurityPolicyRuleRateLimitOptionsThreshold

// Determines the key to enforce the rate_limit_threshold on. Possible values
// are: - ALL: A single rate limit threshold is applied to all the requests
// matching this rule. This is the default value if "enforceOnKey" is not
// configured. - IP: The source IP address of the request is the key. Each IP
// has this limit enforced separately. - HTTP_HEADER: The value of the HTTP
// header whose name is configured under "enforceOnKeyName". The key value is
// truncated to the first 128 bytes of the header value. If no such header is
// present in the request, the key type defaults to ALL. - XFF_IP: The first IP
// address (i.e. the originating client IP address) specified in the list of
// IPs under X-Forwarded-For HTTP header. If no such header is present or the
// value is not a valid IP, the key defaults to the source IP address of the
// request i.e. key type IP. - HTTP_COOKIE: The value of the HTTP cookie whose
// name is configured under "enforceOnKeyName". The key value is truncated to
// the first 128 bytes of the cookie value. If no such cookie is present in the
// request, the key type defaults to ALL. - HTTP_PATH: The URL path of the HTTP
// request. The key value is truncated to the first 128 bytes. - SNI: Server
// name indication in the TLS session of the HTTPS request. The key value is
// truncated to the first 128 bytes. The key type defaults to ALL on a HTTP
// session. - REGION_CODE: The country/region from which the request
// originates. - TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client
// connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type
// defaults to ALL. - USER_IP: The IP address of the originating client, which
// is resolved based on "userIpRequestHeaders" configured with the security
// policy. If there is no "userIpRequestHeaders" configuration or an IP address
// cannot be resolved from it, the key type defaults to IP.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyRuleRateLimitOptions_EnforceOnKey = src.SecurityPolicyRuleRateLimitOptions_EnforceOnKey
type SecurityPolicyRuleRedirectOptions = src.SecurityPolicyRuleRedirectOptions

// Type of the redirect action.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyRuleRedirectOptions_Type = src.SecurityPolicyRuleRedirectOptions_Type
type SecurityPolicyUserDefinedField = src.SecurityPolicyUserDefinedField

// The base relative to which 'offset' is measured. Possible values are: -
// IPV4: Points to the beginning of the IPv4 header. - IPV6: Points to the
// beginning of the IPv6 header. - TCP: Points to the beginning of the TCP
// header, skipping over any IPv4 options or IPv6 extension headers. Not
// present for non-first fragments. - UDP: Points to the beginning of the UDP
// header, skipping over any IPv4 options or IPv6 extension headers. Not
// present for non-first fragments. required
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicyUserDefinedField_Base = src.SecurityPolicyUserDefinedField_Base

// The type indicates the intended use of the security policy. - CLOUD_ARMOR:
// Cloud Armor backend security policies can be configured to filter incoming
// HTTP requests targeting backend services. They filter requests before they
// hit the origin servers. - CLOUD_ARMOR_EDGE: Cloud Armor edge security
// policies can be configured to filter incoming HTTP requests targeting
// backend services (including Cloud CDN-enabled) as well as backend buckets
// (Cloud Storage). They filter requests before the request is served from
// Google's cache. - CLOUD_ARMOR_INTERNAL_SERVICE: Cloud Armor internal service
// policies can be configured to filter HTTP requests targeting services
// managed by Traffic Director in a service mesh. They filter requests before
// the request is served from the application. - CLOUD_ARMOR_NETWORK: Cloud
// Armor network policies can be configured to filter packets targeting network
// load balancing resources such as backend services, target pools, target
// instances, and instances with external IPs. They filter requests before the
// request is served from the application. This field can be set only at
// resource creation time.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecurityPolicy_Type = src.SecurityPolicy_Type

// The authentication and authorization settings for a BackendService.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SecuritySettings = src.SecuritySettings

// A request message for Instances.SendDiagnosticInterrupt. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SendDiagnosticInterruptInstanceRequest = src.SendDiagnosticInterruptInstanceRequest

// A response message for Instances.SendDiagnosticInterrupt. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SendDiagnosticInterruptInstanceResponse = src.SendDiagnosticInterruptInstanceResponse

// An instance serial console output.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SerialPortOutput = src.SerialPortOutput
type ServerBinding = src.ServerBinding
type ServerBinding_Type = src.ServerBinding_Type

// A service account.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ServiceAccount = src.ServiceAccount

// Represents a ServiceAttachment resource. A service attachment represents a
// service that a producer has exposed. It encapsulates the load balancer which
// fronts the service runs and a list of NAT IP ranges that the producers uses
// to represent the consumers connecting to the service.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ServiceAttachment = src.ServiceAttachment

// Contains a list of ServiceAttachmentsScopedList.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ServiceAttachmentAggregatedList = src.ServiceAttachmentAggregatedList

// [Output Only] A connection connected to this service attachment.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ServiceAttachmentConnectedEndpoint = src.ServiceAttachmentConnectedEndpoint

// The status of a connected endpoint to this service attachment.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ServiceAttachmentConnectedEndpoint_Status = src.ServiceAttachmentConnectedEndpoint_Status
type ServiceAttachmentConsumerProjectLimit = src.ServiceAttachmentConsumerProjectLimit
type ServiceAttachmentList = src.ServiceAttachmentList

// The connection preference of service attachment. The value can be set to
// ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC service attachment is one that always
// accepts the connection from consumer forwarding rules.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ServiceAttachment_ConnectionPreference = src.ServiceAttachment_ConnectionPreference
type ServiceAttachmentsScopedList = src.ServiceAttachmentsScopedList

// A request message for TargetSslProxies.SetBackendService. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetBackendServiceTargetSslProxyRequest = src.SetBackendServiceTargetSslProxyRequest

// A request message for TargetTcpProxies.SetBackendService. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetBackendServiceTargetTcpProxyRequest = src.SetBackendServiceTargetTcpProxyRequest

// A request message for TargetPools.SetBackup. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetBackupTargetPoolRequest = src.SetBackupTargetPoolRequest

// A request message for TargetHttpsProxies.SetCertificateMap. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetCertificateMapTargetHttpsProxyRequest = src.SetCertificateMapTargetHttpsProxyRequest

// A request message for TargetSslProxies.SetCertificateMap. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetCertificateMapTargetSslProxyRequest = src.SetCertificateMapTargetSslProxyRequest

// A request message for Projects.SetCloudArmorTier. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetCloudArmorTierProjectRequest = src.SetCloudArmorTierProjectRequest
type SetCommonInstanceMetadataOperationMetadata = src.SetCommonInstanceMetadataOperationMetadata
type SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

// [Output Only] Status of the action, which can be one of the following:
// `PROPAGATING`, `PROPAGATED`, `ABANDONED`, `FAILED`, or `DONE`.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State = src.SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo_State

// A request message for Projects.SetCommonInstanceMetadata. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetCommonInstanceMetadataProjectRequest = src.SetCommonInstanceMetadataProjectRequest

// A request message for Projects.SetDefaultNetworkTier. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetDefaultNetworkTierProjectRequest = src.SetDefaultNetworkTierProjectRequest

// A request message for Instances.SetDeletionProtection. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetDeletionProtectionInstanceRequest = src.SetDeletionProtectionInstanceRequest

// A request message for Instances.SetDiskAutoDelete. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetDiskAutoDeleteInstanceRequest = src.SetDiskAutoDeleteInstanceRequest

// A request message for BackendBuckets.SetEdgeSecurityPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetEdgeSecurityPolicyBackendBucketRequest = src.SetEdgeSecurityPolicyBackendBucketRequest

// A request message for BackendServices.SetEdgeSecurityPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetEdgeSecurityPolicyBackendServiceRequest = src.SetEdgeSecurityPolicyBackendServiceRequest

// A request message for BackendBuckets.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyBackendBucketRequest = src.SetIamPolicyBackendBucketRequest

// A request message for BackendServices.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyBackendServiceRequest = src.SetIamPolicyBackendServiceRequest

// A request message for Disks.SetIamPolicy. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyDiskRequest = src.SetIamPolicyDiskRequest

// A request message for FirewallPolicies.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyFirewallPolicyRequest = src.SetIamPolicyFirewallPolicyRequest

// A request message for Images.SetIamPolicy. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyImageRequest = src.SetIamPolicyImageRequest

// A request message for Instances.SetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyInstanceRequest = src.SetIamPolicyInstanceRequest

// A request message for InstanceTemplates.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyInstanceTemplateRequest = src.SetIamPolicyInstanceTemplateRequest

// A request message for InstantSnapshots.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyInstantSnapshotRequest = src.SetIamPolicyInstantSnapshotRequest

// A request message for Licenses.SetIamPolicy. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyLicenseRequest = src.SetIamPolicyLicenseRequest

// A request message for MachineImages.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyMachineImageRequest = src.SetIamPolicyMachineImageRequest

// A request message for NetworkAttachments.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyNetworkAttachmentRequest = src.SetIamPolicyNetworkAttachmentRequest

// A request message for NetworkFirewallPolicies.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyNetworkFirewallPolicyRequest = src.SetIamPolicyNetworkFirewallPolicyRequest

// A request message for NodeGroups.SetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyNodeGroupRequest = src.SetIamPolicyNodeGroupRequest

// A request message for NodeTemplates.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyNodeTemplateRequest = src.SetIamPolicyNodeTemplateRequest

// A request message for RegionBackendServices.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyRegionBackendServiceRequest = src.SetIamPolicyRegionBackendServiceRequest

// A request message for RegionDisks.SetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyRegionDiskRequest = src.SetIamPolicyRegionDiskRequest

// A request message for RegionInstantSnapshots.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyRegionInstantSnapshotRequest = src.SetIamPolicyRegionInstantSnapshotRequest

// A request message for RegionNetworkFirewallPolicies.SetIamPolicy. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyRegionNetworkFirewallPolicyRequest = src.SetIamPolicyRegionNetworkFirewallPolicyRequest

// A request message for Reservations.SetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyReservationRequest = src.SetIamPolicyReservationRequest

// A request message for ResourcePolicies.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyResourcePolicyRequest = src.SetIamPolicyResourcePolicyRequest

// A request message for ServiceAttachments.SetIamPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyServiceAttachmentRequest = src.SetIamPolicyServiceAttachmentRequest

// A request message for Snapshots.SetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicySnapshotRequest = src.SetIamPolicySnapshotRequest

// A request message for StoragePools.SetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicyStoragePoolRequest = src.SetIamPolicyStoragePoolRequest

// A request message for Subnetworks.SetIamPolicy. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetIamPolicySubnetworkRequest = src.SetIamPolicySubnetworkRequest

// A request message for InstanceGroupManagers.SetInstanceTemplate. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetInstanceTemplateInstanceGroupManagerRequest = src.SetInstanceTemplateInstanceGroupManagerRequest

// A request message for RegionInstanceGroupManagers.SetInstanceTemplate. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetInstanceTemplateRegionInstanceGroupManagerRequest = src.SetInstanceTemplateRegionInstanceGroupManagerRequest

// A request message for Addresses.SetLabels. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsAddressRequest = src.SetLabelsAddressRequest

// A request message for Disks.SetLabels. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsDiskRequest = src.SetLabelsDiskRequest

// A request message for ExternalVpnGateways.SetLabels. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsExternalVpnGatewayRequest = src.SetLabelsExternalVpnGatewayRequest

// A request message for ForwardingRules.SetLabels. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsForwardingRuleRequest = src.SetLabelsForwardingRuleRequest

// A request message for GlobalAddresses.SetLabels. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsGlobalAddressRequest = src.SetLabelsGlobalAddressRequest

// A request message for GlobalForwardingRules.SetLabels. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsGlobalForwardingRuleRequest = src.SetLabelsGlobalForwardingRuleRequest

// A request message for Images.SetLabels. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsImageRequest = src.SetLabelsImageRequest

// A request message for Instances.SetLabels. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsInstanceRequest = src.SetLabelsInstanceRequest

// A request message for InstantSnapshots.SetLabels. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsInstantSnapshotRequest = src.SetLabelsInstantSnapshotRequest

// A request message for InterconnectAttachments.SetLabels. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsInterconnectAttachmentRequest = src.SetLabelsInterconnectAttachmentRequest

// A request message for Interconnects.SetLabels. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsInterconnectRequest = src.SetLabelsInterconnectRequest

// A request message for RegionDisks.SetLabels. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsRegionDiskRequest = src.SetLabelsRegionDiskRequest

// A request message for RegionInstantSnapshots.SetLabels. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsRegionInstantSnapshotRequest = src.SetLabelsRegionInstantSnapshotRequest

// A request message for SecurityPolicies.SetLabels. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsSecurityPolicyRequest = src.SetLabelsSecurityPolicyRequest

// A request message for Snapshots.SetLabels. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsSnapshotRequest = src.SetLabelsSnapshotRequest

// A request message for TargetVpnGateways.SetLabels. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsTargetVpnGatewayRequest = src.SetLabelsTargetVpnGatewayRequest

// A request message for VpnGateways.SetLabels. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsVpnGatewayRequest = src.SetLabelsVpnGatewayRequest

// A request message for VpnTunnels.SetLabels. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetLabelsVpnTunnelRequest = src.SetLabelsVpnTunnelRequest

// A request message for Instances.SetMachineResources. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetMachineResourcesInstanceRequest = src.SetMachineResourcesInstanceRequest

// A request message for Instances.SetMachineType. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetMachineTypeInstanceRequest = src.SetMachineTypeInstanceRequest

// A request message for Instances.SetMetadata. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetMetadataInstanceRequest = src.SetMetadataInstanceRequest

// A request message for Instances.SetMinCpuPlatform. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetMinCpuPlatformInstanceRequest = src.SetMinCpuPlatformInstanceRequest

// A request message for Instances.SetName. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetNameInstanceRequest = src.SetNameInstanceRequest

// A request message for InstanceGroups.SetNamedPorts. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetNamedPortsInstanceGroupRequest = src.SetNamedPortsInstanceGroupRequest

// A request message for RegionInstanceGroups.SetNamedPorts. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetNamedPortsRegionInstanceGroupRequest = src.SetNamedPortsRegionInstanceGroupRequest

// A request message for NodeGroups.SetNodeTemplate. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetNodeTemplateNodeGroupRequest = src.SetNodeTemplateNodeGroupRequest

// A request message for Subnetworks.SetPrivateIpGoogleAccess. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetPrivateIpGoogleAccessSubnetworkRequest = src.SetPrivateIpGoogleAccessSubnetworkRequest

// A request message for TargetSslProxies.SetProxyHeader. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetProxyHeaderTargetSslProxyRequest = src.SetProxyHeaderTargetSslProxyRequest

// A request message for TargetTcpProxies.SetProxyHeader. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetProxyHeaderTargetTcpProxyRequest = src.SetProxyHeaderTargetTcpProxyRequest

// A request message for TargetHttpsProxies.SetQuicOverride. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetQuicOverrideTargetHttpsProxyRequest = src.SetQuicOverrideTargetHttpsProxyRequest

// A request message for Instances.SetScheduling. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSchedulingInstanceRequest = src.SetSchedulingInstanceRequest

// A request message for BackendServices.SetSecurityPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSecurityPolicyBackendServiceRequest = src.SetSecurityPolicyBackendServiceRequest

// A request message for Instances.SetSecurityPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSecurityPolicyInstanceRequest = src.SetSecurityPolicyInstanceRequest

// A request message for RegionBackendServices.SetSecurityPolicy. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSecurityPolicyRegionBackendServiceRequest = src.SetSecurityPolicyRegionBackendServiceRequest

// A request message for TargetInstances.SetSecurityPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSecurityPolicyTargetInstanceRequest = src.SetSecurityPolicyTargetInstanceRequest

// A request message for TargetPools.SetSecurityPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSecurityPolicyTargetPoolRequest = src.SetSecurityPolicyTargetPoolRequest

// A request message for Instances.SetServiceAccount. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetServiceAccountInstanceRequest = src.SetServiceAccountInstanceRequest

// A request message for Instances.SetShieldedInstanceIntegrityPolicy. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetShieldedInstanceIntegrityPolicyInstanceRequest = src.SetShieldedInstanceIntegrityPolicyInstanceRequest

// A request message for RegionTargetHttpsProxies.SetSslCertificates. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSslCertificatesRegionTargetHttpsProxyRequest = src.SetSslCertificatesRegionTargetHttpsProxyRequest

// A request message for TargetHttpsProxies.SetSslCertificates. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSslCertificatesTargetHttpsProxyRequest = src.SetSslCertificatesTargetHttpsProxyRequest

// A request message for TargetSslProxies.SetSslCertificates. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSslCertificatesTargetSslProxyRequest = src.SetSslCertificatesTargetSslProxyRequest

// A request message for TargetHttpsProxies.SetSslPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSslPolicyTargetHttpsProxyRequest = src.SetSslPolicyTargetHttpsProxyRequest

// A request message for TargetSslProxies.SetSslPolicy. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetSslPolicyTargetSslProxyRequest = src.SetSslPolicyTargetSslProxyRequest

// A request message for Instances.SetTags. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetTagsInstanceRequest = src.SetTagsInstanceRequest

// A request message for ForwardingRules.SetTarget. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetTargetForwardingRuleRequest = src.SetTargetForwardingRuleRequest

// A request message for GlobalForwardingRules.SetTarget. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetTargetGlobalForwardingRuleRequest = src.SetTargetGlobalForwardingRuleRequest

// A request message for InstanceGroupManagers.SetTargetPools. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetTargetPoolsInstanceGroupManagerRequest = src.SetTargetPoolsInstanceGroupManagerRequest

// A request message for RegionInstanceGroupManagers.SetTargetPools. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetTargetPoolsRegionInstanceGroupManagerRequest = src.SetTargetPoolsRegionInstanceGroupManagerRequest

// A request message for RegionTargetHttpProxies.SetUrlMap. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetUrlMapRegionTargetHttpProxyRequest = src.SetUrlMapRegionTargetHttpProxyRequest

// A request message for RegionTargetHttpsProxies.SetUrlMap. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetUrlMapRegionTargetHttpsProxyRequest = src.SetUrlMapRegionTargetHttpsProxyRequest

// A request message for TargetHttpProxies.SetUrlMap. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetUrlMapTargetHttpProxyRequest = src.SetUrlMapTargetHttpProxyRequest

// A request message for TargetHttpsProxies.SetUrlMap. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetUrlMapTargetHttpsProxyRequest = src.SetUrlMapTargetHttpsProxyRequest

// A request message for Projects.SetUsageExportBucket. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SetUsageExportBucketProjectRequest = src.SetUsageExportBucketProjectRequest

// The share setting for reservations and sole tenancy node groups.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ShareSettings = src.ShareSettings

// Config for each project in the share settings.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ShareSettingsProjectConfig = src.ShareSettingsProjectConfig

// Type of sharing for this shared-reservation
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ShareSettings_ShareType = src.ShareSettings_ShareType

// A set of Shielded Instance options.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ShieldedInstanceConfig = src.ShieldedInstanceConfig

// A Shielded Instance Identity.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ShieldedInstanceIdentity = src.ShieldedInstanceIdentity

// A Shielded Instance Identity Entry.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ShieldedInstanceIdentityEntry = src.ShieldedInstanceIdentityEntry

// The policy describes the baseline against which Instance boot integrity is
// measured.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ShieldedInstanceIntegrityPolicy = src.ShieldedInstanceIntegrityPolicy

// Represents a customer-supplied Signing Key used by Cloud CDN Signed URLs
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SignedUrlKey = src.SignedUrlKey

// A request message for Instances.SimulateMaintenanceEvent. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SimulateMaintenanceEventInstanceRequest = src.SimulateMaintenanceEventInstanceRequest

// A request message for NodeGroups.SimulateMaintenanceEvent. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SimulateMaintenanceEventNodeGroupRequest = src.SimulateMaintenanceEventNodeGroupRequest

// Represents a Persistent Disk Snapshot resource. You can use snapshots to
// back up data on a regular interval. For more information, read Creating
// persistent disk snapshots.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Snapshot = src.Snapshot

// Contains a list of Snapshot resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SnapshotList = src.SnapshotList
type SnapshotSettings = src.SnapshotSettings
type SnapshotSettingsStorageLocationSettings = src.SnapshotSettingsStorageLocationSettings

// A structure for specifying storage locations.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SnapshotSettingsStorageLocationSettingsStorageLocationPreference = src.SnapshotSettingsStorageLocationSettingsStorageLocationPreference

// The chosen location policy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SnapshotSettingsStorageLocationSettings_Policy = src.SnapshotSettingsStorageLocationSettings_Policy

// [Output Only] The architecture of the snapshot. Valid values are ARM64 or
// X86_64.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Snapshot_Architecture = src.Snapshot_Architecture

// Indicates the type of the snapshot.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Snapshot_SnapshotType = src.Snapshot_SnapshotType

// [Output Only] The status of the snapshot. This can be CREATING, DELETING,
// FAILED, READY, or UPLOADING.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Snapshot_Status = src.Snapshot_Status

// [Output Only] An indicator whether storageBytes is in a stable state or it
// is being adjusted as a result of shared storage reallocation. This status
// can either be UPDATING, meaning the size of the snapshot is being updated,
// or UP_TO_DATE, meaning the size of the snapshot is up-to-date.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Snapshot_StorageBytesStatus = src.Snapshot_StorageBytesStatus
type SourceDiskEncryptionKey = src.SourceDiskEncryptionKey

// A specification of the parameters to use when creating the instance
// template from a source instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SourceInstanceParams = src.SourceInstanceParams

// DEPRECATED: Please use compute#instanceProperties instead. New properties
// will not be added to this field.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SourceInstanceProperties = src.SourceInstanceProperties

// KeyRevocationActionType of the instance. Supported options are "STOP" and
// "NONE". The default value is "NONE" if it is not specified.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SourceInstanceProperties_KeyRevocationActionType = src.SourceInstanceProperties_KeyRevocationActionType

// Represents an SSL certificate resource. Google Compute Engine has two SSL
// certificate resources: *
// [Global](/compute/docs/reference/rest/v1/sslCertificates) *
// [Regional](/compute/docs/reference/rest/v1/regionSslCertificates) The global
// SSL certificates (sslCertificates) are used by: - Global external
// Application Load Balancers - Classic Application Load Balancers - Proxy
// Network Load Balancers (with target SSL proxies) The regional SSL
// certificates (regionSslCertificates) are used by: - Regional external
// Application Load Balancers - Regional internal Application Load Balancers
// Optionally, certificate file contents that you upload can contain a set of
// up to five PEM-encoded certificates. The API call creates an object
// (sslCertificate) that holds this data. You can use SSL keys and certificates
// to secure connections to a load balancer. For more information, read
// Creating and using SSL certificates, SSL certificates quotas and limits, and
// Troubleshooting SSL certificates.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SslCertificate = src.SslCertificate
type SslCertificateAggregatedList = src.SslCertificateAggregatedList

// Contains a list of SslCertificate resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SslCertificateList = src.SslCertificateList

// Configuration and status of a managed SSL certificate.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SslCertificateManagedSslCertificate = src.SslCertificateManagedSslCertificate

// [Output only] Status of the managed certificate resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SslCertificateManagedSslCertificate_Status = src.SslCertificateManagedSslCertificate_Status

// Configuration and status of a self-managed SSL certificate.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SslCertificateSelfManagedSslCertificate = src.SslCertificateSelfManagedSslCertificate

// (Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or
// "MANAGED". If not specified, the certificate is self-managed and the fields
// certificate and private_key are used.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SslCertificate_Type = src.SslCertificate_Type
type SslCertificatesScopedList = src.SslCertificatesScopedList
type SslPoliciesAggregatedList = src.SslPoliciesAggregatedList
type SslPoliciesList = src.SslPoliciesList
type SslPoliciesListAvailableFeaturesResponse = src.SslPoliciesListAvailableFeaturesResponse
type SslPoliciesScopedList = src.SslPoliciesScopedList

// Represents an SSL Policy resource. Use SSL policies to control SSL
// features, such as versions and cipher suites, that are offered by
// Application Load Balancers and proxy Network Load Balancers. For more
// information, read SSL policies overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SslPolicy = src.SslPolicy
type SslPolicyReference = src.SslPolicyReference

// The minimum version of SSL protocol that can be used by the clients to
// establish a connection with the load balancer. This can be one of TLS_1_0,
// TLS_1_1, TLS_1_2.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SslPolicy_MinTlsVersion = src.SslPolicy_MinTlsVersion

// Profile specifies the set of SSL features that can be used by the load
// balancer when negotiating SSL with clients. This can be one of COMPATIBLE,
// MODERN, RESTRICTED, or CUSTOM. If using CUSTOM, the set of SSL features to
// enable must be specified in the customFeatures field.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SslPolicy_Profile = src.SslPolicy_Profile

// A request message for Disks.StartAsyncReplication. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StartAsyncReplicationDiskRequest = src.StartAsyncReplicationDiskRequest

// A request message for RegionDisks.StartAsyncReplication. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StartAsyncReplicationRegionDiskRequest = src.StartAsyncReplicationRegionDiskRequest

// A request message for Instances.Start. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StartInstanceRequest = src.StartInstanceRequest

// A request message for Instances.StartWithEncryptionKey. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StartWithEncryptionKeyInstanceRequest = src.StartWithEncryptionKeyInstanceRequest
type StatefulPolicy = src.StatefulPolicy

// Configuration of preserved resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StatefulPolicyPreservedState = src.StatefulPolicyPreservedState
type StatefulPolicyPreservedStateDiskDevice = src.StatefulPolicyPreservedStateDiskDevice

// These stateful disks will never be deleted during autohealing, update or VM
// instance recreate operations. This flag is used to configure if the disk
// should be deleted after it is no longer used by the group, e.g. when the
// given instance or the whole group is deleted. Note: disks attached in
// READ_ONLY mode cannot be auto-deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StatefulPolicyPreservedStateDiskDevice_AutoDelete = src.StatefulPolicyPreservedStateDiskDevice_AutoDelete
type StatefulPolicyPreservedStateNetworkIp = src.StatefulPolicyPreservedStateNetworkIp

// These stateful IPs will never be released during autohealing, update or VM
// instance recreate operations. This flag is used to configure if the IP
// reservation should be deleted after it is no longer used by the group, e.g.
// when the given instance or the whole group is deleted.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StatefulPolicyPreservedStateNetworkIp_AutoDelete = src.StatefulPolicyPreservedStateNetworkIp_AutoDelete

// The `Status` type defines a logical error model that is suitable for
// different programming environments, including REST APIs and RPC APIs. It is
// used by [gRPC](https://github.com/grpc). Each `Status` message contains
// three pieces of data: error code, error message, and error details. You can
// find out more about this error model and how to work with it in the [API
// Design Guide](https://cloud.google.com/apis/design/errors).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Status = src.Status

// A request message for Disks.StopAsyncReplication. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StopAsyncReplicationDiskRequest = src.StopAsyncReplicationDiskRequest

// A request message for RegionDisks.StopAsyncReplication. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StopAsyncReplicationRegionDiskRequest = src.StopAsyncReplicationRegionDiskRequest

// A request message for Disks.StopGroupAsyncReplication. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StopGroupAsyncReplicationDiskRequest = src.StopGroupAsyncReplicationDiskRequest

// A request message for RegionDisks.StopGroupAsyncReplication. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StopGroupAsyncReplicationRegionDiskRequest = src.StopGroupAsyncReplicationRegionDiskRequest

// A request message for Instances.Stop. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StopInstanceRequest = src.StopInstanceRequest

// Represents a zonal storage pool resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StoragePool = src.StoragePool
type StoragePoolAggregatedList = src.StoragePoolAggregatedList
type StoragePoolDisk = src.StoragePoolDisk

// [Output Only] The disk status.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StoragePoolDisk_Status = src.StoragePoolDisk_Status

// A list of StoragePool resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StoragePoolList = src.StoragePoolList
type StoragePoolListDisks = src.StoragePoolListDisks

// [Output Only] Contains output only fields.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StoragePoolResourceStatus = src.StoragePoolResourceStatus
type StoragePoolType = src.StoragePoolType
type StoragePoolTypeAggregatedList = src.StoragePoolTypeAggregatedList

// Contains a list of storage pool types.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StoragePoolTypeList = src.StoragePoolTypeList
type StoragePoolTypesScopedList = src.StoragePoolTypesScopedList

// Provisioning type of the byte capacity of the pool. Additional supported
// values which may be not listed in the enum directly due to technical
// reasons: ADVANCED STANDARD UNSPECIFIED
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StoragePool_CapacityProvisioningType = src.StoragePool_CapacityProvisioningType

// Provisioning type of the performance-related parameters of the pool, such
// as throughput and IOPS. Additional supported values which may be not listed
// in the enum directly due to technical reasons: ADVANCED STANDARD UNSPECIFIED
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StoragePool_PerformanceProvisioningType = src.StoragePool_PerformanceProvisioningType

// [Output Only] The status of storage pool creation. - CREATING: Storage pool
// is provisioning. storagePool. - FAILED: Storage pool creation failed. -
// READY: Storage pool is ready for use. - DELETING: Storage pool is deleting.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type StoragePool_State = src.StoragePool_State
type StoragePoolsScopedList = src.StoragePoolsScopedList

// Represents a Subnetwork resource. A subnetwork (also known as a subnet) is
// a logical partition of a Virtual Private Cloud network with one primary IP
// range and zero or more secondary IP ranges. For more information, read
// Virtual Private Cloud (VPC) Network.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Subnetwork = src.Subnetwork
type SubnetworkAggregatedList = src.SubnetworkAggregatedList

// Contains a list of Subnetwork resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SubnetworkList = src.SubnetworkList

// The available logging options for this subnetwork.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SubnetworkLogConfig = src.SubnetworkLogConfig

// Can only be specified if VPC flow logging for this subnetwork is enabled.
// Toggles the aggregation interval for collecting flow logs. Increasing the
// interval time will reduce the amount of generated flow logs for long lasting
// connections. Default is an interval of 5 seconds per connection.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SubnetworkLogConfig_AggregationInterval = src.SubnetworkLogConfig_AggregationInterval

// Can only be specified if VPC flow logs for this subnetwork is enabled.
// Configures whether all, none or a subset of metadata fields should be added
// to the reported VPC flow logs. Default is EXCLUDE_ALL_METADATA.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SubnetworkLogConfig_Metadata = src.SubnetworkLogConfig_Metadata

// Represents a secondary IP range of a subnetwork.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SubnetworkSecondaryRange = src.SubnetworkSecondaryRange

// The access type of IPv6 address this subnet holds. It's immutable and can
// only be specified during creation or the first time the subnet is updated
// into IPV4_IPV6 dual stack.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Subnetwork_Ipv6AccessType = src.Subnetwork_Ipv6AccessType

// This field is for internal use. This field can be both set at resource
// creation time and updated using patch.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Subnetwork_PrivateIpv6GoogleAccess = src.Subnetwork_PrivateIpv6GoogleAccess

// The purpose of the resource. This field can be either PRIVATE,
// GLOBAL_MANAGED_PROXY, REGIONAL_MANAGED_PROXY, PRIVATE_SERVICE_CONNECT, or
// PRIVATE is the default purpose for user-created subnets or subnets that are
// automatically created in auto mode networks. Subnets with purpose set to
// GLOBAL_MANAGED_PROXY or REGIONAL_MANAGED_PROXY are user-created subnetworks
// that are reserved for Envoy-based load balancers. A subnet with purpose set
// to PRIVATE_SERVICE_CONNECT is used to publish services using Private Service
// Connect. If unspecified, the subnet purpose defaults to PRIVATE. The
// enableFlowLogs field isn't supported if the subnet purpose field is set to
// GLOBAL_MANAGED_PROXY or REGIONAL_MANAGED_PROXY.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Subnetwork_Purpose = src.Subnetwork_Purpose

// The role of subnetwork. Currently, this field is only used when purpose is
// set to GLOBAL_MANAGED_PROXY or REGIONAL_MANAGED_PROXY. The value can be set
// to ACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being
// used for Envoy-based load balancers in a region. A BACKUP subnetwork is one
// that is ready to be promoted to ACTIVE or is currently draining. This field
// can be updated with a patch request.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Subnetwork_Role = src.Subnetwork_Role

// The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet
// are assigned IPv4 addresses only. If set to IPV4_IPV6, new VMs in the subnet
// can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is
// used. This field can be both set at resource creation time and updated using
// patch.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Subnetwork_StackType = src.Subnetwork_StackType

// [Output Only] The state of the subnetwork, which can be one of the
// following values: READY: Subnetwork is created and ready to use DRAINING:
// only applicable to subnetworks that have the purpose set to
// INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to the load
// balancer are being drained. A subnetwork that is draining cannot be used or
// modified until it reaches a status of READY
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Subnetwork_State = src.Subnetwork_State
type SubnetworksExpandIpCidrRangeRequest = src.SubnetworksExpandIpCidrRangeRequest
type SubnetworksScopedList = src.SubnetworksScopedList
type SubnetworksSetPrivateIpGoogleAccessRequest = src.SubnetworksSetPrivateIpGoogleAccessRequest

// Subsetting configuration for this BackendService. Currently this is
// applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load
// balancing and Traffic Director.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Subsetting = src.Subsetting
type Subsetting_Policy = src.Subsetting_Policy

// A request message for Instances.Suspend. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SuspendInstanceRequest = src.SuspendInstanceRequest

// A request message for Networks.SwitchToCustomMode. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type SwitchToCustomModeNetworkRequest = src.SwitchToCustomModeNetworkRequest
type TCPHealthCheck = src.TCPHealthCheck

// Specifies how a port is selected for health checking. Can be one of the
// following values: USE_FIXED_PORT: Specifies a port number explicitly using
// the port field in the health check. Supported by backend services for
// passthrough load balancers and backend services for proxy load balancers.
// Not supported by target pools. The health check supports all backends
// supported by the backend service provided the backend can be health checked.
// For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network
// endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported.
// USE_SERVING_PORT: Provides an indirect method of specifying the health check
// port by referring to the backend service. Only supported by backend services
// for proxy load balancers. Not supported by target pools. Not supported by
// backend services for passthrough load balancers. Supports all backends that
// can be health checked; for example, GCE_VM_IP_PORT network endpoint groups
// and instance group backends. For GCE_VM_IP_PORT network endpoint group
// backends, the health check uses the port number specified for each endpoint
// in the network endpoint group. For instance group backends, the health check
// uses the port number determined by looking up the backend service's named
// port in the instance group's list of named ports.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TCPHealthCheck_PortSpecification = src.TCPHealthCheck_PortSpecification

// Specifies the type of proxy header to append before sending data to the
// backend, either NONE or PROXY_V1. The default is NONE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TCPHealthCheck_ProxyHeader = src.TCPHealthCheck_ProxyHeader

// A set of instance tags.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Tags = src.Tags

// Represents a Target gRPC Proxy resource. A target gRPC proxy is a component
// of load balancers intended for load balancing gRPC traffic. Only global
// forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can
// reference a target gRPC proxy. The target gRPC Proxy references a URL map
// that specifies how traffic is routed to gRPC backend services.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetGrpcProxy = src.TargetGrpcProxy
type TargetGrpcProxyList = src.TargetGrpcProxyList
type TargetHttpProxiesScopedList = src.TargetHttpProxiesScopedList

// Represents a Target HTTP Proxy resource. Google Compute Engine has two
// Target HTTP Proxy resources: *
// [Global](/compute/docs/reference/rest/v1/targetHttpProxies) *
// [Regional](/compute/docs/reference/rest/v1/regionTargetHttpProxies) A target
// HTTP proxy is a component of Google Cloud HTTP load balancers. *
// targetHttpProxies are used by global external Application Load Balancers,
// classic Application Load Balancers, cross-region internal Application Load
// Balancers, and Traffic Director. * regionTargetHttpProxies are used by
// regional internal Application Load Balancers and regional external
// Application Load Balancers. Forwarding rules reference a target HTTP proxy,
// and the target proxy then references a URL map. For more information, read
// Using Target Proxies and Forwarding rule concepts.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetHttpProxy = src.TargetHttpProxy
type TargetHttpProxyAggregatedList = src.TargetHttpProxyAggregatedList

// A list of TargetHttpProxy resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetHttpProxyList = src.TargetHttpProxyList
type TargetHttpsProxiesScopedList = src.TargetHttpsProxiesScopedList
type TargetHttpsProxiesSetCertificateMapRequest = src.TargetHttpsProxiesSetCertificateMapRequest
type TargetHttpsProxiesSetQuicOverrideRequest = src.TargetHttpsProxiesSetQuicOverrideRequest

// QUIC policy for the TargetHttpsProxy resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride = src.TargetHttpsProxiesSetQuicOverrideRequest_QuicOverride
type TargetHttpsProxiesSetSslCertificatesRequest = src.TargetHttpsProxiesSetSslCertificatesRequest

// Represents a Target HTTPS Proxy resource. Google Compute Engine has two
// Target HTTPS Proxy resources: *
// [Global](/compute/docs/reference/rest/v1/targetHttpsProxies) *
// [Regional](/compute/docs/reference/rest/v1/regionTargetHttpsProxies) A
// target HTTPS proxy is a component of GCP HTTPS load balancers. *
// targetHttpProxies are used by global external Application Load Balancers,
// classic Application Load Balancers, cross-region internal Application Load
// Balancers, and Traffic Director. * regionTargetHttpProxies are used by
// regional internal Application Load Balancers and regional external
// Application Load Balancers. Forwarding rules reference a target HTTPS proxy,
// and the target proxy then references a URL map. For more information, read
// Using Target Proxies and Forwarding rule concepts.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetHttpsProxy = src.TargetHttpsProxy
type TargetHttpsProxyAggregatedList = src.TargetHttpsProxyAggregatedList

// Contains a list of TargetHttpsProxy resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetHttpsProxyList = src.TargetHttpsProxyList

// Specifies the QUIC override policy for this TargetHttpsProxy resource. This
// setting determines whether the load balancer attempts to negotiate QUIC with
// clients. You can specify NONE, ENABLE, or DISABLE. - When quic-override is
// set to NONE, Google manages whether QUIC is used. - When quic-override is
// set to ENABLE, the load balancer uses QUIC when possible. - When
// quic-override is set to DISABLE, the load balancer doesn't use QUIC. - If
// the quic-override flag is not specified, NONE is implied.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetHttpsProxy_QuicOverride = src.TargetHttpsProxy_QuicOverride

// Specifies whether TLS 1.3 0-RTT Data ("Early Data") should be accepted for
// this service. Early Data allows a TLS resumption handshake to include the
// initial application payload (a HTTP request) alongside the handshake,
// reducing the effective round trips to "zero". This applies to TLS 1.3
// connections over TCP (HTTP/2) as well as over UDP (QUIC/h3). This can
// improve application performance, especially on networks where interruptions
// may be common, such as on mobile. Requests with Early Data will have the
// "Early-Data" HTTP header set on the request, with a value of "1", to allow
// the backend to determine whether Early Data was included. Note: TLS Early
// Data may allow requests to be replayed, as the data is sent to the backend
// before the handshake has fully completed. Applications that allow idempotent
// HTTP methods to make non-idempotent changes, such as a GET request updating
// a database, should not accept Early Data on those requests, and reject
// requests with the "Early-Data: 1" HTTP header by returning a HTTP 425 (Too
// Early) status code, in order to remain RFC compliant. The default value is
// DISABLED.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetHttpsProxy_TlsEarlyData = src.TargetHttpsProxy_TlsEarlyData

// Represents a Target Instance resource. You can use a target instance to
// handle traffic for one or more forwarding rules, which is ideal for
// forwarding protocol traffic that is managed by a single source. For example,
// ESP, AH, TCP, or UDP. For more information, read Target instances.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetInstance = src.TargetInstance
type TargetInstanceAggregatedList = src.TargetInstanceAggregatedList

// Contains a list of TargetInstance resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetInstanceList = src.TargetInstanceList

// Must have a value of NO_NAT. Protocol forwarding delivers packets while
// preserving the destination IP address of the forwarding rule referencing the
// target instance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetInstance_NatPolicy = src.TargetInstance_NatPolicy
type TargetInstancesScopedList = src.TargetInstancesScopedList

// Represents a Target Pool resource. Target pools are used with external
// passthrough Network Load Balancers. A target pool references member
// instances, an associated legacy HttpHealthCheck resource, and, optionally, a
// backup target pool. For more information, read Using target pools.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetPool = src.TargetPool
type TargetPoolAggregatedList = src.TargetPoolAggregatedList
type TargetPoolInstanceHealth = src.TargetPoolInstanceHealth

// Contains a list of TargetPool resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetPoolList = src.TargetPoolList

// Session affinity option, must be one of the following values: NONE:
// Connections from the same client IP may go to any instance in the pool.
// CLIENT_IP: Connections from the same client IP will go to the same instance
// in the pool while that instance remains healthy. CLIENT_IP_PROTO:
// Connections from the same client IP with the same IP protocol will go to the
// same instance in the pool while that instance remains healthy.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetPool_SessionAffinity = src.TargetPool_SessionAffinity
type TargetPoolsAddHealthCheckRequest = src.TargetPoolsAddHealthCheckRequest
type TargetPoolsAddInstanceRequest = src.TargetPoolsAddInstanceRequest
type TargetPoolsRemoveHealthCheckRequest = src.TargetPoolsRemoveHealthCheckRequest
type TargetPoolsRemoveInstanceRequest = src.TargetPoolsRemoveInstanceRequest
type TargetPoolsScopedList = src.TargetPoolsScopedList
type TargetReference = src.TargetReference
type TargetSslProxiesSetBackendServiceRequest = src.TargetSslProxiesSetBackendServiceRequest
type TargetSslProxiesSetCertificateMapRequest = src.TargetSslProxiesSetCertificateMapRequest
type TargetSslProxiesSetProxyHeaderRequest = src.TargetSslProxiesSetProxyHeaderRequest

// The new type of proxy header to append before sending data to the backend.
// NONE or PROXY_V1 are allowed.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetSslProxiesSetProxyHeaderRequest_ProxyHeader = src.TargetSslProxiesSetProxyHeaderRequest_ProxyHeader
type TargetSslProxiesSetSslCertificatesRequest = src.TargetSslProxiesSetSslCertificatesRequest

// Represents a Target SSL Proxy resource. A target SSL proxy is a component
// of a Proxy Network Load Balancer. The forwarding rule references the target
// SSL proxy, and the target proxy then references a backend service. For more
// information, read Proxy Network Load Balancer overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetSslProxy = src.TargetSslProxy

// Contains a list of TargetSslProxy resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetSslProxyList = src.TargetSslProxyList

// Specifies the type of proxy header to append before sending data to the
// backend, either NONE or PROXY_V1. The default is NONE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetSslProxy_ProxyHeader = src.TargetSslProxy_ProxyHeader
type TargetTcpProxiesScopedList = src.TargetTcpProxiesScopedList
type TargetTcpProxiesSetBackendServiceRequest = src.TargetTcpProxiesSetBackendServiceRequest
type TargetTcpProxiesSetProxyHeaderRequest = src.TargetTcpProxiesSetProxyHeaderRequest

// The new type of proxy header to append before sending data to the backend.
// NONE or PROXY_V1 are allowed.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetTcpProxiesSetProxyHeaderRequest_ProxyHeader = src.TargetTcpProxiesSetProxyHeaderRequest_ProxyHeader

// Represents a Target TCP Proxy resource. A target TCP proxy is a component
// of a Proxy Network Load Balancer. The forwarding rule references the target
// TCP proxy, and the target proxy then references a backend service. For more
// information, read Proxy Network Load Balancer overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetTcpProxy = src.TargetTcpProxy
type TargetTcpProxyAggregatedList = src.TargetTcpProxyAggregatedList

// Contains a list of TargetTcpProxy resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetTcpProxyList = src.TargetTcpProxyList

// Specifies the type of proxy header to append before sending data to the
// backend, either NONE or PROXY_V1. The default is NONE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetTcpProxy_ProxyHeader = src.TargetTcpProxy_ProxyHeader

// Represents a Target VPN Gateway resource. The target VPN gateway resource
// represents a Classic Cloud VPN gateway. For more information, read the the
// Cloud VPN Overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetVpnGateway = src.TargetVpnGateway
type TargetVpnGatewayAggregatedList = src.TargetVpnGatewayAggregatedList

// Contains a list of TargetVpnGateway resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetVpnGatewayList = src.TargetVpnGatewayList

// [Output Only] The status of the VPN gateway, which can be one of the
// following: CREATING, READY, FAILED, or DELETING.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TargetVpnGateway_Status = src.TargetVpnGateway_Status
type TargetVpnGatewaysScopedList = src.TargetVpnGatewaysScopedList
type TestFailure = src.TestFailure

// A request message for BackendBuckets.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsBackendBucketRequest = src.TestIamPermissionsBackendBucketRequest

// A request message for BackendServices.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsBackendServiceRequest = src.TestIamPermissionsBackendServiceRequest

// A request message for Disks.TestIamPermissions. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsDiskRequest = src.TestIamPermissionsDiskRequest

// A request message for ExternalVpnGateways.TestIamPermissions. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsExternalVpnGatewayRequest = src.TestIamPermissionsExternalVpnGatewayRequest

// A request message for FirewallPolicies.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsFirewallPolicyRequest = src.TestIamPermissionsFirewallPolicyRequest

// A request message for Images.TestIamPermissions. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsImageRequest = src.TestIamPermissionsImageRequest

// A request message for Instances.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsInstanceRequest = src.TestIamPermissionsInstanceRequest

// A request message for InstanceTemplates.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsInstanceTemplateRequest = src.TestIamPermissionsInstanceTemplateRequest

// A request message for InstantSnapshots.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsInstantSnapshotRequest = src.TestIamPermissionsInstantSnapshotRequest

// A request message for LicenseCodes.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsLicenseCodeRequest = src.TestIamPermissionsLicenseCodeRequest

// A request message for Licenses.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsLicenseRequest = src.TestIamPermissionsLicenseRequest

// A request message for MachineImages.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsMachineImageRequest = src.TestIamPermissionsMachineImageRequest

// A request message for NetworkAttachments.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsNetworkAttachmentRequest = src.TestIamPermissionsNetworkAttachmentRequest

// A request message for NetworkEndpointGroups.TestIamPermissions. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsNetworkEndpointGroupRequest = src.TestIamPermissionsNetworkEndpointGroupRequest

// A request message for NetworkFirewallPolicies.TestIamPermissions. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsNetworkFirewallPolicyRequest = src.TestIamPermissionsNetworkFirewallPolicyRequest

// A request message for NodeGroups.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsNodeGroupRequest = src.TestIamPermissionsNodeGroupRequest

// A request message for NodeTemplates.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsNodeTemplateRequest = src.TestIamPermissionsNodeTemplateRequest

// A request message for PacketMirrorings.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsPacketMirroringRequest = src.TestIamPermissionsPacketMirroringRequest

// A request message for RegionBackendServices.TestIamPermissions. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsRegionBackendServiceRequest = src.TestIamPermissionsRegionBackendServiceRequest

// A request message for RegionDisks.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsRegionDiskRequest = src.TestIamPermissionsRegionDiskRequest

// A request message for RegionInstantSnapshots.TestIamPermissions. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsRegionInstantSnapshotRequest = src.TestIamPermissionsRegionInstantSnapshotRequest

// A request message for RegionNetworkFirewallPolicies.TestIamPermissions. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsRegionNetworkFirewallPolicyRequest = src.TestIamPermissionsRegionNetworkFirewallPolicyRequest

// A request message for Reservations.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsReservationRequest = src.TestIamPermissionsReservationRequest

// A request message for ResourcePolicies.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsResourcePolicyRequest = src.TestIamPermissionsResourcePolicyRequest

// A request message for ServiceAttachments.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsServiceAttachmentRequest = src.TestIamPermissionsServiceAttachmentRequest

// A request message for Snapshots.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsSnapshotRequest = src.TestIamPermissionsSnapshotRequest

// A request message for StoragePools.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsStoragePoolRequest = src.TestIamPermissionsStoragePoolRequest

// A request message for Subnetworks.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsSubnetworkRequest = src.TestIamPermissionsSubnetworkRequest

// A request message for VpnGateways.TestIamPermissions. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type TestIamPermissionsVpnGatewayRequest = src.TestIamPermissionsVpnGatewayRequest
type TestPermissionsRequest = src.TestPermissionsRequest
type TestPermissionsResponse = src.TestPermissionsResponse
type Uint128 = src.Uint128

// Upcoming Maintenance notification information.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpcomingMaintenance = src.UpcomingMaintenance
type UpcomingMaintenance_MaintenanceStatus = src.UpcomingMaintenance_MaintenanceStatus

// Defines the type of maintenance.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpcomingMaintenance_Type = src.UpcomingMaintenance_Type

// A request message for Instances.UpdateAccessConfig. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateAccessConfigInstanceRequest = src.UpdateAccessConfigInstanceRequest

// A request message for Autoscalers.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateAutoscalerRequest = src.UpdateAutoscalerRequest

// A request message for BackendBuckets.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateBackendBucketRequest = src.UpdateBackendBucketRequest

// A request message for BackendServices.Update. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateBackendServiceRequest = src.UpdateBackendServiceRequest

// A request message for Disks.Update. See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateDiskRequest = src.UpdateDiskRequest

// A request message for Instances.UpdateDisplayDevice. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateDisplayDeviceInstanceRequest = src.UpdateDisplayDeviceInstanceRequest

// A request message for Firewalls.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateFirewallRequest = src.UpdateFirewallRequest

// A request message for HealthChecks.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateHealthCheckRequest = src.UpdateHealthCheckRequest

// A request message for Instances.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateInstanceRequest = src.UpdateInstanceRequest

// Specifies the action to take when updating an instance even if the updated
// properties do not require it. If not specified, then Compute Engine acts
// based on the minimum action that the updated properties require. Additional
// supported values which may be not listed in the enum directly due to
// technical reasons: INVALID NO_EFFECT REFRESH RESTART
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateInstanceRequest_MinimalAction = src.UpdateInstanceRequest_MinimalAction

// Specifies the most disruptive action that can be taken on the instance as
// part of the update. Compute Engine returns an error if the instance
// properties require a more disruptive action as part of the instance update.
// Valid options from lowest to highest are NO_EFFECT, REFRESH, and RESTART.
// Additional supported values which may be not listed in the enum directly due
// to technical reasons: INVALID NO_EFFECT REFRESH RESTART
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateInstanceRequest_MostDisruptiveAllowedAction = src.UpdateInstanceRequest_MostDisruptiveAllowedAction

// A request message for Instances.UpdateNetworkInterface. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateNetworkInterfaceInstanceRequest = src.UpdateNetworkInterfaceInstanceRequest

// A request message for Networks.UpdatePeering. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdatePeeringNetworkRequest = src.UpdatePeeringNetworkRequest

// A request message for InstanceGroupManagers.UpdatePerInstanceConfigs. See
// the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdatePerInstanceConfigsInstanceGroupManagerRequest = src.UpdatePerInstanceConfigsInstanceGroupManagerRequest

// A request message for RegionInstanceGroupManagers.UpdatePerInstanceConfigs.
// See the method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest = src.UpdatePerInstanceConfigsRegionInstanceGroupManagerRequest

// A request message for RegionAutoscalers.Update. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateRegionAutoscalerRequest = src.UpdateRegionAutoscalerRequest

// A request message for RegionBackendServices.Update. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateRegionBackendServiceRequest = src.UpdateRegionBackendServiceRequest

// A request message for RegionCommitments.Update. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateRegionCommitmentRequest = src.UpdateRegionCommitmentRequest

// A request message for RegionDisks.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateRegionDiskRequest = src.UpdateRegionDiskRequest

// A request message for RegionHealthChecks.Update. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateRegionHealthCheckRequest = src.UpdateRegionHealthCheckRequest

// A request message for RegionUrlMaps.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateRegionUrlMapRequest = src.UpdateRegionUrlMapRequest

// A request message for Reservations.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateReservationRequest = src.UpdateReservationRequest

// A request message for Routers.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateRouterRequest = src.UpdateRouterRequest

// A request message for Instances.UpdateShieldedInstanceConfig. See the
// method description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateShieldedInstanceConfigInstanceRequest = src.UpdateShieldedInstanceConfigInstanceRequest

// A request message for StoragePools.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateStoragePoolRequest = src.UpdateStoragePoolRequest

// A request message for UrlMaps.Update. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UpdateUrlMapRequest = src.UpdateUrlMapRequest

// Represents a URL Map resource. Compute Engine has two URL Map resources: *
// [Global](/compute/docs/reference/rest/v1/urlMaps) *
// [Regional](/compute/docs/reference/rest/v1/regionUrlMaps) A URL map resource
// is a component of certain types of cloud load balancers and Traffic
// Director: * urlMaps are used by global external Application Load Balancers,
// classic Application Load Balancers, and cross-region internal Application
// Load Balancers. * regionUrlMaps are used by internal Application Load
// Balancers, regional external Application Load Balancers and regional
// internal Application Load Balancers. For a list of supported URL map
// features by the load balancer type, see the Load balancing features: Routing
// and traffic management table. For a list of supported URL map features for
// Traffic Director, see the Traffic Director features: Routing and traffic
// management table. This resource defines mappings from hostnames and URL
// paths to either a backend service or a backend bucket. To use the global
// urlMaps resource, the backend service must have a loadBalancingScheme of
// either EXTERNAL, EXTERNAL_MANAGED, or INTERNAL_SELF_MANAGED. To use the
// regionUrlMaps resource, the backend service must have a loadBalancingScheme
// of INTERNAL_MANAGED. For more information, read URL Map Concepts.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UrlMap = src.UrlMap

// Contains a list of UrlMap resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UrlMapList = src.UrlMapList
type UrlMapReference = src.UrlMapReference

// Message for the expected URL mappings.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UrlMapTest = src.UrlMapTest

// HTTP headers used in UrlMapTests.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UrlMapTestHeader = src.UrlMapTestHeader

// Message representing the validation result for a UrlMap.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UrlMapValidationResult = src.UrlMapValidationResult
type UrlMapsAggregatedList = src.UrlMapsAggregatedList
type UrlMapsScopedList = src.UrlMapsScopedList
type UrlMapsValidateRequest = src.UrlMapsValidateRequest
type UrlMapsValidateRequest_LoadBalancingSchemes = src.UrlMapsValidateRequest_LoadBalancingSchemes
type UrlMapsValidateResponse = src.UrlMapsValidateResponse

// The spec for modifying the path before sending the request to the matched
// backend service.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UrlRewrite = src.UrlRewrite

// Subnetwork which the current user has compute.subnetworks.use permission
// on.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UsableSubnetwork = src.UsableSubnetwork

// Secondary IP range of a usable subnetwork.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UsableSubnetworkSecondaryRange = src.UsableSubnetworkSecondaryRange

// The access type of IPv6 address this subnet holds. It's immutable and can
// only be specified during creation or the first time the subnet is updated
// into IPV4_IPV6 dual stack.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UsableSubnetwork_Ipv6AccessType = src.UsableSubnetwork_Ipv6AccessType

// The purpose of the resource. This field can be either PRIVATE,
// GLOBAL_MANAGED_PROXY, REGIONAL_MANAGED_PROXY, PRIVATE_SERVICE_CONNECT, or
// PRIVATE is the default purpose for user-created subnets or subnets that are
// automatically created in auto mode networks. Subnets with purpose set to
// GLOBAL_MANAGED_PROXY or REGIONAL_MANAGED_PROXY are user-created subnetworks
// that are reserved for Envoy-based load balancers. A subnet with purpose set
// to PRIVATE_SERVICE_CONNECT is used to publish services using Private Service
// Connect. If unspecified, the subnet purpose defaults to PRIVATE. The
// enableFlowLogs field isn't supported if the subnet purpose field is set to
// GLOBAL_MANAGED_PROXY or REGIONAL_MANAGED_PROXY.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UsableSubnetwork_Purpose = src.UsableSubnetwork_Purpose

// The role of subnetwork. Currently, this field is only used when purpose is
// set to GLOBAL_MANAGED_PROXY or REGIONAL_MANAGED_PROXY. The value can be set
// to ACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being
// used for Envoy-based load balancers in a region. A BACKUP subnetwork is one
// that is ready to be promoted to ACTIVE or is currently draining. This field
// can be updated with a patch request.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UsableSubnetwork_Role = src.UsableSubnetwork_Role

// The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet
// are assigned IPv4 addresses only. If set to IPV4_IPV6, new VMs in the subnet
// can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is
// used. This field can be both set at resource creation time and updated using
// patch.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UsableSubnetwork_StackType = src.UsableSubnetwork_StackType
type UsableSubnetworksAggregatedList = src.UsableSubnetworksAggregatedList

// The location in Cloud Storage and naming method of the daily usage report.
// Contains bucket_name and report_name prefix.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type UsageExportLocation = src.UsageExportLocation

// A request message for RegionUrlMaps.Validate. See the method description
// for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ValidateRegionUrlMapRequest = src.ValidateRegionUrlMapRequest

// A request message for UrlMaps.Validate. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ValidateUrlMapRequest = src.ValidateUrlMapRequest

// Contain information of Nat mapping for a VM endpoint (i.e., NIC).
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VmEndpointNatMappings = src.VmEndpointNatMappings

// Contain information of Nat mapping for an interface of this endpoint.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VmEndpointNatMappingsInterfaceNatMappings = src.VmEndpointNatMappingsInterfaceNatMappings

// Contains information of NAT Mappings provided by a NAT Rule.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings = src.VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings

// Contains a list of VmEndpointNatMappings.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VmEndpointNatMappingsList = src.VmEndpointNatMappingsList

// Represents a HA VPN gateway. HA VPN is a high-availability (HA) Cloud VPN
// solution that lets you securely connect your on-premises network to your
// Google Cloud Virtual Private Cloud network through an IPsec VPN connection
// in a single region. For more information about Cloud HA VPN solutions, see
// Cloud VPN topologies .
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnGateway = src.VpnGateway
type VpnGatewayAggregatedList = src.VpnGatewayAggregatedList

// Contains a list of VpnGateway resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnGatewayList = src.VpnGatewayList
type VpnGatewayStatus = src.VpnGatewayStatus

// Describes the high availability requirement state for the VPN connection
// between this Cloud VPN gateway and a peer gateway.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnGatewayStatusHighAvailabilityRequirementState = src.VpnGatewayStatusHighAvailabilityRequirementState

// Indicates the high availability requirement state for the VPN connection.
// Valid values are CONNECTION_REDUNDANCY_MET, CONNECTION_REDUNDANCY_NOT_MET.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnGatewayStatusHighAvailabilityRequirementState_State = src.VpnGatewayStatusHighAvailabilityRequirementState_State

// Indicates the reason why the VPN connection does not meet the high
// availability redundancy criteria/requirement. Valid values is
// INCOMPLETE_TUNNELS_COVERAGE.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnGatewayStatusHighAvailabilityRequirementState_UnsatisfiedReason = src.VpnGatewayStatusHighAvailabilityRequirementState_UnsatisfiedReason

// Contains some information about a VPN tunnel.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnGatewayStatusTunnel = src.VpnGatewayStatusTunnel

// A VPN connection contains all VPN tunnels connected from this VpnGateway to
// the same peer gateway. The peer gateway could either be an external VPN
// gateway or a Google Cloud VPN gateway.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnGatewayStatusVpnConnection = src.VpnGatewayStatusVpnConnection

// A VPN gateway interface.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnGatewayVpnGatewayInterface = src.VpnGatewayVpnGatewayInterface

// The IP family of the gateway IPs for the HA-VPN gateway interfaces. If not
// specified, IPV4 will be used.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnGateway_GatewayIpVersion = src.VpnGateway_GatewayIpVersion

// The stack type for this VPN gateway to identify the IP protocols that are
// enabled. Possible values are: IPV4_ONLY, IPV4_IPV6, IPV6_ONLY. If not
// specified, IPV4_ONLY is used if the gateway IP version is IPV4, or IPV4_IPV6
// if the gateway IP version is IPV6.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnGateway_StackType = src.VpnGateway_StackType
type VpnGatewaysGetStatusResponse = src.VpnGatewaysGetStatusResponse
type VpnGatewaysScopedList = src.VpnGatewaysScopedList

// Represents a Cloud VPN Tunnel resource. For more information about VPN,
// read the the Cloud VPN Overview.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnTunnel = src.VpnTunnel
type VpnTunnelAggregatedList = src.VpnTunnelAggregatedList

// Contains a list of VpnTunnel resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnTunnelList = src.VpnTunnelList

// [Output Only] The status of the VPN tunnel, which can be one of the
// following: - PROVISIONING: Resource is being allocated for the VPN tunnel. -
// WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from the
// user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route
// resources are needed to setup the VPN tunnel. - FIRST_HANDSHAKE: Successful
// first handshake with the peer VPN. - ESTABLISHED: Secure session is
// successfully established with the peer VPN. - NETWORK_ERROR: Deprecated,
// replaced by NO_INCOMING_PACKETS - AUTHORIZATION_ERROR: Auth error (for
// example, bad shared secret). - NEGOTIATION_FAILURE: Handshake failed. -
// DEPROVISIONING: Resources are being deallocated for the VPN tunnel. -
// FAILED: Tunnel creation has failed and the tunnel is not ready to be used. -
// NO_INCOMING_PACKETS: No incoming packets from peer. - REJECTED: Tunnel
// configuration was rejected, can be result of being denied access. -
// ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating all required
// resources. - STOPPED: Tunnel is stopped due to its Forwarding Rules being
// deleted for Classic VPN tunnels or the project is in frozen state. -
// PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably
// behind NAT. - TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not
// allowed for an HA-VPN tunnel.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type VpnTunnel_Status = src.VpnTunnel_Status
type VpnTunnelsScopedList = src.VpnTunnelsScopedList
type WafExpressionSet = src.WafExpressionSet
type WafExpressionSetExpression = src.WafExpressionSetExpression

// A request message for GlobalOperations.Wait. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type WaitGlobalOperationRequest = src.WaitGlobalOperationRequest

// A request message for RegionOperations.Wait. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type WaitRegionOperationRequest = src.WaitRegionOperationRequest

// A request message for ZoneOperations.Wait. See the method description for
// details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type WaitZoneOperationRequest = src.WaitZoneOperationRequest

// [Output Only] Informational warning message.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Warning = src.Warning

// [Output Only] A warning code, if applicable. For example, Compute Engine
// returns NO_RESULTS_ON_PAGE if there are no results in the response.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Warning_Code = src.Warning_Code
type Warnings = src.Warnings

// [Output Only] A warning code, if applicable. For example, Compute Engine
// returns NO_RESULTS_ON_PAGE if there are no results in the response.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Warnings_Code = src.Warnings_Code

// In contrast to a single BackendService in HttpRouteAction to which all
// matching traffic is directed to, WeightedBackendService allows traffic to be
// split across multiple backend services. The volume of traffic for each
// backend service is proportional to the weight specified in each
// WeightedBackendService
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type WeightedBackendService = src.WeightedBackendService

// A request message for PublicAdvertisedPrefixes.Withdraw. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type WithdrawPublicAdvertisedPrefixeRequest = src.WithdrawPublicAdvertisedPrefixeRequest

// A request message for PublicDelegatedPrefixes.Withdraw. See the method
// description for details.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type WithdrawPublicDelegatedPrefixeRequest = src.WithdrawPublicDelegatedPrefixeRequest
type XpnHostList = src.XpnHostList

// Service resource (a.k.a service project) ID.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type XpnResourceId = src.XpnResourceId

// The type of the service resource.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type XpnResourceId_Type = src.XpnResourceId_Type

// Represents a Zone resource. A zone is a deployment area. These deployment
// areas are subsets of a region. For example the zone us-east1-b is located in
// the us-east1 region. For more information, read Regions and Zones.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Zone = src.Zone

// Contains a list of zone resources.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type ZoneList = src.ZoneList
type ZoneSetLabelsRequest = src.ZoneSetLabelsRequest
type ZoneSetPolicyRequest = src.ZoneSetPolicyRequest

// [Output Only] Status of the zone, either UP or DOWN.
//
// Deprecated: Please use types in: cloud.google.com/go/compute/apiv1/computepb
type Zone_Status = src.Zone_Status
